#!/usr/bin/env python
#
# LSST Data Management System
#
# Copyright 2018 AURA/LSST.
#
# This product includes software developed by the
# LSST Project (http://www.lsst.org/).
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the LSST License Statement and
# the GNU General Public License along with this program.  If not,
# see <https://www.lsstcorp.org/LegalNotices/>.
#

"""HSC transmission curves in raw form.

The global objects here provide the TransmissionCurve objects that are
persisted into butler-managed data repositories.  All code that isn't
responsible for actually creating those datasets should retrieve these curves
via the butler or an Exposure object instead of using these objects directly.

This module should not be automatically imported by any package-level
__init__ modules, and hence is not in a location that should be part
of any PYTHONPATH.  It is a Python file simply to avoid unnecessary
modifications.
"""

import numpy as np

PIXEL_SIZE = 15E-3  # size of HSC pixels in MM

# Copied from Eli Rykoff's FGCM, who got them from Satoshi Kawanomoto.
# The g, r, r2, i, i2, z, y scans were sent in 10/2017, and the
# azimuthal scans were averaged into radial profiles by Eli Rykoff and
# converted to dict format.
# The n387, n816, and n921 scans were sent in 1/2020, and the azimuthal
# scans were averaged into radial profiles by Kawanomoto-san from scans
# taken at the summit.  The n1010 scans were sent in 1/2020, and the
# azimuthal scans were measured in Mitaka and azimuthally averaged by
# Eli Rykoff.
# Wavelengths in nm, radii in mm
FILTER_DATA = dict(
    g=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                            100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                            180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                            260.0, 270.0, 280.0]),
           lam=np.array([380.35, 380.76, 381.16, 381.57, 381.97, 382.38, 382.78, 383.18,
                         383.59, 383.99, 384.40, 384.80, 385.21, 385.61, 386.02, 386.42,
                         386.83, 387.23, 387.64, 388.04, 388.45, 388.85, 389.26, 389.66,
                         390.07, 390.48, 390.88, 391.29, 391.69, 392.10, 392.50, 392.91,
                         393.31, 393.72, 394.13, 394.53, 394.94, 395.34, 395.75, 396.16,
                         396.56, 396.97, 397.38, 397.78, 398.19, 398.59, 399.00, 399.41,
                         399.81, 400.22, 400.63, 401.03, 401.44, 401.85, 402.25, 402.66,
                         403.07, 403.47, 403.88, 404.29, 404.70, 405.10, 405.51, 405.92,
                         406.33, 406.73, 407.14, 407.55, 407.95, 408.36, 408.77, 409.18,
                         409.59, 409.99, 410.40, 410.81, 411.22, 411.62, 412.03, 412.44,
                         412.85, 413.26, 413.67, 414.07, 414.48, 414.89, 415.30, 415.71,
                         416.12, 416.52, 416.93, 417.34, 417.75, 418.16, 418.57, 418.98,
                         419.38, 419.79, 420.20, 420.61, 421.02, 421.43, 421.84, 422.25,
                         422.66, 423.07, 423.48, 423.88, 424.29, 424.70, 425.11, 425.52,
                         425.93, 426.34, 426.75, 427.16, 427.57, 427.98, 428.39, 428.80,
                         429.21, 429.62, 430.03, 430.44, 430.85, 431.26, 431.67, 432.08,
                         432.49, 432.90, 433.31, 433.72, 434.13, 434.54, 434.95, 435.37,
                         435.78, 436.19, 436.60, 437.01, 437.42, 437.83, 438.24, 438.65,
                         439.06, 439.47, 439.89, 440.30, 440.71, 441.12, 441.53, 441.94,
                         442.35, 442.77, 443.18, 443.59, 444.00, 444.41, 444.82, 445.24,
                         445.65, 446.06, 446.47, 446.88, 447.29, 447.71, 448.12, 448.53,
                         448.94, 449.36, 449.77, 450.18, 450.59, 451.01, 451.42, 451.83,
                         452.24, 452.66, 453.07, 453.48, 453.89, 454.31, 454.72, 455.13,
                         455.54, 455.96, 456.37, 456.78, 457.20, 457.61, 458.02, 458.44,
                         458.85, 459.26, 459.68, 460.09, 460.50, 460.92, 461.33, 461.74,
                         462.16, 462.57, 462.99, 463.40, 463.81, 464.23, 464.64, 465.05,
                         465.47, 465.88, 466.30, 466.71, 467.13, 467.54, 467.95, 468.37,
                         468.78, 469.20, 469.61, 470.03, 470.44, 470.85, 471.27, 471.68,
                         472.10, 472.51, 472.93, 473.34, 473.76, 474.17, 474.59, 475.00,
                         475.42, 475.83, 476.25, 476.66, 477.08, 477.49, 477.91, 478.33,
                         478.74, 479.16, 479.57, 479.99, 480.40, 480.82, 481.23, 481.65,
                         482.07, 482.48, 482.90, 483.31, 483.73, 484.15, 484.56, 484.98,
                         485.39, 485.81, 486.23, 486.64, 487.06, 487.48, 487.89, 488.31,
                         488.73, 489.14, 489.56, 489.98, 490.39, 490.81, 491.23, 491.64,
                         492.06, 492.48, 492.89, 493.31, 493.73, 494.15, 494.56, 494.98,
                         495.40, 495.81, 496.23, 496.65, 497.07, 497.48, 497.90, 498.32,
                         498.74, 499.15, 499.57, 499.99, 500.41, 500.83, 501.24, 501.66,
                         502.08, 502.50, 502.91, 503.33, 503.75, 504.17, 504.59, 505.01,
                         505.42, 505.84, 506.26, 506.68, 507.10, 507.52, 507.94, 508.35,
                         508.77, 509.19, 509.61, 510.03, 510.45, 510.87, 511.29, 511.70,
                         512.12, 512.54, 512.96, 513.38, 513.80, 514.22, 514.64, 515.06,
                         515.48, 515.90, 516.32, 516.74, 517.16, 517.57, 517.99, 518.41,
                         518.83, 519.25, 519.67, 520.09, 520.51, 520.93, 521.35, 521.77,
                         522.19, 522.61, 523.03, 523.45, 523.87, 524.29, 524.71, 525.13,
                         525.56, 525.98, 526.40, 526.82, 527.24, 527.66, 528.08, 528.50,
                         528.92, 529.34, 529.76, 530.18, 530.60, 531.02, 531.45, 531.87,
                         532.29, 532.71, 533.13, 533.55, 533.97, 534.39, 534.82, 535.24,
                         535.66, 536.08, 536.50, 536.92, 537.34, 537.77, 538.19, 538.61,
                         539.03, 539.45, 539.88, 540.30, 540.72, 541.14, 541.56, 541.99,
                         542.41, 542.83, 543.25, 543.67, 544.10, 544.52, 544.94, 545.36,
                         545.79, 546.21, 546.63, 547.05, 547.48, 547.90, 548.32, 548.74,
                         549.17, 549.59, 550.01, 550.44, 550.86, 551.28, 551.71, 552.13,
                         552.55, 552.97, 553.40, 553.82, 554.24, 554.67, 555.09, 555.51,
                         555.94, 556.36, 556.79, 557.21, 557.63, 558.06, 558.48, 558.90,
                         559.33, 559.75, 560.18, 560.60, 561.02, 561.45, 561.87, 562.30,
                         562.72, 563.14, 563.57, 563.99, 564.42, 564.84, 565.27, 565.69,
                         566.11, 566.54, 566.96, 567.39, 567.81, 568.24, 568.66, 569.09,
                         569.51, 569.94, 570.36, 570.79, 571.21, 571.64, 572.06, 572.49,
                         572.91, 573.34, 573.76, 574.19, 574.61]),
           T=np.array([[0.00743, 0.00733, 0.00627, 0.00648, 0.00666, 0.00611, 0.00658,
                        0.00766, 0.00646, 0.00657, 0.00705, 0.00595, 0.00684, 0.00595,
                        0.00510, 0.00831, 0.00689, 0.00558, 0.00733, 0.00684, 0.00660,
                        0.00624, 0.00584, 0.00578, 0.00608, 0.00599, 0.00524, 0.00643, 0.00715],
                       [0.00633, 0.00649, 0.00548, 0.00563, 0.00614, 0.00623, 0.00577,
                        0.00723, 0.00662, 0.00579, 0.00621, 0.00638, 0.00743, 0.00589,
                        0.00479, 0.00674, 0.00582, 0.00608, 0.00686, 0.00579, 0.00549,
                        0.00541, 0.00626, 0.00583, 0.00602, 0.00639, 0.00567, 0.00651, 0.00637],
                       [0.00526, 0.00548, 0.00587, 0.00484, 0.00501, 0.00571, 0.00474,
                        0.00576, 0.00586, 0.00517, 0.00520, 0.00587, 0.00649, 0.00562,
                        0.00478, 0.00492, 0.00507, 0.00606, 0.00556, 0.00505, 0.00499,
                        0.00549, 0.00553, 0.00524, 0.00554, 0.00610, 0.00515, 0.00576, 0.00528],
                       [0.00638, 0.00585, 0.00680, 0.00504, 0.00508, 0.00596, 0.00544,
                        0.00543, 0.00562, 0.00525, 0.00596, 0.00531, 0.00578, 0.00564,
                        0.00520, 0.00477, 0.00544, 0.00666, 0.00534, 0.00599, 0.00557,
                        0.00625, 0.00569, 0.00534, 0.00559, 0.00541, 0.00583, 0.00569, 0.00516],
                       [0.00763, 0.00683, 0.00657, 0.00574, 0.00628, 0.00723, 0.00688,
                        0.00599, 0.00619, 0.00594, 0.00738, 0.00567, 0.00597, 0.00619,
                        0.00586, 0.00567, 0.00614, 0.00712, 0.00574, 0.00674, 0.00634,
                        0.00612, 0.00678, 0.00603, 0.00577, 0.00538, 0.00717, 0.00587, 0.00560],
                       [0.00673, 0.00637, 0.00509, 0.00603, 0.00679, 0.00722, 0.00689,
                        0.00611, 0.00655, 0.00607, 0.00705, 0.00639, 0.00552, 0.00648,
                        0.00590, 0.00620, 0.00575, 0.00646, 0.00575, 0.00601, 0.00631,
                        0.00569, 0.00675, 0.00626, 0.00557, 0.00627, 0.00707, 0.00574, 0.00575],
                       [0.00526, 0.00527, 0.00408, 0.00580, 0.00594, 0.00541, 0.00569,
                        0.00575, 0.00599, 0.00498, 0.00524, 0.00610, 0.00453, 0.00559,
                        0.00508, 0.00536, 0.00506, 0.00546, 0.00562, 0.00468, 0.00565,
                        0.00565, 0.00543, 0.00583, 0.00497, 0.00639, 0.00575, 0.00565, 0.00548],
                       [0.00532, 0.00527, 0.00478, 0.00578, 0.00523, 0.00451, 0.00504,
                        0.00588, 0.00540, 0.00435, 0.00405, 0.00530, 0.00491, 0.00507,
                        0.00513, 0.00452, 0.00536, 0.00570, 0.00598, 0.00470, 0.00552,
                        0.00553, 0.00500, 0.00574, 0.00452, 0.00580, 0.00526, 0.00588, 0.00531],
                       [0.00656, 0.00600, 0.00615, 0.00629, 0.00547, 0.00521, 0.00547,
                        0.00630, 0.00513, 0.00543, 0.00479, 0.00489, 0.00629, 0.00588,
                        0.00588, 0.00526, 0.00595, 0.00658, 0.00634, 0.00588, 0.00578,
                        0.00526, 0.00534, 0.00538, 0.00479, 0.00562, 0.00609, 0.00621, 0.00546],
                       [0.00667, 0.00600, 0.00587, 0.00598, 0.00551, 0.00527, 0.00560,
                        0.00627, 0.00497, 0.00635, 0.00617, 0.00478, 0.00625, 0.00630,
                        0.00576, 0.00632, 0.00547, 0.00600, 0.00598, 0.00586, 0.00530,
                        0.00513, 0.00507, 0.00459, 0.00529, 0.00533, 0.00651, 0.00571, 0.00495],
                       [0.00550, 0.00578, 0.00467, 0.00472, 0.00533, 0.00489, 0.00533,
                        0.00614, 0.00559, 0.00622, 0.00655, 0.00496, 0.00511, 0.00538,
                        0.00544, 0.00656, 0.00455, 0.00506, 0.00579, 0.00500, 0.00462,
                        0.00557, 0.00516, 0.00474, 0.00573, 0.00472, 0.00589, 0.00533, 0.00431],
                       [0.00476, 0.00610, 0.00496, 0.00462, 0.00587, 0.00587, 0.00562,
                        0.00586, 0.00645, 0.00588, 0.00617, 0.00559, 0.00529, 0.00444,
                        0.00601, 0.00634, 0.00486, 0.00565, 0.00600, 0.00509, 0.00479,
                        0.00612, 0.00616, 0.00542, 0.00616, 0.00470, 0.00528, 0.00599, 0.00520],
                       [0.00448, 0.00606, 0.00642, 0.00550, 0.00647, 0.00668, 0.00572,
                        0.00535, 0.00613, 0.00526, 0.00534, 0.00597, 0.00599, 0.00449,
                        0.00622, 0.00586, 0.00571, 0.00625, 0.00526, 0.00561, 0.00478,
                        0.00602, 0.00623, 0.00517, 0.00609, 0.00511, 0.00488, 0.00618, 0.00579],
                       [0.00440, 0.00570, 0.00684, 0.00608, 0.00615, 0.00585, 0.00558,
                        0.00530, 0.00541, 0.00501, 0.00486, 0.00590, 0.00581, 0.00542,
                        0.00538, 0.00531, 0.00599, 0.00599, 0.00490, 0.00580, 0.00485,
                        0.00572, 0.00551, 0.00465, 0.00537, 0.00561, 0.00483, 0.00576, 0.00525],
                       [0.00515, 0.00546, 0.00586, 0.00618, 0.00574, 0.00516, 0.00576,
                        0.00560, 0.00526, 0.00554, 0.00533, 0.00572, 0.00552, 0.00589,
                        0.00441, 0.00518, 0.00619, 0.00591, 0.00595, 0.00647, 0.00599,
                        0.00563, 0.00579, 0.00509, 0.00486, 0.00571, 0.00555, 0.00605, 0.00519],
                       [0.00586, 0.00497, 0.00527, 0.00554, 0.00570, 0.00580, 0.00572,
                        0.00564, 0.00505, 0.00588, 0.00576, 0.00538, 0.00561, 0.00505,
                        0.00464, 0.00510, 0.00639, 0.00595, 0.00639, 0.00713, 0.00661,
                        0.00582, 0.00673, 0.00571, 0.00499, 0.00518, 0.00608, 0.00641, 0.00552],
                       [0.00552, 0.00503, 0.00574, 0.00499, 0.00572, 0.00679, 0.00549,
                        0.00565, 0.00509, 0.00582, 0.00587, 0.00543, 0.00584, 0.00501,
                        0.00582, 0.00522, 0.00630, 0.00588, 0.00577, 0.00652, 0.00594,
                        0.00627, 0.00652, 0.00587, 0.00539, 0.00499, 0.00619, 0.00637, 0.00515],
                       [0.00516, 0.00577, 0.00638, 0.00534, 0.00595, 0.00688, 0.00556,
                        0.00587, 0.00573, 0.00573, 0.00597, 0.00590, 0.00614, 0.00595,
                        0.00595, 0.00560, 0.00589, 0.00573, 0.00519, 0.00569, 0.00543,
                        0.00612, 0.00518, 0.00578, 0.00584, 0.00550, 0.00630, 0.00616, 0.00496],
                       [0.00600, 0.00623, 0.00647, 0.00601, 0.00646, 0.00588, 0.00581,
                        0.00612, 0.00600, 0.00554, 0.00618, 0.00598, 0.00628, 0.00616,
                        0.00553, 0.00566, 0.00564, 0.00558, 0.00533, 0.00571, 0.00565,
                        0.00546, 0.00498, 0.00573, 0.00547, 0.00615, 0.00631, 0.00578, 0.00567],
                       [0.00693, 0.00632, 0.00636, 0.00634, 0.00619, 0.00499, 0.00560,
                        0.00588, 0.00561, 0.00538, 0.00629, 0.00603, 0.00593, 0.00545,
                        0.00605, 0.00562, 0.00552, 0.00605, 0.00593, 0.00612, 0.00579,
                        0.00543, 0.00597, 0.00550, 0.00459, 0.00636, 0.00625, 0.00550, 0.00622],
                       [0.00650, 0.00625, 0.00624, 0.00631, 0.00567, 0.00500, 0.00538,
                        0.00534, 0.00549, 0.00532, 0.00587, 0.00617, 0.00558, 0.00517,
                        0.00640, 0.00573, 0.00516, 0.00660, 0.00597, 0.00615, 0.00580,
                        0.00568, 0.00636, 0.00513, 0.00492, 0.00621, 0.00615, 0.00612, 0.00578],
                       [0.00551, 0.00587, 0.00594, 0.00628, 0.00617, 0.00578, 0.00574,
                        0.00536, 0.00570, 0.00537, 0.00535, 0.00588, 0.00572, 0.00549,
                        0.00587, 0.00588, 0.00517, 0.00664, 0.00540, 0.00593, 0.00562,
                        0.00577, 0.00596, 0.00522, 0.00606, 0.00602, 0.00592, 0.00694, 0.00500],
                       [0.00518, 0.00564, 0.00554, 0.00634, 0.00635, 0.00617, 0.00612,
                        0.00577, 0.00556, 0.00564, 0.00563, 0.00541, 0.00610, 0.00558,
                        0.00578, 0.00596, 0.00555, 0.00641, 0.00507, 0.00613, 0.00516,
                        0.00601, 0.00575, 0.00582, 0.00659, 0.00606, 0.00602, 0.00696, 0.00481],
                       [0.00581, 0.00626, 0.00568, 0.00640, 0.00589, 0.00613, 0.00626,
                        0.00627, 0.00529, 0.00626, 0.00644, 0.00563, 0.00631, 0.00567,
                        0.00654, 0.00629, 0.00620, 0.00596, 0.00566, 0.00649, 0.00533,
                        0.00646, 0.00601, 0.00633, 0.00704, 0.00623, 0.00653, 0.00670, 0.00592],
                       [0.00641, 0.00691, 0.00632, 0.00604, 0.00602, 0.00649, 0.00608,
                        0.00644, 0.00570, 0.00659, 0.00693, 0.00626, 0.00641, 0.00632,
                        0.00694, 0.00663, 0.00673, 0.00545, 0.00636, 0.00642, 0.00626,
                        0.00667, 0.00625, 0.00638, 0.00741, 0.00627, 0.00676, 0.00642, 0.00709],
                       [0.00635, 0.00658, 0.00657, 0.00544, 0.00674, 0.00668, 0.00594,
                        0.00576, 0.00666, 0.00636, 0.00686, 0.00672, 0.00632, 0.00628,
                        0.00649, 0.00642, 0.00674, 0.00553, 0.00630, 0.00612, 0.00678,
                        0.00659, 0.00591, 0.00611, 0.00662, 0.00599, 0.00653, 0.00635, 0.00651],
                       [0.00629, 0.00617, 0.00656, 0.00559, 0.00722, 0.00630, 0.00617,
                        0.00544, 0.00731, 0.00612, 0.00642, 0.00686, 0.00621, 0.00567,
                        0.00621, 0.00631, 0.00676, 0.00631, 0.00584, 0.00631, 0.00664,
                        0.00671, 0.00607, 0.00656, 0.00575, 0.00590, 0.00669, 0.00672, 0.00550],
                       [0.00655, 0.00629, 0.00649, 0.00629, 0.00715, 0.00610, 0.00621,
                        0.00623, 0.00693, 0.00618, 0.00637, 0.00659, 0.00627, 0.00593,
                        0.00657, 0.00676, 0.00663, 0.00697, 0.00554, 0.00648, 0.00629,
                        0.00712, 0.00715, 0.00749, 0.00630, 0.00661, 0.00727, 0.00710, 0.00615],
                       [0.00665, 0.00604, 0.00634, 0.00668, 0.00675, 0.00651, 0.00598,
                        0.00704, 0.00581, 0.00654, 0.00660, 0.00625, 0.00622, 0.00645,
                        0.00669, 0.00703, 0.00639, 0.00698, 0.00581, 0.00658, 0.00621,
                        0.00725, 0.00780, 0.00751, 0.00749, 0.00737, 0.00772, 0.00723, 0.00754],
                       [0.00670, 0.00600, 0.00655, 0.00729, 0.00689, 0.00742, 0.00639,
                        0.00745, 0.00592, 0.00735, 0.00699, 0.00674, 0.00634, 0.00694,
                        0.00659, 0.00735, 0.00702, 0.00716, 0.00706, 0.00742, 0.00683,
                        0.00740, 0.00802, 0.00750, 0.00844, 0.00810, 0.00824, 0.00781, 0.00865],
                       [0.00726, 0.00696, 0.00738, 0.00793, 0.00768, 0.00811, 0.00749,
                        0.00805, 0.00750, 0.00839, 0.00755, 0.00786, 0.00705, 0.00785,
                        0.00721, 0.00786, 0.00809, 0.00790, 0.00835, 0.00858, 0.00796,
                        0.00807, 0.00851, 0.00855, 0.00946, 0.00927, 0.00914, 0.00948, 0.00954],
                       [0.00806, 0.00813, 0.00817, 0.00816, 0.00844, 0.00830, 0.00839,
                        0.00816, 0.00820, 0.00881, 0.00781, 0.00809, 0.00788, 0.00825,
                        0.00809, 0.00793, 0.00830, 0.00813, 0.00855, 0.00877, 0.00869,
                        0.00871, 0.00869, 0.00949, 0.01025, 0.01030, 0.00996, 0.01114, 0.01019],
                       [0.00953, 0.00969, 0.00948, 0.00938, 0.00984, 0.00935, 0.00940,
                        0.00850, 0.00872, 0.00924, 0.00849, 0.00851, 0.00949, 0.00884,
                        0.00938, 0.00874, 0.00872, 0.00840, 0.00924, 0.00936, 0.00970,
                        0.00997, 0.00984, 0.01069, 0.01140, 0.01168, 0.01123, 0.01295, 0.01195],
                       [0.01232, 0.01225, 0.01217, 0.01238, 0.01296, 0.01227, 0.01155,
                        0.01106, 0.01122, 0.01111, 0.01104, 0.01115, 0.01201, 0.01161,
                        0.01197, 0.01137, 0.01126, 0.01072, 0.01186, 0.01196, 0.01238,
                        0.01297, 0.01330, 0.01372, 0.01435, 0.01518, 0.01496, 0.01664, 0.01574],
                       [0.01679, 0.01629, 0.01644, 0.01682, 0.01765, 0.01697, 0.01599,
                        0.01580, 0.01598, 0.01521, 0.01551, 0.01577, 0.01547, 0.01621,
                        0.01594, 0.01586, 0.01593, 0.01559, 0.01622, 0.01651, 0.01671,
                        0.01796, 0.01827, 0.01905, 0.01996, 0.02136, 0.02158, 0.02279, 0.02145],
                       [0.02314, 0.02248, 0.02289, 0.02298, 0.02342, 0.02342, 0.02265,
                        0.02202, 0.02238, 0.02169, 0.02151, 0.02147, 0.02100, 0.02193,
                        0.02151, 0.02189, 0.02182, 0.02188, 0.02228, 0.02266, 0.02298,
                        0.02459, 0.02473, 0.02625, 0.02773, 0.02944, 0.03011, 0.03077, 0.02892],
                       [0.03130, 0.03138, 0.03161, 0.03119, 0.03066, 0.03113, 0.03068,
                        0.02970, 0.03026, 0.02968, 0.02907, 0.02862, 0.02895, 0.02927,
                        0.02906, 0.02936, 0.02910, 0.02930, 0.02983, 0.03057, 0.03134,
                        0.03277, 0.03315, 0.03507, 0.03695, 0.03918, 0.04017, 0.04068, 0.03861],
                       [0.04161, 0.04267, 0.04216, 0.04153, 0.04060, 0.04022, 0.04013,
                        0.03931, 0.03986, 0.03848, 0.03867, 0.03841, 0.03871, 0.03899,
                        0.03887, 0.03892, 0.03868, 0.03878, 0.03931, 0.04066, 0.04157,
                        0.04316, 0.04411, 0.04649, 0.04867, 0.05159, 0.05273, 0.05429, 0.05154],
                       [0.05408, 0.05514, 0.05426, 0.05361, 0.05327, 0.05181, 0.05191,
                        0.05103, 0.05145, 0.04905, 0.05038, 0.05060, 0.05020, 0.05090,
                        0.05084, 0.05083, 0.05035, 0.05072, 0.05178, 0.05292, 0.05456,
                        0.05637, 0.05821, 0.06156, 0.06429, 0.06740, 0.06948, 0.07283, 0.06857],
                       [0.06937, 0.06985, 0.06946, 0.06872, 0.06875, 0.06716, 0.06704,
                        0.06583, 0.06606, 0.06381, 0.06503, 0.06526, 0.06495, 0.06585,
                        0.06603, 0.06584, 0.06525, 0.06646, 0.06797, 0.06888, 0.07180,
                        0.07387, 0.07711, 0.08149, 0.08519, 0.08844, 0.09292, 0.09692, 0.09158],
                       [0.08793, 0.08849, 0.08835, 0.08828, 0.08742, 0.08618, 0.08523,
                        0.08434, 0.08403, 0.08338, 0.08368, 0.08327, 0.08405, 0.08450,
                        0.08497, 0.08471, 0.08508, 0.08660, 0.08801, 0.09009, 0.09327,
                        0.09702, 0.10136, 0.10707, 0.11217, 0.11686, 0.12366, 0.12746, 0.12184],
                       [0.11124, 0.11161, 0.11102, 0.11204, 0.11031, 0.10891, 0.10725,
                        0.10722, 0.10617, 0.10662, 0.10636, 0.10590, 0.10716, 0.10730,
                        0.10826, 0.10862, 0.10990, 0.11106, 0.11291, 0.11674, 0.11974,
                        0.12583, 0.13107, 0.13912, 0.14640, 0.15354, 0.16158, 0.16703, 0.16040],
                       [0.14304, 0.14237, 0.14180, 0.14204, 0.14059, 0.13878, 0.13737,
                        0.13739, 0.13570, 0.13559, 0.13547, 0.13606, 0.13683, 0.13742,
                        0.13891, 0.14056, 0.14146, 0.14336, 0.14640, 0.15102, 0.15558,
                        0.16295, 0.17038, 0.18128, 0.19163, 0.20167, 0.21110, 0.22002, 0.21083],
                       [0.18684, 0.18587, 0.18629, 0.18432, 0.18319, 0.18119, 0.17957,
                        0.17867, 0.17694, 0.17576, 0.17595, 0.17754, 0.17816, 0.17961,
                        0.18169, 0.18404, 0.18441, 0.18839, 0.19254, 0.19748, 0.20532,
                        0.21365, 0.22476, 0.23841, 0.25226, 0.26599, 0.27711, 0.28893, 0.27589],
                       [0.24485, 0.24505, 0.24593, 0.24279, 0.24087, 0.23883, 0.23588,
                        0.23403, 0.23233, 0.23108, 0.23097, 0.23291, 0.23438, 0.23674,
                        0.23914, 0.24088, 0.24224, 0.24737, 0.25287, 0.25882, 0.26955,
                        0.28036, 0.29511, 0.31117, 0.32873, 0.34533, 0.35774, 0.37095, 0.35332],
                       [0.31972, 0.32027, 0.32030, 0.31730, 0.31447, 0.31169, 0.30802,
                        0.30554, 0.30324, 0.30231, 0.30184, 0.30419, 0.30690, 0.30941,
                        0.31113, 0.31228, 0.31576, 0.32045, 0.32770, 0.33562, 0.34775,
                        0.36174, 0.37934, 0.39737, 0.41815, 0.43574, 0.44957, 0.46236, 0.43939],
                       [0.41045, 0.41059, 0.40907, 0.40665, 0.40348, 0.39919, 0.39578,
                        0.39279, 0.38964, 0.38857, 0.38849, 0.39108, 0.39436, 0.39619,
                        0.39739, 0.39904, 0.40347, 0.40844, 0.41642, 0.42707, 0.43949,
                        0.45549, 0.47491, 0.49484, 0.51646, 0.53455, 0.55021, 0.56182, 0.53167],
                       [0.51313, 0.51355, 0.51108, 0.50929, 0.50608, 0.50063, 0.49707,
                        0.49370, 0.49013, 0.48873, 0.48925, 0.49124, 0.49416, 0.49615,
                        0.49784, 0.49985, 0.50350, 0.50998, 0.51737, 0.52988, 0.54220,
                        0.55929, 0.57861, 0.59970, 0.61969, 0.63837, 0.65384, 0.66479, 0.62634],
                       [0.62360, 0.62369, 0.62158, 0.62027, 0.61706, 0.61213, 0.60737,
                        0.60420, 0.60100, 0.59881, 0.59924, 0.60048, 0.60300, 0.60635,
                        0.60811, 0.60919, 0.61249, 0.61943, 0.62650, 0.63804, 0.65023,
                        0.66711, 0.68434, 0.70470, 0.72215, 0.73988, 0.75212, 0.76247, 0.71619],
                       [0.73229, 0.73079, 0.72980, 0.72893, 0.72557, 0.72189, 0.71646,
                        0.71411, 0.71212, 0.70843, 0.70831, 0.70954, 0.71262, 0.71607,
                        0.71688, 0.71718, 0.72064, 0.72654, 0.73320, 0.74215, 0.75307,
                        0.76727, 0.78190, 0.79879, 0.81330, 0.82757, 0.83612, 0.84466, 0.79151],
                       [0.82318, 0.82119, 0.82110, 0.82055, 0.81737, 0.81404, 0.80988,
                        0.80866, 0.80737, 0.80293, 0.80305, 0.80469, 0.80809, 0.80972,
                        0.80974, 0.81046, 0.81316, 0.81743, 0.82281, 0.82937, 0.83755,
                        0.84711, 0.85910, 0.87058, 0.88145, 0.89091, 0.89662, 0.90203, 0.84339],
                       [0.88742, 0.88685, 0.88639, 0.88614, 0.88400, 0.88115, 0.87881,
                        0.87797, 0.87694, 0.87378, 0.87429, 0.87603, 0.87841, 0.87851,
                        0.87844, 0.87957, 0.88091, 0.88352, 0.88751, 0.89180, 0.89751,
                        0.90291, 0.91063, 0.91714, 0.92411, 0.92925, 0.93234, 0.93493, 0.87172],
                       [0.92995, 0.93099, 0.93012, 0.92984, 0.92844, 0.92741, 0.92626,
                        0.92453, 0.92475, 0.92335, 0.92306, 0.92474, 0.92568, 0.92615,
                        0.92579, 0.92690, 0.92712, 0.92831, 0.93112, 0.93292, 0.93693,
                        0.94020, 0.94279, 0.94665, 0.95026, 0.95216, 0.95351, 0.95438, 0.88775],
                       [0.95360, 0.95474, 0.95430, 0.95421, 0.95267, 0.95323, 0.95333,
                        0.95135, 0.95224, 0.95201, 0.95102, 0.95217, 0.95223, 0.95399,
                        0.95250, 0.95329, 0.95359, 0.95335, 0.95548, 0.95519, 0.95732,
                        0.95927, 0.95931, 0.96192, 0.96353, 0.96375, 0.96413, 0.96383, 0.89661],
                       [0.95899, 0.95857, 0.95913, 0.95920, 0.95872, 0.95857, 0.95966,
                        0.95897, 0.95869, 0.95917, 0.95893, 0.95874, 0.95928, 0.96046,
                        0.95894, 0.95863, 0.95963, 0.95927, 0.96043, 0.95967, 0.96001,
                        0.96028, 0.96101, 0.96267, 0.96306, 0.96335, 0.96246, 0.96172, 0.89551],
                       [0.95669, 0.95593, 0.95679, 0.95631, 0.95737, 0.95613, 0.95675,
                        0.95715, 0.95614, 0.95652, 0.95709, 0.95619, 0.95772, 0.95703,
                        0.95721, 0.95568, 0.95673, 0.95738, 0.95702, 0.95697, 0.95635,
                        0.95630, 0.95740, 0.95893, 0.95770, 0.95849, 0.95710, 0.95634, 0.89000],
                       [0.95937, 0.96003, 0.95978, 0.95907, 0.95975, 0.95945, 0.95885,
                        0.95931, 0.95891, 0.95910, 0.95943, 0.95927, 0.95970, 0.95918,
                        0.96002, 0.95869, 0.95905, 0.95972, 0.95873, 0.95884, 0.95865,
                        0.95906, 0.95911, 0.96067, 0.95913, 0.95925, 0.95889, 0.95764, 0.89015],
                       [0.96585, 0.96686, 0.96600, 0.96590, 0.96538, 0.96627, 0.96544,
                        0.96540, 0.96583, 0.96624, 0.96636, 0.96614, 0.96494, 0.96575,
                        0.96556, 0.96568, 0.96499, 0.96514, 0.96499, 0.96449, 0.96518,
                        0.96464, 0.96442, 0.96533, 0.96499, 0.96401, 0.96465, 0.96318, 0.89471],
                       [0.96745, 0.96727, 0.96741, 0.96772, 0.96709, 0.96734, 0.96730,
                        0.96740, 0.96754, 0.96785, 0.96803, 0.96744, 0.96651, 0.96670,
                        0.96609, 0.96701, 0.96605, 0.96567, 0.96655, 0.96654, 0.96658,
                        0.96507, 0.96571, 0.96566, 0.96582, 0.96484, 0.96462, 0.96461, 0.89565],
                       [0.96560, 0.96523, 0.96549, 0.96536, 0.96551, 0.96456, 0.96546,
                        0.96587, 0.96554, 0.96549, 0.96489, 0.96497, 0.96532, 0.96402,
                        0.96446, 0.96432, 0.96402, 0.96343, 0.96436, 0.96519, 0.96442,
                        0.96330, 0.96442, 0.96344, 0.96373, 0.96308, 0.96154, 0.96303, 0.89406],
                       [0.96587, 0.96709, 0.96643, 0.96585, 0.96607, 0.96512, 0.96629,
                        0.96616, 0.96621, 0.96653, 0.96535, 0.96544, 0.96653, 0.96527,
                        0.96617, 0.96492, 0.96488, 0.96492, 0.96525, 0.96563, 0.96552,
                        0.96517, 0.96631, 0.96430, 0.96522, 0.96505, 0.96340, 0.96401, 0.89538],
                       [0.96529, 0.96750, 0.96677, 0.96667, 0.96677, 0.96658, 0.96674,
                        0.96637, 0.96665, 0.96733, 0.96688, 0.96655, 0.96728, 0.96706,
                        0.96707, 0.96638, 0.96562, 0.96642, 0.96639, 0.96653, 0.96643,
                        0.96661, 0.96764, 0.96588, 0.96634, 0.96732, 0.96572, 0.96466, 0.89704],
                       [0.96456, 0.96616, 0.96585, 0.96587, 0.96726, 0.96691, 0.96603,
                        0.96636, 0.96660, 0.96692, 0.96697, 0.96689, 0.96707, 0.96732,
                        0.96674, 0.96730, 0.96618, 0.96668, 0.96663, 0.96731, 0.96684,
                        0.96721, 0.96753, 0.96716, 0.96686, 0.96813, 0.96663, 0.96519, 0.89844],
                       [0.96473, 0.96547, 0.96522, 0.96474, 0.96691, 0.96615, 0.96591,
                        0.96616, 0.96713, 0.96623, 0.96613, 0.96622, 0.96651, 0.96650,
                        0.96657, 0.96762, 0.96707, 0.96663, 0.96651, 0.96718, 0.96758,
                        0.96738, 0.96751, 0.96803, 0.96720, 0.96791, 0.96763, 0.96635, 0.89996],
                       [0.96337, 0.96346, 0.96331, 0.96307, 0.96369, 0.96340, 0.96440,
                        0.96380, 0.96526, 0.96319, 0.96382, 0.96347, 0.96375, 0.96403,
                        0.96434, 0.96518, 0.96553, 0.96431, 0.96436, 0.96399, 0.96580,
                        0.96498, 0.96621, 0.96631, 0.96483, 0.96563, 0.96635, 0.96561, 0.89949],
                       [0.96243, 0.96237, 0.96263, 0.96274, 0.96127, 0.96177, 0.96304,
                        0.96283, 0.96276, 0.96152, 0.96193, 0.96212, 0.96193, 0.96251,
                        0.96211, 0.96260, 0.96435, 0.96247, 0.96309, 0.96207, 0.96419,
                        0.96296, 0.96525, 0.96437, 0.96393, 0.96462, 0.96439, 0.96531, 0.89955],
                       [0.96411, 0.96483, 0.96458, 0.96456, 0.96318, 0.96385, 0.96459,
                        0.96521, 0.96307, 0.96404, 0.96268, 0.96401, 0.96376, 0.96395,
                        0.96262, 0.96339, 0.96554, 0.96429, 0.96527, 0.96486, 0.96528,
                        0.96440, 0.96628, 0.96493, 0.96707, 0.96697, 0.96587, 0.96789, 0.90240],
                       [0.96578, 0.96746, 0.96647, 0.96605, 0.96642, 0.96641, 0.96585,
                        0.96655, 0.96447, 0.96669, 0.96471, 0.96603, 0.96546, 0.96599,
                        0.96454, 0.96533, 0.96597, 0.96628, 0.96684, 0.96763, 0.96659,
                        0.96631, 0.96777, 0.96686, 0.96961, 0.96951, 0.96955, 0.97067, 0.90465],
                       [0.96612, 0.96804, 0.96757, 0.96673, 0.96719, 0.96684, 0.96534,
                        0.96598, 0.96497, 0.96699, 0.96595, 0.96649, 0.96524, 0.96583,
                        0.96600, 0.96603, 0.96464, 0.96545, 0.96601, 0.96701, 0.96667,
                        0.96663, 0.96809, 0.96860, 0.96936, 0.97006, 0.97120, 0.97150, 0.90488],
                       [0.96825, 0.96976, 0.97033, 0.96972, 0.96852, 0.96923, 0.96803,
                        0.96840, 0.96776, 0.96855, 0.96840, 0.96812, 0.96779, 0.96676,
                        0.96817, 0.96801, 0.96615, 0.96686, 0.96783, 0.96768, 0.96873,
                        0.96903, 0.97022, 0.97126, 0.97127, 0.97169, 0.97255, 0.97318, 0.90668],
                       [0.97105, 0.97190, 0.97219, 0.97214, 0.97081, 0.97270, 0.97182,
                        0.97144, 0.97142, 0.97073, 0.97128, 0.97060, 0.97183, 0.96984,
                        0.97016, 0.97054, 0.97005, 0.97062, 0.97115, 0.97017, 0.97118,
                        0.97221, 0.97293, 0.97344, 0.97392, 0.97441, 0.97450, 0.97546, 0.90804],
                       [0.97376, 0.97395, 0.97233, 0.97288, 0.97346, 0.97494, 0.97412,
                        0.97348, 0.97417, 0.97242, 0.97371, 0.97307, 0.97442, 0.97317,
                        0.97282, 0.97332, 0.97356, 0.97364, 0.97406, 0.97278, 0.97303,
                        0.97443, 0.97513, 0.97514, 0.97543, 0.97692, 0.97644, 0.97667, 0.90856],
                       [0.97564, 0.97572, 0.97361, 0.97447, 0.97632, 0.97549, 0.97556,
                        0.97544, 0.97631, 0.97429, 0.97535, 0.97497, 0.97540, 0.97495,
                        0.97566, 0.97571, 0.97580, 0.97556, 0.97648, 0.97494, 0.97545,
                        0.97590, 0.97711, 0.97692, 0.97706, 0.97814, 0.97743, 0.97649, 0.90954],
                       [0.97539, 0.97581, 0.97597, 0.97608, 0.97741, 0.97498, 0.97601,
                        0.97666, 0.97686, 0.97586, 0.97608, 0.97582, 0.97582, 0.97567,
                        0.97686, 0.97623, 0.97707, 0.97677, 0.97714, 0.97658, 0.97736,
                        0.97699, 0.97793, 0.97802, 0.97880, 0.97776, 0.97714, 0.97645, 0.91007],
                       [0.97423, 0.97435, 0.97644, 0.97560, 0.97611, 0.97431, 0.97555,
                        0.97642, 0.97557, 0.97579, 0.97626, 0.97602, 0.97625, 0.97637,
                        0.97673, 0.97543, 0.97719, 0.97709, 0.97661, 0.97747, 0.97793,
                        0.97801, 0.97707, 0.97840, 0.97893, 0.97692, 0.97657, 0.97672, 0.90950],
                       [0.97226, 0.97207, 0.97371, 0.97254, 0.97315, 0.97244, 0.97324,
                        0.97382, 0.97308, 0.97367, 0.97445, 0.97452, 0.97477, 0.97521,
                        0.97477, 0.97369, 0.97516, 0.97501, 0.97473, 0.97574, 0.97586,
                        0.97671, 0.97503, 0.97680, 0.97580, 0.97575, 0.97488, 0.97465, 0.90711],
                       [0.97024, 0.97046, 0.97085, 0.96979, 0.97049, 0.97012, 0.97022,
                        0.97065, 0.97147, 0.97174, 0.97154, 0.97204, 0.97240, 0.97276,
                        0.97209, 0.97208, 0.97266, 0.97225, 0.97195, 0.97289, 0.97214,
                        0.97328, 0.97329, 0.97360, 0.97195, 0.97420, 0.97200, 0.97132, 0.90408],
                       [0.96953, 0.96977, 0.96998, 0.96954, 0.96943, 0.96900, 0.96901,
                        0.96945, 0.97064, 0.97043, 0.97006, 0.97029, 0.97150, 0.97091,
                        0.97033, 0.97095, 0.97125, 0.97173, 0.97070, 0.97106, 0.97055,
                        0.97106, 0.97247, 0.97119, 0.96988, 0.97209, 0.96943, 0.96896, 0.90183],
                       [0.97160, 0.97137, 0.97206, 0.97215, 0.97126, 0.97148, 0.97125,
                        0.97174, 0.97178, 0.97151, 0.97226, 0.97140, 0.97304, 0.97217,
                        0.97139, 0.97180, 0.97260, 0.97415, 0.97278, 0.97184, 0.97312,
                        0.97315, 0.97392, 0.97253, 0.97131, 0.97183, 0.96974, 0.96920, 0.90224],
                       [0.97441, 0.97489, 0.97522, 0.97527, 0.97386, 0.97554, 0.97483,
                        0.97525, 0.97460, 0.97456, 0.97582, 0.97474, 0.97507, 0.97527,
                        0.97443, 0.97434, 0.97479, 0.97653, 0.97539, 0.97449, 0.97611,
                        0.97657, 0.97550, 0.97488, 0.97443, 0.97340, 0.97143, 0.97034, 0.90482],
                       [0.97065, 0.97168, 0.97155, 0.97144, 0.96980, 0.97221, 0.97191,
                        0.97183, 0.97074, 0.97136, 0.97140, 0.97175, 0.97080, 0.97103,
                        0.97115, 0.97062, 0.97042, 0.97136, 0.97038, 0.97127, 0.97138,
                        0.97123, 0.97036, 0.97028, 0.97054, 0.96894, 0.96715, 0.96594, 0.90221],
                       [0.96441, 0.96461, 0.96486, 0.96439, 0.96338, 0.96515, 0.96534,
                        0.96473, 0.96311, 0.96461, 0.96337, 0.96435, 0.96372, 0.96320,
                        0.96402, 0.96380, 0.96332, 0.96274, 0.96221, 0.96424, 0.96337,
                        0.96200, 0.96333, 0.96323, 0.96352, 0.96212, 0.96148, 0.96079, 0.89716],
                       [0.96555, 0.96547, 0.96535, 0.96529, 0.96482, 0.96537, 0.96534,
                        0.96479, 0.96365, 0.96513, 0.96363, 0.96355, 0.96415, 0.96342,
                        0.96433, 0.96464, 0.96356, 0.96198, 0.96260, 0.96434, 0.96335,
                        0.96224, 0.96450, 0.96403, 0.96419, 0.96340, 0.96409, 0.96415, 0.89896],
                       [0.97007, 0.97064, 0.97014, 0.97094, 0.97033, 0.97020, 0.97006,
                        0.96977, 0.96997, 0.96986, 0.96866, 0.96757, 0.96950, 0.96869,
                        0.96970, 0.96985, 0.96844, 0.96795, 0.96857, 0.96929, 0.96879,
                        0.96883, 0.96980, 0.96942, 0.96957, 0.96973, 0.97028, 0.97088, 0.90469],
                       [0.97057, 0.97130, 0.97199, 0.97219, 0.97132, 0.97128, 0.97136,
                        0.97102, 0.97225, 0.97016, 0.96996, 0.96914, 0.97057, 0.96992,
                        0.97102, 0.97064, 0.96972, 0.97118, 0.97032, 0.97007, 0.97076,
                        0.97089, 0.97090, 0.97127, 0.97197, 0.97282, 0.97216, 0.97313, 0.90669],
                       [0.96881, 0.96902, 0.97099, 0.96969, 0.96886, 0.96913, 0.96886,
                        0.96878, 0.96962, 0.96739, 0.96865, 0.96886, 0.96806, 0.96846,
                        0.96852, 0.96798, 0.96810, 0.96973, 0.96790, 0.96730, 0.96915,
                        0.96864, 0.96918, 0.96966, 0.97157, 0.97220, 0.97157, 0.97202, 0.90572],
                       [0.96879, 0.96957, 0.97046, 0.96924, 0.96882, 0.96918, 0.96834,
                        0.96908, 0.96824, 0.96745, 0.96951, 0.97022, 0.96865, 0.96921,
                        0.96828, 0.96817, 0.96909, 0.96949, 0.96822, 0.96800, 0.96927,
                        0.97000, 0.96982, 0.97054, 0.97223, 0.97310, 0.97342, 0.97209, 0.90687],
                       [0.96777, 0.96979, 0.96855, 0.96936, 0.96897, 0.96880, 0.96836,
                        0.96970, 0.96757, 0.96785, 0.96952, 0.97015, 0.96958, 0.96898,
                        0.96877, 0.96952, 0.97028, 0.97009, 0.96949, 0.96949, 0.97030,
                        0.97242, 0.97055, 0.97279, 0.97229, 0.97470, 0.97448, 0.97252, 0.90783],
                       [0.96565, 0.96745, 0.96612, 0.96766, 0.96702, 0.96668, 0.96693,
                        0.96779, 0.96652, 0.96710, 0.96723, 0.96766, 0.96850, 0.96708,
                        0.96807, 0.96930, 0.96911, 0.96960, 0.96968, 0.96879, 0.97046,
                        0.97166, 0.97011, 0.97295, 0.97138, 0.97452, 0.97305, 0.97234, 0.90683],
                       [0.96604, 0.96680, 0.96621, 0.96624, 0.96581, 0.96639, 0.96666,
                        0.96631, 0.96721, 0.96811, 0.96654, 0.96695, 0.96839, 0.96746,
                        0.96882, 0.96942, 0.96852, 0.97020, 0.97128, 0.96915, 0.97082,
                        0.97095, 0.97114, 0.97265, 0.97198, 0.97392, 0.97280, 0.97310, 0.90667],
                       [0.96600, 0.96627, 0.96646, 0.96492, 0.96489, 0.96586, 0.96647,
                        0.96536, 0.96695, 0.96793, 0.96669, 0.96724, 0.96718, 0.96743,
                        0.96860, 0.96863, 0.96777, 0.97019, 0.97103, 0.96917, 0.97049,
                        0.97057, 0.97084, 0.97193, 0.97152, 0.97190, 0.97179, 0.97246, 0.90618],
                       [0.96510, 0.96568, 0.96647, 0.96502, 0.96430, 0.96480, 0.96638,
                        0.96556, 0.96603, 0.96594, 0.96708, 0.96744, 0.96541, 0.96644,
                        0.96708, 0.96749, 0.96744, 0.96887, 0.96900, 0.96829, 0.96965,
                        0.97053, 0.96932, 0.97142, 0.97085, 0.97017, 0.97002, 0.97133, 0.90528],
                       [0.96669, 0.96721, 0.96738, 0.96752, 0.96633, 0.96636, 0.96789,
                        0.96747, 0.96793, 0.96607, 0.96804, 0.96879, 0.96701, 0.96772,
                        0.96815, 0.96864, 0.96924, 0.96921, 0.96930, 0.96930, 0.97033,
                        0.97133, 0.97030, 0.97228, 0.97221, 0.97157, 0.97088, 0.97175, 0.90494],
                       [0.97074, 0.97089, 0.97062, 0.97207, 0.97143, 0.97141, 0.97135,
                        0.97092, 0.97238, 0.97097, 0.97069, 0.97252, 0.97229, 0.97202,
                        0.97286, 0.97289, 0.97318, 0.97322, 0.97338, 0.97354, 0.97463,
                        0.97456, 0.97529, 0.97528, 0.97582, 0.97592, 0.97469, 0.97394, 0.90629],
                       [0.97107, 0.97169, 0.97277, 0.97262, 0.97290, 0.97292, 0.97162,
                        0.97149, 0.97262, 0.97380, 0.97197, 0.97392, 0.97363, 0.97369,
                        0.97386, 0.97430, 0.97387, 0.97472, 0.97509, 0.97537, 0.97645,
                        0.97597, 0.97754, 0.97553, 0.97649, 0.97619, 0.97474, 0.97310, 0.90537],
                       [0.96559, 0.96714, 0.96941, 0.96665, 0.96759, 0.96717, 0.96667,
                        0.96660, 0.96699, 0.96876, 0.96846, 0.96918, 0.96817, 0.96963,
                        0.96773, 0.96922, 0.96874, 0.96954, 0.96970, 0.97089, 0.97143,
                        0.97058, 0.97173, 0.96964, 0.97086, 0.96945, 0.96765, 0.96646, 0.89939],
                       [0.96502, 0.96624, 0.96777, 0.96538, 0.96653, 0.96490, 0.96630,
                        0.96619, 0.96658, 0.96650, 0.96816, 0.96766, 0.96776, 0.96918,
                        0.96644, 0.96828, 0.96857, 0.96858, 0.96709, 0.96922, 0.97000,
                        0.96801, 0.96824, 0.96764, 0.96868, 0.96686, 0.96497, 0.96425, 0.89769],
                       [0.97017, 0.96927, 0.97023, 0.96961, 0.97079, 0.96922, 0.97052,
                        0.97080, 0.97129, 0.97013, 0.97212, 0.97127, 0.97297, 0.97306,
                        0.97204, 0.97278, 0.97384, 0.97355, 0.97080, 0.97187, 0.97319,
                        0.97156, 0.97127, 0.97127, 0.97120, 0.97012, 0.96893, 0.96870, 0.90274],
                       [0.96878, 0.96641, 0.96761, 0.96769, 0.96873, 0.96871, 0.96823,
                        0.96868, 0.96928, 0.96907, 0.96980, 0.96910, 0.97111, 0.96997,
                        0.97162, 0.97061, 0.97202, 0.97183, 0.96998, 0.96925, 0.96940,
                        0.97028, 0.97004, 0.96932, 0.96834, 0.96785, 0.96809, 0.96865, 0.90372],
                       [0.96323, 0.96224, 0.96286, 0.96268, 0.96390, 0.96412, 0.96348,
                        0.96322, 0.96458, 0.96523, 0.96429, 0.96404, 0.96563, 0.96428,
                        0.96595, 0.96504, 0.96619, 0.96549, 0.96528, 0.96491, 0.96362,
                        0.96522, 0.96526, 0.96483, 0.96356, 0.96320, 0.96480, 0.96596, 0.90107],
                       [0.96514, 0.96623, 0.96618, 0.96577, 0.96674, 0.96625, 0.96678,
                        0.96559, 0.96719, 0.96689, 0.96611, 0.96651, 0.96734, 0.96698,
                        0.96660, 0.96658, 0.96735, 0.96584, 0.96657, 0.96814, 0.96676,
                        0.96710, 0.96761, 0.96795, 0.96690, 0.96761, 0.96871, 0.96988, 0.90485],
                       [0.97005, 0.97093, 0.97089, 0.97073, 0.97103, 0.97035, 0.97080,
                        0.96973, 0.97044, 0.96872, 0.97004, 0.97051, 0.97022, 0.97003,
                        0.96970, 0.96971, 0.97012, 0.96886, 0.96958, 0.97224, 0.97068,
                        0.97073, 0.97151, 0.97196, 0.97219, 0.97359, 0.97344, 0.97413, 0.91021],
                       [0.96963, 0.96894, 0.96932, 0.96941, 0.96875, 0.96871, 0.96788,
                        0.96779, 0.96766, 0.96598, 0.96857, 0.96861, 0.96735, 0.96675,
                        0.96715, 0.96788, 0.96726, 0.96738, 0.96770, 0.96892, 0.96756,
                        0.96801, 0.96881, 0.96951, 0.97079, 0.97130, 0.97192, 0.97249, 0.90822],
                       [0.96811, 0.96657, 0.96701, 0.96744, 0.96605, 0.96660, 0.96566,
                        0.96546, 0.96548, 0.96494, 0.96596, 0.96599, 0.96465, 0.96513,
                        0.96474, 0.96579, 0.96497, 0.96574, 0.96595, 0.96456, 0.96466,
                        0.96517, 0.96564, 0.96691, 0.96809, 0.96794, 0.97031, 0.97060, 0.90472],
                       [0.97021, 0.96914, 0.96914, 0.97017, 0.96863, 0.96900, 0.96968,
                        0.96834, 0.96884, 0.96864, 0.96765, 0.96765, 0.96745, 0.96870,
                        0.96839, 0.96792, 0.96828, 0.96857, 0.96904, 0.96682, 0.96754,
                        0.96847, 0.96821, 0.96936, 0.97027, 0.97122, 0.97301, 0.97250, 0.90654],
                       [0.97362, 0.97357, 0.97331, 0.97437, 0.97324, 0.97328, 0.97489,
                        0.97330, 0.97393, 0.97321, 0.97230, 0.97179, 0.97247, 0.97303,
                        0.97380, 0.97228, 0.97329, 0.97292, 0.97359, 0.97297, 0.97298,
                        0.97384, 0.97401, 0.97471, 0.97451, 0.97683, 0.97638, 0.97602, 0.91051],
                       [0.97500, 0.97516, 0.97555, 0.97529, 0.97516, 0.97534, 0.97575,
                        0.97559, 0.97583, 0.97495, 0.97536, 0.97517, 0.97488, 0.97503,
                        0.97549, 0.97536, 0.97546, 0.97540, 0.97552, 0.97598, 0.97615,
                        0.97586, 0.97755, 0.97817, 0.97655, 0.97850, 0.97768, 0.97762, 0.91152],
                       [0.97430, 0.97463, 0.97562, 0.97423, 0.97494, 0.97578, 0.97443,
                        0.97542, 0.97566, 0.97488, 0.97603, 0.97692, 0.97581, 0.97603,
                        0.97573, 0.97648, 0.97604, 0.97644, 0.97602, 0.97579, 0.97653,
                        0.97588, 0.97784, 0.97815, 0.97713, 0.97724, 0.97825, 0.97744, 0.91023],
                       [0.97087, 0.97196, 0.97260, 0.97203, 0.97223, 0.97363, 0.97182,
                        0.97260, 0.97337, 0.97312, 0.97388, 0.97479, 0.97498, 0.97456,
                        0.97461, 0.97406, 0.97448, 0.97453, 0.97440, 0.97367, 0.97406,
                        0.97426, 0.97498, 0.97452, 0.97514, 0.97414, 0.97545, 0.97470, 0.90750],
                       [0.96853, 0.96974, 0.96950, 0.97052, 0.96923, 0.97059, 0.96970,
                        0.96985, 0.97148, 0.97123, 0.97139, 0.97165, 0.97320, 0.97210,
                        0.97264, 0.97139, 0.97237, 0.97248, 0.97231, 0.97229, 0.97220,
                        0.97310, 0.97277, 0.97174, 0.97289, 0.97219, 0.97176, 0.97148, 0.90619],
                       [0.97001, 0.97096, 0.97025, 0.97137, 0.97032, 0.97119, 0.97106,
                        0.97100, 0.97261, 0.97206, 0.97260, 0.97238, 0.97336, 0.97294,
                        0.97320, 0.97310, 0.97333, 0.97403, 0.97374, 0.97429, 0.97422,
                        0.97467, 0.97427, 0.97359, 0.97436, 0.97405, 0.97307, 0.97227, 0.90854],
                       [0.97119, 0.97137, 0.97129, 0.97109, 0.97170, 0.97247, 0.97232,
                        0.97243, 0.97274, 0.97292, 0.97403, 0.97373, 0.97334, 0.97414,
                        0.97405, 0.97499, 0.97454, 0.97507, 0.97552, 0.97578, 0.97571,
                        0.97540, 0.97558, 0.97528, 0.97544, 0.97517, 0.97488, 0.97407, 0.90967],
                       [0.97013, 0.96887, 0.96974, 0.96838, 0.96981, 0.97060, 0.97034,
                        0.97060, 0.96990, 0.97137, 0.97203, 0.97201, 0.97099, 0.97229,
                        0.97192, 0.97294, 0.97345, 0.97300, 0.97349, 0.97391, 0.97367,
                        0.97385, 0.97371, 0.97356, 0.97291, 0.97255, 0.97348, 0.97278, 0.90741],
                       [0.96839, 0.96684, 0.96800, 0.96682, 0.96755, 0.96793, 0.96758,
                        0.96889, 0.96796, 0.96965, 0.96985, 0.96980, 0.96939, 0.97043,
                        0.96966, 0.97023, 0.97177, 0.97130, 0.97035, 0.97143, 0.97118,
                        0.97268, 0.97193, 0.97215, 0.97058, 0.97010, 0.97250, 0.97161, 0.90580],
                       [0.96865, 0.96790, 0.96896, 0.96868, 0.96841, 0.96823, 0.96829,
                        0.97049, 0.97009, 0.97098, 0.97186, 0.97151, 0.97154, 0.97276,
                        0.97188, 0.97186, 0.97237, 0.97336, 0.97190, 0.97241, 0.97260,
                        0.97445, 0.97353, 0.97418, 0.97293, 0.97222, 0.97413, 0.97390, 0.90776],
                       [0.96641, 0.96635, 0.96735, 0.96759, 0.96738, 0.96705, 0.96744,
                        0.96895, 0.97006, 0.97014, 0.97125, 0.97176, 0.97161, 0.97291,
                        0.97228, 0.97213, 0.97138, 0.97310, 0.97250, 0.97200, 0.97245,
                        0.97335, 0.97248, 0.97303, 0.97351, 0.97280, 0.97256, 0.97347, 0.90807],
                       [0.96109, 0.96178, 0.96208, 0.96208, 0.96273, 0.96260, 0.96287,
                        0.96347, 0.96495, 0.96537, 0.96534, 0.96722, 0.96712, 0.96738,
                        0.96689, 0.96776, 0.96740, 0.96829, 0.96753, 0.96749, 0.96780,
                        0.96772, 0.96723, 0.96723, 0.96886, 0.96822, 0.96761, 0.96861, 0.90475],
                       [0.96102, 0.96237, 0.96129, 0.96097, 0.96190, 0.96175, 0.96237,
                        0.96280, 0.96330, 0.96438, 0.96390, 0.96588, 0.96582, 0.96550,
                        0.96500, 0.96678, 0.96734, 0.96684, 0.96609, 0.96635, 0.96691,
                        0.96647, 0.96653, 0.96561, 0.96747, 0.96675, 0.96742, 0.96802, 0.90421],
                       [0.96434, 0.96527, 0.96324, 0.96329, 0.96371, 0.96313, 0.96427,
                        0.96549, 0.96539, 0.96621, 0.96653, 0.96769, 0.96722, 0.96809,
                        0.96785, 0.96834, 0.96953, 0.96793, 0.96899, 0.96835, 0.96863,
                        0.96894, 0.96935, 0.96758, 0.96914, 0.96924, 0.97003, 0.97100, 0.90611],
                       [0.96316, 0.96374, 0.96210, 0.96261, 0.96227, 0.96253, 0.96284,
                        0.96491, 0.96510, 0.96539, 0.96622, 0.96705, 0.96601, 0.96781,
                        0.96772, 0.96676, 0.96821, 0.96646, 0.96887, 0.96763, 0.96671,
                        0.96803, 0.96828, 0.96735, 0.96773, 0.96950, 0.96935, 0.97090, 0.90594],
                       [0.95974, 0.96108, 0.96083, 0.96150, 0.96019, 0.96240, 0.96092,
                        0.96201, 0.96354, 0.96369, 0.96419, 0.96559, 0.96480, 0.96540,
                        0.96470, 0.96469, 0.96583, 0.96527, 0.96552, 0.96584, 0.96469,
                        0.96499, 0.96560, 0.96660, 0.96598, 0.96829, 0.96823, 0.96959, 0.90524],
                       [0.96065, 0.96146, 0.96183, 0.96240, 0.96128, 0.96337, 0.96183,
                        0.96122, 0.96324, 0.96405, 0.96395, 0.96550, 0.96540, 0.96492,
                        0.96432, 0.96524, 0.96578, 0.96621, 0.96400, 0.96621, 0.96589,
                        0.96428, 0.96577, 0.96708, 0.96728, 0.96844, 0.96984, 0.97061, 0.90590],
                       [0.96507, 0.96417, 0.96426, 0.96445, 0.96498, 0.96485, 0.96445,
                        0.96397, 0.96457, 0.96639, 0.96595, 0.96614, 0.96649, 0.96678,
                        0.96748, 0.96774, 0.96753, 0.96789, 0.96630, 0.96802, 0.96799,
                        0.96688, 0.96777, 0.96854, 0.96953, 0.97020, 0.97278, 0.97242, 0.90751],
                       [0.96924, 0.96820, 0.96809, 0.96773, 0.96905, 0.96762, 0.96834,
                        0.96896, 0.96831, 0.96958, 0.96917, 0.96872, 0.96907, 0.97002,
                        0.97109, 0.97116, 0.97054, 0.97059, 0.97058, 0.97032, 0.96992,
                        0.97101, 0.97020, 0.97180, 0.97221, 0.97341, 0.97532, 0.97398, 0.90991],
                       [0.97063, 0.97112, 0.97021, 0.96943, 0.96992, 0.96932, 0.97071,
                        0.97153, 0.97119, 0.97058, 0.97066, 0.97138, 0.97133, 0.97157,
                        0.97205, 0.97260, 0.97178, 0.97158, 0.97259, 0.97083, 0.97067,
                        0.97219, 0.97112, 0.97333, 0.97341, 0.97450, 0.97496, 0.97388, 0.91008],
                       [0.97139, 0.97293, 0.97125, 0.97090, 0.97011, 0.97052, 0.97146,
                        0.97195, 0.97209, 0.97150, 0.97153, 0.97291, 0.97302, 0.97170,
                        0.97239, 0.97298, 0.97181, 0.97158, 0.97275, 0.97092, 0.97189,
                        0.97141, 0.97191, 0.97285, 0.97314, 0.97410, 0.97337, 0.97322, 0.90874],
                       [0.97361, 0.97447, 0.97398, 0.97380, 0.97298, 0.97301, 0.97319,
                        0.97338, 0.97325, 0.97433, 0.97375, 0.97411, 0.97457, 0.97316,
                        0.97403, 0.97433, 0.97344, 0.97305, 0.97329, 0.97303, 0.97395,
                        0.97225, 0.97388, 0.97329, 0.97388, 0.97493, 0.97394, 0.97421, 0.90891],
                       [0.97667, 0.97593, 0.97763, 0.97670, 0.97665, 0.97639, 0.97664,
                        0.97695, 0.97600, 0.97755, 0.97665, 0.97622, 0.97611, 0.97680,
                        0.97645, 0.97654, 0.97639, 0.97603, 0.97520, 0.97616, 0.97552,
                        0.97540, 0.97622, 0.97558, 0.97628, 0.97699, 0.97666, 0.97662, 0.91079],
                       [0.97687, 0.97564, 0.97692, 0.97552, 0.97613, 0.97705, 0.97741,
                        0.97833, 0.97698, 0.97681, 0.97623, 0.97625, 0.97551, 0.97762,
                        0.97612, 0.97650, 0.97568, 0.97648, 0.97558, 0.97585, 0.97453,
                        0.97632, 0.97604, 0.97610, 0.97581, 0.97676, 0.97626, 0.97614, 0.91017],
                       [0.97526, 0.97511, 0.97432, 0.97310, 0.97424, 0.97622, 0.97581,
                        0.97665, 0.97587, 0.97433, 0.97379, 0.97464, 0.97398, 0.97496,
                        0.97392, 0.97479, 0.97380, 0.97490, 0.97451, 0.97465, 0.97363,
                        0.97479, 0.97482, 0.97480, 0.97380, 0.97510, 0.97399, 0.97381, 0.90804],
                       [0.97733, 0.97809, 0.97706, 0.97659, 0.97756, 0.97872, 0.97740,
                        0.97765, 0.97768, 0.97684, 0.97589, 0.97652, 0.97660, 0.97609,
                        0.97575, 0.97647, 0.97703, 0.97651, 0.97689, 0.97805, 0.97747,
                        0.97648, 0.97787, 0.97639, 0.97733, 0.97755, 0.97668, 0.97596, 0.91026],
                       [0.97796, 0.97842, 0.97850, 0.97845, 0.97859, 0.97848, 0.97711,
                        0.97725, 0.97804, 0.97807, 0.97752, 0.97693, 0.97726, 0.97745,
                        0.97726, 0.97693, 0.97765, 0.97639, 0.97757, 0.97824, 0.97867,
                        0.97676, 0.97896, 0.97733, 0.97903, 0.97858, 0.97769, 0.97740, 0.91136],
                       [0.97680, 0.97713, 0.97768, 0.97710, 0.97701, 0.97644, 0.97621,
                        0.97643, 0.97702, 0.97715, 0.97753, 0.97625, 0.97604, 0.97703,
                        0.97694, 0.97601, 0.97573, 0.97549, 0.97614, 0.97626, 0.97713,
                        0.97578, 0.97759, 0.97792, 0.97731, 0.97739, 0.97634, 0.97665, 0.91024],
                       [0.97722, 0.97813, 0.97776, 0.97720, 0.97738, 0.97730, 0.97776,
                        0.97799, 0.97748, 0.97746, 0.97824, 0.97735, 0.97655, 0.97703,
                        0.97678, 0.97638, 0.97605, 0.97677, 0.97579, 0.97670, 0.97761,
                        0.97701, 0.97767, 0.97913, 0.97689, 0.97722, 0.97638, 0.97630, 0.91028],
                       [0.97759, 0.97861, 0.97746, 0.97753, 0.97737, 0.97825, 0.97873,
                        0.97886, 0.97827, 0.97742, 0.97774, 0.97788, 0.97669, 0.97698,
                        0.97633, 0.97621, 0.97704, 0.97714, 0.97578, 0.97738, 0.97819,
                        0.97814, 0.97788, 0.97837, 0.97684, 0.97727, 0.97654, 0.97544, 0.91066],
                       [0.97696, 0.97748, 0.97654, 0.97693, 0.97585, 0.97714, 0.97782,
                        0.97766, 0.97872, 0.97695, 0.97651, 0.97685, 0.97581, 0.97691,
                        0.97635, 0.97555, 0.97694, 0.97587, 0.97608, 0.97688, 0.97767,
                        0.97759, 0.97699, 0.97624, 0.97640, 0.97724, 0.97608, 0.97478, 0.91049],
                       [0.97502, 0.97569, 0.97407, 0.97535, 0.97430, 0.97431, 0.97554,
                        0.97522, 0.97723, 0.97614, 0.97597, 0.97509, 0.97437, 0.97581,
                        0.97618, 0.97529, 0.97491, 0.97443, 0.97546, 0.97504, 0.97591,
                        0.97574, 0.97477, 0.97473, 0.97524, 0.97570, 0.97474, 0.97411, 0.90868],
                       [0.97148, 0.97232, 0.97028, 0.97146, 0.97167, 0.97094, 0.97181,
                        0.97154, 0.97282, 0.97307, 0.97346, 0.97227, 0.97177, 0.97208,
                        0.97348, 0.97325, 0.97144, 0.97222, 0.97222, 0.97167, 0.97228,
                        0.97237, 0.97193, 0.97232, 0.97229, 0.97118, 0.97167, 0.97107, 0.90530],
                       [0.97000, 0.97037, 0.96992, 0.96917, 0.97008, 0.97021, 0.96969,
                        0.96995, 0.97037, 0.97104, 0.97089, 0.97091, 0.97091, 0.97005,
                        0.97119, 0.97117, 0.97056, 0.97113, 0.97035, 0.97092, 0.97040,
                        0.97055, 0.97154, 0.97103, 0.97117, 0.96882, 0.96964, 0.96906, 0.90466],
                       [0.97140, 0.97116, 0.97197, 0.97075, 0.97107, 0.97157, 0.97054,
                        0.97153, 0.97153, 0.97207, 0.97139, 0.97212, 0.97246, 0.97184,
                        0.97130, 0.97168, 0.97247, 0.97173, 0.97150, 0.97260, 0.97163,
                        0.97167, 0.97292, 0.97220, 0.97262, 0.97046, 0.97019, 0.96996, 0.90676],
                       [0.97252, 0.97241, 0.97248, 0.97284, 0.97237, 0.97278, 0.97202,
                        0.97310, 0.97270, 0.97310, 0.97396, 0.97324, 0.97349, 0.97354,
                        0.97234, 0.97339, 0.97345, 0.97237, 0.97261, 0.97282, 0.97321,
                        0.97281, 0.97310, 0.97341, 0.97323, 0.97200, 0.97186, 0.97157, 0.90817],
                       [0.97257, 0.97361, 0.97226, 0.97320, 0.97269, 0.97362, 0.97314,
                        0.97314, 0.97343, 0.97293, 0.97561, 0.97325, 0.97347, 0.97396,
                        0.97304, 0.97443, 0.97313, 0.97296, 0.97283, 0.97281, 0.97385,
                        0.97255, 0.97262, 0.97404, 0.97286, 0.97303, 0.97360, 0.97305, 0.90914],
                       [0.97066, 0.97171, 0.97066, 0.96991, 0.97034, 0.97112, 0.97167,
                        0.97043, 0.97163, 0.97054, 0.97179, 0.97099, 0.97139, 0.97174,
                        0.97085, 0.97194, 0.97088, 0.97106, 0.97099, 0.97107, 0.97156,
                        0.97027, 0.97044, 0.97174, 0.97137, 0.97243, 0.97229, 0.97152, 0.90799],
                       [0.96986, 0.96950, 0.97033, 0.96818, 0.96916, 0.96916, 0.97055,
                        0.96923, 0.96972, 0.96963, 0.96801, 0.96978, 0.96999, 0.96975,
                        0.96947, 0.96985, 0.96923, 0.96959, 0.96988, 0.96940, 0.97004,
                        0.97012, 0.96973, 0.96937, 0.97131, 0.97130, 0.97062, 0.97032, 0.90677],
                       [0.97461, 0.97396, 0.97592, 0.97446, 0.97492, 0.97452, 0.97511,
                        0.97483, 0.97433, 0.97520, 0.97279, 0.97455, 0.97453, 0.97418,
                        0.97478, 0.97472, 0.97334, 0.97448, 0.97451, 0.97428, 0.97487,
                        0.97602, 0.97578, 0.97399, 0.97664, 0.97475, 0.97479, 0.97614, 0.91086],
                       [0.97895, 0.97899, 0.98022, 0.98001, 0.97955, 0.97961, 0.97890,
                        0.97962, 0.97932, 0.97968, 0.97900, 0.97840, 0.97891, 0.97909,
                        0.97988, 0.97928, 0.97796, 0.97889, 0.97853, 0.97945, 0.97914,
                        0.97989, 0.98129, 0.97966, 0.98033, 0.97843, 0.97953, 0.98146, 0.91501],
                       [0.97736, 0.97691, 0.97651, 0.97663, 0.97578, 0.97717, 0.97579,
                        0.97688, 0.97694, 0.97656, 0.97788, 0.97529, 0.97646, 0.97701,
                        0.97759, 0.97675, 0.97663, 0.97632, 0.97591, 0.97677, 0.97682,
                        0.97604, 0.97820, 0.97776, 0.97606, 0.97639, 0.97802, 0.97849, 0.91325],
                       [0.97631, 0.97469, 0.97338, 0.97328, 0.97323, 0.97477, 0.97373,
                        0.97445, 0.97399, 0.97462, 0.97571, 0.97355, 0.97466, 0.97464,
                        0.97514, 0.97504, 0.97567, 0.97454, 0.97486, 0.97399, 0.97601,
                        0.97382, 0.97427, 0.97493, 0.97344, 0.97499, 0.97664, 0.97559, 0.91196],
                       [0.97677, 0.97557, 0.97556, 0.97504, 0.97560, 0.97566, 0.97627,
                        0.97579, 0.97453, 0.97723, 0.97639, 0.97652, 0.97690, 0.97610,
                        0.97636, 0.97655, 0.97764, 0.97619, 0.97823, 0.97568, 0.97832,
                        0.97656, 0.97574, 0.97663, 0.97692, 0.97735, 0.97800, 0.97686, 0.91417],
                       [0.97302, 0.97354, 0.97521, 0.97450, 0.97473, 0.97372, 0.97602,
                        0.97436, 0.97321, 0.97567, 0.97455, 0.97604, 0.97631, 0.97579,
                        0.97485, 0.97439, 0.97582, 0.97530, 0.97726, 0.97525, 0.97603,
                        0.97605, 0.97627, 0.97619, 0.97728, 0.97680, 0.97602, 0.97597, 0.91373],
                       [0.97185, 0.97293, 0.97399, 0.97397, 0.97423, 0.97320, 0.97521,
                        0.97347, 0.97358, 0.97355, 0.97358, 0.97442, 0.97545, 0.97590,
                        0.97410, 0.97375, 0.97419, 0.97523, 0.97524, 0.97499, 0.97415,
                        0.97486, 0.97615, 0.97507, 0.97640, 0.97626, 0.97501, 0.97583, 0.91303],
                       [0.97494, 0.97497, 0.97493, 0.97546, 0.97620, 0.97553, 0.97532,
                        0.97489, 0.97602, 0.97467, 0.97536, 0.97453, 0.97648, 0.97708,
                        0.97604, 0.97618, 0.97555, 0.97695, 0.97573, 0.97641, 0.97568,
                        0.97582, 0.97708, 0.97597, 0.97727, 0.97782, 0.97681, 0.97764, 0.91402],
                       [0.97548, 0.97542, 0.97544, 0.97568, 0.97602, 0.97583, 0.97420,
                        0.97493, 0.97537, 0.97524, 0.97612, 0.97398, 0.97613, 0.97580,
                        0.97613, 0.97616, 0.97602, 0.97697, 0.97547, 0.97594, 0.97611,
                        0.97639, 0.97659, 0.97633, 0.97703, 0.97773, 0.97755, 0.97778, 0.91413],
                       [0.97299, 0.97459, 0.97465, 0.97472, 0.97415, 0.97405, 0.97372,
                        0.97412, 0.97323, 0.97407, 0.97511, 0.97347, 0.97461, 0.97346,
                        0.97457, 0.97363, 0.97505, 0.97533, 0.97428, 0.97438, 0.97493,
                        0.97613, 0.97538, 0.97588, 0.97649, 0.97594, 0.97675, 0.97640, 0.91303],
                       [0.97257, 0.97487, 0.97417, 0.97477, 0.97401, 0.97458, 0.97505,
                        0.97487, 0.97373, 0.97361, 0.97436, 0.97465, 0.97472, 0.97391,
                        0.97452, 0.97377, 0.97493, 0.97495, 0.97482, 0.97504, 0.97553,
                        0.97619, 0.97604, 0.97687, 0.97759, 0.97591, 0.97640, 0.97613, 0.91271],
                       [0.97500, 0.97572, 0.97532, 0.97556, 0.97558, 0.97695, 0.97558,
                        0.97625, 0.97560, 0.97499, 0.97493, 0.97621, 0.97620, 0.97588,
                        0.97608, 0.97670, 0.97634, 0.97631, 0.97712, 0.97672, 0.97740,
                        0.97693, 0.97779, 0.97868, 0.97868, 0.97797, 0.97708, 0.97737, 0.91360],
                       [0.97691, 0.97569, 0.97637, 0.97536, 0.97672, 0.97685, 0.97480,
                        0.97575, 0.97600, 0.97612, 0.97578, 0.97639, 0.97712, 0.97609,
                        0.97703, 0.97737, 0.97733, 0.97676, 0.97810, 0.97677, 0.97765,
                        0.97726, 0.97858, 0.97866, 0.97789, 0.97875, 0.97740, 0.97760, 0.91365],
                       [0.97764, 0.97640, 0.97705, 0.97612, 0.97760, 0.97618, 0.97624,
                        0.97571, 0.97694, 0.97747, 0.97711, 0.97676, 0.97789, 0.97669,
                        0.97751, 0.97678, 0.97802, 0.97683, 0.97795, 0.97749, 0.97759,
                        0.97776, 0.97927, 0.97843, 0.97725, 0.97892, 0.97818, 0.97791, 0.91363],
                       [0.97678, 0.97660, 0.97682, 0.97688, 0.97705, 0.97616, 0.97767,
                        0.97639, 0.97758, 0.97793, 0.97688, 0.97670, 0.97719, 0.97711,
                        0.97717, 0.97683, 0.97766, 0.97660, 0.97696, 0.97783, 0.97738,
                        0.97757, 0.97871, 0.97796, 0.97641, 0.97839, 0.97823, 0.97823, 0.91362],
                       [0.97601, 0.97643, 0.97654, 0.97696, 0.97606, 0.97650, 0.97693,
                        0.97682, 0.97711, 0.97737, 0.97613, 0.97691, 0.97672, 0.97695,
                        0.97667, 0.97796, 0.97747, 0.97719, 0.97664, 0.97768, 0.97733,
                        0.97739, 0.97792, 0.97784, 0.97628, 0.97780, 0.97777, 0.97785, 0.91357],
                       [0.97813, 0.97853, 0.97838, 0.97886, 0.97817, 0.97841, 0.97760,
                        0.97815, 0.97836, 0.97877, 0.97848, 0.97910, 0.97920, 0.97901,
                        0.97851, 0.97961, 0.97927, 0.98019, 0.97910, 0.97925, 0.97905,
                        0.97918, 0.97975, 0.97982, 0.97921, 0.97902, 0.97946, 0.97865, 0.91491],
                       [0.97986, 0.97961, 0.97999, 0.97963, 0.98002, 0.97905, 0.97873,
                        0.97863, 0.97921, 0.97966, 0.98002, 0.97925, 0.98047, 0.98044,
                        0.97992, 0.97934, 0.97962, 0.98106, 0.98062, 0.97976, 0.97984,
                        0.97995, 0.98066, 0.98080, 0.98097, 0.97891, 0.98020, 0.97914, 0.91555],
                       [0.97794, 0.97762, 0.97873, 0.97690, 0.97816, 0.97662, 0.97802,
                        0.97692, 0.97724, 0.97784, 0.97799, 0.97680, 0.97800, 0.97838,
                        0.97854, 0.97781, 0.97697, 0.97819, 0.97873, 0.97765, 0.97790,
                        0.97794, 0.97861, 0.97863, 0.97848, 0.97685, 0.97797, 0.97731, 0.91407],
                       [0.97570, 0.97610, 0.97637, 0.97496, 0.97563, 0.97486, 0.97721,
                        0.97563, 0.97542, 0.97649, 0.97633, 0.97589, 0.97554, 0.97583,
                        0.97714, 0.97680, 0.97583, 0.97615, 0.97663, 0.97561, 0.97604,
                        0.97625, 0.97618, 0.97603, 0.97602, 0.97642, 0.97599, 0.97538, 0.91306],
                       [0.97620, 0.97668, 0.97562, 0.97655, 0.97563, 0.97643, 0.97760,
                        0.97657, 0.97581, 0.97702, 0.97708, 0.97708, 0.97582, 0.97564,
                        0.97732, 0.97682, 0.97755, 0.97662, 0.97689, 0.97571, 0.97650,
                        0.97711, 0.97600, 0.97609, 0.97638, 0.97793, 0.97645, 0.97611, 0.91364],
                       [0.97919, 0.97873, 0.97760, 0.97961, 0.97834, 0.97968, 0.97832,
                        0.97900, 0.97807, 0.97868, 0.97864, 0.97921, 0.97846, 0.97767,
                        0.97867, 0.97817, 0.97993, 0.97812, 0.97895, 0.97846, 0.97850,
                        0.97924, 0.97850, 0.97933, 0.97871, 0.97987, 0.97856, 0.97916, 0.91488],
                       [0.97922, 0.97833, 0.97773, 0.97862, 0.97865, 0.97869, 0.97602,
                        0.97840, 0.97795, 0.97809, 0.97681, 0.97825, 0.97863, 0.97767,
                        0.97791, 0.97740, 0.97852, 0.97757, 0.97768, 0.97882, 0.97752,
                        0.97837, 0.97856, 0.97935, 0.97840, 0.97870, 0.97772, 0.97899, 0.91376],
                       [0.97631, 0.97604, 0.97623, 0.97580, 0.97648, 0.97534, 0.97380,
                        0.97626, 0.97621, 0.97623, 0.97494, 0.97501, 0.97680, 0.97635,
                        0.97575, 0.97571, 0.97501, 0.97619, 0.97450, 0.97649, 0.97453,
                        0.97666, 0.97633, 0.97590, 0.97656, 0.97629, 0.97555, 0.97681, 0.91212],
                       [0.97433, 0.97456, 0.97542, 0.97490, 0.97481, 0.97407, 0.97430,
                        0.97494, 0.97532, 0.97488, 0.97549, 0.97340, 0.97485, 0.97536,
                        0.97432, 0.97499, 0.97354, 0.97491, 0.97323, 0.97503, 0.97334,
                        0.97618, 0.97492, 0.97430, 0.97558, 0.97529, 0.97523, 0.97546, 0.91207],
                       [0.97459, 0.97399, 0.97450, 0.97463, 0.97363, 0.97393, 0.97506,
                        0.97354, 0.97475, 0.97363, 0.97513, 0.97396, 0.97319, 0.97373,
                        0.97381, 0.97446, 0.97412, 0.97362, 0.97288, 0.97452, 0.97403,
                        0.97507, 0.97449, 0.97494, 0.97490, 0.97469, 0.97548, 0.97457, 0.91236],
                       [0.97845, 0.97724, 0.97680, 0.97742, 0.97605, 0.97685, 0.97775,
                        0.97639, 0.97729, 0.97627, 0.97719, 0.97784, 0.97663, 0.97605,
                        0.97716, 0.97746, 0.97816, 0.97657, 0.97626, 0.97705, 0.97800,
                        0.97718, 0.97756, 0.97842, 0.97734, 0.97781, 0.97816, 0.97773, 0.91512],
                       [0.98096, 0.98005, 0.97955, 0.98035, 0.97898, 0.97956, 0.98037,
                        0.98015, 0.97933, 0.97972, 0.97995, 0.98053, 0.98093, 0.98017,
                        0.98059, 0.98075, 0.98152, 0.97970, 0.97991, 0.97963, 0.98091,
                        0.98024, 0.98066, 0.98111, 0.97976, 0.98177, 0.98029, 0.98129, 0.91752],
                       [0.97762, 0.97676, 0.97696, 0.97738, 0.97630, 0.97677, 0.97808,
                        0.97755, 0.97639, 0.97736, 0.97713, 0.97723, 0.97806, 0.97839,
                        0.97781, 0.97793, 0.97873, 0.97712, 0.97745, 0.97771, 0.97787,
                        0.97764, 0.97801, 0.97771, 0.97734, 0.97939, 0.97708, 0.97851, 0.91461],
                       [0.97478, 0.97363, 0.97414, 0.97361, 0.97328, 0.97403, 0.97504,
                        0.97386, 0.97430, 0.97419, 0.97385, 0.97404, 0.97353, 0.97474,
                        0.97396, 0.97383, 0.97501, 0.97469, 0.97446, 0.97546, 0.97476,
                        0.97458, 0.97445, 0.97407, 0.97492, 0.97504, 0.97451, 0.97454, 0.91170],
                       [0.97570, 0.97439, 0.97477, 0.97406, 0.97365, 0.97450, 0.97457,
                        0.97376, 0.97502, 0.97447, 0.97409, 0.97454, 0.97314, 0.97417,
                        0.97372, 0.97318, 0.97390, 0.97508, 0.97434, 0.97538, 0.97525,
                        0.97543, 0.97429, 0.97544, 0.97536, 0.97404, 0.97614, 0.97439, 0.91210],
                       [0.97466, 0.97333, 0.97367, 0.97393, 0.97291, 0.97362, 0.97239,
                        0.97252, 0.97350, 0.97371, 0.97308, 0.97298, 0.97286, 0.97289,
                        0.97282, 0.97254, 0.97174, 0.97329, 0.97257, 0.97351, 0.97384,
                        0.97498, 0.97394, 0.97588, 0.97393, 0.97295, 0.97578, 0.97362, 0.91120],
                       [0.97463, 0.97426, 0.97458, 0.97478, 0.97393, 0.97499, 0.97343,
                        0.97371, 0.97444, 0.97508, 0.97447, 0.97370, 0.97503, 0.97445,
                        0.97424, 0.97459, 0.97350, 0.97352, 0.97420, 0.97430, 0.97421,
                        0.97575, 0.97693, 0.97621, 0.97520, 0.97430, 0.97616, 0.97508, 0.91197],
                       [0.97787, 0.97853, 0.97840, 0.97780, 0.97728, 0.97866, 0.97830,
                        0.97811, 0.97854, 0.97920, 0.97886, 0.97778, 0.97900, 0.97865,
                        0.97773, 0.97902, 0.97882, 0.97694, 0.97932, 0.97859, 0.97887,
                        0.97876, 0.98133, 0.97855, 0.98013, 0.97886, 0.97911, 0.97895, 0.91539],
                       [0.97753, 0.97750, 0.97738, 0.97668, 0.97675, 0.97746, 0.97770,
                        0.97776, 0.97770, 0.97795, 0.97825, 0.97711, 0.97712, 0.97685,
                        0.97646, 0.97755, 0.97835, 0.97707, 0.97889, 0.97841, 0.97980,
                        0.97785, 0.97902, 0.97799, 0.98023, 0.97890, 0.97825, 0.97812, 0.91472],
                       [0.97347, 0.97281, 0.97298, 0.97278, 0.97320, 0.97361, 0.97281,
                        0.97413, 0.97349, 0.97277, 0.97419, 0.97323, 0.97221, 0.97199,
                        0.97355, 0.97249, 0.97365, 0.97426, 0.97438, 0.97444, 0.97594,
                        0.97437, 0.97407, 0.97529, 0.97561, 0.97421, 0.97431, 0.97435, 0.91090],
                       [0.97193, 0.97203, 0.97203, 0.97219, 0.97254, 0.97351, 0.97119,
                        0.97343, 0.97279, 0.97106, 0.97342, 0.97233, 0.97180, 0.97192,
                        0.97423, 0.97200, 0.97244, 0.97350, 0.97300, 0.97363, 0.97363,
                        0.97418, 0.97384, 0.97512, 0.97314, 0.97228, 0.97288, 0.97427, 0.91003],
                       [0.97502, 0.97525, 0.97561, 0.97560, 0.97596, 0.97659, 0.97447,
                        0.97610, 0.97559, 0.97465, 0.97624, 0.97584, 0.97585, 0.97618,
                        0.97757, 0.97621, 0.97598, 0.97661, 0.97625, 0.97724, 0.97525,
                        0.97803, 0.97765, 0.97771, 0.97569, 0.97600, 0.97609, 0.97822, 0.91304],
                       [0.97669, 0.97675, 0.97713, 0.97718, 0.97759, 0.97690, 0.97637,
                        0.97668, 0.97573, 0.97670, 0.97734, 0.97757, 0.97734, 0.97774,
                        0.97788, 0.97783, 0.97726, 0.97820, 0.97821, 0.97774, 0.97632,
                        0.97892, 0.97862, 0.97752, 0.97811, 0.97847, 0.97891, 0.97903, 0.91493],
                       [0.97609, 0.97634, 0.97616, 0.97663, 0.97639, 0.97614, 0.97607,
                        0.97551, 0.97465, 0.97600, 0.97696, 0.97665, 0.97676, 0.97647,
                        0.97629, 0.97683, 0.97635, 0.97699, 0.97709, 0.97552, 0.97652,
                        0.97665, 0.97707, 0.97623, 0.97826, 0.97765, 0.97929, 0.97746, 0.91480],
                       [0.97679, 0.97782, 0.97743, 0.97787, 0.97698, 0.97785, 0.97749,
                        0.97642, 0.97692, 0.97734, 0.97796, 0.97784, 0.97829, 0.97660,
                        0.97741, 0.97739, 0.97784, 0.97697, 0.97684, 0.97668, 0.97830,
                        0.97687, 0.97759, 0.97806, 0.97872, 0.97751, 0.97950, 0.97857, 0.91503],
                       [0.97687, 0.97792, 0.97783, 0.97778, 0.97724, 0.97767, 0.97758,
                        0.97629, 0.97769, 0.97784, 0.97705, 0.97779, 0.97814, 0.97595,
                        0.97785, 0.97731, 0.97789, 0.97634, 0.97615, 0.97752, 0.97815,
                        0.97690, 0.97758, 0.97795, 0.97788, 0.97682, 0.97806, 0.97886, 0.91415],
                       [0.97614, 0.97580, 0.97627, 0.97581, 0.97630, 0.97549, 0.97573,
                        0.97493, 0.97603, 0.97606, 0.97470, 0.97544, 0.97595, 0.97452,
                        0.97649, 0.97619, 0.97594, 0.97517, 0.97494, 0.97659, 0.97644,
                        0.97538, 0.97629, 0.97528, 0.97586, 0.97588, 0.97629, 0.97736, 0.91330],
                       [0.97451, 0.97377, 0.97464, 0.97423, 0.97523, 0.97424, 0.97399,
                        0.97350, 0.97483, 0.97369, 0.97344, 0.97315, 0.97414, 0.97376,
                        0.97474, 0.97454, 0.97424, 0.97437, 0.97366, 0.97537, 0.97497,
                        0.97409, 0.97458, 0.97348, 0.97396, 0.97566, 0.97524, 0.97599, 0.91310],
                       [0.97636, 0.97643, 0.97751, 0.97795, 0.97816, 0.97819, 0.97725,
                        0.97628, 0.97829, 0.97641, 0.97731, 0.97683, 0.97661, 0.97772,
                        0.97693, 0.97683, 0.97695, 0.97693, 0.97673, 0.97729, 0.97733,
                        0.97740, 0.97715, 0.97741, 0.97666, 0.97945, 0.97773, 0.97904, 0.91581],
                       [0.97878, 0.97844, 0.97928, 0.98047, 0.97976, 0.98044, 0.97926,
                        0.97914, 0.98009, 0.97893, 0.97977, 0.98066, 0.97822, 0.97966,
                        0.97813, 0.97825, 0.97845, 0.97777, 0.97871, 0.97773, 0.97842,
                        0.97899, 0.97944, 0.98028, 0.97863, 0.98077, 0.97911, 0.98000, 0.91706],
                       [0.97752, 0.97595, 0.97593, 0.97716, 0.97629, 0.97717, 0.97574,
                        0.97767, 0.97627, 0.97629, 0.97679, 0.97809, 0.97583, 0.97593,
                        0.97542, 0.97547, 0.97608, 0.97486, 0.97547, 0.97507, 0.97596,
                        0.97491, 0.97664, 0.97705, 0.97631, 0.97680, 0.97691, 0.97574, 0.91412],
                       [0.97902, 0.97742, 0.97788, 0.97759, 0.97742, 0.97816, 0.97673,
                        0.97914, 0.97670, 0.97736, 0.97769, 0.97779, 0.97704, 0.97668,
                        0.97697, 0.97716, 0.97850, 0.97708, 0.97687, 0.97771, 0.97813,
                        0.97605, 0.97735, 0.97725, 0.97815, 0.97805, 0.97894, 0.97664, 0.91460],
                       [0.97992, 0.97986, 0.98142, 0.97953, 0.98077, 0.98064, 0.97999,
                        0.98064, 0.97945, 0.97931, 0.97982, 0.97877, 0.97896, 0.97911,
                        0.97888, 0.97946, 0.98077, 0.97975, 0.97932, 0.98032, 0.97986,
                        0.97970, 0.97933, 0.97936, 0.98006, 0.98055, 0.98112, 0.97982, 0.91633],
                       [0.97709, 0.97859, 0.97933, 0.97838, 0.97992, 0.97856, 0.97922,
                        0.97769, 0.97857, 0.97667, 0.97832, 0.97735, 0.97722, 0.97810,
                        0.97707, 0.97711, 0.97762, 0.97731, 0.97701, 0.97817, 0.97689,
                        0.97884, 0.97785, 0.97780, 0.97798, 0.97817, 0.97850, 0.97882, 0.91559],
                       [0.97511, 0.97630, 0.97542, 0.97643, 0.97635, 0.97495, 0.97602,
                        0.97440, 0.97594, 0.97370, 0.97583, 0.97541, 0.97434, 0.97579,
                        0.97478, 0.97378, 0.97394, 0.97421, 0.97394, 0.97562, 0.97426,
                        0.97618, 0.97525, 0.97473, 0.97555, 0.97498, 0.97488, 0.97548, 0.91387],
                       [0.97713, 0.97676, 0.97630, 0.97701, 0.97596, 0.97568, 0.97575,
                        0.97589, 0.97619, 0.97577, 0.97584, 0.97566, 0.97492, 0.97620,
                        0.97622, 0.97508, 0.97510, 0.97530, 0.97466, 0.97655, 0.97599,
                        0.97642, 0.97555, 0.97528, 0.97591, 0.97601, 0.97500, 0.97445, 0.91346],
                       [0.98039, 0.97929, 0.98067, 0.97983, 0.97974, 0.97996, 0.97908,
                        0.98033, 0.97865, 0.98012, 0.97811, 0.97845, 0.97865, 0.97922,
                        0.98001, 0.98021, 0.97942, 0.97907, 0.97820, 0.97964, 0.97969,
                        0.97905, 0.97852, 0.97959, 0.97867, 0.97929, 0.97810, 0.97598, 0.91407],
                       [0.97937, 0.97915, 0.98110, 0.98003, 0.98084, 0.98088, 0.98010,
                        0.98088, 0.97917, 0.98024, 0.97861, 0.97900, 0.98004, 0.97944,
                        0.98064, 0.98128, 0.97997, 0.97941, 0.97917, 0.97962, 0.97977,
                        0.97949, 0.97949, 0.98064, 0.97967, 0.97864, 0.97816, 0.97585, 0.91231],
                       [0.97605, 0.97677, 0.97663, 0.97704, 0.97779, 0.97765, 0.97743,
                        0.97693, 0.97732, 0.97642, 0.97682, 0.97647, 0.97754, 0.97640,
                        0.97794, 0.97695, 0.97660, 0.97588, 0.97681, 0.97618, 0.97663,
                        0.97714, 0.97752, 0.97660, 0.97763, 0.97498, 0.97497, 0.97404, 0.90931],
                       [0.97835, 0.97864, 0.97649, 0.97776, 0.97823, 0.97850, 0.97832,
                        0.97721, 0.97837, 0.97691, 0.97825, 0.97797, 0.97780, 0.97761,
                        0.97913, 0.97657, 0.97723, 0.97670, 0.97777, 0.97741, 0.97737,
                        0.97836, 0.97852, 0.97645, 0.97914, 0.97629, 0.97680, 0.97631, 0.91143],
                       [0.98175, 0.98135, 0.97984, 0.97955, 0.98008, 0.98027, 0.98017,
                        0.98046, 0.98039, 0.98025, 0.98026, 0.98073, 0.97960, 0.98066,
                        0.98123, 0.97928, 0.97965, 0.97966, 0.97977, 0.98115, 0.97948,
                        0.98105, 0.98045, 0.97911, 0.98143, 0.97950, 0.98002, 0.97875, 0.91535],
                       [0.97741, 0.97769, 0.97800, 0.97565, 0.97668, 0.97556, 0.97599,
                        0.97747, 0.97703, 0.97840, 0.97710, 0.97736, 0.97635, 0.97793,
                        0.97680, 0.97654, 0.97668, 0.97689, 0.97622, 0.97873, 0.97663,
                        0.97811, 0.97755, 0.97614, 0.97704, 0.97657, 0.97634, 0.97511, 0.91322],
                       [0.97358, 0.97517, 0.97609, 0.97427, 0.97495, 0.97348, 0.97385,
                        0.97490, 0.97534, 0.97657, 0.97565, 0.97507, 0.97461, 0.97567,
                        0.97447, 0.97475, 0.97469, 0.97545, 0.97469, 0.97658, 0.97522,
                        0.97546, 0.97657, 0.97491, 0.97451, 0.97475, 0.97437, 0.97427, 0.91128],
                       [0.97377, 0.97545, 0.97541, 0.97565, 0.97543, 0.97472, 0.97502,
                        0.97551, 0.97623, 0.97616, 0.97544, 0.97490, 0.97535, 0.97499,
                        0.97576, 0.97586, 0.97464, 0.97597, 0.97520, 0.97637, 0.97524,
                        0.97475, 0.97728, 0.97624, 0.97557, 0.97551, 0.97565, 0.97587, 0.91166],
                       [0.97366, 0.97483, 0.97331, 0.97472, 0.97429, 0.97425, 0.97538,
                        0.97493, 0.97520, 0.97487, 0.97367, 0.97349, 0.97483, 0.97356,
                        0.97538, 0.97581, 0.97347, 0.97449, 0.97399, 0.97483, 0.97399,
                        0.97411, 0.97571, 0.97555, 0.97524, 0.97496, 0.97507, 0.97479, 0.91187],
                       [0.97318, 0.97437, 0.97281, 0.97407, 0.97395, 0.97397, 0.97513,
                        0.97459, 0.97467, 0.97452, 0.97375, 0.97362, 0.97419, 0.97359,
                        0.97478, 0.97564, 0.97407, 0.97386, 0.97419, 0.97466, 0.97399,
                        0.97450, 0.97467, 0.97580, 0.97529, 0.97510, 0.97480, 0.97438, 0.91291],
                       [0.97188, 0.97331, 0.97319, 0.97316, 0.97369, 0.97315, 0.97353,
                        0.97341, 0.97388, 0.97310, 0.97384, 0.97380, 0.97265, 0.97324,
                        0.97318, 0.97419, 0.97486, 0.97309, 0.97416, 0.97472, 0.97366,
                        0.97375, 0.97362, 0.97527, 0.97466, 0.97458, 0.97429, 0.97437, 0.91273],
                       [0.97266, 0.97392, 0.97497, 0.97406, 0.97490, 0.97356, 0.97418,
                        0.97344, 0.97414, 0.97324, 0.97431, 0.97419, 0.97298, 0.97384,
                        0.97316, 0.97351, 0.97524, 0.97402, 0.97446, 0.97521, 0.97440,
                        0.97447, 0.97416, 0.97502, 0.97510, 0.97507, 0.97482, 0.97525, 0.91306],
                       [0.97514, 0.97607, 0.97635, 0.97634, 0.97665, 0.97542, 0.97608,
                        0.97571, 0.97554, 0.97555, 0.97535, 0.97455, 0.97523, 0.97534,
                        0.97546, 0.97468, 0.97552, 0.97600, 0.97510, 0.97537, 0.97625,
                        0.97666, 0.97646, 0.97610, 0.97670, 0.97651, 0.97691, 0.97644, 0.91461],
                       [0.97485, 0.97569, 0.97455, 0.97530, 0.97567, 0.97544, 0.97454,
                        0.97542, 0.97419, 0.97449, 0.97389, 0.97357, 0.97518, 0.97413,
                        0.97480, 0.97429, 0.97400, 0.97504, 0.97362, 0.97304, 0.97465,
                        0.97517, 0.97603, 0.97456, 0.97557, 0.97504, 0.97622, 0.97478, 0.91317],
                       [0.97273, 0.97342, 0.97227, 0.97246, 0.97356, 0.97380, 0.97207,
                        0.97257, 0.97139, 0.97182, 0.97131, 0.97238, 0.97307, 0.97128,
                        0.97194, 0.97258, 0.97208, 0.97260, 0.97146, 0.97107, 0.97104,
                        0.97132, 0.97257, 0.97145, 0.97280, 0.97266, 0.97322, 0.97221, 0.90983],
                       [0.97107, 0.97116, 0.97107, 0.97088, 0.97133, 0.97148, 0.97107,
                        0.97038, 0.97025, 0.97074, 0.96966, 0.97118, 0.97096, 0.96973,
                        0.96999, 0.97064, 0.97014, 0.97046, 0.96988, 0.97048, 0.96887,
                        0.96880, 0.96921, 0.97013, 0.97080, 0.97166, 0.97080, 0.97110, 0.90852],
                       [0.97173, 0.97136, 0.97164, 0.97199, 0.97085, 0.97110, 0.97223,
                        0.97159, 0.97192, 0.97171, 0.97058, 0.97152, 0.97138, 0.97150,
                        0.97064, 0.97042, 0.96972, 0.97042, 0.97072, 0.97131, 0.97024,
                        0.96974, 0.96997, 0.97192, 0.97181, 0.97259, 0.97129, 0.97253, 0.91041],
                       [0.97761, 0.97791, 0.97724, 0.97799, 0.97675, 0.97723, 0.97788,
                        0.97790, 0.97797, 0.97713, 0.97733, 0.97732, 0.97706, 0.97793,
                        0.97673, 0.97614, 0.97574, 0.97645, 0.97718, 0.97679, 0.97750,
                        0.97653, 0.97750, 0.97785, 0.97863, 0.97806, 0.97766, 0.97854, 0.91610],
                       [0.98136, 0.98252, 0.98134, 0.98152, 0.98111, 0.98119, 0.98079,
                        0.98095, 0.98117, 0.98075, 0.98150, 0.98116, 0.97971, 0.98043,
                        0.98110, 0.97962, 0.98057, 0.98094, 0.98054, 0.98019, 0.98173,
                        0.98123, 0.98175, 0.98084, 0.98297, 0.98148, 0.98206, 0.98179, 0.91925],
                       [0.97988, 0.98147, 0.98040, 0.98026, 0.98015, 0.97988, 0.97933,
                        0.97931, 0.97929, 0.97980, 0.97944, 0.97981, 0.97769, 0.97807,
                        0.98035, 0.97805, 0.97944, 0.97979, 0.97841, 0.97898, 0.97942,
                        0.98032, 0.97970, 0.97931, 0.98138, 0.98012, 0.98103, 0.97976, 0.91813],
                       [0.98004, 0.98121, 0.98021, 0.98055, 0.98039, 0.98062, 0.98005,
                        0.97983, 0.97865, 0.98046, 0.97915, 0.97947, 0.97831, 0.97862,
                        0.98057, 0.97867, 0.97891, 0.97961, 0.97830, 0.97965, 0.97835,
                        0.97958, 0.97906, 0.97991, 0.98085, 0.98030, 0.98036, 0.97946, 0.91761],
                       [0.97875, 0.97886, 0.97909, 0.97882, 0.97906, 0.97939, 0.97880,
                        0.97834, 0.97686, 0.97945, 0.97854, 0.97765, 0.97779, 0.97768,
                        0.97821, 0.97821, 0.97737, 0.97796, 0.97736, 0.97893, 0.97729,
                        0.97727, 0.97743, 0.97897, 0.97947, 0.97850, 0.97768, 0.97827, 0.91535],
                       [0.97301, 0.97209, 0.97441, 0.97337, 0.97322, 0.97336, 0.97311,
                        0.97249, 0.97240, 0.97395, 0.97375, 0.97254, 0.97306, 0.97160,
                        0.97178, 0.97231, 0.97275, 0.97239, 0.97254, 0.97343, 0.97298,
                        0.97203, 0.97234, 0.97355, 0.97399, 0.97247, 0.97218, 0.97334, 0.91018],
                       [0.97055, 0.96970, 0.97114, 0.97123, 0.96986, 0.97086, 0.97092,
                        0.97060, 0.97149, 0.97079, 0.97124, 0.97095, 0.97138, 0.96968,
                        0.96995, 0.96898, 0.97096, 0.97033, 0.97027, 0.97002, 0.97093,
                        0.97045, 0.97069, 0.97128, 0.97051, 0.97073, 0.97087, 0.97045, 0.90788],
                       [0.97380, 0.97438, 0.97297, 0.97365, 0.97267, 0.97395, 0.97401,
                        0.97402, 0.97509, 0.97259, 0.97383, 0.97436, 0.97476, 0.97492,
                        0.97399, 0.97308, 0.97368, 0.97381, 0.97317, 0.97183, 0.97378,
                        0.97401, 0.97408, 0.97494, 0.97252, 0.97418, 0.97429, 0.97196, 0.90968],
                       [0.97554, 0.97754, 0.97615, 0.97523, 0.97596, 0.97674, 0.97633,
                        0.97662, 0.97732, 0.97465, 0.97625, 0.97703, 0.97684, 0.97823,
                        0.97653, 0.97707, 0.97642, 0.97630, 0.97601, 0.97407, 0.97658,
                        0.97672, 0.97662, 0.97753, 0.97562, 0.97609, 0.97559, 0.97359, 0.91129],
                       [0.97530, 0.97744, 0.97738, 0.97575, 0.97673, 0.97842, 0.97729,
                        0.97779, 0.97726, 0.97601, 0.97695, 0.97745, 0.97685, 0.97743,
                        0.97685, 0.97718, 0.97753, 0.97622, 0.97727, 0.97632, 0.97740,
                        0.97770, 0.97761, 0.97663, 0.97755, 0.97637, 0.97504, 0.97378, 0.91229],
                       [0.97362, 0.97473, 0.97435, 0.97405, 0.97414, 0.97626, 0.97532,
                        0.97550, 0.97444, 0.97500, 0.97461, 0.97446, 0.97465, 0.97475,
                        0.97434, 0.97367, 0.97434, 0.97335, 0.97550, 0.97576, 0.97473,
                        0.97545, 0.97559, 0.97313, 0.97521, 0.97392, 0.97328, 0.97166, 0.91032],
                       [0.96914, 0.96889, 0.96789, 0.96827, 0.96820, 0.96842, 0.96838,
                        0.96863, 0.96837, 0.97012, 0.96851, 0.96816, 0.96880, 0.96951,
                        0.96858, 0.96758, 0.96741, 0.96810, 0.96927, 0.96970, 0.96859,
                        0.96875, 0.96913, 0.96729, 0.96798, 0.96748, 0.96793, 0.96649, 0.90356],
                       [0.96717, 0.96646, 0.96661, 0.96568, 0.96644, 0.96430, 0.96540,
                        0.96512, 0.96641, 0.96782, 0.96606, 0.96689, 0.96605, 0.96690,
                        0.96660, 0.96578, 0.96591, 0.96690, 0.96602, 0.96666, 0.96689,
                        0.96659, 0.96582, 0.96594, 0.96517, 0.96517, 0.96563, 0.96476, 0.90095],
                       [0.97161, 0.97159, 0.97245, 0.97130, 0.97246, 0.97022, 0.97100,
                        0.97028, 0.97217, 0.97206, 0.97169, 0.97295, 0.97134, 0.97125,
                        0.97194, 0.97190, 0.97242, 0.97246, 0.97116, 0.97185, 0.97286,
                        0.97316, 0.97081, 0.97244, 0.97157, 0.97113, 0.97090, 0.97062, 0.90768],
                       [0.97553, 0.97587, 0.97546, 0.97529, 0.97632, 0.97605, 0.97525,
                        0.97517, 0.97635, 0.97479, 0.97615, 0.97578, 0.97577, 0.97525,
                        0.97562, 0.97635, 0.97669, 0.97589, 0.97610, 0.97568, 0.97653,
                        0.97714, 0.97558, 0.97678, 0.97685, 0.97539, 0.97415, 0.97545, 0.91369],
                       [0.97296, 0.97272, 0.97278, 0.97132, 0.97270, 0.97399, 0.97230,
                        0.97301, 0.97315, 0.97132, 0.97277, 0.97130, 0.97331, 0.97325,
                        0.97226, 0.97312, 0.97303, 0.97237, 0.97364, 0.97221, 0.97298,
                        0.97293, 0.97374, 0.97277, 0.97331, 0.97216, 0.97093, 0.97304, 0.91162],
                       [0.96597, 0.96600, 0.96791, 0.96530, 0.96658, 0.96764, 0.96649,
                        0.96721, 0.96625, 0.96483, 0.96530, 0.96479, 0.96710, 0.96698,
                        0.96631, 0.96636, 0.96557, 0.96596, 0.96618, 0.96540, 0.96595,
                        0.96540, 0.96803, 0.96554, 0.96529, 0.96606, 0.96625, 0.96671, 0.90526],
                       [0.95996, 0.96125, 0.96217, 0.96145, 0.96146, 0.96118, 0.96153,
                        0.96176, 0.95997, 0.95904, 0.95930, 0.96018, 0.96136, 0.95999,
                        0.96116, 0.96047, 0.95971, 0.96059, 0.95972, 0.95967, 0.95954,
                        0.95945, 0.96257, 0.96052, 0.95890, 0.96167, 0.96193, 0.96153, 0.90081],
                       [0.96492, 0.96616, 0.96479, 0.96646, 0.96523, 0.96408, 0.96504,
                        0.96504, 0.96418, 0.96440, 0.96399, 0.96501, 0.96523, 0.96373,
                        0.96520, 0.96442, 0.96476, 0.96460, 0.96502, 0.96439, 0.96380,
                        0.96405, 0.96622, 0.96564, 0.96413, 0.96646, 0.96539, 0.96602, 0.90584],
                       [0.97321, 0.97321, 0.97281, 0.97434, 0.97293, 0.97257, 0.97256,
                        0.97266, 0.97354, 0.97431, 0.97298, 0.97323, 0.97309, 0.97276,
                        0.97336, 0.97323, 0.97368, 0.97291, 0.97393, 0.97305, 0.97294,
                        0.97292, 0.97393, 0.97371, 0.97357, 0.97405, 0.97299, 0.97396, 0.91315],
                       [0.97227, 0.97159, 0.97299, 0.97303, 0.97289, 0.97306, 0.97242,
                        0.97255, 0.97377, 0.97311, 0.97285, 0.97241, 0.97228, 0.97206,
                        0.97273, 0.97369, 0.97294, 0.97301, 0.97264, 0.97217, 0.97325,
                        0.97303, 0.97314, 0.97230, 0.97374, 0.97286, 0.97315, 0.97357, 0.91201],
                       [0.96771, 0.96720, 0.96854, 0.96757, 0.96870, 0.96795, 0.96838,
                        0.96803, 0.96855, 0.96653, 0.96833, 0.96754, 0.96793, 0.96727,
                        0.96819, 0.96933, 0.96774, 0.96850, 0.96696, 0.96735, 0.96889,
                        0.96878, 0.96776, 0.96757, 0.96992, 0.96769, 0.96979, 0.96943, 0.90792],
                       [0.96506, 0.96449, 0.96475, 0.96385, 0.96500, 0.96424, 0.96463,
                        0.96430, 0.96444, 0.96276, 0.96500, 0.96460, 0.96512, 0.96481,
                        0.96520, 0.96586, 0.96467, 0.96462, 0.96336, 0.96476, 0.96478,
                        0.96576, 0.96385, 0.96507, 0.96647, 0.96539, 0.96732, 0.96658, 0.90541],
                       [0.96616, 0.96478, 0.96481, 0.96458, 0.96514, 0.96573, 0.96411,
                        0.96494, 0.96484, 0.96470, 0.96463, 0.96566, 0.96514, 0.96575,
                        0.96448, 0.96551, 0.96566, 0.96438, 0.96448, 0.96562, 0.96457,
                        0.96580, 0.96506, 0.96589, 0.96570, 0.96773, 0.96767, 0.96734, 0.90611],
                       [0.96650, 0.96479, 0.96554, 0.96630, 0.96576, 0.96670, 0.96417,
                        0.96570, 0.96609, 0.96644, 0.96395, 0.96563, 0.96512, 0.96651,
                        0.96342, 0.96475, 0.96568, 0.96477, 0.96535, 0.96563, 0.96570,
                        0.96545, 0.96660, 0.96637, 0.96675, 0.96872, 0.96788, 0.96824, 0.90687],
                       [0.96726, 0.96646, 0.96733, 0.96963, 0.96777, 0.96768, 0.96650,
                        0.96717, 0.96820, 0.96809, 0.96617, 0.96634, 0.96778, 0.96896,
                        0.96610, 0.96669, 0.96758, 0.96759, 0.96700, 0.96798, 0.96817,
                        0.96849, 0.96962, 0.96945, 0.97031, 0.97045, 0.97007, 0.97063, 0.90950],
                       [0.96993, 0.97008, 0.97070, 0.97295, 0.97147, 0.97018, 0.97117,
                        0.97064, 0.97092, 0.97094, 0.97106, 0.96948, 0.97223, 0.97176,
                        0.97182, 0.97135, 0.97225, 0.97193, 0.97092, 0.97280, 0.97169,
                        0.97347, 0.97408, 0.97463, 0.97389, 0.97457, 0.97369, 0.97427, 0.91251],
                       [0.96974, 0.97031, 0.97119, 0.97132, 0.97162, 0.97054, 0.97194,
                        0.97073, 0.96981, 0.97008, 0.97152, 0.97004, 0.97145, 0.96992,
                        0.97220, 0.97166, 0.97241, 0.97182, 0.97190, 0.97292, 0.97139,
                        0.97239, 0.97377, 0.97383, 0.97302, 0.97474, 0.97277, 0.97333, 0.91077],
                       [0.96867, 0.97017, 0.97042, 0.96904, 0.97085, 0.97073, 0.97099,
                        0.96887, 0.96868, 0.96866, 0.97076, 0.97015, 0.96868, 0.96873,
                        0.97026, 0.97037, 0.97045, 0.97017, 0.97159, 0.97057, 0.97028,
                        0.97079, 0.97201, 0.97122, 0.97172, 0.97286, 0.97168, 0.97147, 0.90923],
                       [0.96999, 0.97218, 0.97139, 0.97061, 0.97226, 0.97226, 0.97170,
                        0.97002, 0.97123, 0.97098, 0.97277, 0.97207, 0.96923, 0.97160,
                        0.97129, 0.97223, 0.97101, 0.97092, 0.97262, 0.97072, 0.97245,
                        0.97369, 0.97339, 0.97279, 0.97284, 0.97360, 0.97365, 0.97244, 0.91130],
                       [0.97348, 0.97552, 0.97391, 0.97460, 0.97452, 0.97403, 0.97392,
                        0.97527, 0.97560, 0.97488, 0.97530, 0.97491, 0.97366, 0.97508,
                        0.97459, 0.97593, 0.97434, 0.97424, 0.97554, 0.97469, 0.97679,
                        0.97787, 0.97713, 0.97701, 0.97632, 0.97734, 0.97612, 0.97511, 0.91468],
                       [0.97521, 0.97654, 0.97486, 0.97543, 0.97442, 0.97404, 0.97494,
                        0.97759, 0.97674, 0.97550, 0.97507, 0.97604, 0.97648, 0.97524,
                        0.97572, 0.97595, 0.97586, 0.97660, 0.97725, 0.97729, 0.97788,
                        0.97866, 0.97822, 0.97823, 0.97825, 0.97844, 0.97647, 0.97631, 0.91528],
                       [0.97264, 0.97364, 0.97252, 0.97199, 0.97136, 0.97215, 0.97275,
                        0.97341, 0.97279, 0.97225, 0.97206, 0.97328, 0.97438, 0.97229,
                        0.97328, 0.97206, 0.97345, 0.97486, 0.97483, 0.97515, 0.97412,
                        0.97481, 0.97564, 0.97468, 0.97533, 0.97434, 0.97343, 0.97330, 0.91219],
                       [0.96918, 0.97078, 0.96965, 0.96893, 0.96884, 0.97095, 0.97024,
                        0.96895, 0.96894, 0.96942, 0.97024, 0.96976, 0.97050, 0.97042,
                        0.97010, 0.96942, 0.97093, 0.97187, 0.97122, 0.97206, 0.97125,
                        0.97052, 0.97312, 0.97105, 0.97151, 0.97015, 0.96998, 0.96975, 0.90928],
                       [0.96735, 0.96948, 0.96836, 0.96796, 0.96786, 0.96945, 0.96869,
                        0.96732, 0.96788, 0.96860, 0.96942, 0.96763, 0.96791, 0.96930,
                        0.96796, 0.96839, 0.96937, 0.96947, 0.96873, 0.96980, 0.97029,
                        0.96899, 0.97060, 0.96942, 0.96897, 0.96822, 0.96818, 0.96883, 0.90778],
                       [0.96757, 0.96931, 0.96925, 0.96851, 0.96775, 0.96799, 0.96843,
                        0.96782, 0.96882, 0.96896, 0.96893, 0.96764, 0.96813, 0.96824,
                        0.96841, 0.96843, 0.96899, 0.96870, 0.96843, 0.96923, 0.96955,
                        0.96996, 0.96852, 0.96957, 0.96820, 0.96869, 0.96825, 0.96943, 0.90779],
                       [0.96963, 0.96968, 0.97046, 0.96955, 0.96892, 0.96833, 0.96949,
                        0.96976, 0.97037, 0.96946, 0.96963, 0.96985, 0.97030, 0.96855,
                        0.96986, 0.96987, 0.96993, 0.96986, 0.96974, 0.97025, 0.97047,
                        0.97130, 0.96925, 0.97022, 0.96942, 0.97061, 0.96903, 0.96984, 0.90859],
                       [0.97126, 0.96943, 0.96984, 0.96956, 0.97009, 0.96917, 0.96966,
                        0.97026, 0.97063, 0.96935, 0.96987, 0.97107, 0.97117, 0.96934,
                        0.96956, 0.97054, 0.97027, 0.97111, 0.97049, 0.97054, 0.97183,
                        0.97117, 0.97072, 0.97018, 0.97084, 0.97097, 0.96902, 0.96981, 0.90958],
                       [0.96987, 0.96891, 0.96893, 0.96880, 0.97052, 0.96985, 0.96821,
                        0.96904, 0.96948, 0.96917, 0.96933, 0.96963, 0.97004, 0.96891,
                        0.96899, 0.96958, 0.96930, 0.97044, 0.96988, 0.96929, 0.97165,
                        0.96979, 0.96997, 0.96988, 0.97132, 0.96960, 0.96946, 0.97052, 0.91092],
                       [0.96703, 0.96855, 0.96861, 0.96811, 0.97003, 0.96983, 0.96688,
                        0.96842, 0.96816, 0.96909, 0.96880, 0.96764, 0.96862, 0.96748,
                        0.96912, 0.96808, 0.96846, 0.96825, 0.96872, 0.96771, 0.97059,
                        0.96840, 0.96818, 0.96942, 0.97036, 0.96890, 0.97037, 0.97093, 0.90982],
                       [0.96639, 0.96860, 0.96828, 0.96809, 0.96935, 0.96884, 0.96707,
                        0.96853, 0.96765, 0.96937, 0.96830, 0.96728, 0.96777, 0.96686,
                        0.96826, 0.96713, 0.96840, 0.96701, 0.96788, 0.96647, 0.96899,
                        0.96750, 0.96754, 0.96858, 0.96891, 0.96858, 0.97012, 0.96936, 0.90679],
                       [0.96982, 0.97011, 0.96956, 0.97001, 0.97071, 0.96864, 0.96988,
                        0.97027, 0.96942, 0.97115, 0.96944, 0.96947, 0.96838, 0.96895,
                        0.96861, 0.96838, 0.96990, 0.96878, 0.96854, 0.96761, 0.96880,
                        0.96843, 0.96923, 0.96910, 0.97006, 0.96951, 0.97022, 0.96874, 0.90672],
                       [0.97378, 0.97193, 0.97188, 0.97202, 0.97246, 0.97006, 0.97343,
                        0.97223, 0.97285, 0.97247, 0.97208, 0.97292, 0.97008, 0.97263,
                        0.97244, 0.97152, 0.97275, 0.97254, 0.97205, 0.97286, 0.97164,
                        0.97210, 0.97355, 0.97299, 0.97410, 0.97400, 0.97342, 0.97305, 0.91191],
                       [0.96923, 0.96880, 0.96883, 0.96897, 0.96842, 0.96946, 0.96987,
                        0.96907, 0.97070, 0.96939, 0.97017, 0.97052, 0.96909, 0.97080,
                        0.97193, 0.97108, 0.97202, 0.97178, 0.97299, 0.97392, 0.97278,
                        0.97345, 0.97429, 0.97584, 0.97515, 0.97660, 0.97614, 0.97727, 0.91671],
                       [0.97116, 0.97201, 0.97167, 0.97206, 0.97160, 0.97304, 0.97201,
                        0.97228, 0.97276, 0.97300, 0.97288, 0.97237, 0.97298, 0.97289,
                        0.97412, 0.97428, 0.97483, 0.97450, 0.97542, 0.97570, 0.97593,
                        0.97649, 0.97685, 0.97868, 0.97794, 0.97900, 0.97916, 0.98017, 0.91962],
                       [0.97562, 0.97654, 0.97606, 0.97634, 0.97654, 0.97686, 0.97625,
                        0.97647, 0.97628, 0.97732, 0.97656, 0.97599, 0.97696, 0.97650,
                        0.97755, 0.97769, 0.97787, 0.97789, 0.97782, 0.97803, 0.97847,
                        0.97876, 0.97918, 0.98021, 0.97988, 0.98038, 0.98055, 0.98118, 0.92025],
                       [0.97840, 0.97895, 0.97830, 0.97878, 0.97917, 0.97863, 0.97882,
                        0.97838, 0.97792, 0.97924, 0.97839, 0.97822, 0.97856, 0.97861,
                        0.97921, 0.97893, 0.97891, 0.97916, 0.97833, 0.97849, 0.97895,
                        0.97869, 0.97929, 0.97950, 0.97939, 0.97950, 0.97950, 0.97953, 0.91832],
                       [0.98097, 0.98065, 0.97980, 0.98111, 0.98082, 0.97995, 0.98095,
                        0.98003, 0.97926, 0.98024, 0.98013, 0.98064, 0.97967, 0.98058,
                        0.98031, 0.97994, 0.97982, 0.97992, 0.97867, 0.97856, 0.97945,
                        0.97816, 0.97926, 0.97888, 0.97881, 0.97858, 0.97850, 0.97747, 0.91601],
                       [0.98187, 0.98015, 0.97959, 0.98155, 0.97998, 0.97975, 0.98093,
                        0.98063, 0.97989, 0.97946, 0.98120, 0.98170, 0.97994, 0.98068,
                        0.97954, 0.98045, 0.98056, 0.97944, 0.97864, 0.97823, 0.97956,
                        0.97741, 0.97953, 0.97967, 0.97940, 0.97825, 0.97900, 0.97728, 0.91476],
                       [0.97138, 0.97068, 0.97111, 0.97077, 0.96993, 0.97112, 0.97054,
                        0.97055, 0.97117, 0.97028, 0.97208, 0.97067, 0.97144, 0.97011,
                        0.96986, 0.97239, 0.97196, 0.97061, 0.97146, 0.97172, 0.97220,
                        0.97077, 0.97278, 0.97447, 0.97428, 0.97167, 0.97408, 0.97360, 0.91085],
                       [0.96694, 0.96851, 0.96921, 0.96742, 0.96773, 0.96884, 0.96770,
                        0.96720, 0.96716, 0.96803, 0.96770, 0.96639, 0.96818, 0.96668,
                        0.96718, 0.96836, 0.96729, 0.96805, 0.96943, 0.97038, 0.96965,
                        0.96942, 0.96942, 0.97020, 0.97108, 0.96945, 0.97123, 0.97068, 0.90879],
                       [0.96936, 0.97128, 0.97083, 0.97012, 0.97022, 0.97069, 0.97065,
                        0.97061, 0.96945, 0.97070, 0.96959, 0.96973, 0.96992, 0.97032,
                        0.96984, 0.96946, 0.97010, 0.97092, 0.97109, 0.97189, 0.97085,
                        0.97186, 0.97070, 0.97012, 0.97154, 0.97188, 0.97215, 0.97044, 0.90898],
                       [0.97105, 0.97274, 0.97037, 0.97097, 0.97156, 0.97087, 0.97203,
                        0.97196, 0.97108, 0.97104, 0.97126, 0.97089, 0.97112, 0.97354,
                        0.97117, 0.97111, 0.97291, 0.97295, 0.97056, 0.97157, 0.97077,
                        0.97303, 0.97182, 0.97109, 0.97203, 0.97298, 0.97238, 0.97014, 0.90981],
                       [0.97402, 0.97517, 0.97216, 0.97346, 0.97483, 0.97313, 0.97420,
                        0.97456, 0.97360, 0.97285, 0.97424, 0.97281, 0.97449, 0.97634,
                        0.97391, 0.97534, 0.97539, 0.97550, 0.97230, 0.97438, 0.97368,
                        0.97570, 0.97427, 0.97523, 0.97428, 0.97504, 0.97485, 0.97272, 0.91247],
                       [0.97455, 0.97485, 0.97309, 0.97390, 0.97490, 0.97355, 0.97359,
                        0.97480, 0.97377, 0.97355, 0.97416, 0.97374, 0.97484, 0.97460,
                        0.97485, 0.97544, 0.97442, 0.97435, 0.97371, 0.97571, 0.97520,
                        0.97568, 0.97424, 0.97657, 0.97403, 0.97500, 0.97539, 0.97327, 0.91248],
                       [0.97201, 0.97238, 0.97201, 0.97135, 0.97186, 0.97154, 0.97054,
                        0.97206, 0.97190, 0.97159, 0.97183, 0.97307, 0.97235, 0.97094,
                        0.97241, 0.97157, 0.97147, 0.97126, 0.97278, 0.97346, 0.97300,
                        0.97307, 0.97209, 0.97389, 0.97197, 0.97270, 0.97289, 0.97107, 0.91007],
                       [0.97100, 0.97307, 0.97245, 0.97121, 0.97140, 0.97211, 0.97106,
                        0.97204, 0.97206, 0.97147, 0.97241, 0.97420, 0.97223, 0.97164,
                        0.97158, 0.97158, 0.97126, 0.97238, 0.97303, 0.97294, 0.97222,
                        0.97307, 0.97212, 0.97301, 0.97220, 0.97181, 0.97218, 0.97101, 0.90974],
                       [0.96733, 0.97052, 0.96886, 0.96826, 0.96864, 0.96899, 0.96922,
                        0.96893, 0.96817, 0.96837, 0.96941, 0.97053, 0.96862, 0.96984,
                        0.96911, 0.96988, 0.96869, 0.97019, 0.96932, 0.96925, 0.96851,
                        0.96910, 0.96882, 0.96992, 0.96877, 0.96705, 0.96822, 0.96787, 0.90668],
                       [0.96176, 0.96335, 0.96232, 0.96218, 0.96340, 0.96205, 0.96350,
                        0.96214, 0.96153, 0.96212, 0.96257, 0.96257, 0.96198, 0.96341,
                        0.96376, 0.96403, 0.96400, 0.96282, 0.96334, 0.96278, 0.96206,
                        0.96166, 0.96285, 0.96371, 0.96298, 0.96046, 0.96175, 0.96206, 0.90165],
                       [0.96421, 0.96379, 0.96418, 0.96347, 0.96515, 0.96345, 0.96456,
                        0.96351, 0.96390, 0.96381, 0.96364, 0.96313, 0.96330, 0.96328,
                        0.96517, 0.96491, 0.96628, 0.96243, 0.96565, 0.96511, 0.96416,
                        0.96341, 0.96483, 0.96394, 0.96500, 0.96326, 0.96397, 0.96421, 0.90421],
                       [0.97107, 0.97047, 0.97097, 0.96995, 0.97154, 0.97033, 0.97036,
                        0.97074, 0.97154, 0.97120, 0.97121, 0.97005, 0.97110, 0.96857,
                        0.97140, 0.97123, 0.97230, 0.96862, 0.97195, 0.97240, 0.97170,
                        0.97073, 0.97126, 0.97007, 0.97058, 0.97123, 0.97087, 0.97140, 0.91041],
                       [0.97150, 0.97239, 0.97185, 0.97182, 0.97354, 0.97129, 0.97182,
                        0.97244, 0.97301, 0.97309, 0.97374, 0.97157, 0.97416, 0.97044,
                        0.97214, 0.97253, 0.97198, 0.97141, 0.97163, 0.97216, 0.97303,
                        0.97193, 0.97152, 0.97217, 0.97070, 0.97284, 0.97201, 0.97314, 0.91115],
                       [0.96305, 0.96456, 0.96293, 0.96454, 0.96509, 0.96322, 0.96475,
                        0.96423, 0.96397, 0.96394, 0.96487, 0.96330, 0.96530, 0.96441,
                        0.96319, 0.96404, 0.96260, 0.96493, 0.96235, 0.96205, 0.96449,
                        0.96410, 0.96262, 0.96427, 0.96270, 0.96430, 0.96457, 0.96487, 0.90403],
                       [0.95997, 0.96004, 0.95875, 0.96055, 0.95952, 0.95985, 0.96166,
                        0.96024, 0.95920, 0.95827, 0.95866, 0.95919, 0.95945, 0.96154,
                        0.95903, 0.95983, 0.95920, 0.96093, 0.95837, 0.95830, 0.96012,
                        0.96094, 0.95986, 0.96099, 0.96055, 0.96010, 0.96233, 0.96037, 0.90085],
                       [0.96386, 0.96290, 0.96262, 0.96288, 0.96239, 0.96333, 0.96459,
                        0.96268, 0.96263, 0.96133, 0.96087, 0.96239, 0.96222, 0.96344,
                        0.96341, 0.96354, 0.96352, 0.96277, 0.96264, 0.96351, 0.96300,
                        0.96449, 0.96505, 0.96523, 0.96588, 0.96383, 0.96656, 0.96369, 0.90408],
                       [0.96489, 0.96462, 0.96401, 0.96284, 0.96429, 0.96388, 0.96446,
                        0.96232, 0.96388, 0.96349, 0.96291, 0.96357, 0.96354, 0.96272,
                        0.96500, 0.96533, 0.96454, 0.96311, 0.96490, 0.96520, 0.96354,
                        0.96440, 0.96553, 0.96549, 0.96641, 0.96471, 0.96601, 0.96537, 0.90466],
                       [0.96648, 0.96588, 0.96539, 0.96399, 0.96586, 0.96420, 0.96510,
                        0.96364, 0.96519, 0.96593, 0.96578, 0.96553, 0.96458, 0.96431,
                        0.96590, 0.96612, 0.96548, 0.96519, 0.96593, 0.96548, 0.96417,
                        0.96464, 0.96521, 0.96541, 0.96607, 0.96551, 0.96504, 0.96676, 0.90583],
                       [0.96729, 0.96500, 0.96656, 0.96599, 0.96620, 0.96516, 0.96583,
                        0.96640, 0.96686, 0.96696, 0.96811, 0.96699, 0.96601, 0.96641,
                        0.96697, 0.96597, 0.96677, 0.96730, 0.96553, 0.96625, 0.96583,
                        0.96643, 0.96709, 0.96708, 0.96767, 0.96875, 0.96648, 0.96778, 0.90810],
                       [0.96413, 0.96274, 0.96453, 0.96507, 0.96344, 0.96411, 0.96276,
                        0.96624, 0.96539, 0.96490, 0.96742, 0.96466, 0.96555, 0.96465,
                        0.96564, 0.96458, 0.96629, 0.96536, 0.96361, 0.96577, 0.96631,
                        0.96636, 0.96821, 0.96759, 0.96771, 0.96996, 0.96799, 0.96796, 0.90812],
                       [0.96059, 0.96170, 0.96129, 0.96219, 0.96023, 0.96141, 0.95860,
                        0.96322, 0.96147, 0.96177, 0.96387, 0.96129, 0.96318, 0.96110,
                        0.96236, 0.96299, 0.96375, 0.96172, 0.96200, 0.96342, 0.96439,
                        0.96423, 0.96646, 0.96532, 0.96610, 0.96671, 0.96707, 0.96727, 0.90652],
                       [0.96087, 0.96174, 0.96098, 0.96081, 0.96053, 0.96040, 0.95882,
                        0.96156, 0.96006, 0.96008, 0.96116, 0.96088, 0.96193, 0.96050,
                        0.96104, 0.96210, 0.96129, 0.96169, 0.96188, 0.96219, 0.96270,
                        0.96297, 0.96382, 0.96345, 0.96533, 0.96392, 0.96527, 0.96622, 0.90616],
                       [0.96616, 0.96555, 0.96657, 0.96505, 0.96645, 0.96495, 0.96546,
                        0.96520, 0.96469, 0.96424, 0.96461, 0.96589, 0.96517, 0.96645,
                        0.96560, 0.96543, 0.96452, 0.96749, 0.96643, 0.96621, 0.96571,
                        0.96712, 0.96648, 0.96718, 0.96840, 0.96718, 0.96847, 0.96973, 0.90968],
                       [0.96950, 0.96919, 0.97136, 0.96908, 0.97103, 0.97036, 0.97127,
                        0.96836, 0.96975, 0.96911, 0.96931, 0.97056, 0.96862, 0.97229,
                        0.97000, 0.96950, 0.96985, 0.97189, 0.97081, 0.97109, 0.96935,
                        0.97266, 0.97107, 0.97161, 0.97203, 0.97233, 0.97273, 0.97430, 0.91286],
                       [0.96470, 0.96667, 0.96673, 0.96560, 0.96653, 0.96851, 0.96778,
                        0.96530, 0.96822, 0.96657, 0.96704, 0.96748, 0.96659, 0.96831,
                        0.96655, 0.96803, 0.96840, 0.96752, 0.96823, 0.96914, 0.96709,
                        0.97061, 0.96921, 0.96965, 0.96998, 0.97132, 0.97016, 0.97114, 0.90975],
                       [0.95901, 0.96190, 0.95969, 0.96029, 0.95923, 0.96159, 0.96031,
                        0.96103, 0.96289, 0.96139, 0.96152, 0.96141, 0.96210, 0.96031,
                        0.96095, 0.96382, 0.96236, 0.96125, 0.96269, 0.96269, 0.96294,
                        0.96314, 0.96362, 0.96538, 0.96457, 0.96524, 0.96484, 0.96477, 0.90480],
                       [0.96175, 0.96357, 0.96285, 0.96255, 0.96107, 0.96212, 0.96153,
                        0.96316, 0.96354, 0.96383, 0.96367, 0.96322, 0.96332, 0.96247,
                        0.96343, 0.96554, 0.96361, 0.96402, 0.96405, 0.96313, 0.96540,
                        0.96340, 0.96493, 0.96682, 0.96661, 0.96628, 0.96767, 0.96790, 0.90744],
                       [0.96830, 0.96958, 0.97023, 0.96891, 0.96878, 0.96904, 0.96885,
                        0.96906, 0.96901, 0.97025, 0.97048, 0.96963, 0.96814, 0.97030,
                        0.96987, 0.97137, 0.97015, 0.97076, 0.96957, 0.96924, 0.97151,
                        0.97041, 0.97168, 0.97266, 0.97368, 0.97373, 0.97495, 0.97518, 0.91369],
                       [0.97111, 0.97266, 0.97246, 0.97198, 0.97229, 0.97257, 0.97314,
                        0.97215, 0.97234, 0.97294, 0.97236, 0.97218, 0.97054, 0.97301,
                        0.97248, 0.97350, 0.97324, 0.97193, 0.97165, 0.97221, 0.97344,
                        0.97350, 0.97522, 0.97600, 0.97592, 0.97640, 0.97696, 0.97615, 0.91524],
                       [0.96923, 0.97009, 0.96925, 0.97028, 0.96930, 0.97078, 0.97127,
                        0.97059, 0.97055, 0.97082, 0.96813, 0.96953, 0.96833, 0.96915,
                        0.96965, 0.97022, 0.97045, 0.96766, 0.96918, 0.97022, 0.96949,
                        0.97000, 0.97259, 0.97247, 0.97152, 0.97120, 0.97204, 0.97083, 0.91038],
                       [0.96710, 0.96632, 0.96622, 0.96881, 0.96557, 0.96833, 0.96777,
                        0.96842, 0.96759, 0.96859, 0.96546, 0.96720, 0.96578, 0.96620,
                        0.96668, 0.96678, 0.96659, 0.96594, 0.96730, 0.96810, 0.96594,
                        0.96697, 0.96886, 0.96783, 0.96758, 0.96619, 0.96665, 0.96693, 0.90548],
                       [0.96955, 0.96843, 0.96902, 0.97148, 0.96795, 0.96992, 0.96879,
                        0.97024, 0.96880, 0.97059, 0.97022, 0.97000, 0.96932, 0.96932,
                        0.96898, 0.96931, 0.96907, 0.97117, 0.97077, 0.97050, 0.96965,
                        0.97043, 0.97028, 0.97066, 0.97013, 0.96899, 0.96823, 0.96908, 0.90757],
                       [0.97420, 0.97426, 0.97468, 0.97424, 0.97355, 0.97309, 0.97355,
                        0.97417, 0.97254, 0.97436, 0.97627, 0.97442, 0.97593, 0.97418,
                        0.97429, 0.97478, 0.97528, 0.97783, 0.97651, 0.97524, 0.97604,
                        0.97546, 0.97490, 0.97690, 0.97542, 0.97514, 0.97379, 0.97330, 0.91295],
                       [0.97556, 0.97670, 0.97648, 0.97478, 0.97552, 0.97471, 0.97629,
                        0.97596, 0.97504, 0.97610, 0.97692, 0.97601, 0.97806, 0.97639,
                        0.97692, 0.97678, 0.97724, 0.97883, 0.97855, 0.97753, 0.97834,
                        0.97594, 0.97707, 0.97877, 0.97783, 0.97666, 0.97602, 0.97399, 0.91438],
                       [0.96917, 0.97095, 0.97022, 0.97003, 0.96984, 0.97044, 0.97084,
                        0.97072, 0.97120, 0.97109, 0.97072, 0.97113, 0.97082, 0.97136,
                        0.97137, 0.97179, 0.97044, 0.97051, 0.97224, 0.97242, 0.97291,
                        0.97025, 0.97181, 0.97230, 0.97178, 0.96980, 0.97050, 0.96790, 0.90807],
                       [0.96388, 0.96578, 0.96443, 0.96574, 0.96555, 0.96573, 0.96515,
                        0.96545, 0.96639, 0.96560, 0.96612, 0.96629, 0.96381, 0.96553,
                        0.96558, 0.96684, 0.96429, 0.96346, 0.96612, 0.96695, 0.96683,
                        0.96604, 0.96570, 0.96551, 0.96457, 0.96405, 0.96512, 0.96401, 0.90342],
                       [0.96927, 0.97079, 0.96859, 0.96932, 0.97103, 0.96937, 0.96913,
                        0.96945, 0.97007, 0.96917, 0.97013, 0.97025, 0.96816, 0.96848,
                        0.96989, 0.96981, 0.96864, 0.96874, 0.96989, 0.97052, 0.97002,
                        0.97027, 0.96850, 0.96856, 0.96747, 0.96902, 0.96902, 0.96937, 0.90928],
                       [0.97410, 0.97425, 0.97219, 0.97179, 0.97410, 0.97272, 0.97303,
                        0.97303, 0.97362, 0.97238, 0.97288, 0.97347, 0.97307, 0.97203,
                        0.97359, 0.97292, 0.97316, 0.97383, 0.97303, 0.97369, 0.97401,
                        0.97286, 0.97201, 0.97240, 0.97135, 0.97384, 0.97229, 0.97198, 0.91287],
                       [0.96934, 0.96834, 0.96774, 0.96806, 0.96840, 0.96892, 0.96907,
                        0.96908, 0.96934, 0.96762, 0.96857, 0.96925, 0.96914, 0.96840,
                        0.96878, 0.96959, 0.96954, 0.96941, 0.96868, 0.96927, 0.96994,
                        0.96801, 0.96846, 0.96889, 0.96756, 0.96968, 0.96736, 0.96657, 0.90785],
                       [0.96422, 0.96487, 0.96451, 0.96618, 0.96459, 0.96600, 0.96565,
                        0.96608, 0.96522, 0.96388, 0.96529, 0.96586, 0.96526, 0.96465,
                        0.96493, 0.96661, 0.96567, 0.96548, 0.96558, 0.96549, 0.96514,
                        0.96441, 0.96488, 0.96515, 0.96437, 0.96445, 0.96381, 0.96352, 0.90423],
                       [0.96562, 0.96915, 0.96779, 0.96888, 0.96771, 0.96846, 0.96866,
                        0.96805, 0.96754, 0.96637, 0.96722, 0.96688, 0.96770, 0.96661,
                        0.96688, 0.96807, 0.96744, 0.96764, 0.96786, 0.96744, 0.96583,
                        0.96705, 0.96668, 0.96689, 0.96691, 0.96549, 0.96724, 0.96737, 0.90643],
                       [0.96443, 0.96703, 0.96663, 0.96627, 0.96673, 0.96671, 0.96709,
                        0.96523, 0.96651, 0.96539, 0.96478, 0.96383, 0.96663, 0.96527,
                        0.96456, 0.96531, 0.96640, 0.96554, 0.96604, 0.96634, 0.96472,
                        0.96562, 0.96481, 0.96570, 0.96510, 0.96477, 0.96668, 0.96713, 0.90444],
                       [0.95721, 0.95634, 0.95753, 0.95743, 0.95783, 0.95835, 0.95777,
                        0.95735, 0.95857, 0.95817, 0.95683, 0.95641, 0.95913, 0.95812,
                        0.95654, 0.95670, 0.95969, 0.95740, 0.95716, 0.95814, 0.95815,
                        0.95708, 0.95659, 0.95868, 0.95751, 0.95764, 0.95879, 0.95980, 0.89710],
                       [0.95669, 0.95451, 0.95536, 0.95656, 0.95580, 0.95640, 0.95613,
                        0.95759, 0.95780, 0.95681, 0.95639, 0.95667, 0.95818, 0.95762,
                        0.95688, 0.95554, 0.95856, 0.95694, 0.95514, 0.95628, 0.95696,
                        0.95590, 0.95615, 0.95848, 0.95774, 0.95705, 0.95706, 0.95861, 0.89822],
                       [0.96314, 0.96210, 0.96205, 0.96415, 0.96261, 0.96218, 0.96285,
                        0.96375, 0.96409, 0.96247, 0.96270, 0.96297, 0.96315, 0.96297,
                        0.96418, 0.96206, 0.96359, 0.96344, 0.96230, 0.96303, 0.96230,
                        0.96257, 0.96385, 0.96473, 0.96465, 0.96496, 0.96347, 0.96498, 0.90582],
                       [0.96478, 0.96541, 0.96502, 0.96718, 0.96538, 0.96438, 0.96528,
                        0.96436, 0.96509, 0.96480, 0.96405, 0.96377, 0.96411, 0.96358,
                        0.96536, 0.96447, 0.96536, 0.96546, 0.96590, 0.96573, 0.96405,
                        0.96441, 0.96675, 0.96598, 0.96638, 0.96788, 0.96618, 0.96781, 0.90751],
                       [0.96012, 0.96167, 0.96102, 0.96282, 0.96085, 0.96091, 0.96043,
                        0.95996, 0.96049, 0.96177, 0.95916, 0.95953, 0.96054, 0.95989,
                        0.96033, 0.96165, 0.96190, 0.96207, 0.96221, 0.96123, 0.96067,
                        0.96014, 0.96221, 0.96147, 0.96273, 0.96221, 0.96253, 0.96375, 0.90235],
                       [0.96334, 0.96475, 0.96422, 0.96516, 0.96338, 0.96480, 0.96290,
                        0.96413, 0.96388, 0.96611, 0.96286, 0.96460, 0.96428, 0.96521,
                        0.96430, 0.96642, 0.96529, 0.96593, 0.96496, 0.96430, 0.96540,
                        0.96421, 0.96512, 0.96468, 0.96719, 0.96391, 0.96683, 0.96555, 0.90499],
                       [0.97280, 0.97388, 0.97309, 0.97280, 0.97325, 0.97323, 0.97220,
                        0.97383, 0.97265, 0.97464, 0.97346, 0.97480, 0.97278, 0.97495,
                        0.97394, 0.97423, 0.97326, 0.97366, 0.97268, 0.97486, 0.97567,
                        0.97410, 0.97508, 0.97370, 0.97672, 0.97373, 0.97695, 0.97436, 0.91438],
                       [0.97251, 0.97353, 0.97229, 0.97123, 0.97349, 0.97155, 0.97182,
                        0.97289, 0.97185, 0.97257, 0.97279, 0.97307, 0.97180, 0.97298,
                        0.97222, 0.97114, 0.97143, 0.97159, 0.97149, 0.97530, 0.97419,
                        0.97348, 0.97446, 0.97341, 0.97534, 0.97494, 0.97638, 0.97502, 0.91424],
                       [0.97134, 0.97105, 0.96999, 0.96959, 0.97122, 0.96959, 0.97028,
                        0.97019, 0.97058, 0.96982, 0.96946, 0.96941, 0.97010, 0.96960,
                        0.96950, 0.96900, 0.96917, 0.97041, 0.97073, 0.97228, 0.97083,
                        0.97134, 0.97110, 0.97159, 0.97166, 0.97356, 0.97390, 0.97352, 0.91244],
                       [0.97076, 0.96940, 0.96884, 0.96909, 0.96868, 0.96890, 0.96977,
                        0.96812, 0.96964, 0.96809, 0.96796, 0.96804, 0.96933, 0.96777,
                        0.96862, 0.96862, 0.96801, 0.97046, 0.97003, 0.96900, 0.96895,
                        0.96939, 0.96865, 0.97011, 0.96953, 0.97056, 0.97149, 0.97161, 0.91127],
                       [0.96650, 0.96614, 0.96612, 0.96649, 0.96505, 0.96535, 0.96557,
                        0.96425, 0.96555, 0.96423, 0.96463, 0.96579, 0.96583, 0.96444,
                        0.96583, 0.96513, 0.96435, 0.96735, 0.96566, 0.96404, 0.96488,
                        0.96496, 0.96495, 0.96665, 0.96628, 0.96493, 0.96694, 0.96724, 0.90738],
                       [0.96364, 0.96538, 0.96457, 0.96522, 0.96631, 0.96324, 0.96337,
                        0.96386, 0.96415, 0.96343, 0.96316, 0.96471, 0.96419, 0.96365,
                        0.96479, 0.96414, 0.96368, 0.96570, 0.96333, 0.96264, 0.96380,
                        0.96391, 0.96421, 0.96543, 0.96477, 0.96419, 0.96576, 0.96576, 0.90524],
                       [0.96689, 0.96931, 0.96765, 0.96823, 0.97121, 0.96687, 0.96765,
                        0.96900, 0.96876, 0.96795, 0.96689, 0.96710, 0.96688, 0.96781,
                        0.96747, 0.96804, 0.96866, 0.96787, 0.96607, 0.96675, 0.96825,
                        0.96855, 0.96871, 0.96801, 0.96765, 0.96890, 0.96932, 0.96850, 0.90827],
                       [0.97212, 0.97257, 0.97242, 0.97244, 0.97301, 0.97167, 0.97255,
                        0.97297, 0.97288, 0.97214, 0.97169, 0.97035, 0.97084, 0.97146,
                        0.97060, 0.97107, 0.97225, 0.97008, 0.97016, 0.97108, 0.97239,
                        0.97228, 0.97341, 0.97106, 0.97149, 0.97172, 0.97164, 0.97115, 0.91141],
                       [0.97067, 0.96956, 0.97096, 0.97088, 0.96819, 0.97026, 0.97003,
                        0.96959, 0.97014, 0.97006, 0.97052, 0.96881, 0.96965, 0.96900,
                        0.96914, 0.96894, 0.96874, 0.96822, 0.96969, 0.96928, 0.96959,
                        0.96926, 0.97144, 0.96941, 0.96971, 0.96815, 0.96813, 0.96920, 0.90852],
                       [0.96853, 0.96749, 0.96949, 0.96917, 0.96666, 0.96840, 0.96716,
                        0.96713, 0.96834, 0.96871, 0.96912, 0.96819, 0.96830, 0.96826,
                        0.96889, 0.96761, 0.96717, 0.96800, 0.96945, 0.96835, 0.96754,
                        0.96782, 0.96873, 0.96797, 0.96829, 0.96743, 0.96665, 0.96824, 0.90677],
                       [0.96773, 0.96703, 0.96885, 0.96861, 0.96794, 0.96678, 0.96599,
                        0.96662, 0.96782, 0.96823, 0.96784, 0.96763, 0.96789, 0.96846,
                        0.96856, 0.96596, 0.96756, 0.96765, 0.96893, 0.96872, 0.96741,
                        0.96781, 0.96709, 0.96614, 0.96788, 0.96839, 0.96655, 0.96685, 0.90572],
                       [0.96490, 0.96453, 0.96501, 0.96509, 0.96487, 0.96361, 0.96398,
                        0.96406, 0.96453, 0.96457, 0.96371, 0.96370, 0.96476, 0.96489,
                        0.96422, 0.96294, 0.96412, 0.96359, 0.96425, 0.96567, 0.96492,
                        0.96454, 0.96345, 0.96294, 0.96465, 0.96486, 0.96327, 0.96084, 0.90145],
                       [0.96231, 0.96317, 0.96251, 0.96199, 0.96223, 0.96328, 0.96349,
                        0.96306, 0.96223, 0.96211, 0.96269, 0.96192, 0.96251, 0.96334,
                        0.96237, 0.96311, 0.96223, 0.96128, 0.96145, 0.96328, 0.96347,
                        0.96225, 0.96165, 0.96301, 0.96270, 0.96115, 0.96024, 0.95753, 0.89902],
                       [0.96427, 0.96618, 0.96559, 0.96425, 0.96600, 0.96755, 0.96665,
                        0.96670, 0.96529, 0.96542, 0.96826, 0.96571, 0.96585, 0.96704,
                        0.96729, 0.96762, 0.96714, 0.96569, 0.96708, 0.96580, 0.96688,
                        0.96530, 0.96614, 0.96759, 0.96491, 0.96330, 0.96204, 0.96199, 0.90185],
                       [0.96557, 0.96736, 0.96720, 0.96567, 0.96712, 0.96748, 0.96693,
                        0.96790, 0.96670, 0.96764, 0.97018, 0.96702, 0.96822, 0.96710,
                        0.96926, 0.96812, 0.97015, 0.96876, 0.97073, 0.96653, 0.96816,
                        0.96668, 0.96823, 0.96877, 0.96517, 0.96456, 0.96330, 0.96395, 0.90261],
                       [0.95991, 0.96087, 0.96072, 0.96077, 0.96058, 0.95899, 0.96000,
                        0.96098, 0.96077, 0.96208, 0.96263, 0.96069, 0.96307, 0.96009,
                        0.96251, 0.96093, 0.96320, 0.96310, 0.96301, 0.96067, 0.96214,
                        0.96058, 0.96117, 0.96070, 0.95926, 0.95874, 0.95720, 0.95759, 0.89652],
                       [0.95883, 0.95903, 0.95852, 0.96136, 0.96088, 0.95778, 0.95960,
                        0.95886, 0.95973, 0.96085, 0.96012, 0.96085, 0.96187, 0.96125,
                        0.96098, 0.96009, 0.95942, 0.96078, 0.95933, 0.96027, 0.96182,
                        0.95943, 0.95941, 0.95720, 0.95847, 0.95828, 0.95502, 0.95716, 0.89500],
                       [0.96028, 0.95977, 0.95939, 0.96210, 0.96200, 0.96089, 0.96145,
                        0.96020, 0.96036, 0.96121, 0.96094, 0.96459, 0.96183, 0.96441,
                        0.96096, 0.96079, 0.96052, 0.96074, 0.96003, 0.96197, 0.96291,
                        0.96050, 0.96059, 0.95790, 0.95868, 0.95897, 0.95555, 0.95805, 0.89491],
                       [0.95531, 0.95421, 0.95424, 0.95380, 0.95378, 0.95552, 0.95501,
                        0.95462, 0.95390, 0.95476, 0.95571, 0.95844, 0.95395, 0.95629,
                        0.95300, 0.95414, 0.95647, 0.95465, 0.95548, 0.95581, 0.95445,
                        0.95351, 0.95384, 0.95233, 0.95178, 0.95070, 0.95003, 0.94992, 0.89023],
                       [0.96038, 0.96079, 0.96003, 0.95868, 0.95785, 0.95996, 0.95918,
                        0.95919, 0.95916, 0.96002, 0.96141, 0.96049, 0.95786, 0.95895,
                        0.95748, 0.96021, 0.96123, 0.96057, 0.96120, 0.95920, 0.95778,
                        0.95718, 0.95700, 0.95717, 0.95697, 0.95497, 0.95506, 0.95459, 0.89848],
                       [0.96715, 0.97009, 0.96763, 0.96759, 0.96654, 0.96801, 0.96658,
                        0.96750, 0.96799, 0.96801, 0.96886, 0.96690, 0.96654, 0.96753,
                        0.96732, 0.96786, 0.96834, 0.96852, 0.96756, 0.96532, 0.96570,
                        0.96502, 0.96345, 0.96438, 0.96487, 0.96418, 0.96257, 0.96424, 0.90806],
                       [0.95954, 0.96295, 0.96055, 0.96064, 0.96148, 0.96041, 0.95973,
                        0.96148, 0.96174, 0.96110, 0.96107, 0.96088, 0.96161, 0.96140,
                        0.96300, 0.95938, 0.96128, 0.95994, 0.95878, 0.95874, 0.95895,
                        0.95804, 0.95740, 0.95663, 0.95738, 0.95814, 0.95671, 0.95864, 0.90126],
                       [0.95190, 0.95505, 0.95345, 0.95262, 0.95526, 0.95130, 0.95266,
                        0.95386, 0.95441, 0.95312, 0.95344, 0.95383, 0.95460, 0.95314,
                        0.95597, 0.95262, 0.95318, 0.95144, 0.95177, 0.95250, 0.95091,
                        0.94895, 0.95147, 0.94924, 0.94968, 0.95018, 0.95044, 0.95171, 0.89281],
                       [0.95772, 0.96024, 0.95901, 0.95745, 0.95963, 0.95783, 0.95796,
                        0.95930, 0.95999, 0.95837, 0.96011, 0.95918, 0.95837, 0.95848,
                        0.95967, 0.95939, 0.95806, 0.95756, 0.95915, 0.95745, 0.95489,
                        0.95291, 0.95629, 0.95471, 0.95554, 0.95410, 0.95590, 0.95747, 0.89718],
                       [0.96989, 0.97025, 0.97022, 0.96947, 0.96982, 0.97201, 0.96939,
                        0.97110, 0.97191, 0.97101, 0.97257, 0.97122, 0.96930, 0.97158,
                        0.96923, 0.97008, 0.96922, 0.97002, 0.97055, 0.96790, 0.96607,
                        0.96509, 0.96491, 0.96548, 0.96747, 0.96558, 0.96718, 0.96928, 0.90880],
                       [0.96595, 0.96575, 0.96653, 0.96721, 0.96576, 0.96809, 0.96704,
                        0.96713, 0.96784, 0.96779, 0.96797, 0.96741, 0.96742, 0.96794,
                        0.96559, 0.96574, 0.96526, 0.96607, 0.96479, 0.96486, 0.96369,
                        0.96307, 0.96020, 0.96284, 0.96418, 0.96455, 0.96467, 0.96611, 0.90663],
                       [0.95621, 0.95721, 0.95678, 0.95815, 0.95592, 0.95764, 0.95837,
                        0.95684, 0.95740, 0.95763, 0.95764, 0.95661, 0.95913, 0.95625,
                        0.95805, 0.95742, 0.95603, 0.95615, 0.95487, 0.95698, 0.95580,
                        0.95427, 0.95371, 0.95582, 0.95552, 0.95737, 0.95692, 0.95716, 0.89924],
                       [0.95796, 0.95904, 0.95815, 0.95878, 0.95775, 0.95935, 0.95868,
                        0.95845, 0.95920, 0.95899, 0.95850, 0.95744, 0.95939, 0.95637,
                        0.95983, 0.95989, 0.95903, 0.95830, 0.95778, 0.95840, 0.95800,
                        0.95604, 0.95832, 0.95780, 0.95825, 0.95849, 0.95879, 0.95918, 0.90099],
                       [0.96029, 0.95945, 0.96069, 0.95870, 0.95932, 0.96044, 0.95930,
                        0.96044, 0.96134, 0.96069, 0.95849, 0.95971, 0.95897, 0.95824,
                        0.95961, 0.96040, 0.96145, 0.95944, 0.96069, 0.95841, 0.95887,
                        0.95763, 0.95908, 0.95841, 0.95966, 0.95838, 0.95912, 0.96019, 0.90056],
                       [0.95751, 0.95542, 0.95787, 0.95413, 0.95523, 0.95642, 0.95544,
                        0.95588, 0.95666, 0.95594, 0.95430, 0.95624, 0.95481, 0.95498,
                        0.95596, 0.95524, 0.95643, 0.95420, 0.95730, 0.95343, 0.95469,
                        0.95466, 0.95267, 0.95446, 0.95432, 0.95342, 0.95398, 0.95447, 0.89502],
                       [0.95627, 0.95552, 0.95642, 0.95422, 0.95479, 0.95598, 0.95462,
                        0.95320, 0.95430, 0.95315, 0.95494, 0.95462, 0.95507, 0.95443,
                        0.95768, 0.95446, 0.95315, 0.95428, 0.95505, 0.95271, 0.95343,
                        0.95515, 0.95225, 0.95425, 0.95340, 0.95252, 0.95307, 0.95222, 0.89354],
                       [0.96170, 0.96272, 0.96127, 0.96187, 0.96158, 0.96268, 0.96281,
                        0.96053, 0.96137, 0.96046, 0.96353, 0.96081, 0.96359, 0.96195,
                        0.96507, 0.96260, 0.95940, 0.96439, 0.96011, 0.96091, 0.95994,
                        0.96172, 0.96297, 0.96181, 0.96244, 0.95972, 0.96072, 0.95927, 0.90009],
                       [0.96020, 0.96006, 0.95851, 0.95950, 0.95964, 0.96027, 0.96194,
                        0.96137, 0.96064, 0.96230, 0.96144, 0.95972, 0.96273, 0.96011,
                        0.96009, 0.96158, 0.95938, 0.96298, 0.95875, 0.95994, 0.95828,
                        0.95919, 0.96294, 0.95902, 0.96046, 0.95768, 0.95807, 0.95691, 0.89849],
                       [0.95051, 0.94828, 0.94858, 0.94906, 0.94997, 0.94896, 0.94925,
                        0.95044, 0.94998, 0.95273, 0.94928, 0.94964, 0.95154, 0.94896,
                        0.94788, 0.95062, 0.95018, 0.94962, 0.94991, 0.94888, 0.94767,
                        0.94889, 0.95038, 0.94637, 0.94721, 0.94656, 0.94555, 0.94588, 0.88857],
                       [0.95078, 0.94805, 0.95095, 0.95162, 0.95114, 0.95024, 0.94823,
                        0.94882, 0.95075, 0.95093, 0.94950, 0.94945, 0.95085, 0.94951,
                        0.94953, 0.95012, 0.95139, 0.94817, 0.95080, 0.94897, 0.94916,
                        0.94949, 0.94853, 0.94677, 0.94653, 0.94755, 0.94663, 0.94799, 0.88907],
                       [0.96280, 0.96077, 0.96558, 0.96472, 0.96273, 0.96512, 0.96293,
                        0.96104, 0.96472, 0.96274, 0.96375, 0.96190, 0.96272, 0.96229,
                        0.96341, 0.96198, 0.96465, 0.96111, 0.96160, 0.96159, 0.96328,
                        0.96143, 0.96014, 0.96123, 0.96096, 0.96099, 0.96132, 0.96216, 0.90067],
                       [0.97253, 0.97095, 0.97468, 0.97244, 0.97042, 0.97415, 0.97454,
                        0.97180, 0.97491, 0.97440, 0.97431, 0.97369, 0.97235, 0.97199,
                        0.97413, 0.97150, 0.97448, 0.97267, 0.97023, 0.97177, 0.97361,
                        0.97037, 0.97025, 0.97237, 0.97172, 0.97059, 0.97093, 0.97138, 0.91021],
                       [0.96966, 0.96920, 0.96912, 0.96836, 0.96765, 0.96880, 0.97003,
                        0.96951, 0.97137, 0.97305, 0.97041, 0.97272, 0.96958, 0.96934,
                        0.97177, 0.96878, 0.97113, 0.97138, 0.96906, 0.96962, 0.97032,
                        0.96825, 0.96815, 0.96897, 0.96705, 0.96762, 0.96719, 0.96849, 0.90963],
                       [0.95764, 0.95971, 0.95681, 0.95709, 0.95870, 0.95835, 0.95836,
                        0.95767, 0.96021, 0.96067, 0.95915, 0.96069, 0.95871, 0.95855,
                        0.96008, 0.95950, 0.96016, 0.96010, 0.95921, 0.95972, 0.95845,
                        0.95861, 0.95804, 0.95597, 0.95592, 0.95718, 0.95709, 0.95900, 0.90074],
                       [0.95249, 0.95584, 0.95402, 0.95271, 0.95571, 0.95589, 0.95501,
                        0.95271, 0.95553, 0.95412, 0.95554, 0.95445, 0.95479, 0.95339,
                        0.95561, 0.95683, 0.95652, 0.95534, 0.95382, 0.95593, 0.95332,
                        0.95340, 0.95449, 0.95071, 0.95361, 0.95313, 0.95433, 0.95525, 0.89619],
                       [0.95877, 0.96012, 0.96019, 0.95910, 0.96193, 0.96082, 0.96062,
                        0.95832, 0.95979, 0.95918, 0.96122, 0.95940, 0.96029, 0.95844,
                        0.96267, 0.96205, 0.96141, 0.96122, 0.95739, 0.96018, 0.95795,
                        0.95769, 0.95946, 0.95712, 0.96010, 0.95884, 0.96057, 0.95948, 0.90070],
                       [0.96144, 0.96099, 0.95965, 0.96259, 0.96350, 0.96006, 0.96231,
                        0.96138, 0.95968, 0.96204, 0.96329, 0.96144, 0.96219, 0.96165,
                        0.96417, 0.96332, 0.96092, 0.96210, 0.95873, 0.96033, 0.95946,
                        0.96113, 0.95970, 0.95990, 0.96227, 0.96208, 0.96224, 0.96154, 0.90343],
                       [0.96335, 0.96333, 0.96014, 0.96496, 0.96369, 0.96166, 0.96376,
                        0.96465, 0.96047, 0.96467, 0.96566, 0.96266, 0.96434, 0.96450,
                        0.96176, 0.96430, 0.96082, 0.96182, 0.96328, 0.96268, 0.96154,
                        0.96530, 0.96112, 0.96266, 0.96450, 0.96608, 0.96362, 0.96550, 0.90735],
                       [0.96174, 0.96155, 0.96076, 0.96172, 0.96065, 0.96189, 0.96191,
                        0.96365, 0.95973, 0.96256, 0.96395, 0.96064, 0.96318, 0.96224,
                        0.95753, 0.96081, 0.95906, 0.96068, 0.96467, 0.96294, 0.96062,
                        0.96371, 0.96125, 0.96270, 0.96318, 0.96520, 0.96243, 0.96460, 0.90626],
                       [0.95052, 0.94991, 0.95145, 0.94917, 0.95006, 0.95195, 0.95055,
                        0.95226, 0.95117, 0.95147, 0.95265, 0.95112, 0.95276, 0.95109,
                        0.94904, 0.94943, 0.94952, 0.95189, 0.95299, 0.95221, 0.95093,
                        0.95193, 0.95301, 0.95285, 0.95299, 0.95284, 0.95340, 0.95394, 0.89584],
                       [0.94607, 0.94596, 0.94643, 0.94546, 0.94733, 0.94849, 0.94582,
                        0.94636, 0.94860, 0.94744, 0.94802, 0.94837, 0.94772, 0.94792,
                        0.94829, 0.94732, 0.94706, 0.94781, 0.94626, 0.94652, 0.94764,
                        0.94817, 0.94962, 0.94942, 0.95031, 0.94785, 0.95021, 0.95088, 0.89307],
                       [0.95728, 0.95703, 0.95672, 0.95821, 0.95855, 0.95963, 0.95667,
                        0.95593, 0.95795, 0.95729, 0.95783, 0.95847, 0.95721, 0.95927,
                        0.95989, 0.95962, 0.95841, 0.95720, 0.95585, 0.95620, 0.95865,
                        0.95974, 0.95941, 0.95984, 0.96208, 0.95870, 0.95940, 0.96137, 0.90317],
                       [0.96878, 0.96712, 0.96813, 0.96938, 0.96789, 0.96946, 0.96703,
                        0.96618, 0.96591, 0.96778, 0.96809, 0.96710, 0.96800, 0.96967,
                        0.96876, 0.97035, 0.96845, 0.96771, 0.96745, 0.96637, 0.96933,
                        0.96980, 0.96998, 0.96950, 0.97145, 0.96922, 0.96862, 0.96877, 0.91061],
                       [0.96716, 0.96409, 0.96743, 0.96570, 0.96489, 0.96486, 0.96495,
                        0.96481, 0.96271, 0.96729, 0.96742, 0.96546, 0.96686, 0.96644,
                        0.96598, 0.96864, 0.96682, 0.96641, 0.96759, 0.96432, 0.96683,
                        0.96612, 0.96801, 0.96730, 0.96731, 0.96823, 0.96776, 0.96381, 0.90601],
                       [0.96316, 0.96006, 0.96401, 0.96102, 0.96198, 0.95866, 0.96223,
                        0.96303, 0.96095, 0.96372, 0.96387, 0.96469, 0.96277, 0.96101,
                        0.96320, 0.96405, 0.96390, 0.96304, 0.96354, 0.96207, 0.96202,
                        0.96200, 0.96242, 0.96359, 0.96293, 0.96489, 0.96321, 0.96038, 0.90231],
                       [0.96814, 0.96467, 0.96729, 0.96645, 0.96761, 0.96375, 0.96720,
                        0.96787, 0.96848, 0.96645, 0.96604, 0.97018, 0.96641, 0.96519,
                        0.96703, 0.96579, 0.96847, 0.96731, 0.96592, 0.96888, 0.96580,
                        0.96735, 0.96626, 0.96699, 0.96772, 0.96605, 0.96465, 0.96668, 0.90762],
                       [0.97229, 0.96809, 0.96885, 0.97008, 0.97107, 0.96822, 0.96979,
                        0.96932, 0.97151, 0.96811, 0.96790, 0.97079, 0.96989, 0.96935,
                        0.96843, 0.96852, 0.97132, 0.97013, 0.96902, 0.97216, 0.96929,
                        0.97117, 0.97020, 0.96908, 0.97045, 0.96631, 0.96726, 0.96937, 0.90883],
                       [0.96662, 0.96596, 0.96506, 0.96609, 0.96690, 0.96581, 0.96566,
                        0.96576, 0.96559, 0.96460, 0.96548, 0.96493, 0.96771, 0.96714,
                        0.96490, 0.96653, 0.96704, 0.96743, 0.96663, 0.96737, 0.96608,
                        0.96755, 0.96644, 0.96552, 0.96520, 0.96385, 0.96518, 0.96419, 0.90249],
                       [0.96142, 0.96714, 0.96627, 0.96586, 0.96525, 0.96676, 0.96494,
                        0.96737, 0.96393, 0.96552, 0.96607, 0.96479, 0.96788, 0.96691,
                        0.96591, 0.96616, 0.96557, 0.96809, 0.96575, 0.96632, 0.96596,
                        0.96647, 0.96471, 0.96603, 0.96323, 0.96573, 0.96700, 0.96470, 0.90331],
                       [0.95927, 0.96505, 0.96602, 0.96494, 0.96318, 0.96514, 0.96318,
                        0.96650, 0.96304, 0.96524, 0.96433, 0.96475, 0.96566, 0.96460,
                        0.96441, 0.96435, 0.96313, 0.96642, 0.96293, 0.96411, 0.96543,
                        0.96450, 0.96340, 0.96541, 0.96218, 0.96428, 0.96640, 0.96668, 0.90674],
                       [0.95692, 0.95649, 0.95797, 0.95713, 0.95691, 0.95671, 0.95661,
                        0.95858, 0.95738, 0.95751, 0.95766, 0.95845, 0.95742, 0.95670,
                        0.95605, 0.95846, 0.95556, 0.95653, 0.95593, 0.95593, 0.95814,
                        0.95781, 0.95803, 0.95713, 0.95707, 0.95664, 0.95678, 0.96006, 0.90194],
                       [0.95679, 0.95317, 0.95402, 0.95309, 0.95531, 0.95348, 0.95432,
                        0.95431, 0.95568, 0.95345, 0.95536, 0.95470, 0.95346, 0.95345,
                        0.95382, 0.95608, 0.95328, 0.95099, 0.95347, 0.95289, 0.95442,
                        0.95569, 0.95557, 0.95206, 0.95514, 0.95488, 0.95098, 0.95387, 0.89788],
                       [0.95593, 0.95453, 0.95534, 0.95422, 0.95755, 0.95624, 0.95420,
                        0.95415, 0.95698, 0.95492, 0.95632, 0.95365, 0.95459, 0.95588,
                        0.95692, 0.95628, 0.95628, 0.95336, 0.95515, 0.95516, 0.95584,
                        0.95683, 0.95576, 0.95322, 0.95545, 0.95640, 0.95326, 0.95421, 0.89879],
                       [0.95677, 0.95809, 0.95830, 0.95803, 0.96129, 0.96162, 0.95717,
                        0.95796, 0.95954, 0.95904, 0.96013, 0.95727, 0.95820, 0.96137,
                        0.95985, 0.95924, 0.96065, 0.95970, 0.95956, 0.95953, 0.95965,
                        0.96015, 0.95969, 0.95841, 0.95994, 0.95782, 0.96042, 0.96099, 0.90302],
                       [0.96001, 0.96201, 0.96074, 0.96144, 0.96347, 0.96557, 0.96275,
                        0.96264, 0.96215, 0.96256, 0.96339, 0.96404, 0.96083, 0.96454,
                        0.96074, 0.96286, 0.96313, 0.96429, 0.96319, 0.96312, 0.96266,
                        0.96347, 0.96438, 0.96306, 0.96575, 0.96066, 0.96671, 0.96696, 0.90678],
                       [0.96463, 0.96661, 0.96544, 0.96512, 0.96545, 0.96708, 0.96697,
                        0.96690, 0.96557, 0.96589, 0.96480, 0.96870, 0.96350, 0.96543,
                        0.96346, 0.96573, 0.96542, 0.96686, 0.96567, 0.96596, 0.96602,
                        0.96667, 0.96807, 0.96693, 0.96912, 0.96755, 0.97029, 0.97024, 0.90995],
                       [0.96941, 0.97052, 0.96990, 0.96863, 0.96872, 0.96792, 0.96826,
                        0.97034, 0.96897, 0.96864, 0.96606, 0.97009, 0.96762, 0.96724,
                        0.96826, 0.96880, 0.96844, 0.96901, 0.96757, 0.96904, 0.96998,
                        0.96997, 0.97050, 0.97069, 0.97053, 0.97359, 0.97134, 0.97213, 0.91302],
                       [0.96957, 0.96932, 0.96875, 0.96795, 0.96885, 0.96696, 0.96697,
                        0.96893, 0.96815, 0.96733, 0.96569, 0.96742, 0.96850, 0.96702,
                        0.96854, 0.96868, 0.96807, 0.96761, 0.96733, 0.96869, 0.96907,
                        0.96877, 0.96896, 0.96966, 0.96856, 0.97249, 0.96871, 0.96941, 0.91329],
                       [0.96743, 0.96693, 0.96699, 0.96656, 0.96830, 0.96632, 0.96704,
                        0.96587, 0.96648, 0.96578, 0.96603, 0.96482, 0.96774, 0.96649,
                        0.96646, 0.96718, 0.96721, 0.96642, 0.96841, 0.96724, 0.96715,
                        0.96605, 0.96800, 0.96766, 0.96749, 0.96936, 0.96803, 0.96666, 0.91162],
                       [0.96510, 0.96502, 0.96659, 0.96516, 0.96722, 0.96537, 0.96657,
                        0.96377, 0.96602, 0.96501, 0.96566, 0.96360, 0.96622, 0.96553,
                        0.96517, 0.96549, 0.96621, 0.96661, 0.96813, 0.96513, 0.96590,
                        0.96506, 0.96726, 0.96745, 0.96742, 0.96746, 0.96873, 0.96638, 0.90804],
                       [0.96050, 0.96005, 0.96327, 0.96091, 0.96234, 0.96099, 0.96121,
                        0.96029, 0.96340, 0.96093, 0.96109, 0.96043, 0.96128, 0.96163,
                        0.96226, 0.96074, 0.96131, 0.96304, 0.96164, 0.95978, 0.96131,
                        0.96260, 0.96222, 0.96420, 0.96324, 0.96276, 0.96418, 0.96334, 0.90281],
                       [0.96114, 0.96190, 0.96452, 0.96382, 0.96264, 0.96201, 0.96137,
                        0.96350, 0.96508, 0.96230, 0.96269, 0.96345, 0.96203, 0.96383,
                        0.96410, 0.96115, 0.96226, 0.96432, 0.96126, 0.96236, 0.96193,
                        0.96420, 0.96315, 0.96484, 0.96391, 0.96335, 0.96348, 0.96443, 0.90481],
                       [0.96984, 0.97344, 0.97322, 0.97409, 0.97104, 0.97095, 0.97099,
                        0.97295, 0.97251, 0.97130, 0.97280, 0.97374, 0.97161, 0.97335,
                        0.97263, 0.97014, 0.97182, 0.97288, 0.97210, 0.97452, 0.97124,
                        0.97199, 0.97262, 0.97212, 0.97231, 0.97178, 0.97124, 0.97297, 0.91262],
                       [0.97324, 0.97646, 0.97492, 0.97465, 0.97431, 0.97366, 0.97588,
                        0.97349, 0.97335, 0.97328, 0.97541, 0.97550, 0.97487, 0.97587,
                        0.97436, 0.97414, 0.97411, 0.97397, 0.97666, 0.97810, 0.97403,
                        0.97317, 0.97473, 0.97250, 0.97498, 0.97388, 0.97399, 0.97482, 0.91263],
                       [0.97134, 0.97139, 0.96995, 0.96860, 0.97200, 0.97142, 0.97427,
                        0.96917, 0.97074, 0.97043, 0.97075, 0.97108, 0.97119, 0.97246,
                        0.97074, 0.97230, 0.97052, 0.97141, 0.97229, 0.97256, 0.97091,
                        0.97011, 0.97197, 0.96917, 0.97291, 0.97220, 0.97117, 0.97106, 0.90914],
                       [0.96677, 0.96658, 0.96515, 0.96359, 0.96680, 0.96778, 0.96777,
                        0.96609, 0.96741, 0.96695, 0.96518, 0.96660, 0.96659, 0.96703,
                        0.96627, 0.96810, 0.96649, 0.96937, 0.96577, 0.96467, 0.96832,
                        0.96740, 0.96897, 0.96707, 0.96906, 0.96933, 0.96585, 0.96614, 0.90662],
                       [0.96084, 0.96355, 0.96203, 0.96068, 0.96054, 0.96320, 0.96130,
                        0.96346, 0.96223, 0.96249, 0.96227, 0.96148, 0.96350, 0.96200,
                        0.96185, 0.96388, 0.96277, 0.96444, 0.96216, 0.96020, 0.96538,
                        0.96381, 0.96412, 0.96406, 0.96406, 0.96367, 0.96077, 0.96202, 0.90364],
                       [0.96598, 0.96938, 0.96866, 0.96889, 0.96613, 0.96880, 0.96805,
                        0.96915, 0.96710, 0.96769, 0.96854, 0.96706, 0.97012, 0.96852,
                        0.96789, 0.96947, 0.96885, 0.96882, 0.96984, 0.96938, 0.96986,
                        0.96878, 0.96892, 0.96937, 0.96923, 0.96785, 0.96710, 0.96826, 0.90940],
                       [0.97004, 0.97187, 0.97210, 0.97348, 0.97111, 0.97234, 0.97225,
                        0.97077, 0.97045, 0.97032, 0.97060, 0.97190, 0.97282, 0.97253,
                        0.97175, 0.97124, 0.97238, 0.97165, 0.97266, 0.97416, 0.97086,
                        0.97242, 0.97213, 0.97227, 0.97192, 0.97115, 0.97142, 0.97087, 0.91216],
                       [0.96537, 0.96608, 0.96619, 0.96706, 0.96718, 0.96651, 0.96643,
                        0.96553, 0.96606, 0.96435, 0.96477, 0.96812, 0.96594, 0.96740,
                        0.96626, 0.96439, 0.96658, 0.96577, 0.96582, 0.96639, 0.96374,
                        0.96824, 0.96584, 0.96635, 0.96561, 0.96646, 0.96662, 0.96369, 0.90536],
                       [0.96370, 0.96455, 0.96470, 0.96351, 0.96449, 0.96433, 0.96463,
                        0.96581, 0.96505, 0.96244, 0.96429, 0.96618, 0.96322, 0.96498,
                        0.96324, 0.96299, 0.96381, 0.96397, 0.96423, 0.96285, 0.96175,
                        0.96602, 0.96214, 0.96340, 0.96339, 0.96356, 0.96343, 0.95993, 0.90124],
                       [0.96709, 0.96828, 0.96881, 0.96652, 0.96548, 0.96770, 0.96847,
                        0.96971, 0.96812, 0.96691, 0.96798, 0.96812, 0.96678, 0.96618,
                        0.96640, 0.96736, 0.96623, 0.96760, 0.96817, 0.96744, 0.96687,
                        0.96679, 0.96490, 0.96596, 0.96644, 0.96400, 0.96285, 0.96142, 0.90200],
                       [0.96637, 0.96776, 0.96700, 0.96680, 0.96524, 0.96694, 0.96778,
                        0.96811, 0.96680, 0.96780, 0.96590, 0.96665, 0.96726, 0.96446,
                        0.96736, 0.96684, 0.96588, 0.96665, 0.96710, 0.96779, 0.96832,
                        0.96448, 0.96457, 0.96500, 0.96373, 0.96039, 0.95838, 0.95872, 0.89892],
                       [0.95581, 0.95686, 0.95474, 0.95651, 0.95671, 0.95622, 0.95579,
                        0.95720, 0.95576, 0.95708, 0.95497, 0.95703, 0.95749, 0.95572,
                        0.95776, 0.95566, 0.95695, 0.95703, 0.95614, 0.95636, 0.95701,
                        0.95493, 0.95318, 0.95266, 0.95000, 0.94675, 0.94569, 0.94531, 0.88586],
                       [0.94955, 0.95161, 0.95018, 0.95110, 0.95150, 0.95114, 0.95039,
                        0.95209, 0.95026, 0.95149, 0.95170, 0.95288, 0.95189, 0.95301,
                        0.95242, 0.94943, 0.95214, 0.95266, 0.95087, 0.94954, 0.94859,
                        0.95000, 0.94538, 0.94291, 0.94123, 0.93757, 0.93667, 0.93451, 0.87601],
                       [0.94751, 0.95040, 0.95005, 0.95068, 0.94926, 0.94949, 0.95053,
                        0.95022, 0.94986, 0.95113, 0.95200, 0.95106, 0.94992, 0.95221,
                        0.95087, 0.94798, 0.94924, 0.94960, 0.94918, 0.94664, 0.94558,
                        0.94581, 0.94064, 0.93692, 0.93458, 0.93064, 0.92686, 0.92415, 0.86686],
                       [0.93809, 0.93931, 0.93948, 0.94100, 0.93908, 0.93926, 0.94144,
                        0.94011, 0.94203, 0.94275, 0.94206, 0.94065, 0.94016, 0.94162,
                        0.94133, 0.94052, 0.93942, 0.93768, 0.93858, 0.93583, 0.93559,
                        0.93167, 0.92651, 0.92295, 0.91685, 0.91221, 0.90580, 0.90228, 0.84682],
                       [0.92569, 0.92529, 0.92524, 0.92720, 0.92686, 0.92762, 0.92961,
                        0.92866, 0.93202, 0.93224, 0.93011, 0.92991, 0.92970, 0.92943,
                        0.92954, 0.93093, 0.92902, 0.92578, 0.92541, 0.92312, 0.92125,
                        0.91555, 0.90940, 0.90381, 0.89513, 0.88757, 0.88220, 0.87561, 0.82217],
                       [0.90787, 0.90723, 0.90780, 0.90912, 0.90915, 0.91123, 0.91310,
                        0.91303, 0.91610, 0.91643, 0.91420, 0.91544, 0.91420, 0.91286,
                        0.91116, 0.91285, 0.91172, 0.91025, 0.90644, 0.90454, 0.89952,
                        0.89456, 0.88619, 0.87667, 0.86697, 0.85725, 0.85277, 0.84321, 0.79099],
                       [0.88053, 0.87995, 0.88151, 0.88113, 0.88147, 0.88355, 0.88578,
                        0.88732, 0.88866, 0.88949, 0.88788, 0.88898, 0.88674, 0.88484,
                        0.88190, 0.88215, 0.88236, 0.88167, 0.87611, 0.87314, 0.86577,
                        0.86078, 0.84930, 0.83734, 0.82583, 0.81656, 0.80949, 0.79883, 0.74720],
                       [0.84407, 0.84307, 0.84446, 0.84412, 0.84586, 0.84609, 0.84891,
                        0.85160, 0.85199, 0.85346, 0.85124, 0.85136, 0.84910, 0.84612,
                        0.84413, 0.84242, 0.84397, 0.84044, 0.83518, 0.82970, 0.82117,
                        0.81366, 0.79980, 0.78731, 0.77325, 0.76264, 0.75221, 0.74172, 0.69164],
                       [0.79982, 0.79963, 0.80032, 0.80175, 0.80302, 0.80370, 0.80607,
                        0.80839, 0.80886, 0.80979, 0.80716, 0.80647, 0.80339, 0.80048,
                        0.79926, 0.79713, 0.79709, 0.79259, 0.78625, 0.77860, 0.77062,
                        0.75850, 0.74456, 0.73039, 0.71451, 0.69906, 0.68764, 0.67677, 0.63048],
                       [0.75187, 0.75331, 0.75475, 0.75581, 0.75530, 0.75914, 0.76018,
                        0.76108, 0.76224, 0.76024, 0.75992, 0.75745, 0.75370, 0.75193,
                        0.74950, 0.74846, 0.74447, 0.74134, 0.73363, 0.72441, 0.71703,
                        0.70235, 0.68831, 0.66952, 0.65276, 0.63401, 0.62220, 0.61097, 0.56867],
                       [0.70123, 0.70368, 0.70570, 0.70584, 0.70473, 0.70952, 0.70947,
                        0.70968, 0.71112, 0.70733, 0.70857, 0.70416, 0.70060, 0.69875,
                        0.69474, 0.69316, 0.68836, 0.68419, 0.67671, 0.66646, 0.65745,
                        0.64265, 0.62666, 0.60470, 0.58658, 0.56837, 0.55459, 0.54363, 0.50412],
                       [0.64848, 0.65122, 0.65208, 0.65253, 0.65301, 0.65493, 0.65502,
                        0.65529, 0.65568, 0.65377, 0.65318, 0.64857, 0.64435, 0.64052,
                        0.63651, 0.63272, 0.62948, 0.62219, 0.61543, 0.60539, 0.59279,
                        0.57794, 0.55947, 0.53919, 0.51814, 0.50117, 0.48612, 0.47518, 0.43788],
                       [0.59332, 0.59576, 0.59539, 0.59550, 0.59830, 0.59735, 0.59894,
                        0.59816, 0.59720, 0.59908, 0.59503, 0.59110, 0.58516, 0.57949,
                        0.57598, 0.57099, 0.56791, 0.55857, 0.55066, 0.54217, 0.52627,
                        0.51114, 0.49159, 0.47425, 0.45114, 0.43384, 0.41956, 0.40693, 0.37398],
                       [0.53793, 0.53894, 0.53925, 0.53794, 0.54172, 0.53987, 0.54157,
                        0.54078, 0.53857, 0.54172, 0.53598, 0.53174, 0.52475, 0.51936,
                        0.51409, 0.51071, 0.50547, 0.49699, 0.48618, 0.47814, 0.46138,
                        0.44629, 0.42733, 0.40925, 0.38862, 0.37074, 0.35675, 0.34235, 0.31555],
                       [0.48300, 0.48307, 0.48494, 0.48314, 0.48493, 0.48342, 0.48312,
                        0.48503, 0.48205, 0.48199, 0.47722, 0.47211, 0.46521, 0.46082,
                        0.45302, 0.45059, 0.44505, 0.43760, 0.42465, 0.41469, 0.39993,
                        0.38569, 0.36721, 0.34681, 0.33085, 0.31353, 0.29966, 0.28649, 0.26391],
                       [0.42267, 0.42309, 0.42525, 0.42439, 0.42281, 0.42366, 0.42157,
                        0.42431, 0.42200, 0.41885, 0.41500, 0.40945, 0.40285, 0.39744,
                        0.39081, 0.38599, 0.38244, 0.37414, 0.36229, 0.35076, 0.33844,
                        0.32471, 0.30871, 0.28870, 0.27531, 0.25966, 0.24672, 0.23735, 0.21675],
                       [0.36209, 0.36265, 0.36334, 0.36422, 0.36075, 0.36399, 0.36207,
                        0.36119, 0.36051, 0.35704, 0.35343, 0.34727, 0.34140, 0.33445,
                        0.33090, 0.32366, 0.32031, 0.31107, 0.30252, 0.29176, 0.28092,
                        0.26743, 0.25502, 0.23796, 0.22503, 0.21159, 0.19988, 0.19288, 0.17540],
                       [0.31014, 0.31196, 0.31075, 0.31258, 0.31013, 0.31139, 0.31098,
                        0.30735, 0.30772, 0.30521, 0.30157, 0.29515, 0.29010, 0.28243,
                        0.27957, 0.27274, 0.26872, 0.26011, 0.25282, 0.24408, 0.23489,
                        0.22177, 0.21036, 0.19759, 0.18493, 0.17314, 0.16399, 0.15695, 0.14365],
                       [0.26903, 0.27182, 0.27055, 0.27113, 0.27110, 0.26899, 0.26933,
                        0.26708, 0.26666, 0.26492, 0.26065, 0.25507, 0.25030, 0.24339,
                        0.23938, 0.23365, 0.23009, 0.22297, 0.21521, 0.20789, 0.19948,
                        0.18811, 0.17615, 0.16692, 0.15527, 0.14501, 0.13849, 0.13145, 0.12101],
                       [0.23391, 0.23506, 0.23611, 0.23436, 0.23496, 0.23282, 0.23265,
                        0.23304, 0.23118, 0.22921, 0.22476, 0.22042, 0.21576, 0.21081,
                        0.20579, 0.20093, 0.19784, 0.19160, 0.18447, 0.17786, 0.16877,
                        0.16095, 0.14974, 0.14128, 0.13149, 0.12389, 0.11815, 0.11233, 0.10298],
                       [0.19777, 0.19699, 0.19898, 0.19653, 0.19603, 0.19642, 0.19538,
                        0.19679, 0.19430, 0.19209, 0.18914, 0.18512, 0.18121, 0.17694,
                        0.17284, 0.16952, 0.16568, 0.16010, 0.15447, 0.14866, 0.13999,
                        0.13454, 0.12610, 0.11732, 0.10959, 0.10455, 0.09879, 0.09437, 0.08507],
                       [0.16110, 0.16125, 0.16055, 0.16075, 0.15864, 0.16067, 0.15914,
                        0.16038, 0.15832, 0.15657, 0.15561, 0.15194, 0.14807, 0.14376,
                        0.14134, 0.14025, 0.13553, 0.13064, 0.12620, 0.12109, 0.11532,
                        0.10961, 0.10383, 0.09620, 0.09034, 0.08617, 0.08050, 0.07743, 0.06805],
                       [0.12974, 0.13089, 0.12885, 0.13104, 0.12858, 0.12999, 0.12872,
                        0.12936, 0.12839, 0.12720, 0.12635, 0.12411, 0.11954, 0.11730,
                        0.11486, 0.11463, 0.11031, 0.10605, 0.10298, 0.09810, 0.09416,
                        0.08885, 0.08381, 0.07861, 0.07412, 0.07081, 0.06497, 0.06319, 0.05545],
                       [0.10499, 0.10532, 0.10491, 0.10626, 0.10546, 0.10587, 0.10520,
                        0.10493, 0.10495, 0.10399, 0.10204, 0.10111, 0.09795, 0.09708,
                        0.09398, 0.09287, 0.09046, 0.08680, 0.08498, 0.08041, 0.07554,
                        0.07278, 0.06854, 0.06417, 0.05999, 0.05830, 0.05326, 0.05130, 0.04694],
                       [0.08505, 0.08581, 0.08631, 0.08644, 0.08760, 0.08794, 0.08775,
                        0.08664, 0.08714, 0.08635, 0.08385, 0.08317, 0.08299, 0.08080,
                        0.07854, 0.07686, 0.07556, 0.07263, 0.07196, 0.06833, 0.06263,
                        0.06161, 0.05853, 0.05355, 0.05008, 0.04769, 0.04517, 0.04208, 0.04083],
                       [0.06754, 0.07092, 0.07016, 0.06999, 0.07153, 0.07248, 0.07207,
                        0.07174, 0.07186, 0.07123, 0.06925, 0.06880, 0.06922, 0.06572,
                        0.06583, 0.06355, 0.06275, 0.06080, 0.06095, 0.05838, 0.05404,
                        0.05188, 0.04937, 0.04594, 0.04366, 0.03918, 0.03840, 0.03502, 0.03555],
                       [0.05129, 0.05545, 0.05374, 0.05372, 0.05402, 0.05473, 0.05470,
                        0.05577, 0.05473, 0.05484, 0.05389, 0.05404, 0.05187, 0.05068,
                        0.05113, 0.04903, 0.04916, 0.04783, 0.04719, 0.04528, 0.04352,
                        0.03982, 0.03831, 0.03780, 0.03576, 0.03144, 0.03083, 0.02824, 0.02817],
                       [0.04018, 0.04110, 0.04057, 0.04082, 0.04035, 0.04028, 0.04101,
                        0.04204, 0.04030, 0.04171, 0.04121, 0.04156, 0.03794, 0.03935,
                        0.03822, 0.03738, 0.03766, 0.03626, 0.03455, 0.03401, 0.03387,
                        0.03075, 0.02978, 0.02936, 0.02742, 0.02487, 0.02469, 0.02352, 0.02120],
                       [0.03404, 0.03229, 0.03314, 0.03347, 0.03326, 0.03346, 0.03342,
                        0.03402, 0.03341, 0.03469, 0.03386, 0.03460, 0.03209, 0.03276,
                        0.03101, 0.03102, 0.03104, 0.02983, 0.02838, 0.02858, 0.02862,
                        0.02668, 0.02536, 0.02352, 0.02261, 0.02100, 0.02126, 0.02134, 0.01804],
                       [0.02919, 0.02792, 0.02779, 0.02828, 0.02856, 0.02920, 0.02857,
                        0.02899, 0.02935, 0.03003, 0.02862, 0.02977, 0.02886, 0.02792,
                        0.02646, 0.02641, 0.02667, 0.02583, 0.02558, 0.02490, 0.02444,
                        0.02359, 0.02227, 0.01992, 0.01963, 0.01901, 0.01883, 0.01932, 0.01649],
                       [0.02379, 0.02497, 0.02281, 0.02326, 0.02355, 0.02418, 0.02484,
                        0.02496, 0.02400, 0.02523, 0.02395, 0.02428, 0.02470, 0.02340,
                        0.02259, 0.02242, 0.02231, 0.02151, 0.02239, 0.02106, 0.01929,
                        0.02034, 0.01890, 0.01811, 0.01739, 0.01727, 0.01599, 0.01650, 0.01449],
                       [0.01892, 0.02105, 0.01977, 0.01926, 0.01961, 0.01966, 0.02162,
                        0.02150, 0.01932, 0.02020, 0.02059, 0.01907, 0.02064, 0.01977,
                        0.01953, 0.01927, 0.01907, 0.01823, 0.01871, 0.01775, 0.01540,
                        0.01739, 0.01558, 0.01657, 0.01628, 0.01477, 0.01354, 0.01322, 0.01271],
                       [0.01639, 0.01721, 0.01839, 0.01650, 0.01794, 0.01672, 0.01858,
                        0.01856, 0.01777, 0.01604, 0.01799, 0.01597, 0.01758, 0.01699,
                        0.01688, 0.01655, 0.01733, 0.01683, 0.01620, 0.01529, 0.01433,
                        0.01514, 0.01324, 0.01407, 0.01439, 0.01291, 0.01282, 0.01124, 0.01240],
                       [0.01639, 0.01593, 0.01740, 0.01533, 0.01796, 0.01552, 0.01635,
                        0.01717, 0.01689, 0.01453, 0.01649, 0.01525, 0.01556, 0.01483,
                        0.01493, 0.01506, 0.01568, 0.01629, 0.01521, 0.01402, 0.01517,
                        0.01420, 0.01230, 0.01228, 0.01175, 0.01286, 0.01300, 0.01177, 0.01210],
                       [0.01679, 0.01616, 0.01617, 0.01576, 0.01756, 0.01586, 0.01574,
                        0.01681, 0.01549, 0.01546, 0.01673, 0.01514, 0.01453, 0.01384,
                        0.01472, 0.01533, 0.01436, 0.01539, 0.01479, 0.01380, 0.01495,
                        0.01357, 0.01259, 0.01249, 0.01150, 0.01315, 0.01290, 0.01339, 0.00992],
                       [0.01460, 0.01447, 0.01415, 0.01467, 0.01481, 0.01411, 0.01409,
                        0.01522, 0.01414, 0.01474, 0.01522, 0.01332, 0.01334, 0.01273,
                        0.01413, 0.01453, 0.01352, 0.01332, 0.01280, 0.01248, 0.01190,
                        0.01150, 0.01159, 0.01163, 0.01141, 0.01087, 0.01190, 0.01242, 0.00822],
                       [0.01153, 0.01237, 0.01229, 0.01169, 0.01181, 0.01120, 0.01103,
                        0.01296, 0.01217, 0.01221, 0.01172, 0.01144, 0.01184, 0.01130,
                        0.01183, 0.01219, 0.01244, 0.01102, 0.01074, 0.01011, 0.01006,
                        0.01036, 0.00965, 0.01002, 0.00970, 0.00846, 0.01061, 0.01005, 0.00907],
                       [0.01073, 0.01186, 0.01185, 0.01083, 0.01085, 0.01074, 0.01015,
                        0.01163, 0.01063, 0.01083, 0.01019, 0.01130, 0.01084, 0.01113,
                        0.01039, 0.01061, 0.01198, 0.01075, 0.01053, 0.00970, 0.01117,
                        0.01143, 0.00952, 0.01039, 0.00899, 0.00867, 0.00932, 0.00868, 0.00966],
                       [0.01181, 0.01181, 0.01215, 0.01230, 0.01154, 0.01174, 0.01189,
                        0.01098, 0.01049, 0.01096, 0.01144, 0.01119, 0.01076, 0.01127,
                        0.01065, 0.01083, 0.01205, 0.01188, 0.01075, 0.01089, 0.01147,
                        0.01168, 0.01055, 0.01065, 0.00936, 0.00990, 0.00888, 0.00864, 0.00873],
                       [0.01215, 0.01153, 0.01140, 0.01213, 0.01173, 0.01187, 0.01264,
                        0.01127, 0.00966, 0.01124, 0.01222, 0.01037, 0.01064, 0.01034,
                        0.01042, 0.01147, 0.01127, 0.01091, 0.00981, 0.01077, 0.00881,
                        0.01019, 0.01037, 0.00904, 0.00927, 0.01013, 0.00929, 0.00878, 0.00765],
                       [0.01100, 0.01171, 0.00988, 0.00976, 0.01038, 0.01082, 0.01139,
                        0.01168, 0.00781, 0.01094, 0.01058, 0.01041, 0.01035, 0.01021,
                        0.00901, 0.01106, 0.00975, 0.00866, 0.00888, 0.00907, 0.00690,
                        0.00924, 0.00960, 0.00861, 0.00837, 0.01003, 0.00948, 0.00853, 0.00760],
                       [0.00983, 0.01163, 0.00940, 0.00862, 0.00888, 0.00943, 0.01011,
                        0.01076, 0.00769, 0.01051, 0.00852, 0.01038, 0.00999, 0.01053,
                        0.00777, 0.00977, 0.00906, 0.00793, 0.00842, 0.00767, 0.00825,
                        0.00940, 0.00912, 0.00920, 0.00742, 0.01017, 0.00919, 0.00788, 0.00797],
                       [0.00926, 0.01022, 0.00997, 0.00834, 0.00868, 0.00879, 0.00935,
                        0.00942, 0.00935, 0.00984, 0.00780, 0.00919, 0.00881, 0.00979,
                        0.00758, 0.00819, 0.00884, 0.00810, 0.00835, 0.00753, 0.00976,
                        0.00955, 0.00832, 0.00878, 0.00683, 0.00955, 0.00851, 0.00745, 0.00809],
                       [0.00942, 0.00862, 0.01090, 0.00881, 0.00975, 0.01016, 0.00968,
                        0.00931, 0.01115, 0.00968, 0.00887, 0.00835, 0.00785, 0.01026,
                        0.00895, 0.00794, 0.00890, 0.00962, 0.00997, 0.00931, 0.01012,
                        0.00943, 0.00856, 0.00883, 0.00758, 0.00901, 0.00874, 0.00869, 0.00791],
                       [0.01013, 0.00863, 0.01086, 0.01055, 0.01058, 0.01231, 0.01065,
                        0.01023, 0.01142, 0.01009, 0.01062, 0.00895, 0.00875, 0.01156,
                        0.01040, 0.00938, 0.01035, 0.01198, 0.01257, 0.01115, 0.00985,
                        0.00920, 0.00993, 0.01000, 0.00944, 0.00934, 0.01009, 0.01069, 0.00761],
                       [0.01035, 0.00920, 0.00941, 0.01075, 0.00967, 0.01193, 0.01066,
                        0.01013, 0.00953, 0.00964, 0.01098, 0.00984, 0.00985, 0.01058,
                        0.00943, 0.00941, 0.01082, 0.01099, 0.01176, 0.00986, 0.00860,
                        0.00929, 0.00972, 0.01014, 0.00904, 0.00868, 0.00963, 0.00998, 0.00686],
                       [0.00957, 0.00850, 0.00802, 0.00922, 0.00796, 0.00903, 0.00903,
                        0.00876, 0.00768, 0.00829, 0.01007, 0.00901, 0.00881, 0.00857,
                        0.00760, 0.00731, 0.00901, 0.00722, 0.00832, 0.00736, 0.00672,
                        0.00845, 0.00812, 0.00848, 0.00756, 0.00692, 0.00776, 0.00787, 0.00637],
                       [0.00824, 0.00730, 0.00795, 0.00796, 0.00693, 0.00681, 0.00766,
                        0.00734, 0.00701, 0.00726, 0.00863, 0.00757, 0.00681, 0.00756,
                        0.00708, 0.00623, 0.00676, 0.00531, 0.00622, 0.00599, 0.00569,
                        0.00755, 0.00674, 0.00686, 0.00718, 0.00624, 0.00694, 0.00699, 0.00619],
                       [0.00676, 0.00696, 0.00833, 0.00732, 0.00718, 0.00660, 0.00782,
                        0.00710, 0.00733, 0.00711, 0.00768, 0.00721, 0.00605, 0.00686,
                        0.00716, 0.00648, 0.00565, 0.00657, 0.00642, 0.00602, 0.00607,
                        0.00733, 0.00650, 0.00646, 0.00700, 0.00647, 0.00691, 0.00703, 0.00583],
                       [0.00612, 0.00711, 0.00743, 0.00695, 0.00760, 0.00692, 0.00723,
                        0.00706, 0.00798, 0.00731, 0.00706, 0.00723, 0.00662, 0.00572,
                        0.00679, 0.00717, 0.00556, 0.00809, 0.00688, 0.00691, 0.00621,
                        0.00659, 0.00660, 0.00643, 0.00670, 0.00649, 0.00671, 0.00654, 0.00537],
                       [0.00665, 0.00701, 0.00582, 0.00664, 0.00697, 0.00678, 0.00589,
                        0.00676, 0.00792, 0.00714, 0.00652, 0.00644, 0.00708, 0.00517,
                        0.00635, 0.00734, 0.00599, 0.00718, 0.00619, 0.00743, 0.00603,
                        0.00556, 0.00645, 0.00584, 0.00586, 0.00622, 0.00615, 0.00552, 0.00480],
                       [0.00707, 0.00685, 0.00556, 0.00645, 0.00654, 0.00698, 0.00606,
                        0.00686, 0.00693, 0.00694, 0.00621, 0.00526, 0.00675, 0.00583,
                        0.00628, 0.00629, 0.00576, 0.00545, 0.00601, 0.00740, 0.00646,
                        0.00599, 0.00697, 0.00537, 0.00526, 0.00623, 0.00563, 0.00504, 0.00502],
                       [0.00654, 0.00736, 0.00719, 0.00643, 0.00745, 0.00735, 0.00738,
                        0.00708, 0.00624, 0.00755, 0.00681, 0.00526, 0.00670, 0.00747,
                        0.00646, 0.00553, 0.00628, 0.00592, 0.00749, 0.00744, 0.00680,
                        0.00778, 0.00765, 0.00599, 0.00650, 0.00669, 0.00569, 0.00556, 0.00629],
                       [0.00556, 0.00772, 0.00769, 0.00646, 0.00758, 0.00684, 0.00754,
                        0.00674, 0.00662, 0.00756, 0.00752, 0.00598, 0.00723, 0.00872,
                        0.00643, 0.00584, 0.00769, 0.00670, 0.00846, 0.00699, 0.00638,
                        0.00788, 0.00728, 0.00723, 0.00691, 0.00655, 0.00677, 0.00605, 0.00632],
                       [0.00598, 0.00705, 0.00668, 0.00691, 0.00657, 0.00633, 0.00655,
                        0.00654, 0.00714, 0.00624, 0.00687, 0.00638, 0.00760, 0.00819,
                        0.00594, 0.00649, 0.00779, 0.00557, 0.00775, 0.00668, 0.00606,
                        0.00591, 0.00661, 0.00688, 0.00555, 0.00550, 0.00722, 0.00555, 0.00535],
                       [0.00706, 0.00633, 0.00587, 0.00667, 0.00616, 0.00652, 0.00577,
                        0.00628, 0.00699, 0.00553, 0.00569, 0.00671, 0.00694, 0.00697,
                        0.00549, 0.00703, 0.00584, 0.00460, 0.00647, 0.00683, 0.00620,
                        0.00479, 0.00596, 0.00513, 0.00513, 0.00488, 0.00663, 0.00502, 0.00534],
                       [0.00710, 0.00651, 0.00607, 0.00524, 0.00706, 0.00703, 0.00565,
                        0.00568, 0.00633, 0.00607, 0.00488, 0.00704, 0.00595, 0.00667,
                        0.00579, 0.00710, 0.00438, 0.00497, 0.00583, 0.00655, 0.00653,
                        0.00571, 0.00543, 0.00442, 0.00600, 0.00560, 0.00620, 0.00533, 0.00554],
                       [0.00618, 0.00679, 0.00652, 0.00434, 0.00732, 0.00647, 0.00560,
                        0.00534, 0.00555, 0.00608, 0.00498, 0.00686, 0.00529, 0.00597,
                        0.00642, 0.00582, 0.00466, 0.00582, 0.00605, 0.00563, 0.00630,
                        0.00654, 0.00524, 0.00471, 0.00613, 0.00673, 0.00608, 0.00516, 0.00510],
                       [0.00522, 0.00578, 0.00633, 0.00524, 0.00596, 0.00487, 0.00567,
                        0.00547, 0.00526, 0.00526, 0.00625, 0.00610, 0.00518, 0.00511,
                        0.00657, 0.00476, 0.00598, 0.00662, 0.00588, 0.00488, 0.00601,
                        0.00616, 0.00534, 0.00470, 0.00583, 0.00679, 0.00630, 0.00442, 0.00457],
                       [0.00541, 0.00460, 0.00642, 0.00646, 0.00469, 0.00430, 0.00630,
                        0.00564, 0.00529, 0.00519, 0.00677, 0.00547, 0.00564, 0.00640,
                        0.00587, 0.00551, 0.00728, 0.00694, 0.00508, 0.00482, 0.00553,
                        0.00532, 0.00555, 0.00489, 0.00597, 0.00559, 0.00661, 0.00465, 0.00466],
                       [0.00607, 0.00446, 0.00664, 0.00646, 0.00461, 0.00518, 0.00614,
                        0.00552, 0.00581, 0.00657, 0.00567, 0.00524, 0.00566, 0.00777,
                        0.00536, 0.00639, 0.00715, 0.00638, 0.00495, 0.00498, 0.00496,
                        0.00479, 0.00555, 0.00587, 0.00565, 0.00456, 0.00638, 0.00548, 0.00460],
                       [0.00589, 0.00561, 0.00658, 0.00670, 0.00585, 0.00608, 0.00550,
                        0.00616, 0.00708, 0.00776, 0.00496, 0.00587, 0.00533, 0.00677,
                        0.00621, 0.00621, 0.00628, 0.00570, 0.00608, 0.00523, 0.00579,
                        0.00521, 0.00541, 0.00690, 0.00541, 0.00548, 0.00580, 0.00598, 0.00444],
                       [0.00494, 0.00627, 0.00581, 0.00640, 0.00606, 0.00514, 0.00505,
                        0.00630, 0.00693, 0.00682, 0.00494, 0.00584, 0.00455, 0.00512,
                        0.00640, 0.00520, 0.00588, 0.00466, 0.00657, 0.00471, 0.00603,
                        0.00528, 0.00520, 0.00579, 0.00537, 0.00587, 0.00505, 0.00535, 0.00424],
                       [0.00431, 0.00549, 0.00478, 0.00477, 0.00464, 0.00356, 0.00473,
                        0.00482, 0.00517, 0.00483, 0.00455, 0.00482, 0.00399, 0.00435,
                        0.00473, 0.00452, 0.00501, 0.00389, 0.00545, 0.00359, 0.00452,
                        0.00400, 0.00468, 0.00391, 0.00445, 0.00469, 0.00414, 0.00393, 0.00363],
                       [0.00450, 0.00501, 0.00397, 0.00382, 0.00374, 0.00351, 0.00439,
                        0.00376, 0.00382, 0.00425, 0.00426, 0.00458, 0.00364, 0.00413,
                        0.00348, 0.00450, 0.00399, 0.00407, 0.00470, 0.00317, 0.00355,
                        0.00296, 0.00437, 0.00358, 0.00388, 0.00409, 0.00360, 0.00339, 0.00325],
                       [0.00441, 0.00432, 0.00275, 0.00412, 0.00355, 0.00401, 0.00426,
                        0.00410, 0.00333, 0.00455, 0.00392, 0.00460, 0.00327, 0.00417,
                        0.00352, 0.00437, 0.00355, 0.00424, 0.00465, 0.00365, 0.00357,
                        0.00309, 0.00404, 0.00415, 0.00381, 0.00429, 0.00322, 0.00387, 0.00348],
                       [0.00371, 0.00302, 0.00214, 0.00453, 0.00361, 0.00377, 0.00464,
                        0.00462, 0.00338, 0.00388, 0.00367, 0.00409, 0.00327, 0.00427,
                        0.00394, 0.00391, 0.00379, 0.00420, 0.00424, 0.00417, 0.00351,
                        0.00384, 0.00343, 0.00424, 0.00344, 0.00429, 0.00322, 0.00400, 0.00395],
                       [0.00312, 0.00241, 0.00284, 0.00375, 0.00349, 0.00306, 0.00443,
                        0.00387, 0.00349, 0.00288, 0.00337, 0.00328, 0.00358, 0.00373,
                        0.00352, 0.00313, 0.00366, 0.00361, 0.00323, 0.00389, 0.00308,
                        0.00365, 0.00265, 0.00335, 0.00297, 0.00354, 0.00330, 0.00306, 0.00363],
                       [0.00261, 0.00241, 0.00334, 0.00247, 0.00290, 0.00266, 0.00315,
                        0.00248, 0.00278, 0.00243, 0.00275, 0.00252, 0.00307, 0.00274,
                        0.00245, 0.00237, 0.00269, 0.00241, 0.00223, 0.00283, 0.00269,
                        0.00257, 0.00214, 0.00232, 0.00267, 0.00270, 0.00288, 0.00239, 0.00265],
                       [0.00214, 0.00229, 0.00263, 0.00189, 0.00237, 0.00227, 0.00215,
                        0.00178, 0.00201, 0.00220, 0.00216, 0.00217, 0.00200, 0.00195,
                        0.00185, 0.00185, 0.00191, 0.00171, 0.00180, 0.00187, 0.00224,
                        0.00184, 0.00215, 0.00205, 0.00235, 0.00218, 0.00221, 0.00227, 0.00191],
                       [0.00199, 0.00203, 0.00194, 0.00203, 0.00211, 0.00212, 0.00197,
                        0.00191, 0.00215, 0.00211, 0.00204, 0.00208, 0.00153, 0.00189,
                        0.00172, 0.00173, 0.00190, 0.00187, 0.00192, 0.00164, 0.00203,
                        0.00181, 0.00249, 0.00227, 0.00200, 0.00210, 0.00181, 0.00209, 0.00172],
                       [0.00189, 0.00190, 0.00217, 0.00231, 0.00193, 0.00211, 0.00206,
                        0.00236, 0.00267, 0.00201, 0.00213, 0.00196, 0.00173, 0.00241,
                        0.00181, 0.00198, 0.00229, 0.00232, 0.00216, 0.00196, 0.00207,
                        0.00198, 0.00248, 0.00233, 0.00186, 0.00214, 0.00197, 0.00199, 0.00157],
                       [0.00154, 0.00182, 0.00236, 0.00180, 0.00144, 0.00170, 0.00187,
                        0.00208, 0.00247, 0.00167, 0.00188, 0.00167, 0.00192, 0.00240,
                        0.00188, 0.00186, 0.00199, 0.00214, 0.00196, 0.00193, 0.00192,
                        0.00194, 0.00160, 0.00200, 0.00167, 0.00168, 0.00208, 0.00205, 0.00110],
                       [0.00139, 0.00187, 0.00176, 0.00109, 0.00133, 0.00151, 0.00161,
                        0.00143, 0.00178, 0.00139, 0.00153, 0.00152, 0.00183, 0.00163,
                        0.00186, 0.00138, 0.00164, 0.00168, 0.00152, 0.00151, 0.00167,
                        0.00183, 0.00112, 0.00173, 0.00163, 0.00126, 0.00188, 0.00184, 0.00097],
                       [0.00173, 0.00207, 0.00137, 0.00124, 0.00176, 0.00189, 0.00181,
                        0.00147, 0.00162, 0.00143, 0.00158, 0.00170, 0.00195, 0.00127,
                        0.00181, 0.00134, 0.00204, 0.00167, 0.00150, 0.00154, 0.00150,
                        0.00194, 0.00167, 0.00195, 0.00199, 0.00149, 0.00190, 0.00163, 0.00143],
                       [0.00205, 0.00218, 0.00154, 0.00185, 0.00231, 0.00225, 0.00216,
                        0.00212, 0.00190, 0.00162, 0.00185, 0.00190, 0.00203, 0.00200,
                        0.00188, 0.00166, 0.00228, 0.00184, 0.00196, 0.00185, 0.00139,
                        0.00193, 0.00240, 0.00215, 0.00236, 0.00182, 0.00200, 0.00169, 0.00177],
                       [0.00213, 0.00212, 0.00206, 0.00220, 0.00208, 0.00242, 0.00234,
                        0.00255, 0.00217, 0.00189, 0.00201, 0.00224, 0.00172, 0.00289,
                        0.00210, 0.00205, 0.00208, 0.00187, 0.00243, 0.00202, 0.00171,
                        0.00187, 0.00251, 0.00211, 0.00214, 0.00185, 0.00200, 0.00191, 0.00186],
                       [0.00206, 0.00213, 0.00231, 0.00199, 0.00156, 0.00232, 0.00222,
                        0.00229, 0.00223, 0.00198, 0.00201, 0.00219, 0.00166, 0.00252,
                        0.00203, 0.00222, 0.00193, 0.00185, 0.00213, 0.00203, 0.00227,
                        0.00198, 0.00196, 0.00198, 0.00167, 0.00172, 0.00186, 0.00204, 0.00180],
                       [0.00168, 0.00201, 0.00184, 0.00154, 0.00157, 0.00178, 0.00177,
                        0.00174, 0.00186, 0.00160, 0.00172, 0.00156, 0.00171, 0.00159,
                        0.00141, 0.00168, 0.00163, 0.00159, 0.00149, 0.00170, 0.00190,
                        0.00177, 0.00145, 0.00156, 0.00134, 0.00153, 0.00155, 0.00175, 0.00147],
                       [0.00139, 0.00179, 0.00146, 0.00140, 0.00178, 0.00153, 0.00137,
                        0.00139, 0.00166, 0.00132, 0.00148, 0.00131, 0.00162, 0.00152,
                        0.00118, 0.00131, 0.00138, 0.00130, 0.00143, 0.00147, 0.00145,
                        0.00141, 0.00120, 0.00134, 0.00135, 0.00149, 0.00149, 0.00148, 0.00141],
                       [0.00123, 0.00160, 0.00150, 0.00146, 0.00180, 0.00158, 0.00139,
                        0.00120, 0.00169, 0.00143, 0.00149, 0.00145, 0.00146, 0.00177,
                        0.00130, 0.00145, 0.00138, 0.00137, 0.00166, 0.00150, 0.00151,
                        0.00120, 0.00128, 0.00149, 0.00158, 0.00146, 0.00158, 0.00147, 0.00160],
                       ])),
    r=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                            100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                            180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                            260.0, 270.0, 280.0]),
           lam=np.array([500.06, 500.48, 500.90, 501.31, 501.73, 502.15, 502.57, 502.98,
                         503.40, 503.82, 504.24, 504.66, 505.08, 505.49, 505.91, 506.33,
                         506.75, 507.17, 507.59, 508.01, 508.42, 508.84, 509.26, 509.68,
                         510.10, 510.52, 510.94, 511.36, 511.77, 512.19, 512.61, 513.03,
                         513.45, 513.87, 514.29, 514.71, 515.13, 515.55, 515.97, 516.39,
                         516.81, 517.23, 517.64, 518.06, 518.48, 518.90, 519.32, 519.74,
                         520.16, 520.58, 521.00, 521.42, 521.84, 522.26, 522.68, 523.10,
                         523.52, 523.94, 524.36, 524.78, 525.20, 525.63, 526.05, 526.47,
                         526.89, 527.31, 527.73, 528.15, 528.57, 528.99, 529.41, 529.83,
                         530.25, 530.67, 531.09, 531.52, 531.94, 532.36, 532.78, 533.20,
                         533.62, 534.04, 534.46, 534.89, 535.31, 535.73, 536.15, 536.57,
                         536.99, 537.41, 537.84, 538.26, 538.68, 539.10, 539.52, 539.95,
                         540.37, 540.79, 541.21, 541.63, 542.06, 542.48, 542.90, 543.32,
                         543.74, 544.17, 544.59, 545.01, 545.43, 545.86, 546.28, 546.70,
                         547.12, 547.55, 547.97, 548.39, 548.81, 549.24, 549.66, 550.08,
                         550.51, 550.93, 551.35, 551.78, 552.20, 552.62, 553.04, 553.47,
                         553.89, 554.31, 554.74, 555.16, 555.58, 556.01, 556.43, 556.86,
                         557.28, 557.70, 558.13, 558.55, 558.97, 559.40, 559.82, 560.25,
                         560.67, 561.09, 561.52, 561.94, 562.37, 562.79, 563.21, 563.64,
                         564.06, 564.49, 564.91, 565.34, 565.76, 566.18, 566.61, 567.03,
                         567.46, 567.88, 568.31, 568.73, 569.16, 569.58, 570.01, 570.43,
                         570.86, 571.28, 571.71, 572.13, 572.56, 572.98, 573.41, 573.83,
                         574.26, 574.68, 575.11, 575.53, 575.96, 576.39, 576.81, 577.24,
                         577.66, 578.09, 578.51, 578.94, 579.36, 579.79, 580.22, 580.64,
                         581.07, 581.49, 581.92, 582.35, 582.77, 583.20, 583.62, 584.05,
                         584.48, 584.90, 585.33, 585.76, 586.18, 586.61, 587.04, 587.46,
                         587.89, 588.32, 588.74, 589.17, 589.60, 590.02, 590.45, 590.88,
                         591.30, 591.73, 592.16, 592.58, 593.01, 593.44, 593.87, 594.29,
                         594.72, 595.15, 595.57, 596.00, 596.43, 596.86, 597.28, 597.71,
                         598.14, 598.57, 599.00, 599.42, 599.85, 600.28, 600.71, 601.13,
                         601.56, 601.99, 602.42, 602.85, 603.27, 603.70, 604.13, 604.56,
                         604.99, 605.41, 605.84, 606.27, 606.70, 607.13, 607.56, 607.99,
                         608.41, 608.84, 609.27, 609.70, 610.13, 610.56, 610.99, 611.41,
                         611.84, 612.27, 612.70, 613.13, 613.56, 613.99, 614.42, 614.85,
                         615.28, 615.71, 616.13, 616.56, 616.99, 617.42, 617.85, 618.28,
                         618.71, 619.14, 619.57, 620.00, 620.43, 620.86, 621.29, 621.72,
                         622.15, 622.58, 623.01, 623.44, 623.87, 624.30, 624.73, 625.16,
                         625.59, 626.02, 626.45, 626.88, 627.31, 627.74, 628.17, 628.60,
                         629.03, 629.46, 629.89, 630.32, 630.75, 631.18, 631.61, 632.04,
                         632.48, 632.91, 633.34, 633.77, 634.20, 634.63, 635.06, 635.49,
                         635.92, 636.35, 636.79, 637.22, 637.65, 638.08, 638.51, 638.94,
                         639.37, 639.80, 640.24, 640.67, 641.10, 641.53, 641.96, 642.39,
                         642.83, 643.26, 643.69, 644.12, 644.55, 644.98, 645.42, 645.85,
                         646.28, 646.71, 647.14, 647.58, 648.01, 648.44, 648.87, 649.31,
                         649.74, 650.17, 650.60, 651.03, 651.47, 651.90, 652.33, 652.76,
                         653.20, 653.63, 654.06, 654.50, 654.93, 655.36, 655.79, 656.23,
                         656.66, 657.09, 657.53, 657.96, 658.39, 658.82, 659.26, 659.69,
                         660.12, 660.56, 660.99, 661.42, 661.86, 662.29, 662.72, 663.16,
                         663.59, 664.02, 664.46, 664.89, 665.33, 665.76, 666.19, 666.63,
                         667.06, 667.49, 667.93, 668.36, 668.80, 669.23, 669.66, 670.10,
                         670.53, 670.97, 671.40, 671.83, 672.27, 672.70, 673.14, 673.57,
                         674.01, 674.44, 674.87, 675.31, 675.74, 676.18, 676.61, 677.05,
                         677.48, 677.92, 678.35, 678.79, 679.22, 679.66, 680.09, 680.53,
                         680.96, 681.40, 681.83, 682.27, 682.70, 683.14, 683.57, 684.01,
                         684.44, 684.88, 685.31, 685.75, 686.18, 686.62, 687.05, 687.49,
                         687.93, 688.36, 688.80, 689.23, 689.67, 690.10, 690.54, 690.98,
                         691.41, 691.85, 692.28, 692.72, 693.16, 693.59, 694.03, 694.46,
                         694.90, 695.34, 695.77, 696.21, 696.64, 697.08, 697.52, 697.95,
                         698.39, 698.83, 699.26, 699.70, 700.14, 700.57, 701.01, 701.45,
                         701.88, 702.32, 702.76, 703.19, 703.63, 704.07, 704.50, 704.94,
                         705.38, 705.81, 706.25, 706.69, 707.13, 707.56, 708.00, 708.44,
                         708.87, 709.31, 709.75, 710.19, 710.62, 711.06, 711.50, 711.94,
                         712.37, 712.81, 713.25, 713.69, 714.12, 714.56, 715.00, 715.44,
                         715.88, 716.31, 716.75, 717.19, 717.63, 718.07, 718.50, 718.94,
                         719.38, 719.82, 720.26, 720.69, 721.13, 721.57, 722.01, 722.45,
                         722.89, 723.32, 723.76, 724.20, 724.64, 725.08, 725.52, 725.95,
                         726.39, 726.83, 727.27, 727.71, 728.15, 728.59, 729.03, 729.47,
                         729.90, 730.34, 730.78, 731.22, 731.66, 732.10, 732.54, 732.98,
                         733.42, 733.86, 734.29, 734.73, 735.17, 735.61, 736.05, 736.49,
                         736.93, 737.37, 737.81, 738.25, 738.69, 739.13, 739.57]),
           T=np.array([[0.00669, 0.00635, 0.00642, 0.00634, 0.00609, 0.00587, 0.00579,
                        0.00615, 0.00595, 0.00612, 0.00589, 0.00613, 0.00604, 0.00583,
                        0.00601, 0.00600, 0.00589, 0.00619, 0.00596, 0.00576, 0.00642,
                        0.00599, 0.00614, 0.00600, 0.00596, 0.00592, 0.00595, 0.00598, 0.00555],
                       [0.00642, 0.00598, 0.00631, 0.00620, 0.00587, 0.00604, 0.00627,
                        0.00599, 0.00593, 0.00633, 0.00611, 0.00584, 0.00594, 0.00595,
                        0.00605, 0.00590, 0.00578, 0.00637, 0.00603, 0.00594, 0.00636,
                        0.00611, 0.00618, 0.00587, 0.00588, 0.00558, 0.00606, 0.00590, 0.00551],
                       [0.00634, 0.00604, 0.00628, 0.00621, 0.00602, 0.00612, 0.00645,
                        0.00627, 0.00597, 0.00648, 0.00607, 0.00564, 0.00588, 0.00586,
                        0.00596, 0.00602, 0.00598, 0.00619, 0.00622, 0.00613, 0.00588,
                        0.00607, 0.00610, 0.00582, 0.00583, 0.00569, 0.00607, 0.00591, 0.00524],
                       [0.00646, 0.00629, 0.00641, 0.00629, 0.00637, 0.00610, 0.00630,
                        0.00643, 0.00614, 0.00626, 0.00582, 0.00559, 0.00605, 0.00570,
                        0.00603, 0.00621, 0.00606, 0.00603, 0.00607, 0.00625, 0.00580,
                        0.00601, 0.00606, 0.00601, 0.00591, 0.00629, 0.00589, 0.00596, 0.00531],
                       [0.00633, 0.00630, 0.00633, 0.00624, 0.00657, 0.00609, 0.00609,
                        0.00620, 0.00634, 0.00616, 0.00580, 0.00571, 0.00635, 0.00575,
                        0.00632, 0.00618, 0.00571, 0.00606, 0.00587, 0.00631, 0.00595,
                        0.00603, 0.00597, 0.00624, 0.00586, 0.00642, 0.00593, 0.00599, 0.00558],
                       [0.00620, 0.00653, 0.00622, 0.00614, 0.00645, 0.00618, 0.00598,
                        0.00613, 0.00637, 0.00623, 0.00606, 0.00596, 0.00608, 0.00587,
                        0.00640, 0.00615, 0.00562, 0.00601, 0.00601, 0.00614, 0.00592,
                        0.00598, 0.00601, 0.00620, 0.00576, 0.00605, 0.00619, 0.00616, 0.00534],
                       [0.00626, 0.00675, 0.00629, 0.00617, 0.00614, 0.00633, 0.00596,
                        0.00619, 0.00617, 0.00611, 0.00617, 0.00598, 0.00552, 0.00582,
                        0.00614, 0.00610, 0.00584, 0.00576, 0.00604, 0.00594, 0.00582,
                        0.00595, 0.00621, 0.00588, 0.00592, 0.00586, 0.00610, 0.00614, 0.00494],
                       [0.00643, 0.00650, 0.00631, 0.00618, 0.00588, 0.00649, 0.00603,
                        0.00620, 0.00604, 0.00600, 0.00600, 0.00597, 0.00566, 0.00572,
                        0.00596, 0.00594, 0.00600, 0.00557, 0.00587, 0.00596, 0.00597,
                        0.00605, 0.00621, 0.00563, 0.00601, 0.00582, 0.00589, 0.00605, 0.00515],
                       [0.00646, 0.00611, 0.00628, 0.00606, 0.00574, 0.00650, 0.00608,
                        0.00623, 0.00599, 0.00612, 0.00582, 0.00612, 0.00598, 0.00581,
                        0.00603, 0.00589, 0.00609, 0.00578, 0.00583, 0.00618, 0.00616,
                        0.00604, 0.00598, 0.00589, 0.00580, 0.00593, 0.00600, 0.00599, 0.00551],
                       [0.00623, 0.00623, 0.00633, 0.00613, 0.00595, 0.00625, 0.00594,
                        0.00614, 0.00579, 0.00618, 0.00589, 0.00610, 0.00588, 0.00613,
                        0.00611, 0.00588, 0.00613, 0.00632, 0.00579, 0.00634, 0.00604,
                        0.00591, 0.00584, 0.00618, 0.00582, 0.00598, 0.00609, 0.00570, 0.00542],
                       [0.00617, 0.00640, 0.00633, 0.00636, 0.00627, 0.00600, 0.00605,
                        0.00604, 0.00567, 0.00595, 0.00597, 0.00580, 0.00587, 0.00623,
                        0.00606, 0.00585, 0.00610, 0.00646, 0.00572, 0.00618, 0.00580,
                        0.00585, 0.00598, 0.00603, 0.00613, 0.00580, 0.00580, 0.00558, 0.00522],
                       [0.00644, 0.00607, 0.00616, 0.00636, 0.00623, 0.00601, 0.00628,
                        0.00602, 0.00574, 0.00574, 0.00580, 0.00561, 0.00606, 0.00605,
                        0.00589, 0.00589, 0.00600, 0.00614, 0.00578, 0.00598, 0.00583,
                        0.00596, 0.00620, 0.00594, 0.00616, 0.00574, 0.00550, 0.00597, 0.00528],
                       [0.00648, 0.00596, 0.00598, 0.00608, 0.00606, 0.00613, 0.00608,
                        0.00600, 0.00594, 0.00567, 0.00568, 0.00566, 0.00599, 0.00584,
                        0.00577, 0.00584, 0.00575, 0.00609, 0.00589, 0.00593, 0.00606,
                        0.00596, 0.00628, 0.00607, 0.00590, 0.00589, 0.00560, 0.00616, 0.00548],
                       [0.00614, 0.00624, 0.00607, 0.00601, 0.00612, 0.00628, 0.00592,
                        0.00615, 0.00602, 0.00564, 0.00575, 0.00576, 0.00579, 0.00573,
                        0.00603, 0.00598, 0.00557, 0.00620, 0.00587, 0.00590, 0.00612,
                        0.00571, 0.00613, 0.00595, 0.00579, 0.00602, 0.00603, 0.00570, 0.00549],
                       [0.00600, 0.00645, 0.00632, 0.00618, 0.00629, 0.00638, 0.00592,
                        0.00632, 0.00586, 0.00592, 0.00600, 0.00585, 0.00585, 0.00593,
                        0.00634, 0.00636, 0.00569, 0.00606, 0.00562, 0.00586, 0.00606,
                        0.00570, 0.00600, 0.00574, 0.00587, 0.00600, 0.00627, 0.00523, 0.00522],
                       [0.00620, 0.00648, 0.00630, 0.00605, 0.00631, 0.00617, 0.00588,
                        0.00621, 0.00561, 0.00622, 0.00606, 0.00582, 0.00592, 0.00613,
                        0.00603, 0.00630, 0.00593, 0.00595, 0.00562, 0.00577, 0.00593,
                        0.00599, 0.00590, 0.00559, 0.00593, 0.00580, 0.00595, 0.00549, 0.00511],
                       [0.00619, 0.00639, 0.00617, 0.00588, 0.00622, 0.00588, 0.00594,
                        0.00602, 0.00556, 0.00608, 0.00582, 0.00577, 0.00588, 0.00599,
                        0.00561, 0.00605, 0.00598, 0.00608, 0.00604, 0.00578, 0.00589,
                        0.00615, 0.00568, 0.00561, 0.00585, 0.00561, 0.00546, 0.00598, 0.00524],
                       [0.00594, 0.00622, 0.00614, 0.00612, 0.00609, 0.00586, 0.00603,
                        0.00580, 0.00575, 0.00578, 0.00570, 0.00577, 0.00578, 0.00593,
                        0.00571, 0.00611, 0.00579, 0.00603, 0.00618, 0.00596, 0.00595,
                        0.00599, 0.00567, 0.00585, 0.00570, 0.00572, 0.00556, 0.00604, 0.00520],
                       [0.00594, 0.00617, 0.00613, 0.00633, 0.00592, 0.00588, 0.00608,
                        0.00581, 0.00594, 0.00581, 0.00569, 0.00572, 0.00566, 0.00605,
                        0.00606, 0.00630, 0.00568, 0.00576, 0.00595, 0.00599, 0.00578,
                        0.00583, 0.00588, 0.00597, 0.00578, 0.00588, 0.00598, 0.00591, 0.00512],
                       [0.00601, 0.00628, 0.00628, 0.00609, 0.00593, 0.00585, 0.00600,
                        0.00601, 0.00591, 0.00608, 0.00562, 0.00556, 0.00576, 0.00593,
                        0.00607, 0.00622, 0.00577, 0.00570, 0.00582, 0.00580, 0.00562,
                        0.00587, 0.00603, 0.00591, 0.00604, 0.00576, 0.00600, 0.00570, 0.00519],
                       [0.00598, 0.00621, 0.00649, 0.00589, 0.00626, 0.00609, 0.00585,
                        0.00604, 0.00580, 0.00606, 0.00578, 0.00559, 0.00611, 0.00587,
                        0.00579, 0.00602, 0.00595, 0.00585, 0.00584, 0.00577, 0.00586,
                        0.00600, 0.00591, 0.00576, 0.00610, 0.00566, 0.00586, 0.00570, 0.00536],
                       [0.00605, 0.00586, 0.00625, 0.00604, 0.00633, 0.00639, 0.00589,
                        0.00587, 0.00585, 0.00577, 0.00599, 0.00581, 0.00611, 0.00599,
                        0.00555, 0.00590, 0.00600, 0.00579, 0.00579, 0.00589, 0.00616,
                        0.00597, 0.00567, 0.00546, 0.00583, 0.00579, 0.00582, 0.00613, 0.00550],
                       [0.00609, 0.00576, 0.00592, 0.00607, 0.00608, 0.00633, 0.00599,
                        0.00572, 0.00598, 0.00574, 0.00598, 0.00583, 0.00573, 0.00591,
                        0.00548, 0.00584, 0.00595, 0.00566, 0.00574, 0.00587, 0.00596,
                        0.00592, 0.00574, 0.00543, 0.00562, 0.00577, 0.00579, 0.00633, 0.00538],
                       [0.00611, 0.00620, 0.00586, 0.00583, 0.00591, 0.00595, 0.00598,
                        0.00570, 0.00602, 0.00578, 0.00593, 0.00566, 0.00561, 0.00572,
                        0.00579, 0.00581, 0.00590, 0.00590, 0.00572, 0.00564, 0.00550,
                        0.00597, 0.00606, 0.00574, 0.00571, 0.00556, 0.00580, 0.00595, 0.00521],
                       [0.00626, 0.00643, 0.00593, 0.00583, 0.00593, 0.00561, 0.00596,
                        0.00583, 0.00600, 0.00579, 0.00584, 0.00564, 0.00569, 0.00568,
                        0.00606, 0.00573, 0.00571, 0.00610, 0.00572, 0.00570, 0.00549,
                        0.00585, 0.00612, 0.00596, 0.00591, 0.00566, 0.00589, 0.00547, 0.00523],
                       [0.00634, 0.00606, 0.00591, 0.00602, 0.00607, 0.00573, 0.00596,
                        0.00597, 0.00600, 0.00590, 0.00581, 0.00585, 0.00579, 0.00581,
                        0.00580, 0.00573, 0.00556, 0.00599, 0.00582, 0.00603, 0.00585,
                        0.00571, 0.00595, 0.00579, 0.00600, 0.00598, 0.00598, 0.00549, 0.00515],
                       [0.00618, 0.00575, 0.00575, 0.00593, 0.00608, 0.00605, 0.00594,
                        0.00583, 0.00615, 0.00592, 0.00594, 0.00607, 0.00579, 0.00614,
                        0.00550, 0.00590, 0.00562, 0.00584, 0.00586, 0.00602, 0.00586,
                        0.00569, 0.00589, 0.00559, 0.00595, 0.00599, 0.00591, 0.00579, 0.00499],
                       [0.00589, 0.00586, 0.00572, 0.00571, 0.00596, 0.00614, 0.00603,
                        0.00556, 0.00623, 0.00596, 0.00604, 0.00597, 0.00564, 0.00625,
                        0.00549, 0.00590, 0.00561, 0.00569, 0.00583, 0.00580, 0.00558,
                        0.00575, 0.00581, 0.00576, 0.00589, 0.00579, 0.00563, 0.00593, 0.00512],
                       [0.00585, 0.00606, 0.00589, 0.00574, 0.00594, 0.00602, 0.00591,
                        0.00565, 0.00599, 0.00598, 0.00594, 0.00554, 0.00568, 0.00583,
                        0.00571, 0.00568, 0.00565, 0.00555, 0.00582, 0.00578, 0.00566,
                        0.00587, 0.00562, 0.00591, 0.00578, 0.00582, 0.00547, 0.00592, 0.00531],
                       [0.00603, 0.00621, 0.00606, 0.00596, 0.00608, 0.00580, 0.00552,
                        0.00592, 0.00570, 0.00568, 0.00578, 0.00542, 0.00596, 0.00554,
                        0.00606, 0.00564, 0.00583, 0.00545, 0.00579, 0.00585, 0.00588,
                        0.00577, 0.00552, 0.00586, 0.00570, 0.00597, 0.00574, 0.00579, 0.00525],
                       [0.00608, 0.00620, 0.00592, 0.00600, 0.00617, 0.00552, 0.00539,
                        0.00602, 0.00564, 0.00548, 0.00580, 0.00570, 0.00584, 0.00569,
                        0.00595, 0.00577, 0.00576, 0.00560, 0.00572, 0.00571, 0.00573,
                        0.00553, 0.00567, 0.00575, 0.00579, 0.00585, 0.00590, 0.00565, 0.00524],
                       [0.00605, 0.00610, 0.00565, 0.00592, 0.00611, 0.00560, 0.00569,
                        0.00609, 0.00580, 0.00576, 0.00580, 0.00573, 0.00557, 0.00589,
                        0.00547, 0.00581, 0.00559, 0.00590, 0.00569, 0.00559, 0.00571,
                        0.00563, 0.00596, 0.00566, 0.00602, 0.00572, 0.00564, 0.00566, 0.00529],
                       [0.00607, 0.00604, 0.00565, 0.00586, 0.00594, 0.00602, 0.00599,
                        0.00599, 0.00596, 0.00603, 0.00560, 0.00563, 0.00569, 0.00601,
                        0.00532, 0.00572, 0.00567, 0.00577, 0.00569, 0.00570, 0.00591,
                        0.00596, 0.00590, 0.00579, 0.00613, 0.00586, 0.00551, 0.00572, 0.00533],
                       [0.00618, 0.00605, 0.00592, 0.00573, 0.00577, 0.00600, 0.00579,
                        0.00575, 0.00597, 0.00588, 0.00565, 0.00572, 0.00568, 0.00584,
                        0.00563, 0.00559, 0.00577, 0.00537, 0.00562, 0.00585, 0.00580,
                        0.00602, 0.00561, 0.00598, 0.00597, 0.00588, 0.00573, 0.00571, 0.00544],
                       [0.00623, 0.00616, 0.00607, 0.00559, 0.00584, 0.00567, 0.00553,
                        0.00569, 0.00586, 0.00570, 0.00590, 0.00581, 0.00550, 0.00558,
                        0.00587, 0.00552, 0.00567, 0.00541, 0.00556, 0.00576, 0.00561,
                        0.00584, 0.00561, 0.00599, 0.00583, 0.00571, 0.00584, 0.00588, 0.00534],
                       [0.00612, 0.00613, 0.00592, 0.00563, 0.00594, 0.00573, 0.00568,
                        0.00578, 0.00573, 0.00573, 0.00590, 0.00567, 0.00560, 0.00569,
                        0.00575, 0.00560, 0.00557, 0.00577, 0.00561, 0.00561, 0.00565,
                        0.00573, 0.00560, 0.00581, 0.00588, 0.00563, 0.00560, 0.00604, 0.00509],
                       [0.00595, 0.00597, 0.00586, 0.00589, 0.00590, 0.00602, 0.00591,
                        0.00588, 0.00572, 0.00587, 0.00585, 0.00553, 0.00578, 0.00587,
                        0.00568, 0.00569, 0.00568, 0.00571, 0.00572, 0.00565, 0.00564,
                        0.00573, 0.00550, 0.00575, 0.00594, 0.00570, 0.00546, 0.00587, 0.00515],
                       [0.00575, 0.00586, 0.00610, 0.00610, 0.00589, 0.00601, 0.00592,
                        0.00588, 0.00580, 0.00588, 0.00590, 0.00556, 0.00581, 0.00575,
                        0.00584, 0.00558, 0.00592, 0.00540, 0.00580, 0.00559, 0.00566,
                        0.00585, 0.00563, 0.00573, 0.00579, 0.00580, 0.00573, 0.00572, 0.00527],
                       [0.00573, 0.00585, 0.00624, 0.00600, 0.00606, 0.00591, 0.00590,
                        0.00581, 0.00582, 0.00575, 0.00587, 0.00553, 0.00584, 0.00579,
                        0.00586, 0.00556, 0.00597, 0.00553, 0.00572, 0.00549, 0.00601,
                        0.00594, 0.00582, 0.00559, 0.00559, 0.00586, 0.00592, 0.00576, 0.00518],
                       [0.00596, 0.00595, 0.00611, 0.00581, 0.00614, 0.00598, 0.00585,
                        0.00569, 0.00581, 0.00581, 0.00573, 0.00540, 0.00580, 0.00596,
                        0.00578, 0.00565, 0.00566, 0.00582, 0.00563, 0.00559, 0.00608,
                        0.00576, 0.00585, 0.00563, 0.00555, 0.00577, 0.00577, 0.00570, 0.00502],
                       [0.00603, 0.00616, 0.00614, 0.00596, 0.00592, 0.00597, 0.00582,
                        0.00562, 0.00579, 0.00613, 0.00567, 0.00555, 0.00581, 0.00584,
                        0.00587, 0.00549, 0.00553, 0.00574, 0.00579, 0.00589, 0.00572,
                        0.00559, 0.00582, 0.00581, 0.00567, 0.00569, 0.00571, 0.00567, 0.00499],
                       [0.00594, 0.00624, 0.00611, 0.00609, 0.00575, 0.00586, 0.00588,
                        0.00564, 0.00565, 0.00621, 0.00569, 0.00572, 0.00602, 0.00560,
                        0.00591, 0.00538, 0.00574, 0.00553, 0.00579, 0.00598, 0.00541,
                        0.00560, 0.00584, 0.00577, 0.00575, 0.00566, 0.00579, 0.00567, 0.00518],
                       [0.00589, 0.00606, 0.00577, 0.00588, 0.00577, 0.00589, 0.00597,
                        0.00574, 0.00560, 0.00595, 0.00572, 0.00573, 0.00596, 0.00550,
                        0.00568, 0.00574, 0.00588, 0.00551, 0.00551, 0.00577, 0.00556,
                        0.00556, 0.00574, 0.00574, 0.00567, 0.00563, 0.00570, 0.00556, 0.00515],
                       [0.00583, 0.00591, 0.00560, 0.00569, 0.00589, 0.00598, 0.00596,
                        0.00580, 0.00583, 0.00576, 0.00577, 0.00584, 0.00552, 0.00560,
                        0.00542, 0.00592, 0.00573, 0.00560, 0.00538, 0.00579, 0.00595,
                        0.00543, 0.00555, 0.00586, 0.00573, 0.00572, 0.00562, 0.00553, 0.00485],
                       [0.00591, 0.00600, 0.00591, 0.00593, 0.00601, 0.00596, 0.00589,
                        0.00572, 0.00598, 0.00578, 0.00571, 0.00590, 0.00538, 0.00581,
                        0.00529, 0.00562, 0.00554, 0.00571, 0.00550, 0.00595, 0.00599,
                        0.00543, 0.00563, 0.00592, 0.00587, 0.00581, 0.00569, 0.00568, 0.00491],
                       [0.00613, 0.00611, 0.00638, 0.00629, 0.00601, 0.00592, 0.00593,
                        0.00575, 0.00594, 0.00583, 0.00560, 0.00580, 0.00574, 0.00591,
                        0.00532, 0.00553, 0.00569, 0.00573, 0.00559, 0.00575, 0.00564,
                        0.00555, 0.00588, 0.00589, 0.00592, 0.00589, 0.00566, 0.00578, 0.00518],
                       [0.00610, 0.00606, 0.00648, 0.00622, 0.00595, 0.00592, 0.00589,
                        0.00575, 0.00581, 0.00597, 0.00557, 0.00572, 0.00603, 0.00583,
                        0.00560, 0.00579, 0.00585, 0.00558, 0.00540, 0.00548, 0.00543,
                        0.00562, 0.00585, 0.00572, 0.00594, 0.00585, 0.00550, 0.00578, 0.00513],
                       [0.00588, 0.00599, 0.00626, 0.00603, 0.00581, 0.00592, 0.00571,
                        0.00566, 0.00565, 0.00615, 0.00562, 0.00566, 0.00599, 0.00579,
                        0.00592, 0.00591, 0.00566, 0.00552, 0.00531, 0.00551, 0.00559,
                        0.00564, 0.00577, 0.00562, 0.00580, 0.00581, 0.00564, 0.00570, 0.00505],
                       [0.00593, 0.00595, 0.00620, 0.00602, 0.00565, 0.00590, 0.00577,
                        0.00566, 0.00565, 0.00596, 0.00565, 0.00562, 0.00582, 0.00575,
                        0.00588, 0.00575, 0.00560, 0.00564, 0.00557, 0.00563, 0.00586,
                        0.00556, 0.00587, 0.00570, 0.00567, 0.00599, 0.00591, 0.00550, 0.00519],
                       [0.00622, 0.00599, 0.00626, 0.00601, 0.00583, 0.00595, 0.00604,
                        0.00574, 0.00587, 0.00557, 0.00573, 0.00561, 0.00583, 0.00559,
                        0.00561, 0.00564, 0.00603, 0.00579, 0.00570, 0.00566, 0.00603,
                        0.00563, 0.00601, 0.00578, 0.00592, 0.00610, 0.00594, 0.00544, 0.00536],
                       [0.00615, 0.00610, 0.00615, 0.00596, 0.00605, 0.00595, 0.00609,
                        0.00588, 0.00592, 0.00546, 0.00585, 0.00573, 0.00576, 0.00553,
                        0.00550, 0.00555, 0.00625, 0.00587, 0.00551, 0.00557, 0.00591,
                        0.00590, 0.00603, 0.00566, 0.00601, 0.00582, 0.00571, 0.00566, 0.00537],
                       [0.00582, 0.00619, 0.00604, 0.00604, 0.00590, 0.00597, 0.00592,
                        0.00593, 0.00574, 0.00565, 0.00586, 0.00598, 0.00549, 0.00568,
                        0.00565, 0.00555, 0.00591, 0.00574, 0.00557, 0.00541, 0.00560,
                        0.00595, 0.00585, 0.00557, 0.00581, 0.00570, 0.00562, 0.00596, 0.00516],
                       [0.00586, 0.00614, 0.00602, 0.00612, 0.00574, 0.00615, 0.00568,
                        0.00574, 0.00569, 0.00594, 0.00578, 0.00604, 0.00550, 0.00572,
                        0.00572, 0.00577, 0.00566, 0.00558, 0.00584, 0.00543, 0.00553,
                        0.00565, 0.00564, 0.00569, 0.00575, 0.00599, 0.00579, 0.00580, 0.00506],
                       [0.00620, 0.00598, 0.00600, 0.00610, 0.00570, 0.00622, 0.00565,
                        0.00557, 0.00574, 0.00603, 0.00567, 0.00593, 0.00579, 0.00568,
                        0.00557, 0.00580, 0.00580, 0.00572, 0.00580, 0.00573, 0.00578,
                        0.00548, 0.00565, 0.00579, 0.00574, 0.00605, 0.00586, 0.00543, 0.00527],
                       [0.00635, 0.00605, 0.00609, 0.00603, 0.00580, 0.00616, 0.00601,
                        0.00577, 0.00571, 0.00583, 0.00565, 0.00581, 0.00585, 0.00577,
                        0.00553, 0.00567, 0.00590, 0.00592, 0.00565, 0.00599, 0.00600,
                        0.00570, 0.00570, 0.00568, 0.00564, 0.00589, 0.00581, 0.00554, 0.00529],
                       [0.00631, 0.00638, 0.00629, 0.00600, 0.00598, 0.00602, 0.00624,
                        0.00611, 0.00579, 0.00575, 0.00583, 0.00567, 0.00572, 0.00580,
                        0.00570, 0.00562, 0.00579, 0.00588, 0.00575, 0.00583, 0.00597,
                        0.00591, 0.00574, 0.00554, 0.00553, 0.00584, 0.00587, 0.00584, 0.00513],
                       [0.00622, 0.00656, 0.00639, 0.00602, 0.00589, 0.00586, 0.00600,
                        0.00615, 0.00587, 0.00590, 0.00602, 0.00573, 0.00576, 0.00591,
                        0.00590, 0.00555, 0.00569, 0.00574, 0.00590, 0.00558, 0.00572,
                        0.00577, 0.00594, 0.00560, 0.00553, 0.00577, 0.00584, 0.00586, 0.00529],
                       [0.00609, 0.00635, 0.00627, 0.00610, 0.00573, 0.00591, 0.00571,
                        0.00599, 0.00587, 0.00607, 0.00587, 0.00591, 0.00590, 0.00608,
                        0.00592, 0.00553, 0.00573, 0.00563, 0.00592, 0.00581, 0.00563,
                        0.00570, 0.00600, 0.00572, 0.00580, 0.00580, 0.00585, 0.00584, 0.00535],
                       [0.00623, 0.00619, 0.00612, 0.00612, 0.00584, 0.00603, 0.00576,
                        0.00592, 0.00585, 0.00614, 0.00568, 0.00603, 0.00591, 0.00603,
                        0.00582, 0.00572, 0.00589, 0.00573, 0.00586, 0.00605, 0.00592,
                        0.00600, 0.00576, 0.00565, 0.00612, 0.00599, 0.00599, 0.00582, 0.00507],
                       [0.00657, 0.00621, 0.00601, 0.00604, 0.00599, 0.00603, 0.00599,
                        0.00589, 0.00585, 0.00609, 0.00577, 0.00596, 0.00582, 0.00586,
                        0.00579, 0.00600, 0.00595, 0.00593, 0.00578, 0.00592, 0.00612,
                        0.00609, 0.00566, 0.00560, 0.00603, 0.00603, 0.00603, 0.00570, 0.00504],
                       [0.00672, 0.00637, 0.00605, 0.00610, 0.00604, 0.00594, 0.00611,
                        0.00571, 0.00593, 0.00603, 0.00599, 0.00573, 0.00591, 0.00585,
                        0.00585, 0.00604, 0.00582, 0.00600, 0.00579, 0.00574, 0.00593,
                        0.00586, 0.00585, 0.00587, 0.00576, 0.00583, 0.00607, 0.00566, 0.00535],
                       [0.00674, 0.00680, 0.00635, 0.00612, 0.00606, 0.00581, 0.00604,
                        0.00568, 0.00594, 0.00605, 0.00622, 0.00570, 0.00611, 0.00594,
                        0.00586, 0.00575, 0.00570, 0.00595, 0.00589, 0.00567, 0.00569,
                        0.00587, 0.00593, 0.00606, 0.00568, 0.00571, 0.00606, 0.00568, 0.00548],
                       [0.00695, 0.00715, 0.00653, 0.00604, 0.00611, 0.00590, 0.00604,
                        0.00602, 0.00598, 0.00621, 0.00637, 0.00589, 0.00609, 0.00599,
                        0.00588, 0.00574, 0.00574, 0.00600, 0.00587, 0.00583, 0.00572,
                        0.00598, 0.00582, 0.00585, 0.00566, 0.00584, 0.00595, 0.00580, 0.00526],
                       [0.00725, 0.00722, 0.00640, 0.00611, 0.00604, 0.00630, 0.00616,
                        0.00639, 0.00627, 0.00633, 0.00625, 0.00595, 0.00598, 0.00609,
                        0.00595, 0.00590, 0.00585, 0.00609, 0.00568, 0.00598, 0.00586,
                        0.00588, 0.00570, 0.00567, 0.00569, 0.00594, 0.00589, 0.00604, 0.00509],
                       [0.00755, 0.00734, 0.00625, 0.00623, 0.00604, 0.00659, 0.00618,
                        0.00651, 0.00666, 0.00630, 0.00612, 0.00602, 0.00610, 0.00604,
                        0.00603, 0.00584, 0.00586, 0.00599, 0.00578, 0.00590, 0.00587,
                        0.00585, 0.00583, 0.00580, 0.00592, 0.00604, 0.00608, 0.00598, 0.00525],
                       [0.00792, 0.00753, 0.00636, 0.00619, 0.00618, 0.00642, 0.00618,
                        0.00645, 0.00676, 0.00650, 0.00628, 0.00622, 0.00621, 0.00590,
                        0.00613, 0.00580, 0.00578, 0.00590, 0.00611, 0.00592, 0.00576,
                        0.00590, 0.00605, 0.00591, 0.00619, 0.00624, 0.00632, 0.00578, 0.00535],
                       [0.00820, 0.00782, 0.00669, 0.00608, 0.00617, 0.00609, 0.00637,
                        0.00635, 0.00663, 0.00676, 0.00656, 0.00634, 0.00605, 0.00606,
                        0.00617, 0.00591, 0.00584, 0.00609, 0.00630, 0.00615, 0.00583,
                        0.00583, 0.00608, 0.00601, 0.00623, 0.00632, 0.00631, 0.00593, 0.00534],
                       [0.00830, 0.00808, 0.00688, 0.00619, 0.00613, 0.00628, 0.00646,
                        0.00635, 0.00659, 0.00680, 0.00682, 0.00643, 0.00610, 0.00620,
                        0.00615, 0.00614, 0.00611, 0.00616, 0.00641, 0.00630, 0.00604,
                        0.00596, 0.00606, 0.00618, 0.00611, 0.00620, 0.00610, 0.00620, 0.00545],
                       [0.00844, 0.00832, 0.00681, 0.00640, 0.00623, 0.00664, 0.00649,
                        0.00659, 0.00682, 0.00690, 0.00694, 0.00660, 0.00645, 0.00622,
                        0.00621, 0.00631, 0.00640, 0.00599, 0.00642, 0.00617, 0.00614,
                        0.00629, 0.00613, 0.00634, 0.00614, 0.00616, 0.00622, 0.00626, 0.00532],
                       [0.00882, 0.00885, 0.00681, 0.00647, 0.00646, 0.00655, 0.00678,
                        0.00699, 0.00712, 0.00692, 0.00698, 0.00678, 0.00654, 0.00644,
                        0.00633, 0.00630, 0.00640, 0.00606, 0.00617, 0.00603, 0.00616,
                        0.00649, 0.00625, 0.00654, 0.00640, 0.00644, 0.00672, 0.00624, 0.00512],
                       [0.00910, 0.00932, 0.00702, 0.00658, 0.00669, 0.00646, 0.00699,
                        0.00708, 0.00715, 0.00677, 0.00713, 0.00678, 0.00650, 0.00668,
                        0.00650, 0.00634, 0.00628, 0.00633, 0.00606, 0.00620, 0.00630,
                        0.00638, 0.00630, 0.00654, 0.00664, 0.00677, 0.00689, 0.00634, 0.00530],
                       [0.00917, 0.00952, 0.00728, 0.00668, 0.00671, 0.00673, 0.00683,
                        0.00695, 0.00713, 0.00692, 0.00724, 0.00691, 0.00666, 0.00673,
                        0.00672, 0.00654, 0.00631, 0.00663, 0.00638, 0.00646, 0.00638,
                        0.00614, 0.00627, 0.00649, 0.00669, 0.00681, 0.00683, 0.00647, 0.00554],
                       [0.00957, 0.00977, 0.00743, 0.00666, 0.00668, 0.00689, 0.00674,
                        0.00701, 0.00732, 0.00733, 0.00734, 0.00724, 0.00689, 0.00682,
                        0.00681, 0.00669, 0.00651, 0.00687, 0.00657, 0.00649, 0.00638,
                        0.00625, 0.00634, 0.00655, 0.00672, 0.00678, 0.00696, 0.00644, 0.00560],
                       [0.01048, 0.01017, 0.00768, 0.00687, 0.00668, 0.00683, 0.00711,
                        0.00735, 0.00749, 0.00762, 0.00758, 0.00737, 0.00711, 0.00709,
                        0.00692, 0.00680, 0.00685, 0.00674, 0.00661, 0.00647, 0.00666,
                        0.00684, 0.00661, 0.00666, 0.00687, 0.00704, 0.00700, 0.00631, 0.00572],
                       [0.01163, 0.01087, 0.00799, 0.00718, 0.00674, 0.00679, 0.00753,
                        0.00768, 0.00768, 0.00783, 0.00774, 0.00742, 0.00731, 0.00723,
                        0.00713, 0.00696, 0.00706, 0.00654, 0.00682, 0.00663, 0.00688,
                        0.00721, 0.00689, 0.00676, 0.00705, 0.00740, 0.00697, 0.00643, 0.00576],
                       [0.01304, 0.01185, 0.00825, 0.00729, 0.00707, 0.00704, 0.00746,
                        0.00783, 0.00818, 0.00819, 0.00810, 0.00782, 0.00754, 0.00721,
                        0.00733, 0.00717, 0.00714, 0.00690, 0.00713, 0.00701, 0.00682,
                        0.00699, 0.00689, 0.00696, 0.00729, 0.00762, 0.00732, 0.00678, 0.00568],
                       [0.01473, 0.01266, 0.00861, 0.00730, 0.00739, 0.00739, 0.00730,
                        0.00793, 0.00870, 0.00869, 0.00870, 0.00840, 0.00785, 0.00742,
                        0.00754, 0.00741, 0.00717, 0.00741, 0.00724, 0.00734, 0.00691,
                        0.00687, 0.00678, 0.00729, 0.00751, 0.00774, 0.00784, 0.00698, 0.00585],
                       [0.01647, 0.01364, 0.00903, 0.00748, 0.00742, 0.00749, 0.00760,
                        0.00837, 0.00912, 0.00930, 0.00916, 0.00877, 0.00826, 0.00790,
                        0.00774, 0.00764, 0.00721, 0.00749, 0.00732, 0.00740, 0.00729,
                        0.00722, 0.00697, 0.00757, 0.00783, 0.00789, 0.00815, 0.00716, 0.00615],
                       [0.01807, 0.01509, 0.00931, 0.00768, 0.00748, 0.00749, 0.00816,
                        0.00901, 0.00981, 0.00993, 0.00949, 0.00905, 0.00860, 0.00835,
                        0.00796, 0.00791, 0.00761, 0.00750, 0.00758, 0.00745, 0.00764,
                        0.00752, 0.00739, 0.00775, 0.00820, 0.00814, 0.00828, 0.00731, 0.00610],
                       [0.01957, 0.01687, 0.00969, 0.00772, 0.00773, 0.00779, 0.00869,
                        0.00964, 0.01059, 0.01053, 0.00995, 0.00956, 0.00887, 0.00869,
                        0.00832, 0.00838, 0.00822, 0.00776, 0.00792, 0.00779, 0.00779,
                        0.00765, 0.00786, 0.00804, 0.00836, 0.00859, 0.00857, 0.00733, 0.00588],
                       [0.02093, 0.01931, 0.01027, 0.00797, 0.00798, 0.00839, 0.00908,
                        0.01027, 0.01109, 0.01121, 0.01065, 0.01013, 0.00930, 0.00900,
                        0.00870, 0.00880, 0.00856, 0.00823, 0.00826, 0.00819, 0.00788,
                        0.00790, 0.00819, 0.00839, 0.00858, 0.00897, 0.00898, 0.00748, 0.00600],
                       [0.02217, 0.02292, 0.01099, 0.00841, 0.00828, 0.00896, 0.00953,
                        0.01096, 0.01178, 0.01190, 0.01138, 0.01049, 0.00980, 0.00936,
                        0.00910, 0.00917, 0.00875, 0.00875, 0.00873, 0.00850, 0.00820,
                        0.00829, 0.00831, 0.00867, 0.00912, 0.00919, 0.00920, 0.00777, 0.00646],
                       [0.02337, 0.02754, 0.01186, 0.00888, 0.00875, 0.00934, 0.01029,
                        0.01184, 0.01292, 0.01246, 0.01190, 0.01094, 0.01020, 0.00982,
                        0.00952, 0.00955, 0.00905, 0.00918, 0.00925, 0.00892, 0.00874,
                        0.00873, 0.00851, 0.00890, 0.00950, 0.00957, 0.00936, 0.00801, 0.00671],
                       [0.02454, 0.03298, 0.01283, 0.00943, 0.00926, 0.00972, 0.01123,
                        0.01279, 0.01392, 0.01328, 0.01233, 0.01163, 0.01073, 0.01033,
                        0.00979, 0.00975, 0.00945, 0.00949, 0.00953, 0.00937, 0.00914,
                        0.00907, 0.00902, 0.00919, 0.00949, 0.01012, 0.00979, 0.00834, 0.00662],
                       [0.02632, 0.03960, 0.01404, 0.01011, 0.00990, 0.01039, 0.01214,
                        0.01360, 0.01451, 0.01439, 0.01290, 0.01236, 0.01128, 0.01073,
                        0.00997, 0.01002, 0.00986, 0.00973, 0.00975, 0.00969, 0.00949,
                        0.00927, 0.00945, 0.00956, 0.00976, 0.01056, 0.01036, 0.00875, 0.00671],
                       [0.02930, 0.04733, 0.01566, 0.01093, 0.01095, 0.01139, 0.01299,
                        0.01451, 0.01526, 0.01536, 0.01388, 0.01320, 0.01169, 0.01101,
                        0.01053, 0.01058, 0.01020, 0.01001, 0.01003, 0.01007, 0.00995,
                        0.00946, 0.00960, 0.01002, 0.01037, 0.01070, 0.01081, 0.00924, 0.00705],
                       [0.03383, 0.05576, 0.01745, 0.01180, 0.01205, 0.01252, 0.01398,
                        0.01580, 0.01659, 0.01645, 0.01541, 0.01431, 0.01241, 0.01137,
                        0.01144, 0.01106, 0.01054, 0.01048, 0.01031, 0.01040, 0.01037,
                        0.00979, 0.00994, 0.01039, 0.01086, 0.01105, 0.01124, 0.00994, 0.00735],
                       [0.04062, 0.06482, 0.01953, 0.01264, 0.01269, 0.01350, 0.01513,
                        0.01722, 0.01835, 0.01819, 0.01719, 0.01535, 0.01337, 0.01196,
                        0.01192, 0.01117, 0.01097, 0.01095, 0.01068, 0.01063, 0.01059,
                        0.01019, 0.01052, 0.01057, 0.01137, 0.01195, 0.01195, 0.01056, 0.00767],
                       [0.05083, 0.07489, 0.02240, 0.01358, 0.01334, 0.01443, 0.01627,
                        0.01860, 0.02062, 0.02082, 0.01916, 0.01644, 0.01425, 0.01283,
                        0.01214, 0.01149, 0.01146, 0.01124, 0.01120, 0.01117, 0.01086,
                        0.01056, 0.01092, 0.01091, 0.01186, 0.01297, 0.01303, 0.01118, 0.00828],
                       [0.06616, 0.08622, 0.02588, 0.01467, 0.01433, 0.01552, 0.01747,
                        0.02038, 0.02374, 0.02448, 0.02185, 0.01833, 0.01551, 0.01379,
                        0.01277, 0.01250, 0.01202, 0.01170, 0.01177, 0.01189, 0.01126,
                        0.01097, 0.01115, 0.01151, 0.01236, 0.01399, 0.01445, 0.01218, 0.00902],
                       [0.08872, 0.09916, 0.02993, 0.01588, 0.01553, 0.01675, 0.01910,
                        0.02314, 0.02797, 0.02936, 0.02601, 0.02157, 0.01758, 0.01512,
                        0.01402, 0.01377, 0.01298, 0.01272, 0.01258, 0.01256, 0.01181,
                        0.01163, 0.01163, 0.01219, 0.01343, 0.01566, 0.01634, 0.01355, 0.00952],
                       [0.12020, 0.11444, 0.03480, 0.01723, 0.01677, 0.01808, 0.02135,
                        0.02709, 0.03354, 0.03564, 0.03208, 0.02625, 0.02069, 0.01724,
                        0.01595, 0.01523, 0.01448, 0.01409, 0.01376, 0.01350, 0.01276,
                        0.01250, 0.01246, 0.01309, 0.01521, 0.01824, 0.01889, 0.01534, 0.00990],
                       [0.16088, 0.13246, 0.04064, 0.01874, 0.01793, 0.01958, 0.02417,
                        0.03226, 0.04069, 0.04364, 0.03985, 0.03249, 0.02513, 0.02030,
                        0.01874, 0.01766, 0.01677, 0.01595, 0.01561, 0.01512, 0.01427,
                        0.01362, 0.01358, 0.01449, 0.01774, 0.02193, 0.02244, 0.01762, 0.01059],
                       [0.20863, 0.15334, 0.04773, 0.02047, 0.01915, 0.02148, 0.02790,
                        0.03881, 0.04977, 0.05345, 0.04898, 0.04036, 0.03092, 0.02486,
                        0.02272, 0.02158, 0.02037, 0.01897, 0.01855, 0.01766, 0.01638,
                        0.01532, 0.01501, 0.01667, 0.02128, 0.02739, 0.02715, 0.02039, 0.01179],
                       [0.25994, 0.17725, 0.05609, 0.02254, 0.02103, 0.02419, 0.03291,
                        0.04696, 0.06085, 0.06505, 0.05982, 0.04995, 0.03834, 0.03127,
                        0.02852, 0.02713, 0.02536, 0.02352, 0.02274, 0.02123, 0.01948,
                        0.01790, 0.01729, 0.01985, 0.02615, 0.03460, 0.03320, 0.02379, 0.01305],
                       [0.31107, 0.20423, 0.06563, 0.02542, 0.02407, 0.02824, 0.03930,
                        0.05688, 0.07376, 0.07866, 0.07303, 0.06127, 0.04778, 0.03942,
                        0.03650, 0.03441, 0.03175, 0.02961, 0.02841, 0.02643, 0.02396,
                        0.02155, 0.02106, 0.02437, 0.03262, 0.04323, 0.04111, 0.02788, 0.01421],
                       [0.35844, 0.23450, 0.07714, 0.02970, 0.02818, 0.03383, 0.04743,
                        0.06903, 0.08888, 0.09472, 0.08872, 0.07432, 0.05910, 0.04926,
                        0.04630, 0.04351, 0.04007, 0.03748, 0.03590, 0.03360, 0.03002,
                        0.02677, 0.02636, 0.03040, 0.04082, 0.05383, 0.05076, 0.03266, 0.01586],
                       [0.40079, 0.26800, 0.09132, 0.03558, 0.03353, 0.04082, 0.05760,
                        0.08392, 0.10724, 0.11418, 0.10695, 0.08993, 0.07229, 0.06093,
                        0.05771, 0.05457, 0.05063, 0.04742, 0.04542, 0.04242, 0.03791,
                        0.03401, 0.03323, 0.03814, 0.05101, 0.06696, 0.06193, 0.03857, 0.01818],
                       [0.44022, 0.30348, 0.10800, 0.04308, 0.04062, 0.04948, 0.06983,
                        0.10186, 0.12947, 0.13755, 0.12806, 0.10870, 0.08774, 0.07448,
                        0.07074, 0.06751, 0.06299, 0.05907, 0.05679, 0.05303, 0.04758,
                        0.04295, 0.04189, 0.04787, 0.06328, 0.08226, 0.07533, 0.04592, 0.02095],
                       [0.48110, 0.33976, 0.12740, 0.05255, 0.04958, 0.06039, 0.08464,
                        0.12352, 0.15591, 0.16481, 0.15285, 0.13040, 0.10582, 0.09001,
                        0.08559, 0.08221, 0.07669, 0.07220, 0.06975, 0.06562, 0.05897,
                        0.05345, 0.05245, 0.05964, 0.07761, 0.09961, 0.09134, 0.05454, 0.02400],
                       [0.52822, 0.37681, 0.15026, 0.06416, 0.06050, 0.07358, 0.10275,
                        0.14960, 0.18762, 0.19709, 0.18222, 0.15555, 0.12661, 0.10784,
                        0.10278, 0.09913, 0.09210, 0.08734, 0.08451, 0.07991, 0.07219,
                        0.06577, 0.06492, 0.07345, 0.09439, 0.11957, 0.10974, 0.06488, 0.02760],
                       [0.58397, 0.41484, 0.17665, 0.07821, 0.07380, 0.08919, 0.12475,
                        0.18079, 0.22576, 0.23600, 0.21663, 0.18474, 0.15027, 0.12843,
                        0.12253, 0.11845, 0.11001, 0.10465, 0.10140, 0.09593, 0.08737,
                        0.08009, 0.07936, 0.08939, 0.11368, 0.14246, 0.13073, 0.07760, 0.03246],
                       [0.64686, 0.45359, 0.20576, 0.09512, 0.08976, 0.10810, 0.15143,
                        0.21787, 0.27116, 0.28201, 0.25676, 0.21822, 0.17768, 0.15230,
                        0.14487, 0.14003, 0.13081, 0.12401, 0.12055, 0.11423, 0.10489,
                        0.09672, 0.09591, 0.10753, 0.13521, 0.16820, 0.15520, 0.09313, 0.03903],
                       [0.71250, 0.49294, 0.23740, 0.11495, 0.10883, 0.13108, 0.18323,
                        0.26158, 0.32471, 0.33549, 0.30391, 0.25698, 0.20963, 0.18001,
                        0.17061, 0.16489, 0.15458, 0.14613, 0.14248, 0.13546, 0.12510,
                        0.11585, 0.11484, 0.12791, 0.15956, 0.19739, 0.18421, 0.11209, 0.04723],
                       [0.77390, 0.53356, 0.27144, 0.13779, 0.13159, 0.15860, 0.22032,
                        0.31196, 0.38592, 0.39635, 0.35839, 0.30162, 0.24625, 0.21192,
                        0.20048, 0.19353, 0.18167, 0.17189, 0.16788, 0.16005, 0.14805,
                        0.13754, 0.13645, 0.15093, 0.18745, 0.23096, 0.21838, 0.13487, 0.05746],
                       [0.82264, 0.57656, 0.30712, 0.16436, 0.15821, 0.19115, 0.26307,
                        0.36826, 0.45261, 0.46211, 0.41847, 0.35199, 0.28777, 0.24820,
                        0.23454, 0.22571, 0.21292, 0.20176, 0.19692, 0.18805, 0.17420,
                        0.16215, 0.16089, 0.17746, 0.21899, 0.26988, 0.25804, 0.16160, 0.07035],
                       [0.85281, 0.62230, 0.34433, 0.19537, 0.18921, 0.22898, 0.31169,
                        0.42974, 0.52202, 0.52918, 0.48193, 0.40799, 0.33475, 0.28973,
                        0.27381, 0.26304, 0.24890, 0.23619, 0.23028, 0.21994, 0.20433,
                        0.19048, 0.18843, 0.20793, 0.25479, 0.31536, 0.30377, 0.19224, 0.08631],
                       [0.86263, 0.66939, 0.38323, 0.23088, 0.22569, 0.27284, 0.36598,
                        0.49483, 0.59070, 0.59427, 0.54681, 0.46880, 0.38750, 0.33763,
                        0.32007, 0.30785, 0.29051, 0.27625, 0.26954, 0.25742, 0.23912,
                        0.22324, 0.22004, 0.24267, 0.29599, 0.36705, 0.35574, 0.22680, 0.10570],
                       [0.85481, 0.71508, 0.42341, 0.27090, 0.26850, 0.32355, 0.42524,
                        0.56071, 0.65334, 0.65377, 0.61028, 0.53189, 0.44548, 0.39190,
                        0.37382, 0.36054, 0.33924, 0.32342, 0.31597, 0.30186, 0.27956,
                        0.26078, 0.25713, 0.28250, 0.34261, 0.42279, 0.41284, 0.26494, 0.12859],
                       [0.83580, 0.75685, 0.46512, 0.31574, 0.31786, 0.38054, 0.48781,
                        0.62386, 0.70444, 0.70298, 0.66750, 0.59379, 0.50659, 0.45106,
                        0.43351, 0.41942, 0.39478, 0.37776, 0.36972, 0.35310, 0.32643,
                        0.30409, 0.30025, 0.32803, 0.39401, 0.48140, 0.47369, 0.30629, 0.15542],
                       [0.81301, 0.79181, 0.50896, 0.36580, 0.37336, 0.44234, 0.55129,
                        0.67973, 0.74018, 0.73768, 0.71309, 0.65094, 0.56753, 0.51262,
                        0.49645, 0.48204, 0.45444, 0.43761, 0.42953, 0.41006, 0.37960,
                        0.35400, 0.34892, 0.37907, 0.44952, 0.54211, 0.53644, 0.35054, 0.18671],
                       [0.79226, 0.81522, 0.55501, 0.42050, 0.43421, 0.50665, 0.61289,
                        0.72324, 0.75803, 0.75563, 0.74369, 0.69925, 0.62545, 0.57343,
                        0.55947, 0.54587, 0.51555, 0.50007, 0.49242, 0.47110, 0.43780,
                        0.40926, 0.40282, 0.43436, 0.50752, 0.60112, 0.59696, 0.39682, 0.22190],
                       [0.77677, 0.82388, 0.60238, 0.47863, 0.49888, 0.57092, 0.66897,
                        0.75081, 0.75945, 0.75793, 0.75794, 0.73476, 0.67769, 0.63035,
                        0.61904, 0.60777, 0.57588, 0.56172, 0.55503, 0.53380, 0.49896,
                        0.46788, 0.46092, 0.49230, 0.56548, 0.65342, 0.65023, 0.44428, 0.26027],
                       [0.76718, 0.81942, 0.64949, 0.53852, 0.56453, 0.63286, 0.71500,
                        0.76167, 0.75002, 0.74948, 0.75748, 0.75466, 0.71956, 0.68054,
                        0.67185, 0.66376, 0.63237, 0.61972, 0.61441, 0.59446, 0.56042,
                        0.52826, 0.52066, 0.55127, 0.62059, 0.69623, 0.69336, 0.49203, 0.30213],
                       [0.76261, 0.80651, 0.69391, 0.59804, 0.62781, 0.68868, 0.74703,
                        0.75810, 0.73637, 0.73706, 0.74764, 0.75916, 0.74640, 0.72072,
                        0.71440, 0.70891, 0.68125, 0.67112, 0.66709, 0.64918, 0.61840,
                        0.58750, 0.57943, 0.60821, 0.66986, 0.72812, 0.72524, 0.53870, 0.34745],
                       [0.76210, 0.79089, 0.73266, 0.65501, 0.68533, 0.73380, 0.76316,
                        0.74613, 0.72466, 0.72642, 0.73525, 0.75259, 0.75776, 0.74724,
                        0.74303, 0.73927, 0.71906, 0.71209, 0.70922, 0.69517, 0.66922,
                        0.64200, 0.63459, 0.65953, 0.70975, 0.74813, 0.74542, 0.58284, 0.39473],
                       [0.76420, 0.77645, 0.76324, 0.70673, 0.73343, 0.76381, 0.76450,
                        0.73315, 0.71804, 0.72036, 0.72586, 0.74124, 0.75690, 0.75832,
                        0.75633, 0.75398, 0.74303, 0.73912, 0.73713, 0.72918, 0.71026,
                        0.68852, 0.68235, 0.70197, 0.73776, 0.75683, 0.75431, 0.62325, 0.44230],
                       [0.76736, 0.76491, 0.78397, 0.75010, 0.76804, 0.77629, 0.75505,
                        0.72361, 0.71676, 0.71987, 0.72181, 0.73081, 0.74843, 0.75625,
                        0.75648, 0.75533, 0.75232, 0.75100, 0.74968, 0.74824, 0.73882,
                        0.72417, 0.71930, 0.73297, 0.75405, 0.75736, 0.75373, 0.65848, 0.48914],
                       [0.77120, 0.75818, 0.79423, 0.78106, 0.78619, 0.77346, 0.74126,
                        0.71872, 0.72014, 0.72338, 0.72231, 0.72476, 0.73737, 0.74704,
                        0.74819, 0.74761, 0.74986, 0.74974, 0.74972, 0.75280, 0.75304,
                        0.74716, 0.74410, 0.75198, 0.76060, 0.75312, 0.74733, 0.68674, 0.53339],
                       [0.77487, 0.75674, 0.79444, 0.79595, 0.78767, 0.76081, 0.72919,
                        0.71827, 0.72594, 0.72825, 0.72550, 0.72347, 0.72858, 0.73696,
                        0.73719, 0.73649, 0.74082, 0.74096, 0.74239, 0.74730, 0.75437,
                        0.75696, 0.75675, 0.75969, 0.75935, 0.74622, 0.73866, 0.70714, 0.57215],
                       [0.77788, 0.75958, 0.78698, 0.79583, 0.77665, 0.74547, 0.72206,
                        0.72152, 0.73239, 0.73446, 0.73136, 0.72636, 0.72538, 0.72998,
                        0.72940, 0.72827, 0.73134, 0.73177, 0.73343, 0.73872, 0.74800,
                        0.75605, 0.75898, 0.75889, 0.75325, 0.74020, 0.73093, 0.72091, 0.60410],
                       [0.78062, 0.76470, 0.77536, 0.78498, 0.76028, 0.73278, 0.72010,
                        0.72697, 0.73888, 0.74164, 0.73926, 0.73230, 0.72715, 0.72743,
                        0.72736, 0.72564, 0.72621, 0.72633, 0.72679, 0.73179, 0.73952,
                        0.74912, 0.75403, 0.75346, 0.74629, 0.73780, 0.72724, 0.72945, 0.62916],
                       [0.78345, 0.77036, 0.76435, 0.76926, 0.74506, 0.72532, 0.72162,
                        0.73340, 0.74491, 0.74809, 0.74647, 0.73932, 0.73162, 0.72886,
                        0.72950, 0.72781, 0.72662, 0.72566, 0.72485, 0.72794, 0.73291,
                        0.74083, 0.74624, 0.74666, 0.74176, 0.73931, 0.72854, 0.73295, 0.64788],
                       [0.78681, 0.77654, 0.75748, 0.75456, 0.73478, 0.72331, 0.72543,
                        0.74006, 0.75024, 0.75339, 0.75172, 0.74596, 0.73753, 0.73341,
                        0.73397, 0.73324, 0.73051, 0.72881, 0.72794, 0.72811, 0.73031,
                        0.73517, 0.73968, 0.74120, 0.74077, 0.74311, 0.73311, 0.73224, 0.66074],
                       [0.79046, 0.78288, 0.75452, 0.74435, 0.73030, 0.72542, 0.73132,
                        0.74554, 0.75456, 0.75791, 0.75621, 0.75138, 0.74365, 0.73995,
                        0.73967, 0.73928, 0.73547, 0.73386, 0.73328, 0.73199, 0.73152,
                        0.73353, 0.73638, 0.73848, 0.74226, 0.74697, 0.73835, 0.72878, 0.66736],
                       [0.79460, 0.78940, 0.75518, 0.74016, 0.73104, 0.73052, 0.73855,
                        0.75047, 0.75932, 0.76287, 0.76101, 0.75582, 0.74939, 0.74645,
                        0.74565, 0.74504, 0.74135, 0.73975, 0.73940, 0.73799, 0.73570,
                        0.73534, 0.73692, 0.73963, 0.74548, 0.75084, 0.74359, 0.72463, 0.66874],
                       [0.80047, 0.79634, 0.75929, 0.74088, 0.73522, 0.73698, 0.74510,
                        0.75645, 0.76618, 0.76973, 0.76606, 0.76014, 0.75496, 0.75131,
                        0.75105, 0.75083, 0.74755, 0.74548, 0.74574, 0.74395, 0.74155,
                        0.73935, 0.74019, 0.74402, 0.74978, 0.75465, 0.74871, 0.72178, 0.66661],
                       [0.80835, 0.80277, 0.76540, 0.74456, 0.74129, 0.74365, 0.75083,
                        0.76329, 0.77465, 0.77828, 0.77216, 0.76492, 0.75975, 0.75512,
                        0.75477, 0.75504, 0.75198, 0.75048, 0.75063, 0.74880, 0.74712,
                        0.74426, 0.74443, 0.74905, 0.75382, 0.75726, 0.75213, 0.72138, 0.66231],
                       [0.81773, 0.80887, 0.77240, 0.75016, 0.74821, 0.75053, 0.75728,
                        0.77072, 0.78439, 0.78754, 0.77982, 0.77030, 0.76308, 0.75854,
                        0.75699, 0.75699, 0.75466, 0.75422, 0.75354, 0.75266, 0.75141,
                        0.74918, 0.74908, 0.75302, 0.75697, 0.75829, 0.75356, 0.72309, 0.65693],
                       [0.82836, 0.81589, 0.78027, 0.75677, 0.75523, 0.75735, 0.76468,
                        0.77990, 0.79614, 0.79775, 0.78866, 0.77668, 0.76643, 0.76179,
                        0.75941, 0.75834, 0.75716, 0.75590, 0.75507, 0.75512, 0.75432,
                        0.75327, 0.75322, 0.75575, 0.75927, 0.75884, 0.75480, 0.72634, 0.65186],
                       [0.84006, 0.82387, 0.78826, 0.76439, 0.76228, 0.76394, 0.77288,
                        0.79152, 0.80938, 0.80928, 0.79881, 0.78425, 0.77182, 0.76561,
                        0.76240, 0.76037, 0.75948, 0.75674, 0.75618, 0.75624, 0.75605,
                        0.75588, 0.75558, 0.75774, 0.76083, 0.76031, 0.75664, 0.73114, 0.64911],
                       [0.85256, 0.83194, 0.79574, 0.77241, 0.76900, 0.77075, 0.78236,
                        0.80466, 0.82254, 0.82108, 0.80964, 0.79278, 0.77893, 0.77036,
                        0.76601, 0.76345, 0.76140, 0.75857, 0.75758, 0.75708, 0.75726,
                        0.75740, 0.75667, 0.75921, 0.76197, 0.76366, 0.75884, 0.73673, 0.64889],
                       [0.86538, 0.83993, 0.80309, 0.77874, 0.77543, 0.77852, 0.79308,
                        0.81824, 0.83499, 0.83238, 0.82019, 0.80226, 0.78634, 0.77592,
                        0.77098, 0.76770, 0.76423, 0.76132, 0.75983, 0.75877, 0.75875,
                        0.75834, 0.75783, 0.76031, 0.76358, 0.76876, 0.76274, 0.74233, 0.65013],
                       [0.87737, 0.84860, 0.81012, 0.78422, 0.78263, 0.78781, 0.80471,
                        0.83086, 0.84632, 0.84329, 0.83049, 0.81230, 0.79422, 0.78273,
                        0.77789, 0.77361, 0.76908, 0.76538, 0.76401, 0.76214, 0.76114,
                        0.75924, 0.75958, 0.76193, 0.76702, 0.77540, 0.76973, 0.74787, 0.65262],
                       [0.88733, 0.85804, 0.81725, 0.79130, 0.79104, 0.79879, 0.81735,
                        0.84214, 0.85628, 0.85326, 0.84043, 0.82238, 0.80353, 0.79172,
                        0.78671, 0.78171, 0.77589, 0.77220, 0.77057, 0.76763, 0.76504,
                        0.76183, 0.76218, 0.76495, 0.77282, 0.78455, 0.77938, 0.75356, 0.65611],
                       [0.89593, 0.86767, 0.82579, 0.79983, 0.80056, 0.81117, 0.83044,
                        0.85366, 0.86551, 0.86175, 0.84990, 0.83255, 0.81424, 0.80220,
                        0.79657, 0.79194, 0.78486, 0.78156, 0.77930, 0.77581, 0.77135,
                        0.76741, 0.76671, 0.77049, 0.78113, 0.79679, 0.79148, 0.75987, 0.66005],
                       [0.90325, 0.87684, 0.83512, 0.80911, 0.81148, 0.82398, 0.84312,
                        0.86469, 0.87376, 0.86896, 0.85837, 0.84236, 0.82498, 0.81264,
                        0.80702, 0.80302, 0.79573, 0.79201, 0.78975, 0.78637, 0.78007,
                        0.77557, 0.77386, 0.77897, 0.79183, 0.81072, 0.80566, 0.76687, 0.66382],
                       [0.90743, 0.88532, 0.84393, 0.81937, 0.82331, 0.83692, 0.85507,
                        0.87299, 0.88025, 0.87447, 0.86511, 0.85102, 0.83454, 0.82252,
                        0.81802, 0.81393, 0.80723, 0.80310, 0.80119, 0.79767, 0.79085,
                        0.78505, 0.78310, 0.78940, 0.80409, 0.82512, 0.82032, 0.77444, 0.66726],
                       [0.90883, 0.89363, 0.85275, 0.83046, 0.83543, 0.85002, 0.86608,
                        0.87947, 0.88465, 0.87888, 0.87070, 0.85843, 0.84362, 0.83228,
                        0.82909, 0.82493, 0.81839, 0.81481, 0.81373, 0.80924, 0.80342,
                        0.79589, 0.79403, 0.80104, 0.81721, 0.83953, 0.83487, 0.78283, 0.67109],
                       [0.90913, 0.90137, 0.86207, 0.84163, 0.84777, 0.86199, 0.87560,
                        0.88535, 0.88703, 0.88306, 0.87549, 0.86461, 0.85236, 0.84222,
                        0.83932, 0.83565, 0.82903, 0.82619, 0.82618, 0.82170, 0.81616,
                        0.80830, 0.80666, 0.81374, 0.83073, 0.85289, 0.84917, 0.79193, 0.67585],
                       [0.90822, 0.90686, 0.87143, 0.85249, 0.85977, 0.87185, 0.88305,
                        0.88982, 0.88864, 0.88606, 0.87892, 0.86969, 0.85925, 0.85107,
                        0.84785, 0.84532, 0.83941, 0.83661, 0.83686, 0.83420, 0.82802,
                        0.82136, 0.81989, 0.82704, 0.84390, 0.86425, 0.86184, 0.80178, 0.68123],
                       [0.90577, 0.91013, 0.88020, 0.86273, 0.87042, 0.88027, 0.88815,
                        0.89211, 0.88991, 0.88682, 0.88062, 0.87379, 0.86427, 0.85782,
                        0.85507, 0.85310, 0.84855, 0.84608, 0.84634, 0.84477, 0.83924,
                        0.83413, 0.83237, 0.83987, 0.85571, 0.87336, 0.87213, 0.81250, 0.68745],
                       [0.90320, 0.91293, 0.88828, 0.87306, 0.88000, 0.88817, 0.89167,
                        0.89274, 0.89010, 0.88648, 0.88143, 0.87693, 0.86891, 0.86354,
                        0.86190, 0.85948, 0.85587, 0.85432, 0.85501, 0.85360, 0.84960,
                        0.84602, 0.84425, 0.85152, 0.86587, 0.88049, 0.88072, 0.82393, 0.69558],
                       [0.90212, 0.91500, 0.89556, 0.88372, 0.88866, 0.89470, 0.89442,
                        0.89243, 0.88973, 0.88640, 0.88287, 0.87914, 0.87303, 0.86881,
                        0.86774, 0.86580, 0.86203, 0.86133, 0.86204, 0.86190, 0.85934,
                        0.85635, 0.85541, 0.86206, 0.87405, 0.88574, 0.88765, 0.83577, 0.70546],
                       [0.90257, 0.91543, 0.90184, 0.89293, 0.89590, 0.89903, 0.89658,
                        0.89210, 0.88951, 0.88638, 0.88411, 0.88032, 0.87604, 0.87269,
                        0.87193, 0.87125, 0.86715, 0.86706, 0.86768, 0.86886, 0.86799,
                        0.86500, 0.86550, 0.87138, 0.88018, 0.88893, 0.89207, 0.84721, 0.71640],
                       [0.90398, 0.91538, 0.90707, 0.89960, 0.90172, 0.90162, 0.89756,
                        0.89197, 0.88847, 0.88592, 0.88370, 0.88042, 0.87807, 0.87515,
                        0.87489, 0.87458, 0.87139, 0.87123, 0.87261, 0.87376, 0.87387,
                        0.87218, 0.87399, 0.87859, 0.88488, 0.89044, 0.89351, 0.85757, 0.72821],
                       [0.90689, 0.91573, 0.91127, 0.90445, 0.90565, 0.90294, 0.89700,
                        0.89102, 0.88681, 0.88539, 0.88280, 0.88028, 0.87904, 0.87699,
                        0.87684, 0.87641, 0.87475, 0.87409, 0.87597, 0.87701, 0.87737,
                        0.87729, 0.87966, 0.88315, 0.88814, 0.89108, 0.89320, 0.86628, 0.74038],
                       [0.91099, 0.91578, 0.91406, 0.90779, 0.90748, 0.90287, 0.89562,
                        0.88943, 0.88587, 0.88477, 0.88232, 0.88045, 0.87902, 0.87774,
                        0.87771, 0.87738, 0.87664, 0.87579, 0.87689, 0.87870, 0.87986,
                        0.88066, 0.88274, 0.88570, 0.88945, 0.89046, 0.89241, 0.87324, 0.75207],
                       [0.91544, 0.91570, 0.91511, 0.91015, 0.90794, 0.90227, 0.89403,
                        0.88838, 0.88588, 0.88399, 0.88176, 0.88034, 0.87893, 0.87777,
                        0.87811, 0.87794, 0.87689, 0.87661, 0.87712, 0.87948, 0.88155,
                        0.88334, 0.88494, 0.88728, 0.88918, 0.88891, 0.89109, 0.87922, 0.76316],
                       [0.92082, 0.91644, 0.91550, 0.91207, 0.90772, 0.90152, 0.89242,
                        0.88816, 0.88662, 0.88425, 0.88146, 0.87994, 0.87905, 0.87842,
                        0.87844, 0.87845, 0.87682, 0.87705, 0.87799, 0.88017, 0.88232,
                        0.88483, 0.88659, 0.88800, 0.88857, 0.88780, 0.88979, 0.88384, 0.77364],
                       [0.92694, 0.91798, 0.91551, 0.91239, 0.90701, 0.89961, 0.89120,
                        0.88812, 0.88751, 0.88579, 0.88205, 0.87960, 0.87888, 0.87900,
                        0.87849, 0.87849, 0.87714, 0.87690, 0.87864, 0.88054, 0.88211,
                        0.88461, 0.88670, 0.88756, 0.88809, 0.88730, 0.88886, 0.88619, 0.78263],
                       [0.93240, 0.92009, 0.91497, 0.91112, 0.90583, 0.89738, 0.89056,
                        0.88815, 0.88861, 0.88754, 0.88326, 0.87969, 0.87874, 0.87847,
                        0.87836, 0.87793, 0.87730, 0.87675, 0.87870, 0.88070, 0.88166,
                        0.88378, 0.88568, 0.88669, 0.88726, 0.88730, 0.88782, 0.88734, 0.78988],
                       [0.93722, 0.92339, 0.91501, 0.91009, 0.90468, 0.89633, 0.89057,
                        0.88919, 0.89066, 0.88938, 0.88504, 0.88127, 0.87920, 0.87827,
                        0.87870, 0.87786, 0.87766, 0.87716, 0.87856, 0.88038, 0.88179,
                        0.88345, 0.88483, 0.88637, 0.88693, 0.88800, 0.88729, 0.88835, 0.79561],
                       [0.94217, 0.92746, 0.91593, 0.90964, 0.90354, 0.89595, 0.89141,
                        0.89149, 0.89335, 0.89187, 0.88777, 0.88378, 0.88067, 0.87934,
                        0.87947, 0.87903, 0.87829, 0.87781, 0.87869, 0.87979, 0.88195,
                        0.88352, 0.88470, 0.88664, 0.88790, 0.88922, 0.88787, 0.88885, 0.79931],
                       [0.94665, 0.93114, 0.91665, 0.90872, 0.90213, 0.89579, 0.89287,
                        0.89416, 0.89648, 0.89479, 0.89075, 0.88595, 0.88285, 0.88060,
                        0.88023, 0.88043, 0.87904, 0.87864, 0.87955, 0.88024, 0.88221,
                        0.88357, 0.88524, 0.88716, 0.88882, 0.89071, 0.88949, 0.88875, 0.80118],
                       [0.94954, 0.93446, 0.91726, 0.90751, 0.90175, 0.89641, 0.89451,
                        0.89685, 0.89999, 0.89756, 0.89332, 0.88833, 0.88474, 0.88196,
                        0.88169, 0.88179, 0.88035, 0.88008, 0.88091, 0.88181, 0.88297,
                        0.88374, 0.88572, 0.88775, 0.88965, 0.89296, 0.89167, 0.88820, 0.80232],
                       [0.95050, 0.93753, 0.91863, 0.90746, 0.90274, 0.89765, 0.89638,
                        0.89982, 0.90267, 0.90026, 0.89599, 0.89098, 0.88697, 0.88436,
                        0.88418, 0.88367, 0.88208, 0.88209, 0.88249, 0.88325, 0.88393,
                        0.88435, 0.88592, 0.88856, 0.89159, 0.89589, 0.89359, 0.88753, 0.80250],
                       [0.95087, 0.93998, 0.92073, 0.90894, 0.90412, 0.89985, 0.89927,
                        0.90298, 0.90467, 0.90295, 0.89870, 0.89377, 0.88984, 0.88741,
                        0.88695, 0.88595, 0.88425, 0.88421, 0.88438, 0.88473, 0.88548,
                        0.88573, 0.88702, 0.89022, 0.89422, 0.89845, 0.89551, 0.88704, 0.80157],
                       [0.95113, 0.94169, 0.92284, 0.91070, 0.90574, 0.90289, 0.90272,
                        0.90562, 0.90691, 0.90526, 0.90085, 0.89655, 0.89201, 0.88985,
                        0.88937, 0.88850, 0.88678, 0.88623, 0.88629, 0.88694, 0.88746,
                        0.88747, 0.88934, 0.89246, 0.89649, 0.90049, 0.89775, 0.88652, 0.80054],
                       [0.95069, 0.94315, 0.92523, 0.91261, 0.90827, 0.90572, 0.90579,
                        0.90783, 0.90901, 0.90678, 0.90232, 0.89827, 0.89390, 0.89160,
                        0.89176, 0.89133, 0.88909, 0.88850, 0.88843, 0.88938, 0.88938,
                        0.88947, 0.89198, 0.89446, 0.89874, 0.90315, 0.89999, 0.88641, 0.80000],
                       [0.94987, 0.94459, 0.92816, 0.91571, 0.91156, 0.90849, 0.90863,
                        0.91026, 0.91061, 0.90794, 0.90326, 0.89906, 0.89638, 0.89377,
                        0.89421, 0.89391, 0.89129, 0.89139, 0.89124, 0.89165, 0.89165,
                        0.89221, 0.89427, 0.89665, 0.90149, 0.90619, 0.90191, 0.88713, 0.79922],
                       [0.94856, 0.94548, 0.93101, 0.91964, 0.91489, 0.91156, 0.91114,
                        0.91269, 0.91177, 0.90886, 0.90407, 0.89990, 0.89876, 0.89640,
                        0.89634, 0.89568, 0.89379, 0.89410, 0.89416, 0.89359, 0.89416,
                        0.89510, 0.89599, 0.89902, 0.90401, 0.90843, 0.90357, 0.88819, 0.79808],
                       [0.94655, 0.94541, 0.93404, 0.92338, 0.91856, 0.91475, 0.91347,
                        0.91473, 0.91233, 0.90906, 0.90469, 0.90109, 0.90004, 0.89831,
                        0.89789, 0.89686, 0.89617, 0.89573, 0.89633, 0.89568, 0.89648,
                        0.89736, 0.89783, 0.90156, 0.90635, 0.90996, 0.90567, 0.88954, 0.79806],
                       [0.94435, 0.94473, 0.93721, 0.92653, 0.92216, 0.91787, 0.91621,
                        0.91594, 0.91245, 0.90879, 0.90491, 0.90202, 0.90054, 0.89900,
                        0.89890, 0.89808, 0.89759, 0.89655, 0.89743, 0.89823, 0.89849,
                        0.89904, 0.90055, 0.90412, 0.90854, 0.91080, 0.90777, 0.89081, 0.79875],
                       [0.94252, 0.94420, 0.93924, 0.92955, 0.92495, 0.92057, 0.91892,
                        0.91626, 0.91236, 0.90814, 0.90430, 0.90182, 0.90064, 0.89923,
                        0.89943, 0.89914, 0.89810, 0.89753, 0.89790, 0.90021, 0.90019,
                        0.90040, 0.90337, 0.90604, 0.90998, 0.91094, 0.90860, 0.89193, 0.79909],
                       [0.94098, 0.94419, 0.94020, 0.93277, 0.92749, 0.92307, 0.92046,
                        0.91615, 0.91195, 0.90717, 0.90311, 0.90071, 0.89981, 0.89946,
                        0.89931, 0.89915, 0.89818, 0.89842, 0.89852, 0.90063, 0.90169,
                        0.90160, 0.90475, 0.90720, 0.91057, 0.91113, 0.90885, 0.89311, 0.79976],
                       [0.93945, 0.94387, 0.94134, 0.93527, 0.92999, 0.92522, 0.92049,
                        0.91613, 0.91121, 0.90630, 0.90201, 0.89947, 0.89850, 0.89895,
                        0.89849, 0.89813, 0.89778, 0.89812, 0.89892, 0.89983, 0.90233,
                        0.90299, 0.90508, 0.90764, 0.91036, 0.91123, 0.90934, 0.89395, 0.80104],
                       [0.93858, 0.94272, 0.94262, 0.93671, 0.93175, 0.92652, 0.92038,
                        0.91628, 0.91045, 0.90531, 0.90077, 0.89856, 0.89771, 0.89749,
                        0.89740, 0.89698, 0.89655, 0.89707, 0.89813, 0.89916, 0.90168,
                        0.90444, 0.90585, 0.90780, 0.90984, 0.91074, 0.90912, 0.89469, 0.80222],
                       [0.93874, 0.94169, 0.94336, 0.93806, 0.93272, 0.92740, 0.92131,
                        0.91597, 0.90956, 0.90365, 0.89925, 0.89733, 0.89693, 0.89579,
                        0.89618, 0.89568, 0.89472, 0.89608, 0.89667, 0.89890, 0.90072,
                        0.90465, 0.90626, 0.90798, 0.90938, 0.90973, 0.90806, 0.89561, 0.80352],
                       [0.93917, 0.94116, 0.94353, 0.93942, 0.93354, 0.92815, 0.92204,
                        0.91479, 0.90823, 0.90198, 0.89797, 0.89529, 0.89535, 0.89463,
                        0.89427, 0.89360, 0.89317, 0.89439, 0.89496, 0.89803, 0.90002,
                        0.90334, 0.90534, 0.90732, 0.90839, 0.90818, 0.90716, 0.89640, 0.80550],
                       [0.93916, 0.94041, 0.94347, 0.93987, 0.93427, 0.92828, 0.92137,
                        0.91357, 0.90718, 0.90126, 0.89687, 0.89334, 0.89331, 0.89365,
                        0.89174, 0.89125, 0.89163, 0.89171, 0.89283, 0.89618, 0.89894,
                        0.90182, 0.90423, 0.90561, 0.90655, 0.90616, 0.90647, 0.89715, 0.80731],
                       [0.93902, 0.93944, 0.94322, 0.93949, 0.93439, 0.92761, 0.92012,
                        0.91283, 0.90620, 0.90043, 0.89533, 0.89203, 0.89116, 0.89157,
                        0.88962, 0.88929, 0.88959, 0.88930, 0.89104, 0.89396, 0.89730,
                        0.90027, 0.90337, 0.90383, 0.90435, 0.90355, 0.90517, 0.89791, 0.80825],
                       [0.93943, 0.93915, 0.94253, 0.93889, 0.93377, 0.92697, 0.91900,
                        0.91180, 0.90443, 0.89848, 0.89337, 0.89098, 0.88904, 0.88881,
                        0.88806, 0.88718, 0.88727, 0.88755, 0.88948, 0.89180, 0.89538,
                        0.89833, 0.90167, 0.90230, 0.90198, 0.90099, 0.90308, 0.89783, 0.80903],
                       [0.94021, 0.93892, 0.94135, 0.93830, 0.93304, 0.92655, 0.91788,
                        0.91015, 0.90281, 0.89651, 0.89171, 0.88965, 0.88744, 0.88675,
                        0.88640, 0.88490, 0.88519, 0.88531, 0.88696, 0.88935, 0.89307,
                        0.89667, 0.89923, 0.90080, 0.89956, 0.89908, 0.90106, 0.89718, 0.81033],
                       [0.94041, 0.93759, 0.93995, 0.93805, 0.93272, 0.92588, 0.91677,
                        0.90839, 0.90177, 0.89530, 0.89064, 0.88819, 0.88663, 0.88575,
                        0.88443, 0.88316, 0.88339, 0.88284, 0.88396, 0.88705, 0.89089,
                        0.89516, 0.89738, 0.89925, 0.89782, 0.89737, 0.89949, 0.89706, 0.81168],
                       [0.93907, 0.93602, 0.93855, 0.93770, 0.93230, 0.92492, 0.91540,
                        0.90678, 0.89990, 0.89361, 0.88931, 0.88659, 0.88592, 0.88479,
                        0.88225, 0.88152, 0.88122, 0.88111, 0.88197, 0.88537, 0.88919,
                        0.89283, 0.89568, 0.89720, 0.89616, 0.89533, 0.89771, 0.89692, 0.81252],
                       [0.93584, 0.93453, 0.93734, 0.93652, 0.93089, 0.92351, 0.91360,
                        0.90458, 0.89666, 0.89020, 0.88694, 0.88444, 0.88411, 0.88310,
                        0.88054, 0.87959, 0.87881, 0.87924, 0.88063, 0.88319, 0.88682,
                        0.89011, 0.89288, 0.89433, 0.89350, 0.89279, 0.89562, 0.89595, 0.81268],
                       [0.93131, 0.93253, 0.93605, 0.93485, 0.92915, 0.92165, 0.91145,
                        0.90109, 0.89257, 0.88620, 0.88365, 0.88218, 0.88150, 0.88107,
                        0.87954, 0.87784, 0.87699, 0.87684, 0.87894, 0.88053, 0.88393,
                        0.88775, 0.88971, 0.89141, 0.89088, 0.89056, 0.89351, 0.89449, 0.81262],
                       [0.92584, 0.93028, 0.93437, 0.93330, 0.92801, 0.91979, 0.90899,
                        0.89730, 0.88815, 0.88282, 0.88034, 0.88032, 0.87954, 0.87916,
                        0.87833, 0.87647, 0.87565, 0.87496, 0.87688, 0.87858, 0.88176,
                        0.88559, 0.88774, 0.88935, 0.88908, 0.88889, 0.89106, 0.89286, 0.81243],
                       [0.91952, 0.92767, 0.93228, 0.93189, 0.92657, 0.91778, 0.90604,
                        0.89387, 0.88383, 0.87895, 0.87713, 0.87817, 0.87778, 0.87752,
                        0.87638, 0.87515, 0.87431, 0.87367, 0.87487, 0.87699, 0.88001,
                        0.88366, 0.88640, 0.88760, 0.88743, 0.88706, 0.88850, 0.89104, 0.81155],
                       [0.91284, 0.92398, 0.92935, 0.93011, 0.92427, 0.91507, 0.90252,
                        0.88966, 0.87893, 0.87397, 0.87329, 0.87493, 0.87537, 0.87564,
                        0.87440, 0.87345, 0.87279, 0.87240, 0.87318, 0.87514, 0.87815,
                        0.88204, 0.88448, 0.88552, 0.88594, 0.88522, 0.88663, 0.88927, 0.81069],
                       [0.90660, 0.91985, 0.92638, 0.92824, 0.92201, 0.91231, 0.89902,
                        0.88462, 0.87338, 0.86927, 0.86914, 0.87131, 0.87336, 0.87350,
                        0.87300, 0.87200, 0.87149, 0.87140, 0.87210, 0.87382, 0.87684,
                        0.88053, 0.88272, 0.88405, 0.88495, 0.88432, 0.88531, 0.88758, 0.81032],
                       [0.90092, 0.91582, 0.92413, 0.92662, 0.91998, 0.90947, 0.89506,
                        0.87954, 0.86821, 0.86509, 0.86536, 0.86803, 0.87168, 0.87162,
                        0.87153, 0.87106, 0.87035, 0.87056, 0.87128, 0.87328, 0.87589,
                        0.87890, 0.88123, 0.88345, 0.88393, 0.88401, 0.88369, 0.88545, 0.80934],
                       [0.89557, 0.91100, 0.92179, 0.92453, 0.91743, 0.90551, 0.88981,
                        0.87405, 0.86343, 0.86089, 0.86189, 0.86466, 0.86889, 0.86981,
                        0.86989, 0.86977, 0.86884, 0.86930, 0.87009, 0.87244, 0.87489,
                        0.87736, 0.87958, 0.88234, 0.88290, 0.88297, 0.88183, 0.88284, 0.80755],
                       [0.89058, 0.90531, 0.91843, 0.92131, 0.91375, 0.90048, 0.88406,
                        0.86820, 0.85875, 0.85692, 0.85824, 0.86145, 0.86554, 0.86757,
                        0.86792, 0.86763, 0.86681, 0.86766, 0.86829, 0.87070, 0.87346,
                        0.87591, 0.87839, 0.88059, 0.88219, 0.88143, 0.88022, 0.88042, 0.80558],
                       [0.88627, 0.90008, 0.91383, 0.91693, 0.90894, 0.89502, 0.87843,
                        0.86289, 0.85452, 0.85390, 0.85501, 0.85867, 0.86238, 0.86476,
                        0.86510, 0.86471, 0.86493, 0.86581, 0.86619, 0.86848, 0.87114,
                        0.87420, 0.87748, 0.87915, 0.88143, 0.88052, 0.87848, 0.87814, 0.80329],
                       [0.88371, 0.89605, 0.90929, 0.91228, 0.90354, 0.88926, 0.87270,
                        0.85875, 0.85213, 0.85262, 0.85332, 0.85577, 0.85913, 0.86204,
                        0.86223, 0.86237, 0.86361, 0.86414, 0.86502, 0.86683, 0.86926,
                        0.87295, 0.87659, 0.87853, 0.88088, 0.88040, 0.87678, 0.87555, 0.80059],
                       [0.88371, 0.89289, 0.90589, 0.90810, 0.89824, 0.88379, 0.86734,
                        0.85598, 0.85236, 0.85294, 0.85287, 0.85364, 0.85703, 0.86019,
                        0.86053, 0.86160, 0.86247, 0.86327, 0.86458, 0.86621, 0.86898,
                        0.87275, 0.87606, 0.87877, 0.88110, 0.88037, 0.87597, 0.87327, 0.79803],
                       [0.88591, 0.89057, 0.90266, 0.90365, 0.89321, 0.87868, 0.86357,
                        0.85457, 0.85407, 0.85453, 0.85344, 0.85369, 0.85640, 0.85891,
                        0.85985, 0.86110, 0.86161, 0.86310, 0.86383, 0.86592, 0.86930,
                        0.87261, 0.87560, 0.87919, 0.88176, 0.88055, 0.87570, 0.87182, 0.79569],
                       [0.88889, 0.88876, 0.89854, 0.89858, 0.88776, 0.87307, 0.86083,
                        0.85443, 0.85614, 0.85719, 0.85516, 0.85504, 0.85610, 0.85765,
                        0.85906, 0.85997, 0.86091, 0.86254, 0.86290, 0.86548, 0.86896,
                        0.87190, 0.87493, 0.87905, 0.88204, 0.88165, 0.87555, 0.86997, 0.79313],
                       [0.89209, 0.88760, 0.89398, 0.89338, 0.88162, 0.86768, 0.85794,
                        0.85561, 0.85902, 0.86079, 0.85774, 0.85619, 0.85626, 0.85691,
                        0.85798, 0.85920, 0.86013, 0.86124, 0.86223, 0.86489, 0.86788,
                        0.87103, 0.87458, 0.87856, 0.88201, 0.88296, 0.87572, 0.86722, 0.79003],
                       [0.89635, 0.88856, 0.89063, 0.88837, 0.87603, 0.86401, 0.85618,
                        0.85802, 0.86344, 0.86567, 0.86150, 0.85779, 0.85696, 0.85727,
                        0.85769, 0.85953, 0.85985, 0.86041, 0.86216, 0.86467, 0.86710,
                        0.87082, 0.87469, 0.87843, 0.88244, 0.88392, 0.87634, 0.86519, 0.78658],
                       [0.90169, 0.89152, 0.88894, 0.88400, 0.87220, 0.86172, 0.85674,
                        0.86177, 0.86929, 0.87158, 0.86678, 0.86102, 0.85866, 0.85857,
                        0.85887, 0.86059, 0.86074, 0.86129, 0.86296, 0.86550, 0.86763,
                        0.87134, 0.87478, 0.87914, 0.88340, 0.88533, 0.87765, 0.86436, 0.78345],
                       [0.90745, 0.89514, 0.88789, 0.88078, 0.87002, 0.86092, 0.85917,
                        0.86728, 0.87659, 0.87786, 0.87287, 0.86602, 0.86223, 0.86136,
                        0.86173, 0.86270, 0.86299, 0.86389, 0.86490, 0.86737, 0.86940,
                        0.87223, 0.87557, 0.88069, 0.88530, 0.88780, 0.87995, 0.86380, 0.78104],
                       [0.91325, 0.89969, 0.88751, 0.87844, 0.86892, 0.86209, 0.86322,
                        0.87399, 0.88478, 0.88450, 0.87916, 0.87191, 0.86676, 0.86564,
                        0.86575, 0.86616, 0.86635, 0.86681, 0.86781, 0.86996, 0.87161,
                        0.87385, 0.87754, 0.88272, 0.88815, 0.89089, 0.88259, 0.86363, 0.77905],
                       [0.91914, 0.90556, 0.88844, 0.87724, 0.86916, 0.86476, 0.86891,
                        0.88094, 0.89219, 0.89141, 0.88542, 0.87739, 0.87134, 0.86973,
                        0.87002, 0.87009, 0.86994, 0.86953, 0.87123, 0.87296, 0.87392,
                        0.87628, 0.88016, 0.88506, 0.89093, 0.89420, 0.88521, 0.86425, 0.77725],
                       [0.92538, 0.91146, 0.89028, 0.87765, 0.87099, 0.86912, 0.87527,
                        0.88812, 0.89808, 0.89764, 0.89068, 0.88240, 0.87622, 0.87323,
                        0.87400, 0.87400, 0.87322, 0.87291, 0.87469, 0.87604, 0.87668,
                        0.87895, 0.88275, 0.88738, 0.89342, 0.89745, 0.88840, 0.86491, 0.77599],
                       [0.93163, 0.91646, 0.89311, 0.87954, 0.87416, 0.87468, 0.88122,
                        0.89546, 0.90347, 0.90262, 0.89491, 0.88762, 0.88122, 0.87775,
                        0.87802, 0.87824, 0.87698, 0.87716, 0.87834, 0.87933, 0.88006,
                        0.88173, 0.88517, 0.88977, 0.89603, 0.90074, 0.89201, 0.86563, 0.77484],
                       [0.93745, 0.92126, 0.89765, 0.88307, 0.87864, 0.88045, 0.88773,
                        0.90186, 0.90849, 0.90667, 0.89946, 0.89269, 0.88614, 0.88345,
                        0.88248, 0.88277, 0.88146, 0.88138, 0.88237, 0.88328, 0.88387,
                        0.88492, 0.88798, 0.89274, 0.89900, 0.90403, 0.89577, 0.86732, 0.77319],
                       [0.94240, 0.92614, 0.90285, 0.88774, 0.88430, 0.88683, 0.89537,
                        0.90685, 0.91194, 0.90964, 0.90372, 0.89644, 0.89069, 0.88811,
                        0.88681, 0.88698, 0.88563, 0.88489, 0.88614, 0.88738, 0.88754,
                        0.88830, 0.89102, 0.89587, 0.90191, 0.90672, 0.89948, 0.86990, 0.77212],
                       [0.94622, 0.93044, 0.90783, 0.89297, 0.89070, 0.89421, 0.90254,
                        0.91139, 0.91421, 0.91147, 0.90611, 0.89914, 0.89432, 0.89125,
                        0.89068, 0.89085, 0.88917, 0.88842, 0.88977, 0.89095, 0.89084,
                        0.89190, 0.89407, 0.89882, 0.90477, 0.90908, 0.90258, 0.87294, 0.77290],
                       [0.94939, 0.93411, 0.91340, 0.89914, 0.89751, 0.90187, 0.90852,
                        0.91582, 0.91609, 0.91227, 0.90729, 0.90175, 0.89762, 0.89439,
                        0.89431, 0.89483, 0.89274, 0.89231, 0.89382, 0.89430, 0.89426,
                        0.89574, 0.89755, 0.90191, 0.90768, 0.91140, 0.90527, 0.87586, 0.77491],
                       [0.95148, 0.93715, 0.91952, 0.90585, 0.90512, 0.90889, 0.91382,
                        0.91874, 0.91669, 0.91180, 0.90785, 0.90373, 0.90047, 0.89797,
                        0.89763, 0.89824, 0.89624, 0.89562, 0.89716, 0.89742, 0.89787,
                        0.89922, 0.90126, 0.90517, 0.90995, 0.91323, 0.90830, 0.87884, 0.77707],
                       [0.95108, 0.93849, 0.92482, 0.91218, 0.91261, 0.91511, 0.91804,
                        0.91936, 0.91550, 0.91003, 0.90706, 0.90425, 0.90161, 0.90071,
                        0.89989, 0.89991, 0.89853, 0.89807, 0.89880, 0.89982, 0.90102,
                        0.90199, 0.90418, 0.90769, 0.91138, 0.91428, 0.91092, 0.88235, 0.77919],
                       [0.94830, 0.93795, 0.92900, 0.91861, 0.91883, 0.92055, 0.92071,
                        0.91847, 0.91309, 0.90755, 0.90512, 0.90340, 0.90155, 0.90147,
                        0.90102, 0.90019, 0.89954, 0.89977, 0.89992, 0.90164, 0.90298,
                        0.90413, 0.90606, 0.90908, 0.91264, 0.91454, 0.91200, 0.88551, 0.78160],
                       [0.94385, 0.93691, 0.93274, 0.92525, 0.92444, 0.92509, 0.92250,
                        0.91699, 0.90983, 0.90423, 0.90236, 0.90139, 0.90156, 0.90106,
                        0.90126, 0.90067, 0.90017, 0.90041, 0.90114, 0.90307, 0.90404,
                        0.90600, 0.90759, 0.91023, 0.91381, 0.91423, 0.91227, 0.88825, 0.78480],
                       [0.93717, 0.93502, 0.93580, 0.93082, 0.92938, 0.92811, 0.92333,
                        0.91492, 0.90537, 0.89922, 0.89843, 0.89855, 0.90070, 0.90049,
                        0.90064, 0.90131, 0.90032, 0.89993, 0.90166, 0.90363, 0.90487,
                        0.90742, 0.90916, 0.91153, 0.91396, 0.91351, 0.91248, 0.89127, 0.78821],
                       [0.92796, 0.93128, 0.93737, 0.93482, 0.93273, 0.92938, 0.92229,
                        0.91132, 0.89938, 0.89303, 0.89327, 0.89544, 0.89820, 0.89968,
                        0.89951, 0.90031, 0.89942, 0.89910, 0.90122, 0.90311, 0.90542,
                        0.90793, 0.91014, 0.91227, 0.91316, 0.91222, 0.91195, 0.89408, 0.79163],
                       [0.91634, 0.92617, 0.93730, 0.93764, 0.93478, 0.92963, 0.91945,
                        0.90560, 0.89214, 0.88642, 0.88721, 0.89167, 0.89515, 0.89797,
                        0.89777, 0.89775, 0.89758, 0.89815, 0.89995, 0.90180, 0.90507,
                        0.90734, 0.91018, 0.91171, 0.91226, 0.91044, 0.91005, 0.89551, 0.79542],
                       [0.90253, 0.92015, 0.93602, 0.93954, 0.93593, 0.92894, 0.91606,
                        0.89879, 0.88429, 0.87902, 0.88088, 0.88647, 0.89151, 0.89478,
                        0.89510, 0.89494, 0.89522, 0.89633, 0.89782, 0.90003, 0.90354,
                        0.90622, 0.90967, 0.91061, 0.91097, 0.90807, 0.90710, 0.89591, 0.79889],
                       [0.88760, 0.91273, 0.93364, 0.94007, 0.93541, 0.92655, 0.91182,
                        0.89139, 0.87570, 0.87021, 0.87369, 0.88028, 0.88661, 0.89050,
                        0.89157, 0.89174, 0.89229, 0.89335, 0.89486, 0.89774, 0.90131,
                        0.90485, 0.90816, 0.90927, 0.90822, 0.90439, 0.90347, 0.89599, 0.80195],
                       [0.87308, 0.90380, 0.93032, 0.93913, 0.93355, 0.92279, 0.90558,
                        0.88328, 0.86612, 0.86084, 0.86506, 0.87363, 0.88076, 0.88605,
                        0.88736, 0.88793, 0.88891, 0.88967, 0.89140, 0.89473, 0.89911,
                        0.90290, 0.90565, 0.90691, 0.90449, 0.89986, 0.89932, 0.89605, 0.80503],
                       [0.85915, 0.89401, 0.92593, 0.93710, 0.93094, 0.91811, 0.89757,
                        0.87440, 0.85589, 0.85161, 0.85573, 0.86624, 0.87446, 0.88122,
                        0.88238, 0.88329, 0.88476, 0.88541, 0.88714, 0.89103, 0.89630,
                        0.90033, 0.90322, 0.90395, 0.90093, 0.89496, 0.89473, 0.89560, 0.80780],
                       [0.84569, 0.88384, 0.92036, 0.93406, 0.92673, 0.91169, 0.88898,
                        0.86442, 0.84550, 0.84213, 0.84668, 0.85803, 0.86788, 0.87535,
                        0.87650, 0.87720, 0.87940, 0.88054, 0.88198, 0.88652, 0.89181,
                        0.89697, 0.90069, 0.90076, 0.89693, 0.88941, 0.88945, 0.89349, 0.80980],
                       [0.83397, 0.87358, 0.91368, 0.92972, 0.92067, 0.90359, 0.88012,
                        0.85343, 0.83546, 0.83252, 0.83782, 0.84944, 0.86080, 0.86823,
                        0.87006, 0.87041, 0.87295, 0.87513, 0.87651, 0.88119, 0.88640,
                        0.89250, 0.89664, 0.89650, 0.89149, 0.88320, 0.88340, 0.88998, 0.81060],
                       [0.82510, 0.86379, 0.90613, 0.92414, 0.91403, 0.89490, 0.87042,
                        0.84248, 0.82596, 0.82328, 0.82893, 0.84079, 0.85308, 0.86023,
                        0.86309, 0.86408, 0.86599, 0.86896, 0.87067, 0.87520, 0.88131,
                        0.88736, 0.89143, 0.89121, 0.88549, 0.87659, 0.87706, 0.88632, 0.81049],
                       [0.81887, 0.85476, 0.89819, 0.91702, 0.90660, 0.88558, 0.85992,
                        0.83265, 0.81721, 0.81533, 0.82084, 0.83230, 0.84501, 0.85226,
                        0.85536, 0.85742, 0.85939, 0.86186, 0.86392, 0.86864, 0.87587,
                        0.88228, 0.88604, 0.88570, 0.88009, 0.87018, 0.87072, 0.88279, 0.80979],
                       [0.81511, 0.84657, 0.88946, 0.90779, 0.89684, 0.87490, 0.84883,
                        0.82363, 0.80996, 0.80944, 0.81394, 0.82439, 0.83669, 0.84462,
                        0.84723, 0.84922, 0.85283, 0.85412, 0.85649, 0.86166, 0.86908,
                        0.87635, 0.88006, 0.87967, 0.87418, 0.86430, 0.86405, 0.87859, 0.80837],
                       [0.81417, 0.83921, 0.87989, 0.89743, 0.88514, 0.86307, 0.83756,
                        0.81484, 0.80435, 0.80504, 0.80832, 0.81734, 0.82850, 0.83673,
                        0.83899, 0.84063, 0.84510, 0.84656, 0.84911, 0.85427, 0.86157,
                        0.86895, 0.87339, 0.87303, 0.86720, 0.85830, 0.85726, 0.87356, 0.80659],
                       [0.81661, 0.83343, 0.87062, 0.88742, 0.87371, 0.85166, 0.82732,
                        0.80761, 0.80064, 0.80215, 0.80469, 0.81151, 0.82158, 0.82894,
                        0.83141, 0.83349, 0.83674, 0.83961, 0.84217, 0.84706, 0.85460,
                        0.86157, 0.86690, 0.86657, 0.86062, 0.85248, 0.85180, 0.86846, 0.80449],
                       [0.82204, 0.82992, 0.86200, 0.87716, 0.86289, 0.84106, 0.81858,
                        0.80296, 0.79930, 0.80147, 0.80302, 0.80734, 0.81574, 0.82223,
                        0.82478, 0.82713, 0.82976, 0.83279, 0.83530, 0.84037, 0.84776,
                        0.85502, 0.86011, 0.86003, 0.85492, 0.84788, 0.84776, 0.86345, 0.80154],
                       [0.82959, 0.82891, 0.85383, 0.86588, 0.85175, 0.83098, 0.81130,
                        0.80033, 0.80059, 0.80301, 0.80314, 0.80519, 0.81070, 0.81687,
                        0.81880, 0.82089, 0.82451, 0.82638, 0.82885, 0.83384, 0.84083,
                        0.84891, 0.85306, 0.85340, 0.84974, 0.84455, 0.84394, 0.85871, 0.79753],
                       [0.83902, 0.83006, 0.84617, 0.85453, 0.84110, 0.82188, 0.80587,
                        0.79992, 0.80433, 0.80665, 0.80514, 0.80484, 0.80755, 0.81261,
                        0.81389, 0.81581, 0.81983, 0.82128, 0.82383, 0.82774, 0.83468,
                        0.84280, 0.84714, 0.84780, 0.84518, 0.84169, 0.84081, 0.85462, 0.79320],
                       [0.84979, 0.83268, 0.83954, 0.84405, 0.83143, 0.81407, 0.80236,
                        0.80197, 0.80992, 0.81236, 0.80880, 0.80606, 0.80698, 0.80964,
                        0.81075, 0.81234, 0.81573, 0.81737, 0.81990, 0.82322, 0.82960,
                        0.83689, 0.84204, 0.84315, 0.84159, 0.83995, 0.83941, 0.85059, 0.78915],
                       [0.86103, 0.83671, 0.83416, 0.83464, 0.82208, 0.80779, 0.80092,
                        0.80564, 0.81657, 0.81925, 0.81437, 0.80926, 0.80817, 0.80830,
                        0.80936, 0.81032, 0.81306, 0.81424, 0.81671, 0.82052, 0.82571,
                        0.83202, 0.83710, 0.83920, 0.83955, 0.84048, 0.83920, 0.84665, 0.78454],
                       [0.87223, 0.84266, 0.83044, 0.82659, 0.81457, 0.80389, 0.80194,
                        0.81093, 0.82405, 0.82716, 0.82191, 0.81443, 0.81030, 0.80882,
                        0.80958, 0.81034, 0.81224, 0.81290, 0.81504, 0.81905, 0.82323,
                        0.82861, 0.83315, 0.83657, 0.83935, 0.84226, 0.84008, 0.84375, 0.77950],
                       [0.88295, 0.85025, 0.82877, 0.82033, 0.81019, 0.80293, 0.80524,
                        0.81856, 0.83293, 0.83619, 0.83004, 0.82091, 0.81375, 0.81142,
                        0.81155, 0.81266, 0.81348, 0.81436, 0.81572, 0.81871, 0.82242,
                        0.82683, 0.83090, 0.83528, 0.84020, 0.84486, 0.84268, 0.84181, 0.77514],
                       [0.89242, 0.85859, 0.82881, 0.81613, 0.80784, 0.80424, 0.81049,
                        0.82791, 0.84301, 0.84556, 0.83827, 0.82826, 0.81892, 0.81559,
                        0.81554, 0.81647, 0.81646, 0.81762, 0.81843, 0.82018, 0.82293,
                        0.82663, 0.83038, 0.83536, 0.84170, 0.84877, 0.84644, 0.84002, 0.77109],
                       [0.90037, 0.86726, 0.83029, 0.81433, 0.80732, 0.80734, 0.81743,
                        0.83761, 0.85336, 0.85488, 0.84724, 0.83627, 0.82583, 0.82113,
                        0.82113, 0.82145, 0.82084, 0.82120, 0.82220, 0.82341, 0.82461,
                        0.82756, 0.83154, 0.83700, 0.84468, 0.85337, 0.85048, 0.83888, 0.76737],
                       [0.90685, 0.87614, 0.83346, 0.81501, 0.80944, 0.81264, 0.82542,
                        0.84702, 0.86326, 0.86360, 0.85630, 0.84454, 0.83390, 0.82791,
                        0.82743, 0.82758, 0.82660, 0.82573, 0.82707, 0.82773, 0.82804,
                        0.82998, 0.83391, 0.83983, 0.84907, 0.85854, 0.85479, 0.83913, 0.76419],
                       [0.91158, 0.88519, 0.83849, 0.81780, 0.81416, 0.82014, 0.83437,
                        0.85649, 0.87195, 0.87166, 0.86457, 0.85303, 0.84224, 0.83549,
                        0.83485, 0.83468, 0.83322, 0.83209, 0.83346, 0.83333, 0.83299,
                        0.83414, 0.83720, 0.84375, 0.85401, 0.86470, 0.86014, 0.84033, 0.76131],
                       [0.91461, 0.89388, 0.84511, 0.82234, 0.82116, 0.82924, 0.84430,
                        0.86600, 0.87910, 0.87913, 0.87214, 0.86152, 0.85050, 0.84359,
                        0.84335, 0.84259, 0.84031, 0.83967, 0.84084, 0.84003, 0.83862,
                        0.83939, 0.84193, 0.84884, 0.85977, 0.87096, 0.86629, 0.84211, 0.75953],
                       [0.91663, 0.90149, 0.85296, 0.82896, 0.82988, 0.83879, 0.85469,
                        0.87483, 0.88523, 0.88534, 0.87901, 0.86907, 0.85856, 0.85185,
                        0.85145, 0.85056, 0.84780, 0.84743, 0.84817, 0.84703, 0.84514,
                        0.84508, 0.84758, 0.85459, 0.86638, 0.87647, 0.87174, 0.84458, 0.75905],
                       [0.91815, 0.90803, 0.86138, 0.83773, 0.83957, 0.84845, 0.86464,
                        0.88225, 0.89067, 0.89001, 0.88442, 0.87543, 0.86593, 0.85994,
                        0.85865, 0.85832, 0.85550, 0.85456, 0.85498, 0.85404, 0.85245,
                        0.85090, 0.85305, 0.86044, 0.87246, 0.88144, 0.87663, 0.84763, 0.75855],
                       [0.91932, 0.91371, 0.87011, 0.84767, 0.84967, 0.85893, 0.87362,
                        0.88821, 0.89515, 0.89390, 0.88836, 0.88111, 0.87254, 0.86781,
                        0.86592, 0.86599, 0.86276, 0.86131, 0.86185, 0.86107, 0.85936,
                        0.85741, 0.85920, 0.86645, 0.87743, 0.88643, 0.88177, 0.85093, 0.75812],
                       [0.92057, 0.91804, 0.87917, 0.85791, 0.85986, 0.86937, 0.88167,
                        0.89327, 0.89881, 0.89742, 0.89192, 0.88576, 0.87858, 0.87452,
                        0.87312, 0.87272, 0.86894, 0.86797, 0.86864, 0.86799, 0.86572,
                        0.86456, 0.86643, 0.87274, 0.88208, 0.89116, 0.88620, 0.85447, 0.75930],
                       [0.92207, 0.92107, 0.88792, 0.86818, 0.87011, 0.87871, 0.88866,
                        0.89776, 0.90176, 0.90000, 0.89509, 0.88909, 0.88365, 0.87939,
                        0.87869, 0.87793, 0.87422, 0.87400, 0.87434, 0.87441, 0.87202,
                        0.87114, 0.87293, 0.87882, 0.88716, 0.89452, 0.88929, 0.85836, 0.76167],
                       [0.92412, 0.92388, 0.89631, 0.87815, 0.88030, 0.88758, 0.89456,
                        0.90166, 0.90378, 0.90182, 0.89742, 0.89184, 0.88727, 0.88353,
                        0.88275, 0.88207, 0.87912, 0.87893, 0.87939, 0.87972, 0.87792,
                        0.87682, 0.87829, 0.88420, 0.89210, 0.89687, 0.89210, 0.86213, 0.76395],
                       [0.92725, 0.92627, 0.90397, 0.88778, 0.88952, 0.89551, 0.89978,
                        0.90454, 0.90528, 0.90319, 0.89908, 0.89425, 0.88990, 0.88768,
                        0.88641, 0.88579, 0.88362, 0.88265, 0.88388, 0.88368, 0.88286,
                        0.88193, 0.88348, 0.88874, 0.89568, 0.89951, 0.89482, 0.86551, 0.76643],
                       [0.93136, 0.92757, 0.91024, 0.89668, 0.89770, 0.90133, 0.90439,
                        0.90665, 0.90702, 0.90413, 0.90017, 0.89593, 0.89227, 0.89105,
                        0.88933, 0.88900, 0.88710, 0.88578, 0.88708, 0.88672, 0.88669,
                        0.88656, 0.88822, 0.89272, 0.89831, 0.90177, 0.89666, 0.86921, 0.76966],
                       [0.93536, 0.92882, 0.91575, 0.90423, 0.90471, 0.90577, 0.90779,
                        0.90872, 0.90876, 0.90529, 0.90107, 0.89718, 0.89420, 0.89306,
                        0.89115, 0.89125, 0.88928, 0.88856, 0.88919, 0.88923, 0.88967,
                        0.89024, 0.89169, 0.89598, 0.90075, 0.90266, 0.89778, 0.87296, 0.77309],
                       [0.93876, 0.93093, 0.92074, 0.91039, 0.90977, 0.90968, 0.90997,
                        0.91050, 0.90997, 0.90666, 0.90192, 0.89835, 0.89558, 0.89394,
                        0.89263, 0.89231, 0.89065, 0.89037, 0.89059, 0.89128, 0.89201,
                        0.89269, 0.89427, 0.89789, 0.90231, 0.90298, 0.89870, 0.87579, 0.77614],
                       [0.94187, 0.93278, 0.92433, 0.91522, 0.91366, 0.91283, 0.91156,
                        0.91138, 0.91082, 0.90731, 0.90239, 0.89892, 0.89647, 0.89382,
                        0.89394, 0.89226, 0.89178, 0.89117, 0.89153, 0.89258, 0.89323,
                        0.89439, 0.89620, 0.89904, 0.90255, 0.90328, 0.89931, 0.87782, 0.77902],
                       [0.94443, 0.93398, 0.92654, 0.91895, 0.91735, 0.91524, 0.91284,
                        0.91185, 0.91119, 0.90720, 0.90231, 0.89888, 0.89665, 0.89387,
                        0.89440, 0.89257, 0.89253, 0.89155, 0.89210, 0.89299, 0.89403,
                        0.89546, 0.89741, 0.90003, 0.90238, 0.90329, 0.89943, 0.87956, 0.78173],
                       [0.94645, 0.93524, 0.92839, 0.92215, 0.92048, 0.91730, 0.91413,
                        0.91296, 0.91130, 0.90698, 0.90211, 0.89913, 0.89704, 0.89513,
                        0.89459, 0.89409, 0.89291, 0.89218, 0.89263, 0.89345, 0.89538,
                        0.89634, 0.89835, 0.90110, 0.90253, 0.90320, 0.89964, 0.88131, 0.78443],
                       [0.94777, 0.93630, 0.92990, 0.92489, 0.92243, 0.91908, 0.91546,
                        0.91394, 0.91097, 0.90642, 0.90219, 0.89952, 0.89784, 0.89637,
                        0.89543, 0.89500, 0.89332, 0.89293, 0.89329, 0.89437, 0.89620,
                        0.89759, 0.89905, 0.90175, 0.90305, 0.90315, 0.90019, 0.88287, 0.78714],
                       [0.94713, 0.93679, 0.93077, 0.92688, 0.92339, 0.92038, 0.91639,
                        0.91360, 0.90948, 0.90475, 0.90180, 0.89916, 0.89788, 0.89655,
                        0.89616, 0.89487, 0.89394, 0.89316, 0.89389, 0.89503, 0.89601,
                        0.89842, 0.89962, 0.90165, 0.90375, 0.90317, 0.90013, 0.88374, 0.78889],
                       [0.94426, 0.93709, 0.93203, 0.92836, 0.92448, 0.92127, 0.91717,
                        0.91266, 0.90699, 0.90203, 0.90018, 0.89815, 0.89733, 0.89679,
                        0.89624, 0.89550, 0.89452, 0.89340, 0.89440, 0.89522, 0.89592,
                        0.89827, 0.90015, 0.90179, 0.90396, 0.90325, 0.89957, 0.88467, 0.78992],
                       [0.93983, 0.93734, 0.93330, 0.92950, 0.92629, 0.92197, 0.91753,
                        0.91125, 0.90377, 0.89854, 0.89724, 0.89685, 0.89675, 0.89688,
                        0.89631, 0.89630, 0.89433, 0.89388, 0.89431, 0.89509, 0.89614,
                        0.89800, 0.90015, 0.90206, 0.90305, 0.90248, 0.89899, 0.88569, 0.79123],
                       [0.93429, 0.93681, 0.93300, 0.93020, 0.92780, 0.92259, 0.91669,
                        0.90840, 0.89936, 0.89436, 0.89370, 0.89469, 0.89569, 0.89583,
                        0.89591, 0.89559, 0.89357, 0.89400, 0.89378, 0.89473, 0.89622,
                        0.89802, 0.89980, 0.90161, 0.90190, 0.90101, 0.89792, 0.88530, 0.79283],
                       [0.92810, 0.93487, 0.93241, 0.93105, 0.92851, 0.92312, 0.91531,
                        0.90459, 0.89425, 0.88995, 0.89027, 0.89184, 0.89425, 0.89462,
                        0.89446, 0.89422, 0.89324, 0.89346, 0.89350, 0.89438, 0.89612,
                        0.89796, 0.89948, 0.90102, 0.90162, 0.90016, 0.89692, 0.88442, 0.79397],
                       [0.92103, 0.93165, 0.93261, 0.93198, 0.92876, 0.92276, 0.91353,
                        0.90056, 0.88933, 0.88507, 0.88587, 0.88838, 0.89220, 0.89323,
                        0.89250, 0.89301, 0.89254, 0.89207, 0.89260, 0.89343, 0.89539,
                        0.89725, 0.89871, 0.90036, 0.90108, 0.89917, 0.89598, 0.88411, 0.79418],
                       [0.91378, 0.92771, 0.93245, 0.93230, 0.92850, 0.92115, 0.91029,
                        0.89600, 0.88459, 0.87998, 0.88049, 0.88400, 0.88906, 0.89087,
                        0.89060, 0.89124, 0.89050, 0.89013, 0.89093, 0.89173, 0.89388,
                        0.89581, 0.89777, 0.89921, 0.89916, 0.89692, 0.89431, 0.88365, 0.79424],
                       [0.90766, 0.92362, 0.93134, 0.93204, 0.92768, 0.91878, 0.90603,
                        0.89112, 0.87976, 0.87597, 0.87602, 0.87979, 0.88531, 0.88790,
                        0.88843, 0.88856, 0.88828, 0.88825, 0.88912, 0.89021, 0.89247,
                        0.89441, 0.89695, 0.89776, 0.89699, 0.89476, 0.89232, 0.88321, 0.79454],
                       [0.90244, 0.91919, 0.92950, 0.93076, 0.92622, 0.91569, 0.90153,
                        0.88626, 0.87503, 0.87251, 0.87266, 0.87646, 0.88128, 0.88427,
                        0.88520, 0.88525, 0.88596, 0.88605, 0.88675, 0.88839, 0.89092,
                        0.89313, 0.89533, 0.89639, 0.89537, 0.89336, 0.89031, 0.88295, 0.79459],
                       [0.89809, 0.91424, 0.92718, 0.92899, 0.92369, 0.91158, 0.89662,
                        0.88138, 0.87143, 0.86912, 0.86971, 0.87309, 0.87733, 0.88045,
                        0.88123, 0.88174, 0.88270, 0.88312, 0.88384, 0.88549, 0.88812,
                        0.89129, 0.89316, 0.89479, 0.89401, 0.89161, 0.88846, 0.88218, 0.79483],
                       [0.89533, 0.90979, 0.92442, 0.92738, 0.91988, 0.90709, 0.89160,
                        0.87694, 0.86974, 0.86729, 0.86730, 0.86943, 0.87377, 0.87718,
                        0.87756, 0.87840, 0.87927, 0.87997, 0.88073, 0.88259, 0.88504,
                        0.88905, 0.89127, 0.89267, 0.89255, 0.88985, 0.88707, 0.88105, 0.79525],
                       [0.89431, 0.90628, 0.92128, 0.92466, 0.91545, 0.90254, 0.88682,
                        0.87387, 0.86954, 0.86767, 0.86602, 0.86645, 0.87072, 0.87400,
                        0.87432, 0.87534, 0.87618, 0.87672, 0.87733, 0.88024, 0.88272,
                        0.88667, 0.88917, 0.89052, 0.89114, 0.88909, 0.88629, 0.88026, 0.79491],
                       [0.89505, 0.90324, 0.91778, 0.92060, 0.91111, 0.89735, 0.88225,
                        0.87278, 0.87017, 0.86945, 0.86633, 0.86507, 0.86828, 0.87063,
                        0.87132, 0.87204, 0.87327, 0.87359, 0.87439, 0.87772, 0.88051,
                        0.88430, 0.88695, 0.88893, 0.88978, 0.88900, 0.88627, 0.87970, 0.79429],
                       [0.89756, 0.90129, 0.91398, 0.91608, 0.90637, 0.89166, 0.87861,
                        0.87297, 0.87195, 0.87181, 0.86815, 0.86545, 0.86639, 0.86783,
                        0.86887, 0.86895, 0.87088, 0.87127, 0.87225, 0.87525, 0.87835,
                        0.88217, 0.88498, 0.88795, 0.88875, 0.88905, 0.88665, 0.87921, 0.79418],
                       [0.90194, 0.90121, 0.91006, 0.91139, 0.90108, 0.88678, 0.87672,
                        0.87379, 0.87575, 0.87495, 0.87109, 0.86704, 0.86581, 0.86670,
                        0.86741, 0.86758, 0.86930, 0.86987, 0.87053, 0.87353, 0.87681,
                        0.88050, 0.88343, 0.88694, 0.88859, 0.88964, 0.88729, 0.87901, 0.79423],
                       [0.90799, 0.90263, 0.90692, 0.90686, 0.89621, 0.88374, 0.87626,
                        0.87611, 0.88123, 0.87980, 0.87508, 0.86986, 0.86699, 0.86717,
                        0.86726, 0.86770, 0.86876, 0.86911, 0.87009, 0.87280, 0.87624,
                        0.87982, 0.88275, 0.88603, 0.88922, 0.89118, 0.88865, 0.87909, 0.79411],
                       [0.91525, 0.90515, 0.90519, 0.90298, 0.89247, 0.88223, 0.87678,
                        0.88027, 0.88704, 0.88615, 0.88032, 0.87375, 0.86958, 0.86861,
                        0.86851, 0.86864, 0.86933, 0.86929, 0.87118, 0.87328, 0.87639,
                        0.87995, 0.88316, 0.88625, 0.89080, 0.89368, 0.89073, 0.87962, 0.79413],
                       [0.92273, 0.90822, 0.90390, 0.89939, 0.88914, 0.88121, 0.87829,
                        0.88501, 0.89263, 0.89220, 0.88585, 0.87757, 0.87288, 0.87049,
                        0.87046, 0.87033, 0.87057, 0.87032, 0.87252, 0.87450, 0.87691,
                        0.88003, 0.88390, 0.88741, 0.89248, 0.89645, 0.89307, 0.88035, 0.79391],
                       [0.92943, 0.91167, 0.90261, 0.89597, 0.88660, 0.88073, 0.88107,
                        0.88952, 0.89807, 0.89723, 0.89066, 0.88156, 0.87616, 0.87256,
                        0.87271, 0.87268, 0.87233, 0.87212, 0.87400, 0.87590, 0.87798,
                        0.88045, 0.88429, 0.88850, 0.89368, 0.89897, 0.89561, 0.88082, 0.79339],
                       [0.93586, 0.91625, 0.90222, 0.89378, 0.88622, 0.88209, 0.88535,
                        0.89469, 0.90343, 0.90185, 0.89522, 0.88695, 0.87964, 0.87577,
                        0.87587, 0.87600, 0.87524, 0.87502, 0.87653, 0.87799, 0.88008,
                        0.88223, 0.88530, 0.88999, 0.89561, 0.90174, 0.89845, 0.88149, 0.79319],
                       [0.94252, 0.92225, 0.90346, 0.89375, 0.88750, 0.88574, 0.89072,
                        0.90103, 0.90865, 0.90627, 0.89973, 0.89260, 0.88392, 0.88076,
                        0.88011, 0.88052, 0.87934, 0.87880, 0.88031, 0.88157, 0.88337,
                        0.88477, 0.88794, 0.89260, 0.89881, 0.90489, 0.90146, 0.88283, 0.79356],
                       [0.94842, 0.92818, 0.90595, 0.89498, 0.88982, 0.89055, 0.89628,
                        0.90696, 0.91263, 0.90987, 0.90343, 0.89681, 0.88900, 0.88592,
                        0.88488, 0.88537, 0.88354, 0.88291, 0.88457, 0.88587, 0.88668,
                        0.88740, 0.89124, 0.89578, 0.90229, 0.90737, 0.90414, 0.88461, 0.79462],
                       [0.95242, 0.93292, 0.90908, 0.89674, 0.89351, 0.89536, 0.90168,
                        0.91106, 0.91472, 0.91178, 0.90612, 0.90033, 0.89390, 0.88997,
                        0.88980, 0.88965, 0.88750, 0.88708, 0.88841, 0.88937, 0.88938,
                        0.89049, 0.89398, 0.89867, 0.90502, 0.90887, 0.90588, 0.88628, 0.79582],
                       [0.95430, 0.93716, 0.91270, 0.89968, 0.89819, 0.90051, 0.90682,
                        0.91395, 0.91553, 0.91217, 0.90782, 0.90326, 0.89756, 0.89363,
                        0.89418, 0.89348, 0.89121, 0.89112, 0.89179, 0.89254, 0.89246,
                        0.89390, 0.89645, 0.90112, 0.90684, 0.91010, 0.90706, 0.88774, 0.79630],
                       [0.95440, 0.94115, 0.91667, 0.90427, 0.90347, 0.90662, 0.91139,
                        0.91630, 0.91560, 0.91181, 0.90849, 0.90466, 0.90008, 0.89738,
                        0.89734, 0.89700, 0.89436, 0.89484, 0.89522, 0.89601, 0.89608,
                        0.89711, 0.89910, 0.90349, 0.90817, 0.91128, 0.90826, 0.88962, 0.79691],
                       [0.95285, 0.94406, 0.92103, 0.90948, 0.90925, 0.91264, 0.91514,
                        0.91763, 0.91462, 0.91032, 0.90772, 0.90478, 0.90196, 0.90024,
                        0.89930, 0.89956, 0.89719, 0.89751, 0.89809, 0.89859, 0.89898,
                        0.89994, 0.90146, 0.90554, 0.90901, 0.91142, 0.90870, 0.89133, 0.79859],
                       [0.94982, 0.94572, 0.92571, 0.91442, 0.91511, 0.91743, 0.91827,
                        0.91767, 0.91234, 0.90756, 0.90545, 0.90410, 0.90292, 0.90176,
                        0.90087, 0.90109, 0.89946, 0.89866, 0.89952, 0.89993, 0.90081,
                        0.90214, 0.90334, 0.90683, 0.90942, 0.91000, 0.90802, 0.89218, 0.80060],
                       [0.94576, 0.94617, 0.92999, 0.91960, 0.92054, 0.92125, 0.92057,
                        0.91648, 0.90928, 0.90446, 0.90266, 0.90274, 0.90237, 0.90225,
                        0.90172, 0.90185, 0.90034, 0.89909, 0.89996, 0.90082, 0.90201,
                        0.90336, 0.90485, 0.90737, 0.90940, 0.90779, 0.90662, 0.89294, 0.80211],
                       [0.94097, 0.94547, 0.93373, 0.92503, 0.92510, 0.92418, 0.92125,
                        0.91421, 0.90581, 0.90147, 0.89972, 0.90062, 0.90072, 0.90143,
                        0.90112, 0.90133, 0.89979, 0.89911, 0.89964, 0.90090, 0.90244,
                        0.90359, 0.90564, 0.90716, 0.90838, 0.90575, 0.90481, 0.89390, 0.80335],
                       [0.93594, 0.94365, 0.93702, 0.92996, 0.92907, 0.92616, 0.92055,
                        0.91163, 0.90242, 0.89843, 0.89655, 0.89751, 0.89911, 0.89967,
                        0.89991, 0.89946, 0.89840, 0.89833, 0.89851, 0.89961, 0.90165,
                        0.90295, 0.90555, 0.90634, 0.90664, 0.90403, 0.90328, 0.89486, 0.80482],
                       [0.93118, 0.94096, 0.93926, 0.93399, 0.93265, 0.92753, 0.91921,
                        0.90924, 0.90002, 0.89544, 0.89348, 0.89430, 0.89723, 0.89763,
                        0.89791, 0.89698, 0.89644, 0.89676, 0.89659, 0.89784, 0.90019,
                        0.90201, 0.90454, 0.90524, 0.90505, 0.90220, 0.90209, 0.89589, 0.80673],
                       [0.92640, 0.93822, 0.94025, 0.93652, 0.93442, 0.92752, 0.91737,
                        0.90680, 0.89809, 0.89324, 0.89080, 0.89162, 0.89394, 0.89510,
                        0.89415, 0.89406, 0.89380, 0.89432, 0.89397, 0.89577, 0.89826,
                        0.90098, 0.90263, 0.90389, 0.90307, 0.90022, 0.90041, 0.89630, 0.80847],
                       [0.92215, 0.93504, 0.94058, 0.93776, 0.93404, 0.92588, 0.91507,
                        0.90436, 0.89610, 0.89228, 0.88890, 0.88893, 0.88995, 0.89188,
                        0.89001, 0.89054, 0.89060, 0.89092, 0.89123, 0.89272, 0.89562,
                        0.89889, 0.90022, 0.90178, 0.90034, 0.89841, 0.89831, 0.89596, 0.80953],
                       [0.91965, 0.93138, 0.94024, 0.93856, 0.93277, 0.92354, 0.91232,
                        0.90217, 0.89524, 0.89202, 0.88775, 0.88613, 0.88692, 0.88849,
                        0.88695, 0.88672, 0.88693, 0.88705, 0.88799, 0.88953, 0.89295,
                        0.89582, 0.89784, 0.89896, 0.89784, 0.89677, 0.89677, 0.89549, 0.81031],
                       [0.91870, 0.92856, 0.93902, 0.93831, 0.93099, 0.92096, 0.90975,
                        0.90072, 0.89600, 0.89228, 0.88710, 0.88418, 0.88483, 0.88526,
                        0.88443, 0.88342, 0.88330, 0.88365, 0.88450, 0.88706, 0.89054,
                        0.89308, 0.89571, 0.89646, 0.89644, 0.89551, 0.89620, 0.89513, 0.81104],
                       [0.91858, 0.92633, 0.93713, 0.93652, 0.92848, 0.91830, 0.90766,
                        0.90011, 0.89727, 0.89321, 0.88706, 0.88346, 0.88279, 0.88247,
                        0.88177, 0.88070, 0.88074, 0.88109, 0.88177, 0.88451, 0.88796,
                        0.89103, 0.89353, 0.89445, 0.89527, 0.89487, 0.89610, 0.89463, 0.81131],
                       [0.91959, 0.92462, 0.93485, 0.93412, 0.92545, 0.91601, 0.90601,
                        0.90071, 0.89889, 0.89505, 0.88846, 0.88403, 0.88141, 0.88091,
                        0.87973, 0.87867, 0.87948, 0.87916, 0.87984, 0.88199, 0.88589,
                        0.88933, 0.89168, 0.89286, 0.89426, 0.89526, 0.89616, 0.89420, 0.81126],
                       [0.92220, 0.92452, 0.93230, 0.93145, 0.92267, 0.91413, 0.90524,
                        0.90260, 0.90131, 0.89761, 0.89115, 0.88546, 0.88135, 0.88049,
                        0.87885, 0.87807, 0.87880, 0.87796, 0.87864, 0.88096, 0.88506,
                        0.88791, 0.89060, 0.89244, 0.89439, 0.89707, 0.89651, 0.89396, 0.81129],
                       [0.92615, 0.92539, 0.92998, 0.92844, 0.92045, 0.91218, 0.90524,
                        0.90456, 0.90415, 0.90032, 0.89388, 0.88704, 0.88220, 0.88059,
                        0.87870, 0.87833, 0.87812, 0.87771, 0.87822, 0.88128, 0.88467,
                        0.88707, 0.89005, 0.89282, 0.89520, 0.89926, 0.89769, 0.89379, 0.81138],
                       [0.93080, 0.92642, 0.92844, 0.92565, 0.91862, 0.91083, 0.90619,
                        0.90661, 0.90715, 0.90327, 0.89632, 0.88910, 0.88366, 0.88143,
                        0.87976, 0.87892, 0.87813, 0.87832, 0.87895, 0.88179, 0.88442,
                        0.88716, 0.89002, 0.89344, 0.89669, 0.90090, 0.90004, 0.89384, 0.81126],
                       [0.93559, 0.92800, 0.92727, 0.92360, 0.91709, 0.91116, 0.90828,
                        0.90936, 0.91048, 0.90647, 0.89881, 0.89190, 0.88567, 0.88308,
                        0.88196, 0.88050, 0.87976, 0.87968, 0.88098, 0.88257, 0.88490,
                        0.88806, 0.89062, 0.89449, 0.89874, 0.90252, 0.90239, 0.89388, 0.81041],
                       [0.93993, 0.93004, 0.92617, 0.92192, 0.91557, 0.91216, 0.91038,
                        0.91190, 0.91313, 0.90866, 0.90136, 0.89495, 0.88777, 0.88495,
                        0.88388, 0.88278, 0.88207, 0.88136, 0.88303, 0.88424, 0.88605,
                        0.88940, 0.89141, 0.89543, 0.90002, 0.90433, 0.90371, 0.89388, 0.80902],
                       [0.94329, 0.93255, 0.92556, 0.92028, 0.91449, 0.91262, 0.91199,
                        0.91387, 0.91433, 0.90942, 0.90353, 0.89738, 0.88990, 0.88672,
                        0.88550, 0.88487, 0.88388, 0.88312, 0.88461, 0.88646, 0.88788,
                        0.89058, 0.89259, 0.89665, 0.90090, 0.90586, 0.90431, 0.89392, 0.80799],
                       [0.94612, 0.93572, 0.92576, 0.91962, 0.91548, 0.91371, 0.91398,
                        0.91609, 0.91533, 0.91014, 0.90524, 0.89910, 0.89278, 0.88907,
                        0.88822, 0.88750, 0.88591, 0.88562, 0.88699, 0.88887, 0.89018,
                        0.89191, 0.89475, 0.89894, 0.90305, 0.90738, 0.90525, 0.89406, 0.80766],
                       [0.94902, 0.93885, 0.92662, 0.92044, 0.91844, 0.91629, 0.91702,
                        0.91824, 0.91663, 0.91144, 0.90658, 0.90084, 0.89591, 0.89248,
                        0.89183, 0.89105, 0.88891, 0.88890, 0.89028, 0.89162, 0.89252,
                        0.89424, 0.89727, 0.90125, 0.90601, 0.90929, 0.90703, 0.89453, 0.80765],
                       [0.95112, 0.94141, 0.92823, 0.92192, 0.92117, 0.91952, 0.92026,
                        0.91950, 0.91705, 0.91226, 0.90725, 0.90254, 0.89834, 0.89580,
                        0.89483, 0.89429, 0.89229, 0.89204, 0.89361, 0.89441, 0.89527,
                        0.89703, 0.89950, 0.90322, 0.90828, 0.91088, 0.90851, 0.89519, 0.80745],
                       [0.95136, 0.94341, 0.93072, 0.92366, 0.92309, 0.92241, 0.92213,
                        0.92009, 0.91636, 0.91180, 0.90729, 0.90369, 0.90026, 0.89808,
                        0.89696, 0.89680, 0.89529, 0.89488, 0.89623, 0.89699, 0.89799,
                        0.89938, 0.90179, 0.90536, 0.90963, 0.91191, 0.90901, 0.89593, 0.80696],
                       [0.94991, 0.94480, 0.93305, 0.92581, 0.92512, 0.92490, 0.92276,
                        0.92012, 0.91501, 0.91013, 0.90661, 0.90431, 0.90145, 0.89940,
                        0.89889, 0.89900, 0.89751, 0.89722, 0.89805, 0.89897, 0.90001,
                        0.90126, 0.90386, 0.90684, 0.91038, 0.91240, 0.90893, 0.89662, 0.80665],
                       [0.94701, 0.94524, 0.93438, 0.92812, 0.92736, 0.92688, 0.92307,
                        0.91910, 0.91243, 0.90763, 0.90507, 0.90390, 0.90165, 0.90006,
                        0.90041, 0.90032, 0.89880, 0.89844, 0.89931, 0.89986, 0.90132,
                        0.90246, 0.90486, 0.90758, 0.91066, 0.91192, 0.90837, 0.89656, 0.80682],
                       [0.94310, 0.94458, 0.93565, 0.93031, 0.92973, 0.92805, 0.92305,
                        0.91708, 0.90901, 0.90528, 0.90318, 0.90233, 0.90127, 0.90057,
                        0.90112, 0.90082, 0.89954, 0.89908, 0.89988, 0.90021, 0.90208,
                        0.90320, 0.90547, 0.90847, 0.91080, 0.91128, 0.90798, 0.89634, 0.80712],
                       [0.93905, 0.94312, 0.93739, 0.93260, 0.93203, 0.92870, 0.92249,
                        0.91482, 0.90635, 0.90307, 0.90113, 0.90030, 0.90083, 0.90094,
                        0.90113, 0.90092, 0.90000, 0.89957, 0.89997, 0.90078, 0.90259,
                        0.90390, 0.90626, 0.90910, 0.91085, 0.91110, 0.90811, 0.89688, 0.80699],
                       [0.93490, 0.94152, 0.93884, 0.93497, 0.93387, 0.92910, 0.92168,
                        0.91290, 0.90439, 0.90052, 0.89887, 0.89859, 0.90061, 0.90074,
                        0.90083, 0.90037, 0.89997, 0.89949, 0.90001, 0.90137, 0.90301,
                        0.90439, 0.90688, 0.90935, 0.91079, 0.91089, 0.90790, 0.89738, 0.80690],
                       [0.93084, 0.94012, 0.93933, 0.93707, 0.93516, 0.92903, 0.92066,
                        0.91093, 0.90213, 0.89836, 0.89683, 0.89739, 0.89976, 0.90006,
                        0.90025, 0.89964, 0.89931, 0.89912, 0.89993, 0.90141, 0.90308,
                        0.90461, 0.90735, 0.90949, 0.91098, 0.91041, 0.90734, 0.89752, 0.80781],
                       [0.92712, 0.93760, 0.93906, 0.93787, 0.93537, 0.92791, 0.91876,
                        0.90831, 0.90017, 0.89706, 0.89524, 0.89600, 0.89761, 0.89857,
                        0.89870, 0.89880, 0.89812, 0.89827, 0.89918, 0.90056, 0.90243,
                        0.90450, 0.90705, 0.90883, 0.91084, 0.90959, 0.90693, 0.89758, 0.80874],
                       [0.92374, 0.93382, 0.93870, 0.93763, 0.93403, 0.92583, 0.91576,
                        0.90584, 0.89908, 0.89585, 0.89382, 0.89401, 0.89543, 0.89638,
                        0.89668, 0.89721, 0.89672, 0.89658, 0.89765, 0.89897, 0.90112,
                        0.90381, 0.90582, 0.90768, 0.90980, 0.90883, 0.90684, 0.89755, 0.80886],
                       [0.92108, 0.93070, 0.93807, 0.93763, 0.93222, 0.92373, 0.91273,
                        0.90392, 0.89811, 0.89467, 0.89274, 0.89196, 0.89379, 0.89445,
                        0.89487, 0.89530, 0.89534, 0.89515, 0.89637, 0.89740, 0.89986,
                        0.90295, 0.90496, 0.90742, 0.90890, 0.90871, 0.90702, 0.89786, 0.80890],
                       [0.91950, 0.92866, 0.93672, 0.93743, 0.93091, 0.92142, 0.91046,
                        0.90191, 0.89731, 0.89460, 0.89220, 0.89081, 0.89214, 0.89314,
                        0.89313, 0.89354, 0.89406, 0.89442, 0.89545, 0.89626, 0.89938,
                        0.90201, 0.90485, 0.90767, 0.90867, 0.90911, 0.90693, 0.89818, 0.80925],
                       [0.91917, 0.92710, 0.93500, 0.93610, 0.92920, 0.91855, 0.90860,
                        0.90040, 0.89749, 0.89554, 0.89226, 0.89082, 0.89090, 0.89227,
                        0.89177, 0.89197, 0.89277, 0.89342, 0.89411, 0.89531, 0.89891,
                        0.90076, 0.90449, 0.90719, 0.90852, 0.90970, 0.90665, 0.89770, 0.80963],
                       [0.92042, 0.92581, 0.93342, 0.93374, 0.92674, 0.91607, 0.90711,
                        0.90026, 0.89838, 0.89664, 0.89305, 0.89111, 0.89050, 0.89168,
                        0.89110, 0.89078, 0.89180, 0.89204, 0.89311, 0.89459, 0.89783,
                        0.89996, 0.90361, 0.90648, 0.90861, 0.91053, 0.90715, 0.89735, 0.80999],
                       [0.92273, 0.92456, 0.93179, 0.93106, 0.92417, 0.91416, 0.90581,
                        0.90095, 0.89936, 0.89772, 0.89437, 0.89128, 0.89044, 0.89092,
                        0.89083, 0.89013, 0.89108, 0.89137, 0.89258, 0.89427, 0.89694,
                        0.90014, 0.90313, 0.90630, 0.90902, 0.91128, 0.90828, 0.89737, 0.81020],
                       [0.92523, 0.92395, 0.92996, 0.92872, 0.92140, 0.91250, 0.90459,
                        0.90186, 0.90072, 0.89907, 0.89557, 0.89197, 0.89059, 0.89021,
                        0.89055, 0.89055, 0.89041, 0.89125, 0.89211, 0.89434, 0.89674,
                        0.90039, 0.90317, 0.90635, 0.90957, 0.91144, 0.90913, 0.89728, 0.81014],
                       [0.92846, 0.92447, 0.92845, 0.92672, 0.91859, 0.91086, 0.90396,
                        0.90284, 0.90278, 0.90099, 0.89673, 0.89316, 0.89107, 0.89041,
                        0.89038, 0.89139, 0.89031, 0.89109, 0.89237, 0.89482, 0.89710,
                        0.90015, 0.90331, 0.90631, 0.91024, 0.91158, 0.90947, 0.89773, 0.81034],
                       [0.93254, 0.92577, 0.92714, 0.92488, 0.91676, 0.90944, 0.90434,
                        0.90401, 0.90508, 0.90342, 0.89851, 0.89478, 0.89202, 0.89142,
                        0.89115, 0.89179, 0.89124, 0.89158, 0.89340, 0.89558, 0.89791,
                        0.90046, 0.90393, 0.90683, 0.91098, 0.91252, 0.90972, 0.89839, 0.81105],
                       [0.93650, 0.92765, 0.92579, 0.92313, 0.91576, 0.90913, 0.90554,
                        0.90567, 0.90711, 0.90516, 0.90034, 0.89662, 0.89324, 0.89252,
                        0.89260, 0.89265, 0.89267, 0.89263, 0.89434, 0.89625, 0.89868,
                        0.90162, 0.90488, 0.90813, 0.91167, 0.91356, 0.91034, 0.89836, 0.81159],
                       [0.94012, 0.92999, 0.92499, 0.92152, 0.91479, 0.90973, 0.90700,
                        0.90739, 0.90882, 0.90601, 0.90179, 0.89790, 0.89449, 0.89337,
                        0.89393, 0.89391, 0.89392, 0.89373, 0.89507, 0.89693, 0.89937,
                        0.90260, 0.90552, 0.90934, 0.91221, 0.91370, 0.91098, 0.89819, 0.81143],
                       [0.94309, 0.93210, 0.92485, 0.92017, 0.91406, 0.91024, 0.90820,
                        0.90890, 0.90989, 0.90694, 0.90270, 0.89857, 0.89553, 0.89414,
                        0.89481, 0.89447, 0.89461, 0.89445, 0.89577, 0.89780, 0.90002,
                        0.90298, 0.90589, 0.90972, 0.91219, 0.91274, 0.91034, 0.89812, 0.81084],
                       [0.94558, 0.93414, 0.92545, 0.91952, 0.91438, 0.91114, 0.90923,
                        0.91103, 0.91073, 0.90789, 0.90331, 0.89932, 0.89681, 0.89526,
                        0.89574, 0.89536, 0.89531, 0.89496, 0.89665, 0.89889, 0.90076,
                        0.90336, 0.90636, 0.90968, 0.91179, 0.91132, 0.90873, 0.89787, 0.81076],
                       [0.94766, 0.93666, 0.92693, 0.91989, 0.91609, 0.91322, 0.91114,
                        0.91311, 0.91201, 0.90811, 0.90384, 0.90015, 0.89847, 0.89674,
                        0.89732, 0.89734, 0.89651, 0.89629, 0.89781, 0.89994, 0.90172,
                        0.90405, 0.90690, 0.90985, 0.91158, 0.91047, 0.90753, 0.89794, 0.81150],
                       [0.94844, 0.93919, 0.92829, 0.92105, 0.91794, 0.91567, 0.91366,
                        0.91388, 0.91246, 0.90729, 0.90323, 0.90048, 0.89906, 0.89807,
                        0.89861, 0.89855, 0.89728, 0.89762, 0.89832, 0.90027, 0.90212,
                        0.90459, 0.90734, 0.90995, 0.91096, 0.90928, 0.90632, 0.89787, 0.81189],
                       [0.94819, 0.94122, 0.92956, 0.92266, 0.91932, 0.91787, 0.91573,
                        0.91431, 0.91136, 0.90584, 0.90189, 0.90035, 0.89874, 0.89874,
                        0.89871, 0.89848, 0.89740, 0.89783, 0.89806, 0.90015, 0.90207,
                        0.90466, 0.90769, 0.90977, 0.90971, 0.90688, 0.90451, 0.89682, 0.81166],
                       [0.94696, 0.94216, 0.93103, 0.92413, 0.92091, 0.91962, 0.91707,
                        0.91464, 0.90948, 0.90374, 0.90070, 0.89952, 0.89841, 0.89850,
                        0.89784, 0.89804, 0.89720, 0.89733, 0.89785, 0.89996, 0.90201,
                        0.90392, 0.90720, 0.90895, 0.90787, 0.90405, 0.90181, 0.89535, 0.81159],
                       [0.94435, 0.94223, 0.93238, 0.92561, 0.92313, 0.92105, 0.91758,
                        0.91385, 0.90718, 0.90108, 0.89869, 0.89757, 0.89760, 0.89765,
                        0.89675, 0.89727, 0.89647, 0.89656, 0.89724, 0.89901, 0.90138,
                        0.90271, 0.90582, 0.90731, 0.90539, 0.90105, 0.89845, 0.89406, 0.81175],
                       [0.94152, 0.94230, 0.93417, 0.92781, 0.92597, 0.92249, 0.91778,
                        0.91231, 0.90436, 0.89849, 0.89558, 0.89510, 0.89601, 0.89643,
                        0.89583, 0.89594, 0.89515, 0.89513, 0.89592, 0.89727, 0.89989,
                        0.90176, 0.90433, 0.90549, 0.90287, 0.89757, 0.89538, 0.89257, 0.81179],
                       [0.93899, 0.94188, 0.93607, 0.93032, 0.92819, 0.92385, 0.91807,
                        0.91036, 0.90139, 0.89549, 0.89212, 0.89250, 0.89362, 0.89458,
                        0.89456, 0.89416, 0.89342, 0.89318, 0.89424, 0.89527, 0.89766,
                        0.90058, 0.90260, 0.90319, 0.90022, 0.89393, 0.89228, 0.89043, 0.81104],
                       [0.93594, 0.94056, 0.93717, 0.93235, 0.92916, 0.92472, 0.91765,
                        0.90774, 0.89798, 0.89144, 0.88860, 0.88938, 0.89089, 0.89209,
                        0.89235, 0.89170, 0.89130, 0.89110, 0.89174, 0.89292, 0.89491,
                        0.89849, 0.90031, 0.89980, 0.89684, 0.89029, 0.88848, 0.88811, 0.80954],
                       [0.93229, 0.93882, 0.93761, 0.93380, 0.93009, 0.92484, 0.91627,
                        0.90502, 0.89373, 0.88716, 0.88526, 0.88576, 0.88823, 0.88946,
                        0.88944, 0.88846, 0.88864, 0.88846, 0.88843, 0.89021, 0.89200,
                        0.89581, 0.89752, 0.89649, 0.89307, 0.88668, 0.88450, 0.88620, 0.80821],
                       [0.92876, 0.93624, 0.93750, 0.93462, 0.93114, 0.92392, 0.91413,
                        0.90200, 0.88969, 0.88335, 0.88175, 0.88196, 0.88491, 0.88657,
                        0.88625, 0.88496, 0.88528, 0.88523, 0.88502, 0.88718, 0.88919,
                        0.89283, 0.89425, 0.89359, 0.88933, 0.88316, 0.88088, 0.88395, 0.80711],
                       [0.92582, 0.93285, 0.93675, 0.93487, 0.93117, 0.92228, 0.91099,
                        0.89782, 0.88607, 0.87989, 0.87764, 0.87810, 0.88094, 0.88309,
                        0.88268, 0.88160, 0.88140, 0.88143, 0.88150, 0.88373, 0.88629,
                        0.88934, 0.89072, 0.89016, 0.88574, 0.87950, 0.87753, 0.88081, 0.80557],
                       [0.92316, 0.92968, 0.93582, 0.93480, 0.92978, 0.92043, 0.90760,
                        0.89344, 0.88217, 0.87653, 0.87381, 0.87442, 0.87742, 0.87940,
                        0.87884, 0.87855, 0.87782, 0.87754, 0.87795, 0.87979, 0.88250,
                        0.88546, 0.88739, 0.88618, 0.88244, 0.87571, 0.87411, 0.87780, 0.80385],
                       [0.92062, 0.92672, 0.93470, 0.93415, 0.92753, 0.91767, 0.90448,
                        0.88981, 0.87856, 0.87318, 0.87095, 0.87117, 0.87395, 0.87552,
                        0.87494, 0.87501, 0.87472, 0.87412, 0.87431, 0.87548, 0.87810,
                        0.88164, 0.88378, 0.88212, 0.87902, 0.87246, 0.87068, 0.87526, 0.80223],
                       [0.91824, 0.92343, 0.93270, 0.93248, 0.92523, 0.91398, 0.90098,
                        0.88625, 0.87552, 0.87033, 0.86837, 0.86812, 0.87018, 0.87151,
                        0.87100, 0.87058, 0.87121, 0.87064, 0.87034, 0.87156, 0.87417,
                        0.87794, 0.87957, 0.87848, 0.87539, 0.87024, 0.86827, 0.87254, 0.80009],
                       [0.91613, 0.91973, 0.92975, 0.92982, 0.92267, 0.91022, 0.89690,
                        0.88244, 0.87280, 0.86819, 0.86575, 0.86521, 0.86661, 0.86790,
                        0.86764, 0.86659, 0.86749, 0.86697, 0.86684, 0.86844, 0.87088,
                        0.87413, 0.87563, 0.87559, 0.87247, 0.86889, 0.86707, 0.86982, 0.79749],
                       [0.91438, 0.91641, 0.92626, 0.92656, 0.91898, 0.90647, 0.89249,
                        0.87912, 0.87061, 0.86623, 0.86353, 0.86258, 0.86371, 0.86491,
                        0.86494, 0.86361, 0.86416, 0.86366, 0.86398, 0.86528, 0.86776,
                        0.87041, 0.87249, 0.87282, 0.87012, 0.86798, 0.86589, 0.86736, 0.79482],
                       [0.91278, 0.91400, 0.92273, 0.92334, 0.91478, 0.90245, 0.88825,
                        0.87692, 0.86945, 0.86526, 0.86204, 0.86071, 0.86192, 0.86259,
                        0.86239, 0.86139, 0.86135, 0.86113, 0.86135, 0.86222, 0.86476,
                        0.86767, 0.86975, 0.86999, 0.86842, 0.86732, 0.86468, 0.86528, 0.79229],
                       [0.91121, 0.91129, 0.91922, 0.92003, 0.91073, 0.89820, 0.88493,
                        0.87533, 0.86894, 0.86556, 0.86152, 0.85975, 0.86045, 0.86076,
                        0.86003, 0.85962, 0.85918, 0.85940, 0.85904, 0.86012, 0.86233,
                        0.86564, 0.86707, 0.86769, 0.86765, 0.86695, 0.86466, 0.86380, 0.78987],
                       [0.90953, 0.90816, 0.91590, 0.91626, 0.90659, 0.89431, 0.88255,
                        0.87376, 0.86844, 0.86569, 0.86194, 0.85921, 0.85877, 0.85913,
                        0.85811, 0.85785, 0.85769, 0.85801, 0.85705, 0.85844, 0.86071,
                        0.86340, 0.86505, 0.86622, 0.86726, 0.86751, 0.86573, 0.86245, 0.78757],
                       [0.90769, 0.90579, 0.91264, 0.91187, 0.90260, 0.89093, 0.88035,
                        0.87261, 0.86850, 0.86560, 0.86244, 0.85909, 0.85795, 0.85773,
                        0.85693, 0.85653, 0.85650, 0.85648, 0.85584, 0.85713, 0.85952,
                        0.86151, 0.86359, 0.86545, 0.86714, 0.86923, 0.86671, 0.86111, 0.78576],
                       [0.90618, 0.90435, 0.90914, 0.90738, 0.89881, 0.88779, 0.87861,
                        0.87245, 0.86964, 0.86657, 0.86293, 0.85971, 0.85812, 0.85718,
                        0.85680, 0.85634, 0.85569, 0.85554, 0.85576, 0.85702, 0.85862,
                        0.86059, 0.86278, 0.86534, 0.86794, 0.87137, 0.86801, 0.86030, 0.78412],
                       [0.90487, 0.90326, 0.90598, 0.90382, 0.89505, 0.88496, 0.87750,
                        0.87314, 0.87142, 0.86868, 0.86431, 0.86081, 0.85885, 0.85767,
                        0.85751, 0.85702, 0.85603, 0.85594, 0.85640, 0.85743, 0.85829,
                        0.86028, 0.86285, 0.86586, 0.86988, 0.87371, 0.87057, 0.86017, 0.78214],
                       [0.90314, 0.90221, 0.90343, 0.90078, 0.89187, 0.88272, 0.87629,
                        0.87409, 0.87345, 0.87094, 0.86625, 0.86201, 0.85971, 0.85849,
                        0.85827, 0.85775, 0.85726, 0.85689, 0.85741, 0.85773, 0.85903,
                        0.86068, 0.86300, 0.86662, 0.87213, 0.87628, 0.87369, 0.86059, 0.78014],
                       [0.90126, 0.90135, 0.90121, 0.89781, 0.88943, 0.88130, 0.87567,
                        0.87497, 0.87559, 0.87306, 0.86806, 0.86327, 0.86034, 0.85940,
                        0.85900, 0.85850, 0.85868, 0.85798, 0.85847, 0.85897, 0.86075,
                        0.86175, 0.86357, 0.86784, 0.87420, 0.87951, 0.87669, 0.86146, 0.77856],
                       [0.89986, 0.90065, 0.89946, 0.89551, 0.88754, 0.88068, 0.87657,
                        0.87682, 0.87802, 0.87549, 0.87037, 0.86526, 0.86168, 0.86087,
                        0.86050, 0.86055, 0.86058, 0.85994, 0.86011, 0.86160, 0.86270,
                        0.86352, 0.86558, 0.87013, 0.87692, 0.88363, 0.88023, 0.86298, 0.77790],
                       [0.89917, 0.90045, 0.89858, 0.89380, 0.88678, 0.88090, 0.87840,
                        0.87979, 0.88071, 0.87821, 0.87318, 0.86815, 0.86438, 0.86316,
                        0.86297, 0.86362, 0.86298, 0.86252, 0.86310, 0.86472, 0.86494,
                        0.86620, 0.86892, 0.87332, 0.88065, 0.88784, 0.88441, 0.86511, 0.77837],
                       [0.89884, 0.90066, 0.89803, 0.89256, 0.88667, 0.88155, 0.88023,
                        0.88199, 0.88313, 0.88063, 0.87561, 0.87096, 0.86714, 0.86560,
                        0.86555, 0.86593, 0.86525, 0.86483, 0.86604, 0.86728, 0.86759,
                        0.86890, 0.87213, 0.87678, 0.88417, 0.89106, 0.88782, 0.86673, 0.77867],
                       [0.89865, 0.90085, 0.89738, 0.89207, 0.88635, 0.88262, 0.88187,
                        0.88369, 0.88549, 0.88308, 0.87808, 0.87327, 0.86938, 0.86779,
                        0.86776, 0.86788, 0.86744, 0.86730, 0.86856, 0.86940, 0.87070,
                        0.87141, 0.87466, 0.88033, 0.88728, 0.89373, 0.88977, 0.86814, 0.77854],
                       [0.89888, 0.90163, 0.89727, 0.89216, 0.88676, 0.88440, 0.88381,
                        0.88657, 0.88805, 0.88591, 0.88071, 0.87571, 0.87200, 0.87011,
                        0.87030, 0.87078, 0.87022, 0.87051, 0.87176, 0.87249, 0.87416,
                        0.87459, 0.87756, 0.88361, 0.89074, 0.89675, 0.89187, 0.87066, 0.77910],
                       [0.89975, 0.90300, 0.89801, 0.89297, 0.88831, 0.88633, 0.88632,
                        0.88963, 0.89036, 0.88836, 0.88287, 0.87844, 0.87461, 0.87261,
                        0.87339, 0.87400, 0.87344, 0.87385, 0.87516, 0.87647, 0.87723,
                        0.87847, 0.88130, 0.88664, 0.89427, 0.89937, 0.89487, 0.87314, 0.78027],
                       [0.90130, 0.90419, 0.89930, 0.89450, 0.89019, 0.88822, 0.88902,
                        0.89132, 0.89208, 0.88985, 0.88504, 0.88066, 0.87666, 0.87513,
                        0.87621, 0.87654, 0.87637, 0.87676, 0.87806, 0.87977, 0.87990,
                        0.88233, 0.88534, 0.88987, 0.89694, 0.90093, 0.89704, 0.87452, 0.78161],
                       [0.90348, 0.90527, 0.90104, 0.89600, 0.89241, 0.89067, 0.89146,
                        0.89279, 0.89362, 0.89092, 0.88728, 0.88222, 0.87886, 0.87788,
                        0.87868, 0.87900, 0.87899, 0.87959, 0.88082, 0.88224, 0.88304,
                        0.88572, 0.88901, 0.89340, 0.89890, 0.90197, 0.89797, 0.87612, 0.78307],
                       [0.90619, 0.90654, 0.90287, 0.89722, 0.89478, 0.89357, 0.89364,
                        0.89486, 0.89509, 0.89225, 0.88888, 0.88404, 0.88136, 0.88074,
                        0.88097, 0.88186, 0.88155, 0.88223, 0.88374, 0.88459, 0.88668,
                        0.88843, 0.89191, 0.89685, 0.90073, 0.90314, 0.89879, 0.87828, 0.78461],
                       [0.90955, 0.90811, 0.90427, 0.89893, 0.89692, 0.89616, 0.89553,
                        0.89645, 0.89592, 0.89360, 0.88969, 0.88610, 0.88354, 0.88297,
                        0.88299, 0.88441, 0.88403, 0.88415, 0.88604, 0.88711, 0.88971,
                        0.89062, 0.89423, 0.89945, 0.90237, 0.90388, 0.89927, 0.87989, 0.78610],
                       [0.91316, 0.91005, 0.90597, 0.90137, 0.89942, 0.89827, 0.89716,
                        0.89721, 0.89615, 0.89420, 0.89021, 0.88749, 0.88551, 0.88453,
                        0.88497, 0.88644, 0.88586, 0.88612, 0.88748, 0.88962, 0.89156,
                        0.89291, 0.89638, 0.90084, 0.90335, 0.90321, 0.89841, 0.88061, 0.78753],
                       [0.91640, 0.91229, 0.90847, 0.90396, 0.90237, 0.90048, 0.89871,
                        0.89756, 0.89623, 0.89384, 0.89059, 0.88841, 0.88721, 0.88593,
                        0.88702, 0.88807, 0.88711, 0.88803, 0.88891, 0.89139, 0.89293,
                        0.89524, 0.89834, 0.90170, 0.90350, 0.90136, 0.89668, 0.88106, 0.78928],
                       [0.91909, 0.91415, 0.91042, 0.90617, 0.90474, 0.90288, 0.89990,
                        0.89735, 0.89530, 0.89259, 0.89016, 0.88869, 0.88791, 0.88712,
                        0.88835, 0.88857, 0.88814, 0.88851, 0.88999, 0.89190, 0.89401,
                        0.89665, 0.89951, 0.90205, 0.90265, 0.89915, 0.89478, 0.88121, 0.79083],
                       [0.92138, 0.91585, 0.91182, 0.90827, 0.90677, 0.90460, 0.90052,
                        0.89659, 0.89296, 0.89038, 0.88894, 0.88757, 0.88772, 0.88788,
                        0.88857, 0.88828, 0.88870, 0.88841, 0.89013, 0.89177, 0.89413,
                        0.89709, 0.89968, 0.90163, 0.90101, 0.89658, 0.89256, 0.88075, 0.79172],
                       [0.92319, 0.91760, 0.91360, 0.91048, 0.90888, 0.90531, 0.90066,
                        0.89546, 0.89031, 0.88737, 0.88697, 0.88591, 0.88717, 0.88786,
                        0.88800, 0.88822, 0.88843, 0.88848, 0.88938, 0.89124, 0.89355,
                        0.89665, 0.89925, 0.90046, 0.89878, 0.89337, 0.88956, 0.87997, 0.79239],
                       [0.92398, 0.91829, 0.91494, 0.91235, 0.91037, 0.90553, 0.90039,
                        0.89375, 0.88760, 0.88386, 0.88341, 0.88415, 0.88594, 0.88679,
                        0.88718, 0.88789, 0.88703, 0.88770, 0.88803, 0.89005, 0.89268,
                        0.89525, 0.89805, 0.89810, 0.89564, 0.88959, 0.88567, 0.87861, 0.79308],
                       [0.92335, 0.91797, 0.91558, 0.91361, 0.91133, 0.90562, 0.89948,
                        0.89128, 0.88409, 0.87972, 0.87889, 0.88165, 0.88396, 0.88514,
                        0.88611, 0.88645, 0.88518, 0.88585, 0.88626, 0.88832, 0.89112,
                        0.89365, 0.89596, 0.89535, 0.89172, 0.88517, 0.88152, 0.87661, 0.79370],
                       [0.92182, 0.91756, 0.91632, 0.91472, 0.91207, 0.90576, 0.89787,
                        0.88803, 0.87947, 0.87478, 0.87476, 0.87826, 0.88157, 0.88327,
                        0.88407, 0.88386, 0.88309, 0.88318, 0.88372, 0.88560, 0.88854,
                        0.89159, 0.89320, 0.89270, 0.88768, 0.88046, 0.87768, 0.87447, 0.79362],
                       [0.91978, 0.91699, 0.91683, 0.91572, 0.91200, 0.90539, 0.89531,
                        0.88387, 0.87406, 0.86923, 0.87033, 0.87372, 0.87825, 0.88051,
                        0.88075, 0.88018, 0.87978, 0.87990, 0.88019, 0.88176, 0.88489,
                        0.88834, 0.88969, 0.88918, 0.88350, 0.87554, 0.87378, 0.87213, 0.79262],
                       [0.91650, 0.91575, 0.91664, 0.91598, 0.91138, 0.90379, 0.89205,
                        0.87928, 0.86817, 0.86322, 0.86436, 0.86810, 0.87378, 0.87664,
                        0.87649, 0.87602, 0.87571, 0.87617, 0.87620, 0.87771, 0.88068,
                        0.88429, 0.88560, 0.88459, 0.87873, 0.87026, 0.86921, 0.86970, 0.79153],
                       [0.91175, 0.91372, 0.91603, 0.91542, 0.91061, 0.90137, 0.88906,
                        0.87492, 0.86226, 0.85719, 0.85755, 0.86242, 0.86890, 0.87231,
                        0.87181, 0.87175, 0.87168, 0.87175, 0.87207, 0.87379, 0.87668,
                        0.88019, 0.88146, 0.87971, 0.87391, 0.86531, 0.86439, 0.86712, 0.79078],
                       [0.90682, 0.91077, 0.91479, 0.91474, 0.90914, 0.89863, 0.88574,
                        0.87005, 0.85652, 0.85129, 0.85114, 0.85684, 0.86381, 0.86766,
                        0.86682, 0.86650, 0.86650, 0.86628, 0.86703, 0.86930, 0.87242,
                        0.87590, 0.87714, 0.87489, 0.86912, 0.86064, 0.85971, 0.86385, 0.78959],
                       [0.90197, 0.90723, 0.91275, 0.91356, 0.90707, 0.89556, 0.88126,
                        0.86434, 0.85072, 0.84522, 0.84521, 0.85073, 0.85788, 0.86199,
                        0.86148, 0.86044, 0.86042, 0.86033, 0.86118, 0.86361, 0.86732,
                        0.87081, 0.87218, 0.86995, 0.86412, 0.85572, 0.85520, 0.86025, 0.78764],
                       [0.89653, 0.90336, 0.91038, 0.91156, 0.90433, 0.89197, 0.87615,
                        0.85901, 0.84524, 0.83944, 0.83937, 0.84432, 0.85124, 0.85542,
                        0.85559, 0.85456, 0.85483, 0.85476, 0.85543, 0.85730, 0.86199,
                        0.86538, 0.86692, 0.86502, 0.85930, 0.85093, 0.85094, 0.85726, 0.78576],
                       [0.89106, 0.89900, 0.90773, 0.90931, 0.90079, 0.88777, 0.87114,
                        0.85438, 0.84027, 0.83453, 0.83386, 0.83807, 0.84486, 0.84900,
                        0.84922, 0.84854, 0.84916, 0.84929, 0.84960, 0.85151, 0.85654,
                        0.86008, 0.86188, 0.86009, 0.85484, 0.84685, 0.84712, 0.85476, 0.78408],
                       [0.88641, 0.89467, 0.90458, 0.90624, 0.89677, 0.88321, 0.86638,
                        0.84945, 0.83558, 0.83034, 0.82919, 0.83233, 0.83885, 0.84303,
                        0.84274, 0.84220, 0.84294, 0.84333, 0.84354, 0.84642, 0.85089,
                        0.85475, 0.85693, 0.85519, 0.85035, 0.84349, 0.84393, 0.85187, 0.78209],
                       [0.88260, 0.89062, 0.90101, 0.90197, 0.89228, 0.87845, 0.86174,
                        0.84435, 0.83151, 0.82705, 0.82522, 0.82732, 0.83297, 0.83708,
                        0.83627, 0.83611, 0.83691, 0.83704, 0.83767, 0.84107, 0.84522,
                        0.84944, 0.85201, 0.85056, 0.84583, 0.84036, 0.84102, 0.84858, 0.77986],
                       [0.87899, 0.88649, 0.89703, 0.89774, 0.88767, 0.87323, 0.85703,
                        0.84049, 0.82897, 0.82476, 0.82164, 0.82288, 0.82763, 0.83120,
                        0.83032, 0.83037, 0.83148, 0.83129, 0.83231, 0.83517, 0.84001,
                        0.84458, 0.84727, 0.84620, 0.84205, 0.83769, 0.83844, 0.84570, 0.77737],
                       [0.87593, 0.88279, 0.89323, 0.89382, 0.88290, 0.86797, 0.85227,
                        0.83812, 0.82807, 0.82345, 0.81918, 0.81923, 0.82303, 0.82566,
                        0.82528, 0.82514, 0.82647, 0.82642, 0.82756, 0.82998, 0.83560,
                        0.84014, 0.84262, 0.84236, 0.83948, 0.83621, 0.83633, 0.84343, 0.77469],
                       [0.87441, 0.87997, 0.88980, 0.88919, 0.87757, 0.86313, 0.84809,
                        0.83637, 0.82807, 0.82347, 0.81880, 0.81695, 0.81912, 0.82095,
                        0.82070, 0.82048, 0.82193, 0.82220, 0.82332, 0.82607, 0.83125,
                        0.83588, 0.83838, 0.83913, 0.83761, 0.83562, 0.83480, 0.84151, 0.77211],
                       [0.87433, 0.87735, 0.88565, 0.88394, 0.87193, 0.85829, 0.84485,
                        0.83521, 0.82925, 0.82478, 0.81967, 0.81602, 0.81617, 0.81731,
                        0.81656, 0.81635, 0.81801, 0.81859, 0.81953, 0.82285, 0.82689,
                        0.83198, 0.83491, 0.83613, 0.83589, 0.83545, 0.83462, 0.83950, 0.76978],
                       [0.87537, 0.87543, 0.88130, 0.87890, 0.86696, 0.85376, 0.84254,
                        0.83527, 0.83181, 0.82760, 0.82118, 0.81608, 0.81459, 0.81474,
                        0.81385, 0.81374, 0.81509, 0.81581, 0.81676, 0.82038, 0.82372,
                        0.82880, 0.83211, 0.83377, 0.83489, 0.83600, 0.83567, 0.83755, 0.76758],
                       [0.87729, 0.87496, 0.87792, 0.87457, 0.86308, 0.85073, 0.84156,
                        0.83692, 0.83534, 0.83194, 0.82423, 0.81750, 0.81450, 0.81360,
                        0.81306, 0.81290, 0.81386, 0.81435, 0.81554, 0.81881, 0.82214,
                        0.82654, 0.83013, 0.83275, 0.83529, 0.83791, 0.83716, 0.83660, 0.76541],
                       [0.87985, 0.87535, 0.87522, 0.87068, 0.85924, 0.84878, 0.84161,
                        0.83976, 0.84002, 0.83694, 0.82879, 0.82020, 0.81537, 0.81362,
                        0.81318, 0.81285, 0.81404, 0.81412, 0.81568, 0.81788, 0.82134,
                        0.82541, 0.82933, 0.83278, 0.83685, 0.84113, 0.83887, 0.83658, 0.76342],
                       [0.88368, 0.87636, 0.87321, 0.86719, 0.85567, 0.84711, 0.84241,
                        0.84320, 0.84595, 0.84251, 0.83384, 0.82396, 0.81744, 0.81474,
                        0.81408, 0.81398, 0.81499, 0.81479, 0.81678, 0.81827, 0.82151,
                        0.82567, 0.82962, 0.83347, 0.83906, 0.84488, 0.84186, 0.83638, 0.76161],
                       [0.88823, 0.87777, 0.87184, 0.86397, 0.85339, 0.84638, 0.84420,
                        0.84753, 0.85214, 0.84873, 0.83929, 0.82889, 0.82098, 0.81714,
                        0.81633, 0.81665, 0.81654, 0.81652, 0.81827, 0.82020, 0.82298,
                        0.82674, 0.83021, 0.83482, 0.84133, 0.84879, 0.84621, 0.83603, 0.75972],
                       [0.89200, 0.87980, 0.87065, 0.86125, 0.85210, 0.84702, 0.84686,
                        0.85274, 0.85811, 0.85536, 0.84574, 0.83443, 0.82527, 0.82044,
                        0.81978, 0.81991, 0.81915, 0.81923, 0.82027, 0.82281, 0.82466,
                        0.82799, 0.83134, 0.83705, 0.84405, 0.85324, 0.85064, 0.83674, 0.75803],
                       [0.89559, 0.88308, 0.87034, 0.86005, 0.85193, 0.84886, 0.85056,
                        0.85832, 0.86434, 0.86201, 0.85246, 0.84020, 0.83019, 0.82465,
                        0.82449, 0.82385, 0.82327, 0.82303, 0.82388, 0.82612, 0.82707,
                        0.83016, 0.83400, 0.84032, 0.84819, 0.85840, 0.85511, 0.83860, 0.75684],
                       [0.89995, 0.88722, 0.87139, 0.86037, 0.85317, 0.85169, 0.85536,
                        0.86444, 0.87088, 0.86807, 0.85862, 0.84660, 0.83576, 0.83031,
                        0.82990, 0.82918, 0.82853, 0.82825, 0.82939, 0.83069, 0.83143,
                        0.83373, 0.83763, 0.84419, 0.85347, 0.86365, 0.85999, 0.84084, 0.75614],
                       [0.90409, 0.89113, 0.87302, 0.86126, 0.85502, 0.85521, 0.86051,
                        0.87084, 0.87702, 0.87364, 0.86434, 0.85314, 0.84185, 0.83650,
                        0.83559, 0.83530, 0.83421, 0.83426, 0.83555, 0.83621, 0.83662,
                        0.83796, 0.84135, 0.84829, 0.85863, 0.86870, 0.86499, 0.84302, 0.75617],
                       [0.90726, 0.89482, 0.87515, 0.86293, 0.85782, 0.85951, 0.86593,
                        0.87692, 0.88223, 0.87866, 0.86969, 0.85919, 0.84841, 0.84240,
                        0.84189, 0.84170, 0.84024, 0.84023, 0.84156, 0.84195, 0.84192,
                        0.84279, 0.84581, 0.85325, 0.86372, 0.87416, 0.87012, 0.84542, 0.75682],
                       [0.91008, 0.89924, 0.87847, 0.86596, 0.86250, 0.86506, 0.87230,
                        0.88249, 0.88654, 0.88264, 0.87480, 0.86500, 0.85509, 0.84879,
                        0.84849, 0.84861, 0.84681, 0.84628, 0.84773, 0.84790, 0.84784,
                        0.84863, 0.85161, 0.85902, 0.86931, 0.87963, 0.87562, 0.84852, 0.75786],
                       [0.91258, 0.90342, 0.88226, 0.86969, 0.86798, 0.87110, 0.87859,
                        0.88704, 0.88968, 0.88547, 0.87883, 0.87012, 0.86108, 0.85546,
                        0.85490, 0.85535, 0.85332, 0.85264, 0.85412, 0.85425, 0.85395,
                        0.85454, 0.85764, 0.86441, 0.87446, 0.88411, 0.88076, 0.85200, 0.75925],
                       [0.91384, 0.90652, 0.88625, 0.87367, 0.87334, 0.87684, 0.88358,
                        0.89043, 0.89174, 0.88713, 0.88127, 0.87391, 0.86586, 0.86134,
                        0.86099, 0.86154, 0.85929, 0.85895, 0.86042, 0.86062, 0.85980,
                        0.85988, 0.86296, 0.86930, 0.87915, 0.88782, 0.88462, 0.85545, 0.76074],
                       [0.91403, 0.90937, 0.89072, 0.87854, 0.87894, 0.88249, 0.88787,
                        0.89310, 0.89256, 0.88750, 0.88264, 0.87678, 0.87005, 0.86643,
                        0.86635, 0.86718, 0.86466, 0.86485, 0.86616, 0.86607, 0.86507,
                        0.86517, 0.86807, 0.87411, 0.88380, 0.89093, 0.88716, 0.85853, 0.76228],
                       [0.91427, 0.91242, 0.89505, 0.88451, 0.88488, 0.88817, 0.89209,
                        0.89504, 0.89187, 0.88710, 0.88313, 0.87895, 0.87417, 0.87110,
                        0.87089, 0.87181, 0.86935, 0.86996, 0.87099, 0.87080, 0.86991,
                        0.87036, 0.87333, 0.87904, 0.88758, 0.89317, 0.88908, 0.86124, 0.76444],
                       [0.91433, 0.91526, 0.89956, 0.89060, 0.89109, 0.89370, 0.89604,
                        0.89591, 0.89079, 0.88619, 0.88296, 0.88038, 0.87768, 0.87518,
                        0.87522, 0.87591, 0.87372, 0.87393, 0.87526, 0.87561, 0.87494,
                        0.87563, 0.87830, 0.88381, 0.89042, 0.89479, 0.89094, 0.86432, 0.76762],
                       [0.91379, 0.91725, 0.90430, 0.89611, 0.89699, 0.89856, 0.89902,
                        0.89555, 0.88967, 0.88435, 0.88216, 0.88071, 0.87972, 0.87793,
                        0.87873, 0.87944, 0.87770, 0.87723, 0.87885, 0.87956, 0.87954,
                        0.88032, 0.88242, 0.88747, 0.89279, 0.89570, 0.89186, 0.86742, 0.77106],
                       [0.91290, 0.91809, 0.90830, 0.90126, 0.90188, 0.90217, 0.90035,
                        0.89392, 0.88725, 0.88171, 0.88026, 0.87942, 0.87978, 0.87905,
                        0.88042, 0.88113, 0.88000, 0.88004, 0.88098, 0.88189, 0.88276,
                        0.88327, 0.88580, 0.88987, 0.89416, 0.89512, 0.89126, 0.86953, 0.77387],
                       [0.91209, 0.91818, 0.91125, 0.90616, 0.90609, 0.90471, 0.90058,
                        0.89205, 0.88397, 0.87933, 0.87742, 0.87732, 0.87857, 0.87961,
                        0.88076, 0.88133, 0.88031, 0.88167, 0.88179, 0.88325, 0.88460,
                        0.88550, 0.88857, 0.89171, 0.89439, 0.89328, 0.88992, 0.87100, 0.77632],
                       [0.91217, 0.91821, 0.91375, 0.91046, 0.90981, 0.90672, 0.90037,
                        0.89095, 0.88166, 0.87746, 0.87502, 0.87577, 0.87756, 0.87987,
                        0.88049, 0.88103, 0.88019, 0.88185, 0.88213, 0.88413, 0.88578,
                        0.88776, 0.89012, 0.89308, 0.89428, 0.89152, 0.88843, 0.87258, 0.77931],
                       [0.91275, 0.91825, 0.91614, 0.91380, 0.91233, 0.90771, 0.89938,
                        0.88959, 0.88016, 0.87552, 0.87333, 0.87437, 0.87664, 0.87876,
                        0.87950, 0.88002, 0.88008, 0.88097, 0.88200, 0.88392, 0.88613,
                        0.88881, 0.89035, 0.89325, 0.89362, 0.88975, 0.88605, 0.87394, 0.78241],
                       [0.91334, 0.91787, 0.91796, 0.91632, 0.91354, 0.90726, 0.89754,
                        0.88703, 0.87838, 0.87359, 0.87115, 0.87188, 0.87466, 0.87660,
                        0.87743, 0.87815, 0.87884, 0.87936, 0.88050, 0.88223, 0.88522,
                        0.88823, 0.88984, 0.89227, 0.89165, 0.88692, 0.88270, 0.87428, 0.78449],
                       [0.91419, 0.91702, 0.91895, 0.91794, 0.91381, 0.90616, 0.89521,
                        0.88395, 0.87664, 0.87187, 0.86879, 0.86886, 0.87186, 0.87428,
                        0.87463, 0.87543, 0.87634, 0.87709, 0.87786, 0.87985, 0.88339,
                        0.88673, 0.88906, 0.89062, 0.88893, 0.88312, 0.87942, 0.87345, 0.78589],
                       [0.91532, 0.91639, 0.91918, 0.91832, 0.91329, 0.90484, 0.89296,
                        0.88176, 0.87572, 0.87107, 0.86765, 0.86649, 0.86926, 0.87172,
                        0.87167, 0.87217, 0.87345, 0.87445, 0.87512, 0.87748, 0.88101,
                        0.88489, 0.88794, 0.88849, 0.88603, 0.87981, 0.87655, 0.87197, 0.78718],
                       [0.91714, 0.91644, 0.91891, 0.91806, 0.91229, 0.90271, 0.89098,
                        0.88109, 0.87588, 0.87185, 0.86782, 0.86520, 0.86703, 0.86915,
                        0.86894, 0.86919, 0.87060, 0.87129, 0.87235, 0.87488, 0.87842,
                        0.88265, 0.88593, 0.88627, 0.88299, 0.87768, 0.87419, 0.87072, 0.78787],
                       [0.91993, 0.91716, 0.91898, 0.91791, 0.91111, 0.90021, 0.88922,
                        0.88136, 0.87715, 0.87353, 0.86860, 0.86498, 0.86544, 0.86708,
                        0.86683, 0.86712, 0.86813, 0.86800, 0.86996, 0.87199, 0.87593,
                        0.88014, 0.88325, 0.88389, 0.88041, 0.87584, 0.87204, 0.86986, 0.78838],
                       [0.92326, 0.91811, 0.91892, 0.91715, 0.90936, 0.89806, 0.88791,
                        0.88194, 0.87905, 0.87523, 0.86962, 0.86523, 0.86454, 0.86524,
                        0.86485, 0.86542, 0.86603, 0.86566, 0.86762, 0.86927, 0.87348,
                        0.87751, 0.88046, 0.88093, 0.87838, 0.87374, 0.86983, 0.86850, 0.78891],
                       [0.92656, 0.91861, 0.91773, 0.91490, 0.90653, 0.89603, 0.88696,
                        0.88265, 0.88109, 0.87728, 0.87074, 0.86565, 0.86371, 0.86338,
                        0.86275, 0.86333, 0.86386, 0.86390, 0.86428, 0.86656, 0.87068,
                        0.87457, 0.87718, 0.87768, 0.87618, 0.87181, 0.86833, 0.86663, 0.78816],
                       [0.92967, 0.91961, 0.91635, 0.91206, 0.90364, 0.89421, 0.88649,
                        0.88401, 0.88364, 0.87993, 0.87240, 0.86642, 0.86316, 0.86223,
                        0.86135, 0.86131, 0.86175, 0.86194, 0.86113, 0.86403, 0.86749,
                        0.87172, 0.87374, 0.87482, 0.87383, 0.87103, 0.86783, 0.86502, 0.78627],
                       [0.93287, 0.92183, 0.91563, 0.91021, 0.90197, 0.89293, 0.88701,
                        0.88644, 0.88694, 0.88294, 0.87513, 0.86798, 0.86368, 0.86205,
                        0.86108, 0.86037, 0.86040, 0.86029, 0.86007, 0.86249, 0.86507,
                        0.86947, 0.87140, 0.87276, 0.87192, 0.87153, 0.86798, 0.86362, 0.78491],
                       [0.93620, 0.92423, 0.91540, 0.90936, 0.90114, 0.89259, 0.88871,
                        0.88953, 0.89061, 0.88645, 0.87848, 0.87048, 0.86530, 0.86251,
                        0.86170, 0.86085, 0.86012, 0.85986, 0.86077, 0.86169, 0.86409,
                        0.86753, 0.87010, 0.87140, 0.87118, 0.87247, 0.86881, 0.86253, 0.78420],
                       [0.93921, 0.92668, 0.91540, 0.90830, 0.90009, 0.89321, 0.89084,
                        0.89273, 0.89431, 0.89000, 0.88188, 0.87335, 0.86715, 0.86394,
                        0.86284, 0.86213, 0.86067, 0.86036, 0.86127, 0.86133, 0.86363,
                        0.86590, 0.86910, 0.87047, 0.87161, 0.87334, 0.87029, 0.86198, 0.78285],
                       [0.94158, 0.92912, 0.91586, 0.90700, 0.89945, 0.89423, 0.89295,
                        0.89593, 0.89806, 0.89343, 0.88550, 0.87652, 0.86920, 0.86614,
                        0.86422, 0.86351, 0.86180, 0.86094, 0.86123, 0.86174, 0.86363,
                        0.86501, 0.86824, 0.87003, 0.87269, 0.87487, 0.87251, 0.86186, 0.78069],
                       [0.94324, 0.93104, 0.91670, 0.90656, 0.89998, 0.89568, 0.89545,
                        0.89941, 0.90154, 0.89674, 0.88874, 0.87979, 0.87169, 0.86803,
                        0.86604, 0.86497, 0.86346, 0.86218, 0.86210, 0.86292, 0.86414,
                        0.86493, 0.86777, 0.87022, 0.87416, 0.87758, 0.87547, 0.86201, 0.77884],
                       [0.94441, 0.93319, 0.91776, 0.90729, 0.90118, 0.89826, 0.89867,
                        0.90317, 0.90454, 0.89925, 0.89130, 0.88258, 0.87450, 0.87002,
                        0.86854, 0.86708, 0.86577, 0.86454, 0.86428, 0.86455, 0.86487,
                        0.86590, 0.86821, 0.87134, 0.87587, 0.88079, 0.87868, 0.86256, 0.77773],
                       [0.94523, 0.93588, 0.91944, 0.90862, 0.90293, 0.90148, 0.90252,
                        0.90669, 0.90705, 0.90131, 0.89399, 0.88519, 0.87781, 0.87285,
                        0.87130, 0.86998, 0.86828, 0.86698, 0.86720, 0.86651, 0.86645,
                        0.86765, 0.86951, 0.87300, 0.87800, 0.88412, 0.88188, 0.86342, 0.77687],
                       [0.94533, 0.93837, 0.92141, 0.91017, 0.90569, 0.90440, 0.90642,
                        0.90953, 0.90915, 0.90364, 0.89660, 0.88804, 0.88125, 0.87607,
                        0.87404, 0.87317, 0.87061, 0.86913, 0.87012, 0.86901, 0.86912,
                        0.86951, 0.87124, 0.87483, 0.88075, 0.88757, 0.88510, 0.86455, 0.77614],
                       [0.94490, 0.94022, 0.92323, 0.91207, 0.90888, 0.90754, 0.90965,
                        0.91193, 0.91100, 0.90578, 0.89835, 0.89056, 0.88397, 0.87919,
                        0.87713, 0.87633, 0.87335, 0.87201, 0.87261, 0.87215, 0.87208,
                        0.87169, 0.87351, 0.87757, 0.88412, 0.89116, 0.88868, 0.86654, 0.77583],
                       [0.94460, 0.94131, 0.92573, 0.91449, 0.91185, 0.91146, 0.91246,
                        0.91408, 0.91234, 0.90696, 0.89945, 0.89245, 0.88625, 0.88217,
                        0.88082, 0.87962, 0.87661, 0.87588, 0.87544, 0.87558, 0.87480,
                        0.87463, 0.87672, 0.88118, 0.88794, 0.89455, 0.89217, 0.86919, 0.77627],
                       [0.94377, 0.94171, 0.92851, 0.91752, 0.91479, 0.91513, 0.91505,
                        0.91531, 0.91228, 0.90673, 0.90001, 0.89382, 0.88833, 0.88453,
                        0.88393, 0.88245, 0.87969, 0.87919, 0.87858, 0.87845, 0.87760,
                        0.87757, 0.88001, 0.88419, 0.89114, 0.89727, 0.89496, 0.87132, 0.77713],
                       [0.94209, 0.94177, 0.93078, 0.92118, 0.91819, 0.91795, 0.91721,
                        0.91577, 0.91119, 0.90565, 0.90005, 0.89459, 0.89021, 0.88646,
                        0.88592, 0.88447, 0.88227, 0.88117, 0.88155, 0.88098, 0.88067,
                        0.88054, 0.88275, 0.88681, 0.89384, 0.89969, 0.89777, 0.87310, 0.77815],
                       [0.94047, 0.94172, 0.93322, 0.92464, 0.92215, 0.92073, 0.91929,
                        0.91623, 0.91042, 0.90452, 0.89966, 0.89523, 0.89183, 0.88841,
                        0.88768, 0.88650, 0.88459, 0.88315, 0.88454, 0.88403, 0.88400,
                        0.88415, 0.88596, 0.89015, 0.89693, 0.90238, 0.90048, 0.87552, 0.77977],
                       [0.93906, 0.94121, 0.93568, 0.92720, 0.92557, 0.92350, 0.92095,
                        0.91606, 0.90949, 0.90296, 0.89842, 0.89557, 0.89278, 0.88996,
                        0.88923, 0.88835, 0.88671, 0.88566, 0.88686, 0.88701, 0.88740,
                        0.88755, 0.88946, 0.89338, 0.89934, 0.90448, 0.90185, 0.87850, 0.78158],
                       [0.93680, 0.94011, 0.93704, 0.92950, 0.92787, 0.92561, 0.92142,
                        0.91440, 0.90719, 0.90049, 0.89612, 0.89456, 0.89263, 0.89062,
                        0.89002, 0.88931, 0.88801, 0.88731, 0.88796, 0.88894, 0.88983,
                        0.88992, 0.89203, 0.89580, 0.90059, 0.90504, 0.90199, 0.88080, 0.78298],
                       [0.93414, 0.93922, 0.93782, 0.93215, 0.93019, 0.92730, 0.92125,
                        0.91235, 0.90419, 0.89780, 0.89385, 0.89258, 0.89161, 0.89090,
                        0.89025, 0.88977, 0.88860, 0.88810, 0.88889, 0.89044, 0.89127,
                        0.89195, 0.89422, 0.89804, 0.90194, 0.90475, 0.90228, 0.88212, 0.78468],
                       [0.93240, 0.93832, 0.93871, 0.93460, 0.93259, 0.92842, 0.92061,
                        0.91075, 0.90111, 0.89494, 0.89176, 0.89045, 0.89052, 0.89093,
                        0.89004, 0.88994, 0.88888, 0.88870, 0.88992, 0.89172, 0.89245,
                        0.89407, 0.89644, 0.89987, 0.90341, 0.90416, 0.90244, 0.88347, 0.78716],
                       [0.93089, 0.93677, 0.93907, 0.93664, 0.93406, 0.92848, 0.91925,
                        0.90852, 0.89778, 0.89119, 0.88876, 0.88809, 0.88916, 0.88976,
                        0.88937, 0.88940, 0.88843, 0.88863, 0.89005, 0.89188, 0.89314,
                        0.89553, 0.89785, 0.90095, 0.90362, 0.90304, 0.90160, 0.88513, 0.78995],
                       [0.92890, 0.93472, 0.93882, 0.93800, 0.93443, 0.92769, 0.91726,
                        0.90486, 0.89381, 0.88668, 0.88462, 0.88479, 0.88683, 0.88740,
                        0.88784, 0.88772, 0.88710, 0.88731, 0.88879, 0.89069, 0.89301,
                        0.89578, 0.89817, 0.90099, 0.90249, 0.90115, 0.89967, 0.88629, 0.79227],
                       [0.92678, 0.93260, 0.93854, 0.93837, 0.93416, 0.92653, 0.91472,
                        0.90081, 0.88922, 0.88200, 0.88006, 0.88078, 0.88368, 0.88482,
                        0.88510, 0.88519, 0.88520, 0.88525, 0.88656, 0.88888, 0.89227,
                        0.89501, 0.89795, 0.90004, 0.90104, 0.89856, 0.89696, 0.88655, 0.79391],
                       [0.92437, 0.93054, 0.93810, 0.93814, 0.93350, 0.92528, 0.91216,
                        0.89722, 0.88459, 0.87745, 0.87605, 0.87706, 0.88044, 0.88209,
                        0.88217, 0.88217, 0.88254, 0.88308, 0.88419, 0.88677, 0.89089,
                        0.89373, 0.89723, 0.89871, 0.89918, 0.89554, 0.89419, 0.88644, 0.79557],
                       [0.92179, 0.92842, 0.93691, 0.93758, 0.93233, 0.92324, 0.90931,
                        0.89360, 0.88051, 0.87359, 0.87240, 0.87345, 0.87709, 0.87876,
                        0.87934, 0.87880, 0.87937, 0.88053, 0.88179, 0.88412, 0.88863,
                        0.89233, 0.89579, 0.89703, 0.89646, 0.89238, 0.89164, 0.88618, 0.79730],
                       [0.91970, 0.92620, 0.93511, 0.93682, 0.93075, 0.92007, 0.90555,
                        0.88973, 0.87704, 0.87057, 0.86841, 0.86975, 0.87317, 0.87522,
                        0.87570, 0.87533, 0.87624, 0.87744, 0.87883, 0.88125, 0.88591,
                        0.89054, 0.89382, 0.89493, 0.89333, 0.88921, 0.88907, 0.88552, 0.79837],
                       [0.91791, 0.92400, 0.93301, 0.93551, 0.92860, 0.91667, 0.90146,
                        0.88593, 0.87354, 0.86750, 0.86458, 0.86609, 0.86892, 0.87167,
                        0.87144, 0.87163, 0.87276, 0.87362, 0.87507, 0.87841, 0.88295,
                        0.88753, 0.89153, 0.89222, 0.89020, 0.88619, 0.88617, 0.88446, 0.79902],
                       [0.91574, 0.92147, 0.93038, 0.93274, 0.92551, 0.91313, 0.89760,
                        0.88205, 0.87004, 0.86410, 0.86134, 0.86213, 0.86492, 0.86737,
                        0.86713, 0.86748, 0.86879, 0.86920, 0.87098, 0.87487, 0.87950,
                        0.88373, 0.88801, 0.88864, 0.88673, 0.88296, 0.88291, 0.88295, 0.79926],
                       [0.91337, 0.91852, 0.92742, 0.92911, 0.92207, 0.90903, 0.89382,
                        0.87826, 0.86733, 0.86134, 0.85854, 0.85847, 0.86120, 0.86255,
                        0.86298, 0.86319, 0.86459, 0.86518, 0.86699, 0.87028, 0.87547,
                        0.88033, 0.88357, 0.88482, 0.88327, 0.87986, 0.88001, 0.88124, 0.79881],
                       [0.91160, 0.91578, 0.92441, 0.92587, 0.91840, 0.90468, 0.89002,
                        0.87524, 0.86553, 0.86015, 0.85664, 0.85571, 0.85748, 0.85861,
                        0.85935, 0.85934, 0.86035, 0.86148, 0.86317, 0.86584, 0.87123,
                        0.87724, 0.87997, 0.88153, 0.88040, 0.87784, 0.87798, 0.87979, 0.79831],
                       [0.91070, 0.91369, 0.92144, 0.92277, 0.91416, 0.90053, 0.88632,
                        0.87350, 0.86461, 0.86026, 0.85564, 0.85375, 0.85429, 0.85583,
                        0.85609, 0.85596, 0.85684, 0.85796, 0.85949, 0.86275, 0.86746,
                        0.87371, 0.87716, 0.87874, 0.87798, 0.87646, 0.87626, 0.87840, 0.79788],
                       [0.91023, 0.91260, 0.91906, 0.91954, 0.91000, 0.89683, 0.88326,
                        0.87267, 0.86510, 0.86102, 0.85528, 0.85253, 0.85240, 0.85366,
                        0.85307, 0.85309, 0.85452, 0.85547, 0.85677, 0.86052, 0.86487,
                        0.87013, 0.87447, 0.87610, 0.87632, 0.87560, 0.87508, 0.87670, 0.79718],
                       [0.90992, 0.91154, 0.91684, 0.91586, 0.90592, 0.89334, 0.88106,
                        0.87213, 0.86683, 0.86225, 0.85578, 0.85179, 0.85131, 0.85159,
                        0.85063, 0.85078, 0.85250, 0.85333, 0.85499, 0.85813, 0.86269,
                        0.86690, 0.87179, 0.87355, 0.87511, 0.87540, 0.87509, 0.87473, 0.79595],
                       [0.91025, 0.91005, 0.91387, 0.91156, 0.90170, 0.89002, 0.87939,
                        0.87225, 0.86903, 0.86419, 0.85718, 0.85205, 0.85039, 0.84971,
                        0.84915, 0.84919, 0.85047, 0.85113, 0.85328, 0.85584, 0.86029,
                        0.86439, 0.86907, 0.87175, 0.87387, 0.87571, 0.87542, 0.87297, 0.79411],
                       [0.91145, 0.90920, 0.91067, 0.90782, 0.89811, 0.88720, 0.87808,
                        0.87322, 0.87153, 0.86672, 0.85949, 0.85367, 0.84999, 0.84879,
                        0.84863, 0.84856, 0.84930, 0.85003, 0.85214, 0.85460, 0.85854,
                        0.86321, 0.86708, 0.87082, 0.87333, 0.87657, 0.87573, 0.87168, 0.79231],
                       [0.91289, 0.90895, 0.90831, 0.90493, 0.89530, 0.88520, 0.87779,
                        0.87501, 0.87448, 0.86971, 0.86241, 0.85559, 0.85057, 0.84916,
                        0.84892, 0.84861, 0.84927, 0.85021, 0.85206, 0.85470, 0.85820,
                        0.86271, 0.86656, 0.87021, 0.87397, 0.87803, 0.87691, 0.87078, 0.79070],
                       [0.91482, 0.90928, 0.90662, 0.90217, 0.89284, 0.88412, 0.87871,
                        0.87783, 0.87796, 0.87355, 0.86564, 0.85753, 0.85243, 0.85021,
                        0.84996, 0.84945, 0.85019, 0.85106, 0.85292, 0.85591, 0.85888,
                        0.86212, 0.86685, 0.87010, 0.87563, 0.88010, 0.87885, 0.87002, 0.78887],
                       [0.91778, 0.91065, 0.90551, 0.89978, 0.89065, 0.88365, 0.88000,
                        0.88115, 0.88210, 0.87783, 0.86896, 0.86042, 0.85494, 0.85188,
                        0.85197, 0.85144, 0.85181, 0.85241, 0.85462, 0.85746, 0.85984,
                        0.86223, 0.86716, 0.87113, 0.87743, 0.88226, 0.88042, 0.86927, 0.78730],
                       [0.92122, 0.91242, 0.90541, 0.89819, 0.88938, 0.88382, 0.88152,
                        0.88444, 0.88612, 0.88153, 0.87234, 0.86406, 0.85729, 0.85440,
                        0.85464, 0.85423, 0.85411, 0.85442, 0.85677, 0.85892, 0.86131,
                        0.86382, 0.86791, 0.87313, 0.87918, 0.88424, 0.88144, 0.86841, 0.78610],
                       [0.92434, 0.91420, 0.90536, 0.89702, 0.88957, 0.88476, 0.88384,
                        0.88763, 0.88919, 0.88421, 0.87573, 0.86728, 0.86008, 0.85724,
                        0.85721, 0.85723, 0.85658, 0.85692, 0.85906, 0.86104, 0.86348,
                        0.86608, 0.86943, 0.87532, 0.88122, 0.88594, 0.88238, 0.86733, 0.78457],
                       [0.92697, 0.91654, 0.90512, 0.89593, 0.89034, 0.88636, 0.88648,
                        0.89047, 0.89166, 0.88599, 0.87841, 0.86992, 0.86353, 0.85992,
                        0.85964, 0.86016, 0.85893, 0.85966, 0.86131, 0.86382, 0.86582,
                        0.86818, 0.87132, 0.87692, 0.88305, 0.88711, 0.88324, 0.86652, 0.78242],
                       [0.92926, 0.91960, 0.90584, 0.89595, 0.89134, 0.88867, 0.88913,
                        0.89289, 0.89362, 0.88728, 0.88034, 0.87266, 0.86667, 0.86272,
                        0.86276, 0.86311, 0.86164, 0.86263, 0.86380, 0.86659, 0.86801,
                        0.87037, 0.87371, 0.87843, 0.88464, 0.88800, 0.88390, 0.86642, 0.78052],
                       [0.93128, 0.92301, 0.90744, 0.89777, 0.89326, 0.89178, 0.89262,
                        0.89523, 0.89451, 0.88828, 0.88206, 0.87535, 0.86929, 0.86599,
                        0.86662, 0.86650, 0.86511, 0.86556, 0.86704, 0.86936, 0.87052,
                        0.87289, 0.87629, 0.88098, 0.88640, 0.88871, 0.88396, 0.86630, 0.77949],
                       [0.93314, 0.92633, 0.90957, 0.90037, 0.89593, 0.89542, 0.89689,
                        0.89730, 0.89453, 0.88854, 0.88304, 0.87713, 0.87199, 0.86942,
                        0.86982, 0.87004, 0.86855, 0.86799, 0.87050, 0.87198, 0.87337,
                        0.87543, 0.87847, 0.88388, 0.88804, 0.88877, 0.88342, 0.86560, 0.77884],
                       [0.93484, 0.92925, 0.91237, 0.90291, 0.89938, 0.89939, 0.90027,
                        0.89853, 0.89401, 0.88755, 0.88269, 0.87798, 0.87440, 0.87249,
                        0.87205, 0.87261, 0.87088, 0.87035, 0.87301, 0.87435, 0.87593,
                        0.87771, 0.88073, 0.88563, 0.88853, 0.88783, 0.88232, 0.86462, 0.77821],
                       [0.93597, 0.93156, 0.91524, 0.90546, 0.90325, 0.90307, 0.90175,
                        0.89853, 0.89246, 0.88499, 0.88073, 0.87765, 0.87543, 0.87435,
                        0.87366, 0.87371, 0.87175, 0.87249, 0.87381, 0.87601, 0.87750,
                        0.87931, 0.88255, 0.88601, 0.88754, 0.88562, 0.87980, 0.86335, 0.77733],
                       [0.93625, 0.93332, 0.91803, 0.90831, 0.90668, 0.90603, 0.90283,
                        0.89763, 0.88928, 0.88101, 0.87733, 0.87580, 0.87521, 0.87459,
                        0.87459, 0.87407, 0.87217, 0.87318, 0.87384, 0.87649, 0.87800,
                        0.88007, 0.88327, 0.88576, 0.88592, 0.88197, 0.87581, 0.86134, 0.77613],
                       [0.93604, 0.93420, 0.92104, 0.91167, 0.91009, 0.90864, 0.90422,
                        0.89585, 0.88462, 0.87600, 0.87308, 0.87309, 0.87430, 0.87390,
                        0.87440, 0.87409, 0.87267, 0.87256, 0.87376, 0.87599, 0.87777,
                        0.88020, 0.88346, 0.88535, 0.88393, 0.87684, 0.87114, 0.85832, 0.77485],
                       [0.93526, 0.93404, 0.92337, 0.91496, 0.91346, 0.91084, 0.90417,
                        0.89220, 0.87875, 0.86948, 0.86746, 0.86941, 0.87211, 0.87256,
                        0.87261, 0.87288, 0.87166, 0.87123, 0.87236, 0.87430, 0.87664,
                        0.87937, 0.88269, 0.88422, 0.88057, 0.87015, 0.86510, 0.85437, 0.77334],
                       [0.93393, 0.93332, 0.92474, 0.91775, 0.91624, 0.91207, 0.90193,
                        0.88673, 0.87126, 0.86095, 0.85970, 0.86355, 0.86787, 0.86990,
                        0.86965, 0.86981, 0.86847, 0.86840, 0.86912, 0.87099, 0.87400,
                        0.87735, 0.88038, 0.88104, 0.87489, 0.86170, 0.85666, 0.84933, 0.77130],
                       [0.93228, 0.93197, 0.92639, 0.92042, 0.91854, 0.91227, 0.89913,
                        0.88043, 0.86228, 0.85104, 0.85035, 0.85572, 0.86242, 0.86601,
                        0.86592, 0.86509, 0.86427, 0.86390, 0.86472, 0.86628, 0.86996,
                        0.87455, 0.87690, 0.87611, 0.86712, 0.85167, 0.84622, 0.84286, 0.76897],
                       [0.93006, 0.92946, 0.92844, 0.92311, 0.92036, 0.91183, 0.89628,
                        0.87321, 0.85194, 0.83978, 0.84028, 0.84741, 0.85654, 0.86113,
                        0.86090, 0.85928, 0.85917, 0.85871, 0.85953, 0.86093, 0.86529,
                        0.87060, 0.87247, 0.87056, 0.85832, 0.84030, 0.83456, 0.83515, 0.76631],
                       [0.92702, 0.92530, 0.92920, 0.92512, 0.92131, 0.91027, 0.89158,
                        0.86393, 0.83931, 0.82597, 0.82838, 0.83799, 0.84892, 0.85442,
                        0.85397, 0.85270, 0.85232, 0.85245, 0.85297, 0.85467, 0.85952,
                        0.86475, 0.86687, 0.86368, 0.84832, 0.82632, 0.82079, 0.82604, 0.76289],
                       [0.92274, 0.91975, 0.92775, 0.92607, 0.92095, 0.90731, 0.88435,
                        0.85220, 0.82358, 0.80914, 0.81336, 0.82565, 0.83865, 0.84539,
                        0.84535, 0.84460, 0.84382, 0.84398, 0.84425, 0.84627, 0.85178,
                        0.85716, 0.85948, 0.85440, 0.83590, 0.80905, 0.80378, 0.81512, 0.75870],
                       [0.91664, 0.91309, 0.92509, 0.92594, 0.91930, 0.90340, 0.87547,
                        0.83836, 0.80487, 0.78947, 0.79589, 0.81087, 0.82636, 0.83470,
                        0.83545, 0.83413, 0.83358, 0.83350, 0.83307, 0.83574, 0.84185,
                        0.84771, 0.84982, 0.84285, 0.82049, 0.78885, 0.78347, 0.80198, 0.75347],
                       [0.90852, 0.90503, 0.92176, 0.92491, 0.91661, 0.89806, 0.86536,
                        0.82197, 0.78343, 0.76678, 0.77607, 0.79462, 0.81297, 0.82283,
                        0.82381, 0.82173, 0.82102, 0.82164, 0.82006, 0.82332, 0.82972,
                        0.83614, 0.83809, 0.82923, 0.80264, 0.76554, 0.76008, 0.78671, 0.74700],
                       [0.89807, 0.89514, 0.91713, 0.92293, 0.91274, 0.89083, 0.85352,
                        0.80275, 0.75845, 0.74089, 0.75287, 0.77609, 0.79786, 0.80914,
                        0.80985, 0.80792, 0.80664, 0.80775, 0.80600, 0.80876, 0.81582,
                        0.82267, 0.82423, 0.81317, 0.78241, 0.73915, 0.73388, 0.76985, 0.73927],
                       [0.88443, 0.88302, 0.91082, 0.91917, 0.90751, 0.88188, 0.83954,
                        0.78086, 0.72972, 0.71164, 0.72615, 0.75430, 0.77976, 0.79294,
                        0.79336, 0.79197, 0.79080, 0.79117, 0.78994, 0.79214, 0.80006,
                        0.80730, 0.80799, 0.79461, 0.75896, 0.70958, 0.70447, 0.75101, 0.73033],
                       [0.86693, 0.86832, 0.90263, 0.91318, 0.90046, 0.87085, 0.82272,
                        0.75555, 0.69745, 0.67847, 0.69635, 0.72891, 0.75862, 0.77388,
                        0.77414, 0.77275, 0.77236, 0.77192, 0.77031, 0.77286, 0.78131,
                        0.78910, 0.78919, 0.77330, 0.73197, 0.67612, 0.67127, 0.72928, 0.72026],
                       [0.84486, 0.85078, 0.89212, 0.90571, 0.89129, 0.85753, 0.80239,
                        0.72664, 0.66152, 0.64161, 0.66340, 0.70005, 0.73470, 0.75197,
                        0.75227, 0.75028, 0.75039, 0.74989, 0.74737, 0.75033, 0.75933,
                        0.76760, 0.76733, 0.74870, 0.70191, 0.63916, 0.63486, 0.70490, 0.70837],
                       [0.81802, 0.83021, 0.87941, 0.89718, 0.88018, 0.84155, 0.77890,
                        0.69450, 0.62261, 0.60243, 0.62695, 0.66851, 0.70791, 0.72745,
                        0.72761, 0.72511, 0.72564, 0.72511, 0.72186, 0.72476, 0.73471,
                        0.74343, 0.74218, 0.72071, 0.66867, 0.59967, 0.59605, 0.67865, 0.69431],
                       [0.78698, 0.80629, 0.86489, 0.88668, 0.86713, 0.82262, 0.75284,
                        0.65911, 0.58164, 0.56139, 0.58750, 0.63423, 0.67801, 0.69985,
                        0.69983, 0.69707, 0.69847, 0.69761, 0.69349, 0.69626, 0.70692,
                        0.71644, 0.71393, 0.68939, 0.63210, 0.55780, 0.55537, 0.65065, 0.67874],
                       [0.75199, 0.77865, 0.84827, 0.87330, 0.85171, 0.80102, 0.72402,
                        0.62114, 0.53892, 0.51843, 0.54616, 0.59686, 0.64516, 0.66920,
                        0.66901, 0.66616, 0.66809, 0.66709, 0.66189, 0.66474, 0.67572,
                        0.68601, 0.68275, 0.65505, 0.59304, 0.51417, 0.51338, 0.62095, 0.66154],
                       [0.71234, 0.74704, 0.82872, 0.85724, 0.83337, 0.77648, 0.69167,
                        0.58123, 0.49498, 0.47432, 0.50352, 0.55718, 0.60960, 0.63622,
                        0.63543, 0.63235, 0.63422, 0.63344, 0.62733, 0.63010, 0.64185,
                        0.65236, 0.64876, 0.61825, 0.55233, 0.46993, 0.47059, 0.58960, 0.64248],
                       [0.66783, 0.71123, 0.80570, 0.83897, 0.81168, 0.74816, 0.65568,
                        0.53947, 0.45062, 0.43014, 0.45980, 0.51550, 0.57121, 0.60035,
                        0.59887, 0.59532, 0.59749, 0.59669, 0.59012, 0.59238, 0.60510,
                        0.61595, 0.61156, 0.57894, 0.51000, 0.42539, 0.42744, 0.55681, 0.62168],
                       [0.61959, 0.67161, 0.77944, 0.81803, 0.78616, 0.71599, 0.61699,
                        0.49645, 0.40668, 0.38660, 0.41571, 0.47221, 0.53043, 0.56122,
                        0.55968, 0.55564, 0.55892, 0.55723, 0.55032, 0.55202, 0.56514,
                        0.57673, 0.57125, 0.53698, 0.46589, 0.38093, 0.38456, 0.52289, 0.59858],
                       [0.56886, 0.62867, 0.75030, 0.79356, 0.75641, 0.68049, 0.57626,
                        0.45305, 0.36369, 0.34392, 0.37228, 0.42823, 0.48803, 0.51995,
                        0.51878, 0.51397, 0.51855, 0.51607, 0.50837, 0.50960, 0.52300,
                        0.53478, 0.52906, 0.49349, 0.42134, 0.33768, 0.34268, 0.48823, 0.57332],
                       [0.51615, 0.58283, 0.71845, 0.76553, 0.72308, 0.64206, 0.53405,
                        0.40987, 0.32197, 0.30255, 0.33012, 0.38464, 0.44488, 0.47766,
                        0.47653, 0.47091, 0.47633, 0.47399, 0.46496, 0.46594, 0.47991,
                        0.49135, 0.48601, 0.44972, 0.37794, 0.29647, 0.30221, 0.45301, 0.54681],
                       [0.46214, 0.53529, 0.68384, 0.73431, 0.68704, 0.60085, 0.49118,
                        0.36783, 0.28222, 0.26355, 0.28980, 0.34257, 0.40185, 0.43508,
                        0.43346, 0.42769, 0.43368, 0.43133, 0.42131, 0.42241, 0.43630,
                        0.44774, 0.44244, 0.40595, 0.33600, 0.25779, 0.26390, 0.41736, 0.51950],
                       [0.40796, 0.48708, 0.64599, 0.69972, 0.64788, 0.55733, 0.44766,
                        0.32739, 0.24480, 0.22739, 0.25176, 0.30223, 0.35949, 0.39250,
                        0.39052, 0.38497, 0.39132, 0.38860, 0.37821, 0.37963, 0.39250,
                        0.40414, 0.39852, 0.36255, 0.29565, 0.22204, 0.22844, 0.38204, 0.49141],
                       [0.35492, 0.43856, 0.60557, 0.66192, 0.60569, 0.51274, 0.40428,
                        0.28872, 0.21006, 0.19395, 0.21637, 0.26371, 0.31851, 0.35047,
                        0.34877, 0.34294, 0.34953, 0.34685, 0.33633, 0.33748, 0.34973,
                        0.36109, 0.35541, 0.32077, 0.25753, 0.18972, 0.19622, 0.34776, 0.46264],
                       [0.30420, 0.39024, 0.56338, 0.62118, 0.56127, 0.46808, 0.36224,
                        0.25218, 0.17813, 0.16340, 0.18377, 0.22742, 0.27923, 0.30987,
                        0.30836, 0.30219, 0.30900, 0.30638, 0.29640, 0.29673, 0.30878,
                        0.31954, 0.31412, 0.28155, 0.22234, 0.16075, 0.16708, 0.31438, 0.43318],
                       [0.25698, 0.34341, 0.51968, 0.57817, 0.51569, 0.42353, 0.32201,
                        0.21790, 0.14917, 0.13614, 0.15416, 0.19378, 0.24208, 0.27136,
                        0.26946, 0.26365, 0.27042, 0.26768, 0.25839, 0.25840, 0.26980,
                        0.28003, 0.27503, 0.24479, 0.19043, 0.13503, 0.14094, 0.28192, 0.40327],
                       [0.21400, 0.29883, 0.47498, 0.53350, 0.46950, 0.37940, 0.28350,
                        0.18594, 0.12358, 0.11232, 0.12794, 0.16330, 0.20761, 0.23511,
                        0.23297, 0.22757, 0.23421, 0.23173, 0.22251, 0.22274, 0.23315,
                        0.24292, 0.23832, 0.21048, 0.16143, 0.11256, 0.11791, 0.25063, 0.37339],
                       [0.17588, 0.25683, 0.43015, 0.48784, 0.42318, 0.33691, 0.24698,
                        0.15698, 0.10152, 0.09188, 0.10529, 0.13622, 0.17611, 0.20142,
                        0.19941, 0.19396, 0.20050, 0.19855, 0.18962, 0.19005, 0.19951,
                        0.20878, 0.20442, 0.17937, 0.13552, 0.09324, 0.09799, 0.22086, 0.34349],
                       [0.14323, 0.21814, 0.38613, 0.44196, 0.37782, 0.29668, 0.21313,
                        0.13150, 0.08280, 0.07474, 0.08606, 0.11265, 0.14790, 0.17072,
                        0.16876, 0.16347, 0.16980, 0.16801, 0.16010, 0.16072, 0.16922,
                        0.17782, 0.17408, 0.15176, 0.11335, 0.07685, 0.08102, 0.19337, 0.31355],
                       [0.11586, 0.18309, 0.34323, 0.39641, 0.33434, 0.25882, 0.18206,
                        0.10912, 0.06715, 0.06054, 0.06997, 0.09246, 0.12299, 0.14304,
                        0.14134, 0.13663, 0.14268, 0.14066, 0.13393, 0.13464, 0.14238,
                        0.14990, 0.14721, 0.12736, 0.09444, 0.06316, 0.06672, 0.16807, 0.28417],
                       [0.09317, 0.15167, 0.30199, 0.35234, 0.29334, 0.22340, 0.15392,
                        0.08964, 0.05433, 0.04909, 0.05678, 0.07539, 0.10130, 0.11857,
                        0.11732, 0.11323, 0.11879, 0.11705, 0.11119, 0.11174, 0.11897,
                        0.12528, 0.12313, 0.10607, 0.07792, 0.05190, 0.05489, 0.14483, 0.25568],
                       [0.07475, 0.12432, 0.26308, 0.31034, 0.25486, 0.19068, 0.12898,
                        0.07310, 0.04411, 0.04001, 0.04605, 0.06118, 0.08290, 0.09766,
                        0.09649, 0.09280, 0.09781, 0.09680, 0.09169, 0.09205, 0.09854,
                        0.10413, 0.10188, 0.08775, 0.06387, 0.04261, 0.04501, 0.12395, 0.22821],
                       [0.06027, 0.10135, 0.22694, 0.27040, 0.21877, 0.16119, 0.10697,
                        0.05941, 0.03604, 0.03278, 0.03747, 0.04971, 0.06765, 0.07999,
                        0.07878, 0.07549, 0.08005, 0.07936, 0.07516, 0.07549, 0.08082,
                        0.08605, 0.08406, 0.07215, 0.05246, 0.03498, 0.03682, 0.10531, 0.20213],
                       [0.04906, 0.08246, 0.19404, 0.23312, 0.18575, 0.13507, 0.08785,
                        0.04835, 0.02961, 0.02712, 0.03086, 0.04061, 0.05504, 0.06510,
                        0.06413, 0.06164, 0.06545, 0.06476, 0.06143, 0.06181, 0.06604,
                        0.07064, 0.06936, 0.05927, 0.04315, 0.02891, 0.03032, 0.08889, 0.17768],
                       [0.04032, 0.06692, 0.16450, 0.19898, 0.15647, 0.11200, 0.07183,
                        0.03948, 0.02468, 0.02273, 0.02576, 0.03333, 0.04484, 0.05293,
                        0.05232, 0.05068, 0.05344, 0.05297, 0.05019, 0.05069, 0.05423,
                        0.05789, 0.05704, 0.04880, 0.03549, 0.02415, 0.02525, 0.07479, 0.15489],
                       [0.03339, 0.05425, 0.13807, 0.16819, 0.13065, 0.09192, 0.05856,
                        0.03239, 0.02100, 0.01927, 0.02173, 0.02756, 0.03683, 0.04330,
                        0.04293, 0.04154, 0.04379, 0.04356, 0.04120, 0.04181, 0.04483,
                        0.04758, 0.04683, 0.04028, 0.02922, 0.02032, 0.02120, 0.06272, 0.13388],
                       [0.02791, 0.04424, 0.11474, 0.14081, 0.10777, 0.07516, 0.04763,
                        0.02684, 0.01799, 0.01649, 0.01855, 0.02323, 0.03054, 0.03563,
                        0.03523, 0.03403, 0.03626, 0.03589, 0.03410, 0.03451, 0.03708,
                        0.03922, 0.03849, 0.03319, 0.02431, 0.01732, 0.01799, 0.05226, 0.11494],
                       [0.02349, 0.03635, 0.09465, 0.11678, 0.08803, 0.06149, 0.03889,
                        0.02250, 0.01531, 0.01410, 0.01589, 0.01981, 0.02548, 0.02946,
                        0.02887, 0.02829, 0.03036, 0.02956, 0.02829, 0.02843, 0.03051,
                        0.03246, 0.03169, 0.02722, 0.02062, 0.01492, 0.01545, 0.04330, 0.09812],
                       [0.02000, 0.03017, 0.07771, 0.09621, 0.07184, 0.05008, 0.03214,
                        0.01907, 0.01321, 0.01223, 0.01366, 0.01673, 0.02133, 0.02460,
                        0.02406, 0.02371, 0.02533, 0.02463, 0.02353, 0.02368, 0.02525,
                        0.02694, 0.02646, 0.02275, 0.01761, 0.01287, 0.01332, 0.03588, 0.08319],
                       [0.01730, 0.02533, 0.06349, 0.07884, 0.05887, 0.04073, 0.02676,
                        0.01628, 0.01168, 0.01092, 0.01194, 0.01425, 0.01804, 0.02081,
                        0.02057, 0.01991, 0.02098, 0.02091, 0.01989, 0.02013, 0.02119,
                        0.02251, 0.02238, 0.01952, 0.01505, 0.01121, 0.01155, 0.02983, 0.07004],
                       [0.01519, 0.02150, 0.05185, 0.06436, 0.04827, 0.03358, 0.02245,
                        0.01410, 0.01037, 0.00983, 0.01061, 0.01258, 0.01561, 0.01779,
                        0.01778, 0.01704, 0.01772, 0.01789, 0.01714, 0.01723, 0.01811,
                        0.01918, 0.01893, 0.01676, 0.01302, 0.00985, 0.01021, 0.02492, 0.05857],
                       [0.01350, 0.01852, 0.04268, 0.05263, 0.03959, 0.02814, 0.01916,
                        0.01249, 0.00921, 0.00881, 0.00953, 0.01126, 0.01371, 0.01541,
                        0.01532, 0.01480, 0.01544, 0.01528, 0.01495, 0.01483, 0.01572,
                        0.01651, 0.01630, 0.01442, 0.01145, 0.00870, 0.00913, 0.02099, 0.04874],
                       [0.01194, 0.01608, 0.03542, 0.04311, 0.03262, 0.02367, 0.01640,
                        0.01113, 0.00832, 0.00791, 0.00860, 0.00994, 0.01201, 0.01336,
                        0.01315, 0.01288, 0.01351, 0.01313, 0.01299, 0.01291, 0.01362,
                        0.01426, 0.01425, 0.01250, 0.01012, 0.00781, 0.00816, 0.01778, 0.04053],
                       [0.01050, 0.01393, 0.02942, 0.03545, 0.02716, 0.01997, 0.01411,
                        0.00986, 0.00759, 0.00715, 0.00773, 0.00880, 0.01055, 0.01149,
                        0.01152, 0.01131, 0.01169, 0.01153, 0.01133, 0.01137, 0.01178,
                        0.01241, 0.01225, 0.01094, 0.00891, 0.00715, 0.00731, 0.01516, 0.03366],
                       [0.00939, 0.01213, 0.02441, 0.02947, 0.02282, 0.01713, 0.01240,
                        0.00874, 0.00692, 0.00652, 0.00697, 0.00792, 0.00937, 0.01001,
                        0.01038, 0.01009, 0.01023, 0.01026, 0.01001, 0.01001, 0.01032,
                        0.01086, 0.01051, 0.00976, 0.00794, 0.00657, 0.00658, 0.01305, 0.02794],
                       [0.00854, 0.01088, 0.02056, 0.02476, 0.01931, 0.01489, 0.01097,
                        0.00775, 0.00631, 0.00602, 0.00635, 0.00719, 0.00833, 0.00899,
                        0.00937, 0.00903, 0.00917, 0.00912, 0.00892, 0.00887, 0.00919,
                        0.00951, 0.00930, 0.00872, 0.00721, 0.00601, 0.00602, 0.01127, 0.02330],
                       [0.00776, 0.00991, 0.01767, 0.02098, 0.01663, 0.01301, 0.00967,
                        0.00699, 0.00571, 0.00559, 0.00577, 0.00649, 0.00743, 0.00824,
                        0.00832, 0.00800, 0.00825, 0.00818, 0.00803, 0.00803, 0.00820,
                        0.00843, 0.00848, 0.00769, 0.00646, 0.00552, 0.00561, 0.00983, 0.01964],
                       [0.00704, 0.00879, 0.01534, 0.01792, 0.01460, 0.01152, 0.00870,
                        0.00657, 0.00527, 0.00513, 0.00526, 0.00591, 0.00682, 0.00754,
                        0.00743, 0.00717, 0.00743, 0.00738, 0.00727, 0.00740, 0.00742,
                        0.00771, 0.00778, 0.00687, 0.00576, 0.00512, 0.00523, 0.00874, 0.01673],
                       [0.00642, 0.00774, 0.01342, 0.01543, 0.01284, 0.01033, 0.00798,
                        0.00612, 0.00498, 0.00469, 0.00489, 0.00546, 0.00636, 0.00682,
                        0.00682, 0.00659, 0.00669, 0.00671, 0.00647, 0.00675, 0.00680,
                        0.00715, 0.00701, 0.00640, 0.00536, 0.00476, 0.00485, 0.00787, 0.01430],
                       [0.00595, 0.00714, 0.01186, 0.01352, 0.01128, 0.00923, 0.00726,
                        0.00552, 0.00462, 0.00444, 0.00464, 0.00507, 0.00587, 0.00618,
                        0.00624, 0.00604, 0.00608, 0.00622, 0.00575, 0.00607, 0.00617,
                        0.00663, 0.00641, 0.00598, 0.00518, 0.00439, 0.00457, 0.00711, 0.01223],
                       [0.00554, 0.00670, 0.01055, 0.01202, 0.01000, 0.00816, 0.00655,
                        0.00506, 0.00423, 0.00429, 0.00436, 0.00475, 0.00537, 0.00569,
                        0.00566, 0.00553, 0.00570, 0.00579, 0.00539, 0.00546, 0.00563,
                        0.00606, 0.00598, 0.00545, 0.00498, 0.00404, 0.00431, 0.00643, 0.01054],
                       [0.00513, 0.00615, 0.00943, 0.01067, 0.00895, 0.00736, 0.00599,
                        0.00475, 0.00392, 0.00403, 0.00400, 0.00447, 0.00496, 0.00522,
                        0.00527, 0.00512, 0.00542, 0.00535, 0.00517, 0.00505, 0.00527,
                        0.00533, 0.00534, 0.00504, 0.00464, 0.00378, 0.00404, 0.00591, 0.00932],
                       [0.00467, 0.00561, 0.00839, 0.00944, 0.00814, 0.00680, 0.00555,
                        0.00443, 0.00368, 0.00375, 0.00372, 0.00419, 0.00469, 0.00484,
                        0.00495, 0.00472, 0.00508, 0.00497, 0.00487, 0.00484, 0.00496,
                        0.00472, 0.00473, 0.00477, 0.00423, 0.00367, 0.00381, 0.00549, 0.00828],
                       [0.00429, 0.00516, 0.00746, 0.00840, 0.00741, 0.00622, 0.00515,
                        0.00406, 0.00351, 0.00359, 0.00360, 0.00395, 0.00442, 0.00459,
                        0.00457, 0.00437, 0.00461, 0.00462, 0.00454, 0.00459, 0.00457,
                        0.00448, 0.00457, 0.00439, 0.00394, 0.00363, 0.00359, 0.00502, 0.00727],
                       [0.00415, 0.00481, 0.00679, 0.00764, 0.00671, 0.00567, 0.00479,
                        0.00379, 0.00341, 0.00342, 0.00353, 0.00370, 0.00407, 0.00436,
                        0.00426, 0.00414, 0.00422, 0.00430, 0.00419, 0.00423, 0.00426,
                        0.00444, 0.00461, 0.00408, 0.00377, 0.00351, 0.00345, 0.00460, 0.00654],
                       [0.00396, 0.00457, 0.00632, 0.00697, 0.00619, 0.00531, 0.00447,
                        0.00365, 0.00334, 0.00318, 0.00343, 0.00347, 0.00377, 0.00417,
                        0.00403, 0.00395, 0.00401, 0.00411, 0.00386, 0.00385, 0.00404,
                        0.00434, 0.00433, 0.00396, 0.00365, 0.00329, 0.00334, 0.00430, 0.00610],
                       [0.00366, 0.00434, 0.00584, 0.00636, 0.00576, 0.00505, 0.00422,
                        0.00350, 0.00325, 0.00310, 0.00335, 0.00339, 0.00360, 0.00393,
                        0.00380, 0.00383, 0.00386, 0.00396, 0.00370, 0.00365, 0.00383,
                        0.00413, 0.00385, 0.00381, 0.00349, 0.00314, 0.00326, 0.00408, 0.00561],
                       [0.00356, 0.00400, 0.00532, 0.00592, 0.00529, 0.00470, 0.00400,
                        0.00343, 0.00311, 0.00313, 0.00320, 0.00339, 0.00352, 0.00361,
                        0.00359, 0.00371, 0.00367, 0.00375, 0.00363, 0.00365, 0.00369,
                        0.00385, 0.00363, 0.00362, 0.00326, 0.00311, 0.00317, 0.00393, 0.00509],
                       [0.00363, 0.00370, 0.00496, 0.00556, 0.00495, 0.00426, 0.00378,
                        0.00336, 0.00303, 0.00307, 0.00296, 0.00330, 0.00349, 0.00339,
                        0.00344, 0.00354, 0.00355, 0.00353, 0.00359, 0.00358, 0.00361,
                        0.00363, 0.00374, 0.00354, 0.00310, 0.00302, 0.00298, 0.00379, 0.00471],
                       [0.00356, 0.00356, 0.00480, 0.00524, 0.00471, 0.00403, 0.00359,
                        0.00317, 0.00306, 0.00290, 0.00283, 0.00312, 0.00330, 0.00331,
                        0.00335, 0.00339, 0.00343, 0.00328, 0.00349, 0.00343, 0.00344,
                        0.00342, 0.00372, 0.00342, 0.00306, 0.00287, 0.00284, 0.00365, 0.00437],
                       [0.00327, 0.00350, 0.00464, 0.00491, 0.00436, 0.00406, 0.00356,
                        0.00306, 0.00304, 0.00280, 0.00291, 0.00300, 0.00305, 0.00327,
                        0.00327, 0.00330, 0.00328, 0.00310, 0.00327, 0.00329, 0.00328,
                        0.00325, 0.00342, 0.00319, 0.00306, 0.00286, 0.00286, 0.00349, 0.00412],
                       [0.00304, 0.00346, 0.00436, 0.00445, 0.00405, 0.00395, 0.00354,
                        0.00301, 0.00283, 0.00282, 0.00294, 0.00287, 0.00301, 0.00317,
                        0.00315, 0.00320, 0.00310, 0.00313, 0.00311, 0.00313, 0.00315,
                        0.00317, 0.00319, 0.00313, 0.00305, 0.00294, 0.00282, 0.00329, 0.00398],
                       [0.00310, 0.00338, 0.00402, 0.00412, 0.00390, 0.00367, 0.00336,
                        0.00295, 0.00269, 0.00284, 0.00289, 0.00271, 0.00303, 0.00309,
                        0.00307, 0.00301, 0.00298, 0.00315, 0.00307, 0.00298, 0.00298,
                        0.00317, 0.00314, 0.00320, 0.00299, 0.00290, 0.00275, 0.00311, 0.00375],
                       [0.00322, 0.00323, 0.00374, 0.00409, 0.00384, 0.00344, 0.00313,
                        0.00291, 0.00275, 0.00282, 0.00287, 0.00273, 0.00296, 0.00309,
                        0.00295, 0.00285, 0.00300, 0.00305, 0.00308, 0.00286, 0.00291,
                        0.00311, 0.00304, 0.00309, 0.00284, 0.00275, 0.00273, 0.00304, 0.00343],
                       [0.00312, 0.00310, 0.00363, 0.00398, 0.00375, 0.00332, 0.00302,
                        0.00283, 0.00275, 0.00276, 0.00275, 0.00283, 0.00290, 0.00301,
                        0.00282, 0.00290, 0.00305, 0.00291, 0.00301, 0.00285, 0.00297,
                        0.00296, 0.00290, 0.00280, 0.00270, 0.00268, 0.00273, 0.00306, 0.00324],
                       [0.00283, 0.00302, 0.00361, 0.00372, 0.00356, 0.00326, 0.00306,
                        0.00284, 0.00259, 0.00260, 0.00259, 0.00276, 0.00286, 0.00288,
                        0.00278, 0.00293, 0.00299, 0.00282, 0.00283, 0.00297, 0.00296,
                        0.00285, 0.00277, 0.00261, 0.00276, 0.00263, 0.00263, 0.00302, 0.00320],
                       [0.00273, 0.00296, 0.00349, 0.00357, 0.00344, 0.00321, 0.00303,
                        0.00291, 0.00252, 0.00249, 0.00256, 0.00267, 0.00282, 0.00283,
                        0.00280, 0.00282, 0.00280, 0.00280, 0.00276, 0.00300, 0.00285,
                        0.00283, 0.00277, 0.00271, 0.00282, 0.00256, 0.00252, 0.00290, 0.00319],
                       [0.00288, 0.00296, 0.00334, 0.00358, 0.00346, 0.00315, 0.00286,
                        0.00290, 0.00260, 0.00260, 0.00258, 0.00261, 0.00276, 0.00278,
                        0.00275, 0.00270, 0.00277, 0.00278, 0.00285, 0.00283, 0.00276,
                        0.00277, 0.00288, 0.00283, 0.00266, 0.00255, 0.00255, 0.00281, 0.00309],
                       [0.00293, 0.00297, 0.00327, 0.00352, 0.00342, 0.00307, 0.00280,
                        0.00275, 0.00262, 0.00272, 0.00258, 0.00255, 0.00267, 0.00271,
                        0.00265, 0.00275, 0.00288, 0.00275, 0.00277, 0.00270, 0.00278,
                        0.00265, 0.00281, 0.00273, 0.00246, 0.00258, 0.00263, 0.00277, 0.00292],
                       [0.00280, 0.00295, 0.00326, 0.00335, 0.00332, 0.00307, 0.00289,
                        0.00259, 0.00263, 0.00268, 0.00258, 0.00254, 0.00263, 0.00277,
                        0.00263, 0.00289, 0.00281, 0.00274, 0.00262, 0.00270, 0.00279,
                        0.00255, 0.00267, 0.00264, 0.00247, 0.00258, 0.00261, 0.00276, 0.00287],
                       [0.00267, 0.00291, 0.00319, 0.00319, 0.00317, 0.00307, 0.00290,
                        0.00257, 0.00264, 0.00249, 0.00257, 0.00253, 0.00266, 0.00283,
                        0.00267, 0.00281, 0.00260, 0.00270, 0.00258, 0.00266, 0.00269,
                        0.00255, 0.00262, 0.00257, 0.00253, 0.00256, 0.00251, 0.00277, 0.00283],
                       [0.00269, 0.00285, 0.00305, 0.00320, 0.00309, 0.00304, 0.00279,
                        0.00263, 0.00257, 0.00236, 0.00257, 0.00255, 0.00264, 0.00270,
                        0.00265, 0.00268, 0.00254, 0.00263, 0.00257, 0.00260, 0.00265,
                        0.00269, 0.00263, 0.00249, 0.00252, 0.00258, 0.00257, 0.00278, 0.00266],
                       [0.00271, 0.00279, 0.00300, 0.00328, 0.00317, 0.00301, 0.00269,
                        0.00266, 0.00248, 0.00237, 0.00254, 0.00257, 0.00256, 0.00252,
                        0.00255, 0.00269, 0.00261, 0.00261, 0.00256, 0.00258, 0.00260,
                        0.00274, 0.00265, 0.00253, 0.00253, 0.00259, 0.00273, 0.00269, 0.00255],
                       [0.00261, 0.00273, 0.00307, 0.00313, 0.00319, 0.00291, 0.00267,
                        0.00265, 0.00241, 0.00246, 0.00252, 0.00247, 0.00246, 0.00251,
                        0.00255, 0.00273, 0.00259, 0.00260, 0.00256, 0.00256, 0.00250,
                        0.00263, 0.00263, 0.00257, 0.00253, 0.00249, 0.00267, 0.00253, 0.00258],
                       [0.00255, 0.00272, 0.00310, 0.00291, 0.00307, 0.00274, 0.00265,
                        0.00255, 0.00240, 0.00247, 0.00251, 0.00238, 0.00245, 0.00262,
                        0.00260, 0.00263, 0.00252, 0.00255, 0.00251, 0.00250, 0.00250,
                        0.00260, 0.00264, 0.00252, 0.00253, 0.00229, 0.00240, 0.00243, 0.00268],
                       [0.00255, 0.00275, 0.00301, 0.00293, 0.00299, 0.00262, 0.00263,
                        0.00243, 0.00245, 0.00240, 0.00246, 0.00240, 0.00253, 0.00260,
                        0.00259, 0.00241, 0.00253, 0.00249, 0.00251, 0.00248, 0.00253,
                        0.00264, 0.00264, 0.00242, 0.00257, 0.00228, 0.00225, 0.00245, 0.00269],
                       [0.00261, 0.00274, 0.00285, 0.00297, 0.00297, 0.00270, 0.00267,
                        0.00246, 0.00244, 0.00237, 0.00233, 0.00245, 0.00258, 0.00242,
                        0.00254, 0.00233, 0.00259, 0.00250, 0.00257, 0.00257, 0.00248,
                        0.00265, 0.00255, 0.00242, 0.00256, 0.00245, 0.00236, 0.00260, 0.00253],
                       [0.00268, 0.00266, 0.00272, 0.00286, 0.00289, 0.00283, 0.00263,
                        0.00260, 0.00234, 0.00237, 0.00227, 0.00249, 0.00255, 0.00239,
                        0.00244, 0.00243, 0.00259, 0.00252, 0.00258, 0.00257, 0.00248,
                        0.00257, 0.00247, 0.00253, 0.00245, 0.00254, 0.00245, 0.00267, 0.00238],
                       [0.00261, 0.00257, 0.00272, 0.00282, 0.00280, 0.00274, 0.00249,
                        0.00269, 0.00234, 0.00240, 0.00239, 0.00244, 0.00247, 0.00250,
                        0.00247, 0.00247, 0.00253, 0.00249, 0.00253, 0.00245, 0.00264,
                        0.00244, 0.00251, 0.00258, 0.00244, 0.00252, 0.00237, 0.00255, 0.00235],
                       [0.00246, 0.00254, 0.00285, 0.00291, 0.00282, 0.00259, 0.00245,
                        0.00258, 0.00244, 0.00244, 0.00243, 0.00228, 0.00239, 0.00248,
                        0.00259, 0.00246, 0.00247, 0.00248, 0.00247, 0.00240, 0.00267,
                        0.00241, 0.00258, 0.00246, 0.00251, 0.00258, 0.00234, 0.00242, 0.00241],
                       [0.00243, 0.00256, 0.00291, 0.00293, 0.00284, 0.00259, 0.00256,
                        0.00235, 0.00239, 0.00245, 0.00233, 0.00222, 0.00243, 0.00234,
                        0.00259, 0.00244, 0.00240, 0.00255, 0.00247, 0.00243, 0.00252,
                        0.00249, 0.00251, 0.00234, 0.00245, 0.00255, 0.00245, 0.00244, 0.00250],
                       [0.00242, 0.00250, 0.00281, 0.00284, 0.00277, 0.00266, 0.00261,
                        0.00228, 0.00227, 0.00233, 0.00232, 0.00228, 0.00252, 0.00228,
                        0.00238, 0.00240, 0.00236, 0.00247, 0.00241, 0.00241, 0.00243,
                        0.00252, 0.00244, 0.00229, 0.00232, 0.00235, 0.00244, 0.00255, 0.00247],
                       [0.00242, 0.00241, 0.00266, 0.00273, 0.00262, 0.00269, 0.00258,
                        0.00240, 0.00229, 0.00219, 0.00237, 0.00232, 0.00241, 0.00229,
                        0.00218, 0.00240, 0.00234, 0.00230, 0.00238, 0.00237, 0.00246,
                        0.00246, 0.00251, 0.00232, 0.00235, 0.00230, 0.00235, 0.00258, 0.00236],
                       [0.00249, 0.00236, 0.00255, 0.00260, 0.00256, 0.00263, 0.00250,
                        0.00245, 0.00230, 0.00222, 0.00234, 0.00232, 0.00225, 0.00241,
                        0.00217, 0.00233, 0.00229, 0.00223, 0.00243, 0.00240, 0.00241,
                        0.00239, 0.00256, 0.00236, 0.00244, 0.00231, 0.00228, 0.00242, 0.00227],
                       [0.00244, 0.00241, 0.00260, 0.00258, 0.00266, 0.00253, 0.00239,
                        0.00242, 0.00221, 0.00233, 0.00228, 0.00233, 0.00235, 0.00246,
                        0.00225, 0.00227, 0.00237, 0.00220, 0.00236, 0.00250, 0.00226,
                        0.00239, 0.00242, 0.00234, 0.00251, 0.00232, 0.00226, 0.00225, 0.00228],
                       [0.00237, 0.00247, 0.00275, 0.00272, 0.00270, 0.00243, 0.00243,
                        0.00238, 0.00217, 0.00230, 0.00221, 0.00232, 0.00251, 0.00224,
                        0.00232, 0.00230, 0.00252, 0.00225, 0.00231, 0.00253, 0.00226,
                        0.00239, 0.00234, 0.00233, 0.00246, 0.00237, 0.00225, 0.00226, 0.00235],
                       [0.00247, 0.00253, 0.00275, 0.00279, 0.00268, 0.00242, 0.00263,
                        0.00235, 0.00221, 0.00228, 0.00218, 0.00231, 0.00247, 0.00211,
                        0.00232, 0.00228, 0.00247, 0.00243, 0.00237, 0.00243, 0.00248,
                        0.00239, 0.00245, 0.00232, 0.00226, 0.00229, 0.00221, 0.00246, 0.00235],
                       [0.00249, 0.00250, 0.00258, 0.00275, 0.00265, 0.00245, 0.00269,
                        0.00231, 0.00225, 0.00233, 0.00223, 0.00229, 0.00231, 0.00220,
                        0.00220, 0.00226, 0.00233, 0.00243, 0.00236, 0.00232, 0.00258,
                        0.00238, 0.00246, 0.00229, 0.00212, 0.00220, 0.00225, 0.00253, 0.00228],
                       [0.00240, 0.00239, 0.00251, 0.00270, 0.00251, 0.00249, 0.00248,
                        0.00227, 0.00226, 0.00228, 0.00228, 0.00230, 0.00223, 0.00226,
                        0.00212, 0.00233, 0.00233, 0.00222, 0.00233, 0.00224, 0.00240,
                        0.00230, 0.00236, 0.00235, 0.00217, 0.00230, 0.00236, 0.00225, 0.00222],
                       [0.00238, 0.00233, 0.00261, 0.00263, 0.00238, 0.00249, 0.00227,
                        0.00231, 0.00223, 0.00221, 0.00224, 0.00232, 0.00222, 0.00230,
                        0.00220, 0.00235, 0.00241, 0.00218, 0.00232, 0.00227, 0.00226,
                        0.00221, 0.00237, 0.00244, 0.00227, 0.00233, 0.00239, 0.00206, 0.00214],
                       [0.00234, 0.00229, 0.00263, 0.00256, 0.00234, 0.00246, 0.00234,
                        0.00237, 0.00220, 0.00222, 0.00213, 0.00230, 0.00227, 0.00232,
                        0.00228, 0.00230, 0.00249, 0.00226, 0.00231, 0.00238, 0.00235,
                        0.00220, 0.00236, 0.00234, 0.00228, 0.00213, 0.00231, 0.00215, 0.00211],
                       [0.00232, 0.00227, 0.00248, 0.00256, 0.00233, 0.00240, 0.00248,
                        0.00237, 0.00218, 0.00224, 0.00207, 0.00225, 0.00231, 0.00228,
                        0.00231, 0.00221, 0.00245, 0.00226, 0.00228, 0.00233, 0.00240,
                        0.00228, 0.00232, 0.00217, 0.00227, 0.00199, 0.00217, 0.00225, 0.00223],
                       [0.00241, 0.00232, 0.00239, 0.00257, 0.00230, 0.00236, 0.00243,
                        0.00225, 0.00213, 0.00226, 0.00216, 0.00221, 0.00225, 0.00220,
                        0.00232, 0.00219, 0.00231, 0.00225, 0.00223, 0.00224, 0.00230,
                        0.00239, 0.00236, 0.00220, 0.00237, 0.00209, 0.00208, 0.00229, 0.00235],
                       [0.00249, 0.00243, 0.00240, 0.00249, 0.00233, 0.00244, 0.00231,
                        0.00216, 0.00216, 0.00226, 0.00229, 0.00229, 0.00222, 0.00219,
                        0.00226, 0.00219, 0.00229, 0.00225, 0.00220, 0.00231, 0.00224,
                        0.00240, 0.00237, 0.00229, 0.00242, 0.00225, 0.00228, 0.00234, 0.00223],
                       [0.00239, 0.00242, 0.00248, 0.00245, 0.00248, 0.00249, 0.00232,
                        0.00226, 0.00223, 0.00221, 0.00227, 0.00240, 0.00226, 0.00228,
                        0.00216, 0.00220, 0.00230, 0.00226, 0.00211, 0.00231, 0.00224,
                        0.00230, 0.00227, 0.00228, 0.00229, 0.00226, 0.00257, 0.00235, 0.00197],
                       [0.00226, 0.00231, 0.00257, 0.00246, 0.00253, 0.00233, 0.00236,
                        0.00235, 0.00216, 0.00223, 0.00218, 0.00234, 0.00228, 0.00228,
                        0.00212, 0.00227, 0.00223, 0.00231, 0.00204, 0.00221, 0.00220,
                        0.00216, 0.00222, 0.00227, 0.00221, 0.00218, 0.00251, 0.00227, 0.00195],
                       [0.00225, 0.00223, 0.00253, 0.00240, 0.00240, 0.00227, 0.00231,
                        0.00217, 0.00199, 0.00224, 0.00213, 0.00217, 0.00228, 0.00215,
                        0.00223, 0.00230, 0.00219, 0.00228, 0.00210, 0.00213, 0.00222,
                        0.00206, 0.00226, 0.00224, 0.00218, 0.00222, 0.00221, 0.00220, 0.00216],
                       [0.00226, 0.00223, 0.00239, 0.00237, 0.00232, 0.00251, 0.00229,
                        0.00201, 0.00199, 0.00214, 0.00211, 0.00216, 0.00223, 0.00209,
                        0.00231, 0.00225, 0.00219, 0.00216, 0.00224, 0.00215, 0.00224,
                        0.00211, 0.00224, 0.00217, 0.00210, 0.00228, 0.00210, 0.00213, 0.00226],
                       [0.00225, 0.00229, 0.00234, 0.00244, 0.00238, 0.00262, 0.00230,
                        0.00216, 0.00217, 0.00210, 0.00216, 0.00222, 0.00225, 0.00215,
                        0.00226, 0.00212, 0.00222, 0.00213, 0.00229, 0.00224, 0.00214,
                        0.00227, 0.00209, 0.00215, 0.00212, 0.00221, 0.00218, 0.00206, 0.00215],
                       [0.00232, 0.00235, 0.00241, 0.00250, 0.00238, 0.00239, 0.00229,
                        0.00235, 0.00228, 0.00210, 0.00224, 0.00217, 0.00226, 0.00227,
                        0.00222, 0.00205, 0.00223, 0.00223, 0.00224, 0.00229, 0.00209,
                        0.00233, 0.00201, 0.00217, 0.00218, 0.00213, 0.00225, 0.00213, 0.00201],
                       [0.00238, 0.00234, 0.00254, 0.00251, 0.00229, 0.00228, 0.00223,
                        0.00224, 0.00221, 0.00204, 0.00224, 0.00205, 0.00216, 0.00228,
                        0.00224, 0.00211, 0.00220, 0.00222, 0.00218, 0.00223, 0.00214,
                        0.00229, 0.00213, 0.00219, 0.00210, 0.00212, 0.00226, 0.00225, 0.00193],
                       [0.00236, 0.00230, 0.00252, 0.00244, 0.00223, 0.00238, 0.00218,
                        0.00204, 0.00203, 0.00207, 0.00215, 0.00206, 0.00214, 0.00217,
                        0.00217, 0.00216, 0.00214, 0.00205, 0.00215, 0.00208, 0.00219,
                        0.00228, 0.00231, 0.00223, 0.00204, 0.00210, 0.00223, 0.00229, 0.00202],
                       [0.00221, 0.00228, 0.00234, 0.00233, 0.00235, 0.00234, 0.00222,
                        0.00212, 0.00195, 0.00216, 0.00206, 0.00214, 0.00221, 0.00216,
                        0.00207, 0.00215, 0.00207, 0.00201, 0.00219, 0.00206, 0.00218,
                        0.00222, 0.00234, 0.00228, 0.00213, 0.00211, 0.00213, 0.00225, 0.00218],
                       [0.00209, 0.00223, 0.00224, 0.00233, 0.00244, 0.00228, 0.00225,
                        0.00230, 0.00207, 0.00219, 0.00202, 0.00215, 0.00217, 0.00218,
                        0.00212, 0.00216, 0.00206, 0.00213, 0.00225, 0.00215, 0.00210,
                        0.00219, 0.00218, 0.00229, 0.00218, 0.00212, 0.00203, 0.00217, 0.00211],
                       [0.00215, 0.00219, 0.00226, 0.00241, 0.00238, 0.00235, 0.00224,
                        0.00224, 0.00223, 0.00219, 0.00204, 0.00211, 0.00213, 0.00212,
                        0.00221, 0.00218, 0.00210, 0.00216, 0.00224, 0.00214, 0.00206,
                        0.00232, 0.00202, 0.00223, 0.00209, 0.00214, 0.00202, 0.00213, 0.00191],
                       [0.00220, 0.00221, 0.00230, 0.00237, 0.00231, 0.00237, 0.00221,
                        0.00204, 0.00222, 0.00221, 0.00209, 0.00211, 0.00223, 0.00217,
                        0.00213, 0.00220, 0.00213, 0.00210, 0.00212, 0.00206, 0.00212,
                        0.00239, 0.00206, 0.00217, 0.00204, 0.00220, 0.00205, 0.00211, 0.00191],
                       [0.00215, 0.00222, 0.00240, 0.00229, 0.00229, 0.00232, 0.00215,
                        0.00203, 0.00210, 0.00218, 0.00220, 0.00218, 0.00234, 0.00221,
                        0.00207, 0.00218, 0.00221, 0.00210, 0.00199, 0.00206, 0.00218,
                        0.00225, 0.00217, 0.00219, 0.00211, 0.00215, 0.00201, 0.00212, 0.00203],
                       [0.00206, 0.00221, 0.00241, 0.00230, 0.00227, 0.00225, 0.00214,
                        0.00219, 0.00199, 0.00205, 0.00223, 0.00215, 0.00218, 0.00212,
                        0.00210, 0.00208, 0.00221, 0.00212, 0.00196, 0.00208, 0.00217,
                        0.00207, 0.00212, 0.00223, 0.00209, 0.00201, 0.00205, 0.00214, 0.00206],
                       [0.00210, 0.00216, 0.00230, 0.00227, 0.00227, 0.00222, 0.00225,
                        0.00237, 0.00202, 0.00197, 0.00206, 0.00208, 0.00187, 0.00206,
                        0.00206, 0.00202, 0.00206, 0.00205, 0.00201, 0.00210, 0.00216,
                        0.00206, 0.00200, 0.00214, 0.00196, 0.00198, 0.00218, 0.00212, 0.00206],
                       [0.00222, 0.00215, 0.00228, 0.00222, 0.00228, 0.00225, 0.00231,
                        0.00228, 0.00208, 0.00205, 0.00192, 0.00212, 0.00183, 0.00208,
                        0.00195, 0.00210, 0.00197, 0.00200, 0.00207, 0.00213, 0.00212,
                        0.00211, 0.00201, 0.00202, 0.00197, 0.00198, 0.00217, 0.00200, 0.00206],
                       [0.00218, 0.00222, 0.00237, 0.00230, 0.00228, 0.00226, 0.00233,
                        0.00195, 0.00212, 0.00216, 0.00194, 0.00211, 0.00199, 0.00210,
                        0.00195, 0.00219, 0.00201, 0.00209, 0.00215, 0.00217, 0.00200,
                        0.00216, 0.00214, 0.00209, 0.00216, 0.00201, 0.00201, 0.00192, 0.00201],
                       [0.00202, 0.00223, 0.00235, 0.00230, 0.00232, 0.00223, 0.00230,
                        0.00184, 0.00212, 0.00212, 0.00213, 0.00203, 0.00203, 0.00213,
                        0.00210, 0.00213, 0.00202, 0.00216, 0.00212, 0.00219, 0.00190,
                        0.00223, 0.00217, 0.00210, 0.00228, 0.00208, 0.00195, 0.00205, 0.00189],
                       [0.00199, 0.00222, 0.00227, 0.00222, 0.00230, 0.00228, 0.00224,
                        0.00203, 0.00202, 0.00208, 0.00228, 0.00201, 0.00202, 0.00216,
                        0.00211, 0.00206, 0.00198, 0.00210, 0.00199, 0.00208, 0.00199,
                        0.00229, 0.00209, 0.00196, 0.00224, 0.00207, 0.00205, 0.00219, 0.00188],
                       [0.00203, 0.00219, 0.00215, 0.00224, 0.00219, 0.00226, 0.00222,
                        0.00214, 0.00192, 0.00211, 0.00221, 0.00204, 0.00204, 0.00210,
                        0.00195, 0.00213, 0.00203, 0.00198, 0.00199, 0.00190, 0.00211,
                        0.00225, 0.00208, 0.00193, 0.00208, 0.00203, 0.00217, 0.00219, 0.00194],
                       [0.00198, 0.00213, 0.00212, 0.00232, 0.00220, 0.00211, 0.00216,
                        0.00202, 0.00206, 0.00206, 0.00210, 0.00205, 0.00200, 0.00201,
                        0.00193, 0.00215, 0.00211, 0.00191, 0.00209, 0.00188, 0.00203,
                        0.00222, 0.00210, 0.00207, 0.00197, 0.00199, 0.00220, 0.00204, 0.00189],
                       [0.00197, 0.00212, 0.00230, 0.00228, 0.00226, 0.00202, 0.00206,
                        0.00193, 0.00221, 0.00197, 0.00201, 0.00204, 0.00197, 0.00199,
                        0.00208, 0.00206, 0.00208, 0.00199, 0.00210, 0.00196, 0.00197,
                        0.00218, 0.00202, 0.00219, 0.00199, 0.00203, 0.00210, 0.00193, 0.00178],
                       [0.00211, 0.00209, 0.00237, 0.00214, 0.00227, 0.00198, 0.00200,
                        0.00197, 0.00206, 0.00192, 0.00193, 0.00202, 0.00201, 0.00205,
                        0.00204, 0.00206, 0.00199, 0.00213, 0.00207, 0.00198, 0.00201,
                        0.00207, 0.00192, 0.00221, 0.00204, 0.00209, 0.00192, 0.00196, 0.00185],
                       [0.00210, 0.00208, 0.00227, 0.00214, 0.00230, 0.00204, 0.00203,
                        0.00195, 0.00183, 0.00186, 0.00190, 0.00194, 0.00205, 0.00208,
                        0.00189, 0.00199, 0.00198, 0.00211, 0.00199, 0.00198, 0.00211,
                        0.00202, 0.00192, 0.00211, 0.00210, 0.00198, 0.00184, 0.00203, 0.00196],
                       ])),
    r2=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                             100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                             180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                             260.0, 270.0, 280.0]),
            lam=np.array([500.38, 500.80, 501.21, 501.63, 502.05, 502.47, 502.88, 503.30,
                          503.72, 504.14, 504.56, 504.98, 505.39, 505.81, 506.23, 506.65,
                          507.07, 507.49, 507.91, 508.32, 508.74, 509.16, 509.58, 510.00,
                          510.42, 510.84, 511.26, 511.67, 512.09, 512.51, 512.93, 513.35,
                          513.77, 514.19, 514.61, 515.03, 515.45, 515.87, 516.29, 516.71,
                          517.13, 517.54, 517.96, 518.38, 518.80, 519.22, 519.64, 520.06,
                          520.48, 520.90, 521.32, 521.74, 522.16, 522.58, 523.00, 523.42,
                          523.84, 524.26, 524.68, 525.10, 525.53, 525.95, 526.37, 526.79,
                          527.21, 527.63, 528.05, 528.47, 528.89, 529.31, 529.73, 530.15,
                          530.57, 530.99, 531.42, 531.84, 532.26, 532.68, 533.10, 533.52,
                          533.94, 534.36, 534.79, 535.21, 535.63, 536.05, 536.47, 536.89,
                          537.31, 537.74, 538.16, 538.58, 539.00, 539.42, 539.85, 540.27,
                          540.69, 541.11, 541.53, 541.96, 542.38, 542.80, 543.22, 543.64,
                          544.07, 544.49, 544.91, 545.33, 545.76, 546.18, 546.60, 547.02,
                          547.45, 547.87, 548.29, 548.71, 549.14, 549.56, 549.98, 550.41,
                          550.83, 551.25, 551.68, 552.10, 552.52, 552.94, 553.37, 553.79,
                          554.21, 554.64, 555.06, 555.48, 555.91, 556.33, 556.76, 557.18,
                          557.60, 558.03, 558.45, 558.87, 559.30, 559.72, 560.15, 560.57,
                          560.99, 561.42, 561.84, 562.27, 562.69, 563.11, 563.54, 563.96,
                          564.39, 564.81, 565.24, 565.66, 566.08, 566.51, 566.93, 567.36,
                          567.78, 568.21, 568.63, 569.06, 569.48, 569.91, 570.33, 570.76,
                          571.18, 571.61, 572.03, 572.46, 572.88, 573.31, 573.73, 574.16,
                          574.58, 575.01, 575.43, 575.86, 576.29, 576.71, 577.14, 577.56,
                          577.99, 578.41, 578.84, 579.26, 579.69, 580.12, 580.54, 580.97,
                          581.39, 581.82, 582.25, 582.67, 583.10, 583.52, 583.95, 584.38,
                          584.80, 585.23, 585.66, 586.08, 586.51, 586.94, 587.36, 587.79,
                          588.22, 588.64, 589.07, 589.50, 589.92, 590.35, 590.78, 591.20,
                          591.63, 592.06, 592.48, 592.91, 593.34, 593.77, 594.19, 594.62,
                          595.05, 595.47, 595.90, 596.33, 596.76, 597.18, 597.61, 598.04,
                          598.47, 598.90, 599.32, 599.75, 600.18, 600.61, 601.03, 601.46,
                          601.89, 602.32, 602.75, 603.17, 603.60, 604.03, 604.46, 604.89,
                          605.31, 605.74, 606.17, 606.60, 607.03, 607.46, 607.89, 608.31,
                          608.74, 609.17, 609.60, 610.03, 610.46, 610.89, 611.31, 611.74,
                          612.17, 612.60, 613.03, 613.46, 613.89, 614.32, 614.75, 615.18,
                          615.61, 616.03, 616.46, 616.89, 617.32, 617.75, 618.18, 618.61,
                          619.04, 619.47, 619.90, 620.33, 620.76, 621.19, 621.62, 622.05,
                          622.48, 622.91, 623.34, 623.77, 624.20, 624.63, 625.06, 625.49,
                          625.92, 626.35, 626.78, 627.21, 627.64, 628.07, 628.50, 628.93,
                          629.36, 629.79, 630.22, 630.65, 631.08, 631.51, 631.94, 632.38,
                          632.81, 633.24, 633.67, 634.10, 634.53, 634.96, 635.39, 635.82,
                          636.25, 636.69, 637.12, 637.55, 637.98, 638.41, 638.84, 639.27,
                          639.70, 640.14, 640.57, 641.00, 641.43, 641.86, 642.29, 642.73,
                          643.16, 643.59, 644.02, 644.45, 644.88, 645.32, 645.75, 646.18,
                          646.61, 647.04, 647.48, 647.91, 648.34, 648.77, 649.21, 649.64,
                          650.07, 650.50, 650.93, 651.37, 651.80, 652.23, 652.66, 653.10,
                          653.53, 653.96, 654.40, 654.83, 655.26, 655.69, 656.13, 656.56,
                          656.99, 657.43, 657.86, 658.29, 658.72, 659.16, 659.59, 660.02,
                          660.46, 660.89, 661.32, 661.76, 662.19, 662.62, 663.06, 663.49,
                          663.92, 664.36, 664.79, 665.23, 665.66, 666.09, 666.53, 666.96,
                          667.39, 667.83, 668.26, 668.70, 669.13, 669.56, 670.00, 670.43,
                          670.87, 671.30, 671.73, 672.17, 672.60, 673.04, 673.47, 673.91,
                          674.34, 674.77, 675.21, 675.64, 676.08, 676.51, 676.95, 677.38,
                          677.82, 678.25, 678.69, 679.12, 679.56, 679.99, 680.43, 680.86,
                          681.30, 681.73, 682.17, 682.60, 683.04, 683.47, 683.91, 684.34,
                          684.78, 685.21, 685.65, 686.08, 686.52, 686.95, 687.39, 687.83,
                          688.26, 688.70, 689.13, 689.57, 690.00, 690.44, 690.88, 691.31,
                          691.75, 692.18, 692.62, 693.06, 693.49, 693.93, 694.36, 694.80,
                          695.24, 695.67, 696.11, 696.54, 696.98, 697.42, 697.85, 698.29,
                          698.73, 699.16, 699.60, 700.04, 700.47, 700.91, 701.35, 701.78,
                          702.22, 702.66, 703.09, 703.53, 703.97, 704.40, 704.84, 705.28,
                          705.71, 706.15, 706.59, 707.03, 707.46, 707.90, 708.34, 708.77,
                          709.21, 709.65, 710.09, 710.52, 710.96, 711.40, 711.84, 712.27,
                          712.71, 713.15, 713.59, 714.02, 714.46, 714.90, 715.34, 715.78,
                          716.21, 716.65, 717.09, 717.53, 717.97, 718.40, 718.84, 719.28,
                          719.72, 720.16, 720.59, 721.03, 721.47, 721.91, 722.35, 722.79,
                          723.22, 723.66, 724.10, 724.54, 724.98, 725.42, 725.85, 726.29,
                          726.73, 727.17, 727.61, 728.05, 728.49, 728.93, 729.37, 729.80,
                          730.24, 730.68, 731.12, 731.56, 732.00, 732.44, 732.88, 733.32,
                          733.76, 734.19, 734.63, 735.07, 735.51, 735.95, 736.39, 736.83,
                          737.27, 737.71, 738.15, 738.59, 739.03, 739.47, 739.91]),
            T=np.array([[0.00376, 0.00405, 0.00383, 0.00396, 0.00402, 0.00405, 0.00364,
                         0.00385, 0.00383, 0.00395, 0.00406, 0.00424, 0.00426, 0.00370,
                         0.00409, 0.00421, 0.00408, 0.00389, 0.00402, 0.00405, 0.00387,
                         0.00371, 0.00408, 0.00416, 0.00393, 0.00399, 0.00431, 0.00387, 0.00385],
                        [0.00372, 0.00397, 0.00362, 0.00425, 0.00401, 0.00399, 0.00403,
                         0.00379, 0.00394, 0.00404, 0.00426, 0.00401, 0.00448, 0.00358,
                         0.00384, 0.00386, 0.00401, 0.00409, 0.00383, 0.00443, 0.00370,
                         0.00360, 0.00415, 0.00398, 0.00393, 0.00366, 0.00405, 0.00408, 0.00325],
                        [0.00410, 0.00398, 0.00373, 0.00422, 0.00417, 0.00404, 0.00416,
                         0.00384, 0.00450, 0.00420, 0.00426, 0.00386, 0.00440, 0.00396,
                         0.00406, 0.00389, 0.00398, 0.00424, 0.00372, 0.00436, 0.00367,
                         0.00386, 0.00402, 0.00361, 0.00385, 0.00392, 0.00362, 0.00405, 0.00319],
                        [0.00432, 0.00383, 0.00411, 0.00418, 0.00432, 0.00403, 0.00381,
                         0.00381, 0.00465, 0.00406, 0.00417, 0.00404, 0.00418, 0.00414,
                         0.00407, 0.00424, 0.00422, 0.00428, 0.00397, 0.00402, 0.00388,
                         0.00402, 0.00399, 0.00363, 0.00378, 0.00431, 0.00350, 0.00393, 0.00394],
                        [0.00388, 0.00387, 0.00429, 0.00423, 0.00417, 0.00409, 0.00378,
                         0.00381, 0.00414, 0.00383, 0.00418, 0.00409, 0.00409, 0.00386,
                         0.00395, 0.00420, 0.00427, 0.00410, 0.00428, 0.00390, 0.00400,
                         0.00407, 0.00418, 0.00413, 0.00402, 0.00440, 0.00397, 0.00407, 0.00451],
                        [0.00361, 0.00401, 0.00416, 0.00434, 0.00372, 0.00410, 0.00427,
                         0.00404, 0.00384, 0.00380, 0.00416, 0.00398, 0.00425, 0.00394,
                         0.00401, 0.00405, 0.00390, 0.00409, 0.00429, 0.00386, 0.00413,
                         0.00426, 0.00442, 0.00425, 0.00428, 0.00444, 0.00438, 0.00439, 0.00427],
                        [0.00388, 0.00406, 0.00390, 0.00422, 0.00360, 0.00404, 0.00444,
                         0.00398, 0.00412, 0.00411, 0.00410, 0.00408, 0.00425, 0.00426,
                         0.00415, 0.00410, 0.00381, 0.00438, 0.00426, 0.00371, 0.00424,
                         0.00426, 0.00450, 0.00393, 0.00417, 0.00439, 0.00423, 0.00455, 0.00386],
                        [0.00410, 0.00409, 0.00391, 0.00376, 0.00393, 0.00427, 0.00428,
                         0.00369, 0.00440, 0.00447, 0.00424, 0.00445, 0.00402, 0.00403,
                         0.00413, 0.00397, 0.00417, 0.00435, 0.00424, 0.00372, 0.00408,
                         0.00387, 0.00428, 0.00386, 0.00400, 0.00422, 0.00407, 0.00440, 0.00395],
                        [0.00415, 0.00412, 0.00425, 0.00366, 0.00426, 0.00437, 0.00436,
                         0.00391, 0.00446, 0.00449, 0.00456, 0.00458, 0.00402, 0.00385,
                         0.00401, 0.00398, 0.00435, 0.00406, 0.00407, 0.00409, 0.00413,
                         0.00393, 0.00411, 0.00410, 0.00403, 0.00419, 0.00414, 0.00430, 0.00434],
                        [0.00415, 0.00399, 0.00440, 0.00412, 0.00433, 0.00414, 0.00448,
                         0.00438, 0.00461, 0.00415, 0.00451, 0.00424, 0.00415, 0.00414,
                         0.00400, 0.00430, 0.00427, 0.00395, 0.00399, 0.00441, 0.00445,
                         0.00431, 0.00420, 0.00419, 0.00409, 0.00427, 0.00408, 0.00426, 0.00436],
                        [0.00422, 0.00396, 0.00420, 0.00457, 0.00419, 0.00414, 0.00422,
                         0.00446, 0.00481, 0.00375, 0.00426, 0.00398, 0.00421, 0.00439,
                         0.00419, 0.00444, 0.00411, 0.00417, 0.00417, 0.00450, 0.00437,
                         0.00434, 0.00446, 0.00407, 0.00416, 0.00442, 0.00408, 0.00412, 0.00418],
                        [0.00432, 0.00409, 0.00413, 0.00459, 0.00424, 0.00437, 0.00403,
                         0.00429, 0.00464, 0.00372, 0.00425, 0.00399, 0.00423, 0.00423,
                         0.00442, 0.00425, 0.00408, 0.00433, 0.00431, 0.00460, 0.00400,
                         0.00438, 0.00450, 0.00409, 0.00427, 0.00454, 0.00434, 0.00407, 0.00419],
                        [0.00437, 0.00420, 0.00444, 0.00441, 0.00454, 0.00436, 0.00417,
                         0.00425, 0.00434, 0.00404, 0.00446, 0.00421, 0.00428, 0.00397,
                         0.00440, 0.00412, 0.00419, 0.00408, 0.00438, 0.00451, 0.00405,
                         0.00444, 0.00436, 0.00426, 0.00427, 0.00439, 0.00457, 0.00425, 0.00426],
                        [0.00429, 0.00441, 0.00437, 0.00430, 0.00444, 0.00423, 0.00422,
                         0.00415, 0.00422, 0.00426, 0.00456, 0.00437, 0.00438, 0.00392,
                         0.00417, 0.00414, 0.00431, 0.00392, 0.00456, 0.00424, 0.00446,
                         0.00426, 0.00440, 0.00426, 0.00422, 0.00431, 0.00442, 0.00450, 0.00406],
                        [0.00405, 0.00462, 0.00389, 0.00439, 0.00415, 0.00410, 0.00440,
                         0.00415, 0.00414, 0.00443, 0.00423, 0.00417, 0.00445, 0.00411,
                         0.00412, 0.00428, 0.00435, 0.00402, 0.00451, 0.00415, 0.00469,
                         0.00411, 0.00461, 0.00437, 0.00430, 0.00456, 0.00413, 0.00454, 0.00385],
                        [0.00398, 0.00438, 0.00386, 0.00452, 0.00416, 0.00409, 0.00457,
                         0.00446, 0.00419, 0.00467, 0.00395, 0.00420, 0.00435, 0.00416,
                         0.00436, 0.00451, 0.00434, 0.00413, 0.00420, 0.00414, 0.00451,
                         0.00428, 0.00470, 0.00437, 0.00449, 0.00469, 0.00423, 0.00440, 0.00390],
                        [0.00412, 0.00391, 0.00417, 0.00452, 0.00445, 0.00422, 0.00453,
                         0.00444, 0.00434, 0.00451, 0.00424, 0.00447, 0.00422, 0.00413,
                         0.00458, 0.00456, 0.00432, 0.00427, 0.00407, 0.00431, 0.00425,
                         0.00453, 0.00464, 0.00402, 0.00460, 0.00448, 0.00463, 0.00435, 0.00414],
                        [0.00411, 0.00415, 0.00421, 0.00453, 0.00462, 0.00450, 0.00442,
                         0.00418, 0.00440, 0.00411, 0.00455, 0.00454, 0.00420, 0.00428,
                         0.00434, 0.00457, 0.00429, 0.00443, 0.00426, 0.00469, 0.00433,
                         0.00452, 0.00457, 0.00418, 0.00452, 0.00426, 0.00467, 0.00423, 0.00435],
                        [0.00398, 0.00475, 0.00417, 0.00454, 0.00445, 0.00480, 0.00436,
                         0.00429, 0.00436, 0.00419, 0.00452, 0.00449, 0.00433, 0.00433,
                         0.00413, 0.00456, 0.00416, 0.00429, 0.00441, 0.00466, 0.00465,
                         0.00445, 0.00437, 0.00477, 0.00422, 0.00424, 0.00438, 0.00410, 0.00436],
                        [0.00409, 0.00490, 0.00439, 0.00446, 0.00427, 0.00486, 0.00444,
                         0.00443, 0.00424, 0.00460, 0.00440, 0.00450, 0.00462, 0.00432,
                         0.00443, 0.00441, 0.00423, 0.00410, 0.00440, 0.00416, 0.00465,
                         0.00454, 0.00421, 0.00476, 0.00422, 0.00449, 0.00437, 0.00431, 0.00440],
                        [0.00419, 0.00472, 0.00444, 0.00440, 0.00422, 0.00461, 0.00446,
                         0.00440, 0.00447, 0.00462, 0.00434, 0.00454, 0.00471, 0.00450,
                         0.00464, 0.00438, 0.00440, 0.00419, 0.00432, 0.00399, 0.00425,
                         0.00441, 0.00420, 0.00425, 0.00458, 0.00480, 0.00460, 0.00468, 0.00466],
                        [0.00402, 0.00447, 0.00431, 0.00444, 0.00430, 0.00427, 0.00415,
                         0.00447, 0.00474, 0.00424, 0.00427, 0.00466, 0.00446, 0.00468,
                         0.00448, 0.00469, 0.00436, 0.00439, 0.00435, 0.00444, 0.00427,
                         0.00410, 0.00422, 0.00419, 0.00460, 0.00483, 0.00458, 0.00464, 0.00474],
                        [0.00396, 0.00430, 0.00439, 0.00445, 0.00442, 0.00424, 0.00395,
                         0.00434, 0.00452, 0.00420, 0.00415, 0.00446, 0.00423, 0.00454,
                         0.00424, 0.00494, 0.00426, 0.00427, 0.00447, 0.00487, 0.00462,
                         0.00422, 0.00440, 0.00444, 0.00432, 0.00445, 0.00442, 0.00430, 0.00454],
                        [0.00423, 0.00438, 0.00446, 0.00438, 0.00456, 0.00435, 0.00444,
                         0.00414, 0.00439, 0.00468, 0.00429, 0.00422, 0.00435, 0.00438,
                         0.00421, 0.00452, 0.00444, 0.00400, 0.00451, 0.00479, 0.00457,
                         0.00462, 0.00441, 0.00446, 0.00419, 0.00422, 0.00439, 0.00440, 0.00436],
                        [0.00440, 0.00446, 0.00438, 0.00456, 0.00457, 0.00434, 0.00480,
                         0.00416, 0.00467, 0.00488, 0.00456, 0.00447, 0.00455, 0.00458,
                         0.00446, 0.00390, 0.00491, 0.00422, 0.00442, 0.00450, 0.00435,
                         0.00468, 0.00398, 0.00447, 0.00427, 0.00438, 0.00442, 0.00478, 0.00427],
                        [0.00434, 0.00443, 0.00433, 0.00472, 0.00427, 0.00457, 0.00446,
                         0.00424, 0.00494, 0.00468, 0.00456, 0.00479, 0.00455, 0.00473,
                         0.00471, 0.00394, 0.00501, 0.00465, 0.00438, 0.00439, 0.00441,
                         0.00443, 0.00400, 0.00463, 0.00441, 0.00444, 0.00451, 0.00480, 0.00435],
                        [0.00416, 0.00460, 0.00433, 0.00449, 0.00418, 0.00470, 0.00415,
                         0.00425, 0.00486, 0.00448, 0.00441, 0.00462, 0.00446, 0.00455,
                         0.00466, 0.00433, 0.00433, 0.00449, 0.00445, 0.00436, 0.00465,
                         0.00442, 0.00455, 0.00468, 0.00457, 0.00444, 0.00457, 0.00447, 0.00463],
                        [0.00424, 0.00464, 0.00433, 0.00429, 0.00441, 0.00442, 0.00437,
                         0.00448, 0.00459, 0.00446, 0.00439, 0.00437, 0.00445, 0.00422,
                         0.00450, 0.00456, 0.00395, 0.00412, 0.00449, 0.00438, 0.00474,
                         0.00460, 0.00473, 0.00461, 0.00465, 0.00449, 0.00445, 0.00434, 0.00462],
                        [0.00448, 0.00430, 0.00446, 0.00435, 0.00464, 0.00437, 0.00473,
                         0.00474, 0.00464, 0.00466, 0.00452, 0.00453, 0.00452, 0.00407,
                         0.00450, 0.00466, 0.00442, 0.00433, 0.00461, 0.00465, 0.00461,
                         0.00459, 0.00443, 0.00451, 0.00465, 0.00448, 0.00434, 0.00446, 0.00422],
                        [0.00434, 0.00420, 0.00465, 0.00446, 0.00472, 0.00463, 0.00464,
                         0.00476, 0.00487, 0.00482, 0.00471, 0.00485, 0.00449, 0.00436,
                         0.00447, 0.00466, 0.00490, 0.00466, 0.00477, 0.00493, 0.00459,
                         0.00460, 0.00437, 0.00457, 0.00460, 0.00468, 0.00447, 0.00454, 0.00404],
                        [0.00436, 0.00444, 0.00476, 0.00456, 0.00465, 0.00471, 0.00443,
                         0.00464, 0.00469, 0.00480, 0.00475, 0.00500, 0.00448, 0.00469,
                         0.00453, 0.00440, 0.00482, 0.00469, 0.00481, 0.00481, 0.00447,
                         0.00464, 0.00460, 0.00488, 0.00475, 0.00490, 0.00474, 0.00466, 0.00436],
                        [0.00446, 0.00462, 0.00470, 0.00466, 0.00452, 0.00456, 0.00458,
                         0.00470, 0.00440, 0.00461, 0.00460, 0.00483, 0.00441, 0.00476,
                         0.00476, 0.00430, 0.00435, 0.00471, 0.00475, 0.00459, 0.00436,
                         0.00459, 0.00456, 0.00497, 0.00499, 0.00477, 0.00482, 0.00476, 0.00470],
                        [0.00427, 0.00489, 0.00458, 0.00469, 0.00445, 0.00474, 0.00480,
                         0.00484, 0.00463, 0.00447, 0.00442, 0.00446, 0.00432, 0.00482,
                         0.00465, 0.00470, 0.00422, 0.00485, 0.00475, 0.00471, 0.00465,
                         0.00470, 0.00452, 0.00482, 0.00476, 0.00460, 0.00465, 0.00460, 0.00466],
                        [0.00431, 0.00494, 0.00475, 0.00459, 0.00445, 0.00492, 0.00464,
                         0.00474, 0.00487, 0.00454, 0.00446, 0.00432, 0.00446, 0.00465,
                         0.00437, 0.00496, 0.00463, 0.00476, 0.00473, 0.00496, 0.00506,
                         0.00479, 0.00488, 0.00475, 0.00431, 0.00468, 0.00471, 0.00456, 0.00440],
                        [0.00449, 0.00456, 0.00502, 0.00449, 0.00465, 0.00474, 0.00451,
                         0.00468, 0.00475, 0.00474, 0.00469, 0.00445, 0.00464, 0.00432,
                         0.00446, 0.00481, 0.00489, 0.00451, 0.00469, 0.00481, 0.00516,
                         0.00479, 0.00518, 0.00474, 0.00441, 0.00483, 0.00493, 0.00497, 0.00429],
                        [0.00456, 0.00440, 0.00499, 0.00464, 0.00502, 0.00467, 0.00459,
                         0.00480, 0.00476, 0.00484, 0.00493, 0.00452, 0.00466, 0.00449,
                         0.00485, 0.00463, 0.00468, 0.00466, 0.00476, 0.00445, 0.00480,
                         0.00481, 0.00497, 0.00472, 0.00480, 0.00498, 0.00479, 0.00518, 0.00450],
                        [0.00456, 0.00469, 0.00481, 0.00483, 0.00504, 0.00479, 0.00466,
                         0.00484, 0.00493, 0.00485, 0.00490, 0.00454, 0.00455, 0.00467,
                         0.00504, 0.00466, 0.00478, 0.00471, 0.00479, 0.00454, 0.00452,
                         0.00472, 0.00471, 0.00470, 0.00480, 0.00496, 0.00461, 0.00481, 0.00477],
                        [0.00456, 0.00494, 0.00472, 0.00486, 0.00469, 0.00477, 0.00476,
                         0.00482, 0.00489, 0.00484, 0.00472, 0.00463, 0.00457, 0.00462,
                         0.00470, 0.00479, 0.00496, 0.00440, 0.00475, 0.00493, 0.00461,
                         0.00463, 0.00475, 0.00468, 0.00459, 0.00465, 0.00479, 0.00443, 0.00475],
                        [0.00468, 0.00510, 0.00490, 0.00479, 0.00471, 0.00496, 0.00482,
                         0.00488, 0.00483, 0.00481, 0.00473, 0.00487, 0.00481, 0.00476,
                         0.00460, 0.00488, 0.00471, 0.00454, 0.00481, 0.00497, 0.00467,
                         0.00478, 0.00490, 0.00476, 0.00465, 0.00466, 0.00497, 0.00475, 0.00472],
                        [0.00505, 0.00521, 0.00507, 0.00486, 0.00497, 0.00532, 0.00475,
                         0.00502, 0.00486, 0.00483, 0.00482, 0.00517, 0.00511, 0.00503,
                         0.00502, 0.00496, 0.00462, 0.00506, 0.00501, 0.00481, 0.00468,
                         0.00504, 0.00504, 0.00494, 0.00489, 0.00510, 0.00507, 0.00539, 0.00476],
                        [0.00545, 0.00508, 0.00495, 0.00506, 0.00490, 0.00521, 0.00483,
                         0.00504, 0.00468, 0.00500, 0.00488, 0.00508, 0.00513, 0.00509,
                         0.00507, 0.00506, 0.00486, 0.00531, 0.00510, 0.00485, 0.00487,
                         0.00507, 0.00513, 0.00503, 0.00478, 0.00520, 0.00521, 0.00535, 0.00467],
                        [0.00533, 0.00482, 0.00488, 0.00499, 0.00477, 0.00479, 0.00492,
                         0.00511, 0.00472, 0.00507, 0.00487, 0.00480, 0.00507, 0.00494,
                         0.00495, 0.00517, 0.00498, 0.00522, 0.00505, 0.00488, 0.00505,
                         0.00483, 0.00517, 0.00495, 0.00465, 0.00505, 0.00526, 0.00497, 0.00445],
                        [0.00484, 0.00497, 0.00493, 0.00480, 0.00480, 0.00454, 0.00482,
                         0.00525, 0.00502, 0.00491, 0.00477, 0.00481, 0.00530, 0.00490,
                         0.00498, 0.00519, 0.00504, 0.00502, 0.00509, 0.00495, 0.00498,
                         0.00476, 0.00521, 0.00488, 0.00483, 0.00513, 0.00526, 0.00495, 0.00452],
                        [0.00479, 0.00520, 0.00511, 0.00489, 0.00491, 0.00454, 0.00478,
                         0.00529, 0.00514, 0.00501, 0.00499, 0.00496, 0.00531, 0.00497,
                         0.00488, 0.00513, 0.00518, 0.00498, 0.00517, 0.00517, 0.00488,
                         0.00496, 0.00538, 0.00506, 0.00508, 0.00534, 0.00546, 0.00512, 0.00491],
                        [0.00515, 0.00501, 0.00527, 0.00505, 0.00502, 0.00480, 0.00482,
                         0.00518, 0.00497, 0.00507, 0.00535, 0.00492, 0.00497, 0.00504,
                         0.00492, 0.00522, 0.00520, 0.00502, 0.00497, 0.00524, 0.00505,
                         0.00504, 0.00539, 0.00529, 0.00517, 0.00529, 0.00548, 0.00532, 0.00511],
                        [0.00528, 0.00488, 0.00519, 0.00511, 0.00507, 0.00521, 0.00494,
                         0.00505, 0.00494, 0.00494, 0.00527, 0.00485, 0.00477, 0.00519,
                         0.00510, 0.00535, 0.00516, 0.00515, 0.00486, 0.00518, 0.00530,
                         0.00505, 0.00515, 0.00526, 0.00514, 0.00513, 0.00532, 0.00551, 0.00516],
                        [0.00500, 0.00508, 0.00522, 0.00518, 0.00513, 0.00534, 0.00517,
                         0.00495, 0.00514, 0.00512, 0.00499, 0.00499, 0.00504, 0.00525,
                         0.00517, 0.00521, 0.00507, 0.00554, 0.00528, 0.00528, 0.00517,
                         0.00518, 0.00510, 0.00532, 0.00524, 0.00529, 0.00528, 0.00549, 0.00524],
                        [0.00475, 0.00513, 0.00552, 0.00532, 0.00527, 0.00522, 0.00523,
                         0.00495, 0.00517, 0.00529, 0.00502, 0.00531, 0.00540, 0.00514,
                         0.00531, 0.00525, 0.00496, 0.00574, 0.00564, 0.00564, 0.00492,
                         0.00537, 0.00534, 0.00562, 0.00540, 0.00542, 0.00518, 0.00543, 0.00516],
                        [0.00478, 0.00488, 0.00543, 0.00523, 0.00523, 0.00535, 0.00501,
                         0.00509, 0.00521, 0.00526, 0.00535, 0.00549, 0.00543, 0.00505,
                         0.00559, 0.00546, 0.00511, 0.00551, 0.00547, 0.00571, 0.00523,
                         0.00538, 0.00548, 0.00573, 0.00532, 0.00524, 0.00507, 0.00552, 0.00495],
                        [0.00512, 0.00483, 0.00513, 0.00504, 0.00504, 0.00544, 0.00508,
                         0.00536, 0.00533, 0.00532, 0.00546, 0.00537, 0.00542, 0.00514,
                         0.00562, 0.00537, 0.00534, 0.00546, 0.00511, 0.00536, 0.00560,
                         0.00518, 0.00558, 0.00550, 0.00528, 0.00518, 0.00526, 0.00540, 0.00485],
                        [0.00535, 0.00521, 0.00532, 0.00512, 0.00515, 0.00535, 0.00547,
                         0.00558, 0.00532, 0.00545, 0.00516, 0.00532, 0.00538, 0.00532,
                         0.00529, 0.00525, 0.00526, 0.00555, 0.00525, 0.00527, 0.00542,
                         0.00529, 0.00561, 0.00519, 0.00537, 0.00546, 0.00558, 0.00529, 0.00499],
                        [0.00532, 0.00562, 0.00552, 0.00540, 0.00538, 0.00542, 0.00547,
                         0.00544, 0.00540, 0.00542, 0.00503, 0.00548, 0.00541, 0.00543,
                         0.00513, 0.00534, 0.00516, 0.00540, 0.00580, 0.00539, 0.00521,
                         0.00565, 0.00547, 0.00518, 0.00546, 0.00559, 0.00562, 0.00551, 0.00519],
                        [0.00540, 0.00566, 0.00558, 0.00553, 0.00544, 0.00557, 0.00546,
                         0.00519, 0.00571, 0.00522, 0.00537, 0.00546, 0.00560, 0.00548,
                         0.00549, 0.00561, 0.00547, 0.00528, 0.00606, 0.00537, 0.00564,
                         0.00571, 0.00551, 0.00550, 0.00561, 0.00559, 0.00542, 0.00581, 0.00524],
                        [0.00548, 0.00557, 0.00568, 0.00553, 0.00562, 0.00557, 0.00560,
                         0.00527, 0.00587, 0.00520, 0.00558, 0.00544, 0.00564, 0.00552,
                         0.00594, 0.00606, 0.00578, 0.00545, 0.00597, 0.00556, 0.00598,
                         0.00566, 0.00579, 0.00584, 0.00577, 0.00565, 0.00558, 0.00577, 0.00544],
                        [0.00547, 0.00551, 0.00557, 0.00555, 0.00576, 0.00571, 0.00561,
                         0.00568, 0.00576, 0.00559, 0.00559, 0.00576, 0.00556, 0.00572,
                         0.00597, 0.00613, 0.00568, 0.00567, 0.00574, 0.00590, 0.00568,
                         0.00587, 0.00591, 0.00602, 0.00578, 0.00580, 0.00611, 0.00563, 0.00585],
                        [0.00550, 0.00519, 0.00545, 0.00570, 0.00567, 0.00595, 0.00570,
                         0.00583, 0.00562, 0.00585, 0.00572, 0.00600, 0.00558, 0.00574,
                         0.00576, 0.00574, 0.00561, 0.00569, 0.00554, 0.00587, 0.00557,
                         0.00599, 0.00590, 0.00591, 0.00564, 0.00601, 0.00617, 0.00579, 0.00591],
                        [0.00577, 0.00513, 0.00569, 0.00586, 0.00580, 0.00604, 0.00598,
                         0.00570, 0.00562, 0.00585, 0.00573, 0.00593, 0.00578, 0.00565,
                         0.00587, 0.00573, 0.00588, 0.00578, 0.00568, 0.00580, 0.00602,
                         0.00592, 0.00613, 0.00583, 0.00556, 0.00609, 0.00599, 0.00627, 0.00587],
                        [0.00583, 0.00560, 0.00606, 0.00584, 0.00608, 0.00611, 0.00615,
                         0.00560, 0.00583, 0.00606, 0.00561, 0.00587, 0.00606, 0.00578,
                         0.00613, 0.00593, 0.00597, 0.00592, 0.00596, 0.00588, 0.00630,
                         0.00596, 0.00625, 0.00593, 0.00583, 0.00614, 0.00599, 0.00643, 0.00599],
                        [0.00568, 0.00606, 0.00620, 0.00592, 0.00623, 0.00606, 0.00602,
                         0.00583, 0.00607, 0.00638, 0.00571, 0.00613, 0.00629, 0.00615,
                         0.00616, 0.00603, 0.00595, 0.00606, 0.00612, 0.00608, 0.00621,
                         0.00615, 0.00614, 0.00615, 0.00622, 0.00628, 0.00597, 0.00631, 0.00599],
                        [0.00596, 0.00625, 0.00615, 0.00621, 0.00625, 0.00590, 0.00582,
                         0.00626, 0.00602, 0.00635, 0.00601, 0.00648, 0.00619, 0.00638,
                         0.00610, 0.00635, 0.00623, 0.00626, 0.00615, 0.00641, 0.00606,
                         0.00614, 0.00619, 0.00636, 0.00631, 0.00627, 0.00606, 0.00626, 0.00589],
                        [0.00630, 0.00625, 0.00624, 0.00631, 0.00612, 0.00605, 0.00589,
                         0.00641, 0.00604, 0.00624, 0.00632, 0.00654, 0.00611, 0.00622,
                         0.00611, 0.00671, 0.00659, 0.00640, 0.00624, 0.00665, 0.00616,
                         0.00598, 0.00639, 0.00643, 0.00627, 0.00609, 0.00631, 0.00635, 0.00600],
                        [0.00619, 0.00616, 0.00644, 0.00616, 0.00610, 0.00641, 0.00622,
                         0.00623, 0.00639, 0.00628, 0.00643, 0.00633, 0.00641, 0.00612,
                         0.00625, 0.00678, 0.00659, 0.00638, 0.00635, 0.00646, 0.00648,
                         0.00600, 0.00656, 0.00633, 0.00641, 0.00617, 0.00644, 0.00657, 0.00634],
                        [0.00617, 0.00613, 0.00651, 0.00624, 0.00630, 0.00660, 0.00650,
                         0.00626, 0.00659, 0.00639, 0.00641, 0.00626, 0.00658, 0.00629,
                         0.00646, 0.00669, 0.00637, 0.00639, 0.00643, 0.00637, 0.00668,
                         0.00649, 0.00670, 0.00624, 0.00659, 0.00672, 0.00650, 0.00669, 0.00654],
                        [0.00641, 0.00642, 0.00645, 0.00657, 0.00650, 0.00655, 0.00650,
                         0.00658, 0.00658, 0.00649, 0.00657, 0.00644, 0.00654, 0.00642,
                         0.00661, 0.00664, 0.00653, 0.00648, 0.00663, 0.00659, 0.00673,
                         0.00698, 0.00676, 0.00635, 0.00658, 0.00724, 0.00673, 0.00678, 0.00646],
                        [0.00653, 0.00695, 0.00640, 0.00666, 0.00669, 0.00640, 0.00643,
                         0.00681, 0.00666, 0.00649, 0.00670, 0.00656, 0.00655, 0.00658,
                         0.00669, 0.00651, 0.00711, 0.00672, 0.00681, 0.00679, 0.00658,
                         0.00697, 0.00665, 0.00652, 0.00646, 0.00716, 0.00702, 0.00687, 0.00642],
                        [0.00652, 0.00712, 0.00648, 0.00659, 0.00693, 0.00652, 0.00665,
                         0.00680, 0.00680, 0.00677, 0.00678, 0.00656, 0.00660, 0.00696,
                         0.00671, 0.00662, 0.00728, 0.00699, 0.00687, 0.00704, 0.00652,
                         0.00690, 0.00680, 0.00685, 0.00670, 0.00682, 0.00710, 0.00687, 0.00671],
                        [0.00652, 0.00680, 0.00667, 0.00686, 0.00709, 0.00686, 0.00696,
                         0.00683, 0.00666, 0.00720, 0.00692, 0.00669, 0.00675, 0.00715,
                         0.00690, 0.00708, 0.00698, 0.00702, 0.00700, 0.00715, 0.00695,
                         0.00700, 0.00721, 0.00726, 0.00715, 0.00697, 0.00716, 0.00688, 0.00715],
                        [0.00670, 0.00666, 0.00678, 0.00737, 0.00706, 0.00717, 0.00701,
                         0.00714, 0.00669, 0.00721, 0.00697, 0.00696, 0.00711, 0.00698,
                         0.00714, 0.00741, 0.00704, 0.00713, 0.00712, 0.00724, 0.00751,
                         0.00708, 0.00742, 0.00750, 0.00738, 0.00745, 0.00723, 0.00703, 0.00733],
                        [0.00690, 0.00694, 0.00686, 0.00756, 0.00706, 0.00726, 0.00695,
                         0.00747, 0.00717, 0.00711, 0.00704, 0.00705, 0.00760, 0.00696,
                         0.00719, 0.00739, 0.00747, 0.00751, 0.00736, 0.00759, 0.00763,
                         0.00726, 0.00747, 0.00750, 0.00755, 0.00753, 0.00714, 0.00721, 0.00723],
                        [0.00706, 0.00722, 0.00717, 0.00738, 0.00728, 0.00727, 0.00710,
                         0.00777, 0.00759, 0.00739, 0.00741, 0.00717, 0.00800, 0.00743,
                         0.00742, 0.00749, 0.00789, 0.00779, 0.00771, 0.00774, 0.00759,
                         0.00759, 0.00758, 0.00762, 0.00764, 0.00759, 0.00722, 0.00751, 0.00738],
                        [0.00746, 0.00744, 0.00753, 0.00740, 0.00733, 0.00753, 0.00752,
                         0.00786, 0.00758, 0.00758, 0.00773, 0.00751, 0.00794, 0.00784,
                         0.00775, 0.00782, 0.00800, 0.00781, 0.00784, 0.00771, 0.00768,
                         0.00783, 0.00770, 0.00796, 0.00757, 0.00791, 0.00773, 0.00788, 0.00770],
                        [0.00789, 0.00786, 0.00776, 0.00781, 0.00749, 0.00794, 0.00795,
                         0.00798, 0.00767, 0.00772, 0.00780, 0.00792, 0.00768, 0.00788,
                         0.00799, 0.00804, 0.00812, 0.00811, 0.00799, 0.00802, 0.00795,
                         0.00808, 0.00805, 0.00831, 0.00781, 0.00814, 0.00836, 0.00811, 0.00788],
                        [0.00794, 0.00827, 0.00797, 0.00833, 0.00804, 0.00823, 0.00812,
                         0.00827, 0.00814, 0.00808, 0.00804, 0.00822, 0.00788, 0.00809,
                         0.00831, 0.00822, 0.00864, 0.00866, 0.00849, 0.00856, 0.00841,
                         0.00847, 0.00855, 0.00851, 0.00832, 0.00847, 0.00882, 0.00847, 0.00814],
                        [0.00791, 0.00845, 0.00827, 0.00863, 0.00864, 0.00838, 0.00828,
                         0.00856, 0.00855, 0.00856, 0.00849, 0.00838, 0.00855, 0.00870,
                         0.00876, 0.00869, 0.00918, 0.00904, 0.00903, 0.00906, 0.00907,
                         0.00882, 0.00910, 0.00902, 0.00888, 0.00901, 0.00917, 0.00915, 0.00867],
                        [0.00831, 0.00872, 0.00866, 0.00886, 0.00906, 0.00865, 0.00881,
                         0.00891, 0.00885, 0.00917, 0.00891, 0.00864, 0.00923, 0.00928,
                         0.00939, 0.00936, 0.00956, 0.00930, 0.00951, 0.00948, 0.00961,
                         0.00919, 0.00951, 0.00973, 0.00955, 0.00953, 0.00953, 0.00962, 0.00930],
                        [0.00899, 0.00932, 0.00917, 0.00931, 0.00937, 0.00928, 0.00960,
                         0.00932, 0.00923, 0.00971, 0.00944, 0.00938, 0.00982, 0.00976,
                         0.00999, 0.01005, 0.00995, 0.00978, 0.01007, 0.00995, 0.01011,
                         0.00995, 0.00993, 0.01017, 0.01021, 0.01013, 0.00994, 0.01000, 0.00970],
                        [0.00975, 0.01002, 0.00986, 0.00993, 0.00987, 0.01008, 0.01023,
                         0.00989, 0.00984, 0.01020, 0.01015, 0.01030, 0.01027, 0.01037,
                         0.01035, 0.01077, 0.01044, 0.01059, 0.01056, 0.01070, 0.01077,
                         0.01081, 0.01077, 0.01064, 0.01071, 0.01089, 0.01066, 0.01076, 0.01020],
                        [0.01054, 0.01056, 0.01063, 0.01048, 0.01064, 0.01074, 0.01068,
                         0.01070, 0.01059, 0.01088, 0.01079, 0.01089, 0.01072, 0.01094,
                         0.01081, 0.01139, 0.01117, 0.01155, 0.01114, 0.01150, 0.01136,
                         0.01135, 0.01163, 0.01128, 0.01122, 0.01162, 0.01155, 0.01153, 0.01115],
                        [0.01136, 0.01115, 0.01136, 0.01104, 0.01143, 0.01145, 0.01138,
                         0.01162, 0.01126, 0.01151, 0.01140, 0.01146, 0.01149, 0.01166,
                         0.01165, 0.01210, 0.01208, 0.01235, 0.01219, 0.01219, 0.01202,
                         0.01210, 0.01245, 0.01190, 0.01221, 0.01232, 0.01235, 0.01232, 0.01227],
                        [0.01219, 0.01210, 0.01189, 0.01192, 0.01212, 0.01223, 0.01226,
                         0.01254, 0.01192, 0.01205, 0.01224, 0.01218, 0.01235, 0.01265,
                         0.01265, 0.01303, 0.01286, 0.01296, 0.01337, 0.01297, 0.01316,
                         0.01325, 0.01339, 0.01283, 0.01337, 0.01294, 0.01331, 0.01342, 0.01308],
                        [0.01301, 0.01311, 0.01242, 0.01304, 0.01279, 0.01294, 0.01299,
                         0.01344, 0.01284, 0.01276, 0.01326, 0.01279, 0.01325, 0.01373,
                         0.01358, 0.01402, 0.01378, 0.01383, 0.01413, 0.01400, 0.01444,
                         0.01424, 0.01442, 0.01412, 0.01417, 0.01382, 0.01441, 0.01446, 0.01367],
                        [0.01373, 0.01375, 0.01318, 0.01394, 0.01350, 0.01380, 0.01372,
                         0.01412, 0.01383, 0.01362, 0.01416, 0.01366, 0.01421, 0.01460,
                         0.01448, 0.01496, 0.01498, 0.01502, 0.01498, 0.01526, 0.01534,
                         0.01504, 0.01541, 0.01533, 0.01512, 0.01518, 0.01541, 0.01522, 0.01478],
                        [0.01438, 0.01442, 0.01426, 0.01482, 0.01476, 0.01501, 0.01475,
                         0.01474, 0.01477, 0.01481, 0.01492, 0.01494, 0.01536, 0.01546,
                         0.01563, 0.01588, 0.01609, 0.01631, 0.01630, 0.01670, 0.01635,
                         0.01609, 0.01634, 0.01647, 0.01658, 0.01666, 0.01653, 0.01632, 0.01634],
                        [0.01526, 0.01548, 0.01558, 0.01580, 0.01630, 0.01622, 0.01593,
                         0.01577, 0.01571, 0.01617, 0.01591, 0.01611, 0.01651, 0.01670,
                         0.01694, 0.01691, 0.01704, 0.01747, 0.01736, 0.01784, 0.01756,
                         0.01726, 0.01736, 0.01772, 0.01795, 0.01781, 0.01779, 0.01791, 0.01749],
                        [0.01645, 0.01656, 0.01697, 0.01683, 0.01734, 0.01731, 0.01722,
                         0.01713, 0.01679, 0.01717, 0.01723, 0.01718, 0.01743, 0.01786,
                         0.01824, 0.01818, 0.01835, 0.01863, 0.01833, 0.01867, 0.01873,
                         0.01865, 0.01863, 0.01922, 0.01903, 0.01901, 0.01905, 0.01942, 0.01858],
                        [0.01770, 0.01759, 0.01818, 0.01819, 0.01820, 0.01840, 0.01836,
                         0.01845, 0.01813, 0.01818, 0.01852, 0.01845, 0.01841, 0.01878,
                         0.01950, 0.01960, 0.02007, 0.02009, 0.01989, 0.02002, 0.02008,
                         0.02014, 0.02024, 0.02076, 0.02036, 0.02064, 0.02056, 0.02093, 0.02021],
                        [0.01913, 0.01907, 0.01937, 0.01977, 0.01961, 0.01974, 0.01952,
                         0.01960, 0.01973, 0.01961, 0.01970, 0.01984, 0.01988, 0.02024,
                         0.02090, 0.02124, 0.02165, 0.02176, 0.02187, 0.02199, 0.02180,
                         0.02184, 0.02204, 0.02214, 0.02214, 0.02237, 0.02245, 0.02274, 0.02215],
                        [0.02073, 0.02087, 0.02079, 0.02122, 0.02136, 0.02160, 0.02115,
                         0.02106, 0.02138, 0.02109, 0.02115, 0.02145, 0.02192, 0.02214,
                         0.02252, 0.02319, 0.02306, 0.02347, 0.02375, 0.02384, 0.02381,
                         0.02392, 0.02388, 0.02377, 0.02403, 0.02406, 0.02441, 0.02467, 0.02412],
                        [0.02230, 0.02250, 0.02247, 0.02270, 0.02308, 0.02371, 0.02315,
                         0.02311, 0.02320, 0.02276, 0.02301, 0.02347, 0.02396, 0.02412,
                         0.02464, 0.02532, 0.02519, 0.02566, 0.02575, 0.02575, 0.02602,
                         0.02610, 0.02607, 0.02603, 0.02612, 0.02613, 0.02636, 0.02671, 0.02617],
                        [0.02410, 0.02426, 0.02438, 0.02455, 0.02519, 0.02557, 0.02539,
                         0.02541, 0.02522, 0.02499, 0.02531, 0.02576, 0.02583, 0.02654,
                         0.02719, 0.02774, 0.02817, 0.02850, 0.02831, 0.02844, 0.02853,
                         0.02847, 0.02859, 0.02878, 0.02870, 0.02882, 0.02885, 0.02916, 0.02861],
                        [0.02647, 0.02661, 0.02665, 0.02707, 0.02772, 0.02768, 0.02781,
                         0.02788, 0.02754, 0.02780, 0.02803, 0.02820, 0.02823, 0.02941,
                         0.03011, 0.03074, 0.03130, 0.03173, 0.03158, 0.03184, 0.03175,
                         0.03149, 0.03149, 0.03189, 0.03192, 0.03202, 0.03218, 0.03233, 0.03174],
                        [0.02951, 0.02969, 0.02972, 0.03046, 0.03064, 0.03068, 0.03071,
                         0.03081, 0.03068, 0.03102, 0.03104, 0.03122, 0.03158, 0.03266,
                         0.03377, 0.03427, 0.03469, 0.03553, 0.03550, 0.03565, 0.03567,
                         0.03543, 0.03539, 0.03555, 0.03592, 0.03580, 0.03622, 0.03644, 0.03565],
                        [0.03310, 0.03349, 0.03360, 0.03438, 0.03449, 0.03472, 0.03465,
                         0.03459, 0.03455, 0.03470, 0.03459, 0.03526, 0.03579, 0.03674,
                         0.03813, 0.03868, 0.03919, 0.04021, 0.04023, 0.04012, 0.04006,
                         0.04035, 0.04036, 0.04024, 0.04081, 0.04053, 0.04098, 0.04151, 0.04040],
                        [0.03740, 0.03789, 0.03804, 0.03867, 0.03944, 0.03966, 0.03954,
                         0.03957, 0.03920, 0.03925, 0.03928, 0.04008, 0.04095, 0.04200,
                         0.04318, 0.04444, 0.04503, 0.04597, 0.04623, 0.04583, 0.04569,
                         0.04621, 0.04608, 0.04621, 0.04647, 0.04655, 0.04657, 0.04737, 0.04623],
                        [0.04279, 0.04297, 0.04333, 0.04394, 0.04510, 0.04556, 0.04528,
                         0.04559, 0.04493, 0.04475, 0.04523, 0.04577, 0.04696, 0.04819,
                         0.04957, 0.05119, 0.05196, 0.05271, 0.05353, 0.05315, 0.05318,
                         0.05314, 0.05293, 0.05310, 0.05314, 0.05346, 0.05328, 0.05427, 0.05327],
                        [0.04933, 0.04944, 0.05020, 0.05067, 0.05174, 0.05256, 0.05223,
                         0.05250, 0.05178, 0.05145, 0.05232, 0.05290, 0.05406, 0.05547,
                         0.05762, 0.05914, 0.06040, 0.06089, 0.06195, 0.06194, 0.06196,
                         0.06147, 0.06161, 0.06127, 0.06153, 0.06154, 0.06161, 0.06286, 0.06165],
                        [0.05716, 0.05749, 0.05853, 0.05880, 0.05989, 0.06087, 0.06058,
                         0.06054, 0.06002, 0.05988, 0.06047, 0.06148, 0.06284, 0.06449,
                         0.06718, 0.06881, 0.07054, 0.07120, 0.07186, 0.07201, 0.07185,
                         0.07160, 0.07193, 0.07138, 0.07175, 0.07184, 0.07194, 0.07326, 0.07187],
                        [0.06672, 0.06688, 0.06803, 0.06878, 0.07001, 0.07081, 0.07047,
                         0.07024, 0.07006, 0.07013, 0.07011, 0.07164, 0.07336, 0.07549,
                         0.07820, 0.08021, 0.08229, 0.08334, 0.08368, 0.08381, 0.08372,
                         0.08378, 0.08371, 0.08345, 0.08385, 0.08427, 0.08424, 0.08536, 0.08416],
                        [0.07779, 0.07757, 0.07889, 0.08058, 0.08189, 0.08246, 0.08210,
                         0.08185, 0.08164, 0.08183, 0.08182, 0.08359, 0.08546, 0.08822,
                         0.09071, 0.09338, 0.09578, 0.09701, 0.09772, 0.09766, 0.09788,
                         0.09782, 0.09736, 0.09736, 0.09808, 0.09825, 0.09851, 0.09964, 0.09832],
                        [0.09024, 0.09020, 0.09155, 0.09357, 0.09530, 0.09572, 0.09557,
                         0.09542, 0.09475, 0.09497, 0.09557, 0.09732, 0.09935, 0.10237,
                         0.10518, 0.10869, 0.11125, 0.11277, 0.11385, 0.11370, 0.11377,
                         0.11365, 0.11330, 0.11344, 0.11407, 0.11404, 0.11480, 0.11632, 0.11432],
                        [0.10482, 0.10506, 0.10648, 0.10814, 0.11063, 0.11083, 0.11098,
                         0.11090, 0.11013, 0.11015, 0.11102, 0.11287, 0.11523, 0.11846,
                         0.12221, 0.12617, 0.12881, 0.13073, 0.13170, 0.13193, 0.13133,
                         0.13134, 0.13142, 0.13162, 0.13168, 0.13221, 0.13306, 0.13495, 0.13249],
                        [0.12186, 0.12183, 0.12353, 0.12500, 0.12774, 0.12817, 0.12823,
                         0.12810, 0.12788, 0.12756, 0.12810, 0.13017, 0.13310, 0.13691,
                         0.14145, 0.14519, 0.14815, 0.15058, 0.15136, 0.15206, 0.15115,
                         0.15108, 0.15139, 0.15140, 0.15171, 0.15261, 0.15341, 0.15562, 0.15317],
                        [0.14054, 0.14037, 0.14220, 0.14408, 0.14654, 0.14760, 0.14719,
                         0.14697, 0.14713, 0.14691, 0.14720, 0.14929, 0.15291, 0.15746,
                         0.16217, 0.16596, 0.16960, 0.17228, 0.17323, 0.17416, 0.17354,
                         0.17313, 0.17336, 0.17336, 0.17419, 0.17504, 0.17595, 0.17861, 0.17580],
                        [0.16046, 0.16065, 0.16235, 0.16496, 0.16744, 0.16884, 0.16826,
                         0.16797, 0.16793, 0.16805, 0.16858, 0.17063, 0.17473, 0.17985,
                         0.18466, 0.18930, 0.19354, 0.19597, 0.19746, 0.19824, 0.19778,
                         0.19746, 0.19757, 0.19811, 0.19862, 0.19981, 0.20070, 0.20367, 0.20020],
                        [0.18242, 0.18301, 0.18467, 0.18781, 0.19058, 0.19192, 0.19164,
                         0.19149, 0.19117, 0.19092, 0.19206, 0.19448, 0.19860, 0.20420,
                         0.20958, 0.21508, 0.21962, 0.22203, 0.22371, 0.22425, 0.22362,
                         0.22400, 0.22384, 0.22499, 0.22533, 0.22662, 0.22765, 0.23075, 0.22679],
                        [0.20730, 0.20788, 0.20966, 0.21307, 0.21621, 0.21720, 0.21730,
                         0.21733, 0.21694, 0.21602, 0.21777, 0.22085, 0.22485, 0.23078,
                         0.23716, 0.24288, 0.24779, 0.25092, 0.25232, 0.25277, 0.25226,
                         0.25272, 0.25248, 0.25364, 0.25458, 0.25541, 0.25691, 0.26036, 0.25550],
                        [0.23496, 0.23508, 0.23708, 0.24059, 0.24451, 0.24528, 0.24548,
                         0.24523, 0.24511, 0.24417, 0.24606, 0.24934, 0.25400, 0.26017,
                         0.26743, 0.27332, 0.27872, 0.28255, 0.28389, 0.28427, 0.28434,
                         0.28391, 0.28398, 0.28486, 0.28634, 0.28707, 0.28880, 0.29282, 0.28673],
                        [0.26463, 0.26446, 0.26691, 0.27060, 0.27511, 0.27617, 0.27624,
                         0.27584, 0.27568, 0.27532, 0.27677, 0.28005, 0.28579, 0.29256,
                         0.30025, 0.30675, 0.31253, 0.31631, 0.31825, 0.31851, 0.31885,
                         0.31806, 0.31827, 0.31911, 0.32029, 0.32143, 0.32326, 0.32741, 0.32071],
                        [0.29680, 0.29695, 0.29968, 0.30384, 0.30852, 0.31002, 0.30995,
                         0.30989, 0.30918, 0.30938, 0.31054, 0.31380, 0.32024, 0.32793,
                         0.33606, 0.34313, 0.34945, 0.35310, 0.35585, 0.35597, 0.35581,
                         0.35518, 0.35550, 0.35607, 0.35695, 0.35812, 0.36029, 0.36441, 0.35713],
                        [0.33294, 0.33356, 0.33623, 0.34090, 0.34597, 0.34729, 0.34750,
                         0.34743, 0.34645, 0.34658, 0.34793, 0.35138, 0.35843, 0.36674,
                         0.37549, 0.38349, 0.39034, 0.39447, 0.39724, 0.39736, 0.39647,
                         0.39572, 0.39601, 0.39624, 0.39736, 0.39838, 0.40040, 0.40490, 0.39616],
                        [0.37330, 0.37403, 0.37701, 0.38191, 0.38719, 0.38802, 0.38876,
                         0.38865, 0.38753, 0.38704, 0.38859, 0.39323, 0.40034, 0.40918,
                         0.41847, 0.42776, 0.43479, 0.43963, 0.44182, 0.44221, 0.44073,
                         0.44007, 0.43967, 0.44007, 0.44123, 0.44239, 0.44385, 0.44854, 0.43835],
                        [0.41674, 0.41768, 0.42107, 0.42656, 0.43135, 0.43257, 0.43327,
                         0.43332, 0.43209, 0.43132, 0.43297, 0.43837, 0.44534, 0.45500,
                         0.46502, 0.47479, 0.48208, 0.48730, 0.48897, 0.48972, 0.48807,
                         0.48744, 0.48640, 0.48676, 0.48800, 0.48883, 0.49039, 0.49481, 0.48338],
                        [0.46315, 0.46422, 0.46771, 0.47443, 0.47882, 0.48102, 0.48124,
                         0.48089, 0.47976, 0.47941, 0.48084, 0.48601, 0.49376, 0.50378,
                         0.51462, 0.52421, 0.53203, 0.53723, 0.53921, 0.53964, 0.53808,
                         0.53690, 0.53610, 0.53593, 0.53714, 0.53731, 0.53920, 0.54342, 0.53009],
                        [0.51343, 0.51369, 0.51750, 0.52455, 0.52990, 0.53209, 0.53244,
                         0.53133, 0.53035, 0.53009, 0.53105, 0.53653, 0.54497, 0.55499,
                         0.56622, 0.57577, 0.58395, 0.58944, 0.59200, 0.59162, 0.58982,
                         0.58804, 0.58777, 0.58740, 0.58795, 0.58795, 0.58966, 0.59376, 0.57821],
                        [0.56654, 0.56616, 0.57036, 0.57648, 0.58360, 0.58495, 0.58564,
                         0.58456, 0.58336, 0.58261, 0.58391, 0.58953, 0.59791, 0.60813,
                         0.61930, 0.62923, 0.63708, 0.64299, 0.64542, 0.64448, 0.64239,
                         0.64038, 0.63981, 0.64000, 0.63990, 0.64006, 0.64160, 0.64523, 0.62747],
                        [0.62009, 0.62044, 0.62466, 0.63039, 0.63783, 0.63885, 0.63914,
                         0.63871, 0.63714, 0.63602, 0.63806, 0.64308, 0.65150, 0.66156,
                         0.67257, 0.68281, 0.69002, 0.69538, 0.69793, 0.69662, 0.69457,
                         0.69265, 0.69119, 0.69191, 0.69153, 0.69211, 0.69304, 0.69634, 0.67602],
                        [0.67330, 0.67445, 0.67843, 0.68476, 0.69093, 0.69237, 0.69235,
                         0.69188, 0.69019, 0.68912, 0.69066, 0.69550, 0.70420, 0.71384,
                         0.72420, 0.73399, 0.74109, 0.74531, 0.74813, 0.74709, 0.74497,
                         0.74345, 0.74141, 0.74175, 0.74125, 0.74223, 0.74210, 0.74525, 0.72235],
                        [0.72585, 0.72662, 0.73048, 0.73688, 0.74209, 0.74367, 0.74404,
                         0.74318, 0.74132, 0.74090, 0.74125, 0.74646, 0.75459, 0.76387,
                         0.77313, 0.78208, 0.78903, 0.79256, 0.79473, 0.79472, 0.79252,
                         0.79113, 0.78929, 0.78865, 0.78815, 0.78894, 0.78872, 0.79145, 0.76614],
                        [0.77549, 0.77567, 0.77910, 0.78475, 0.78967, 0.79083, 0.79135,
                         0.79095, 0.78934, 0.78916, 0.78923, 0.79443, 0.80080, 0.80953,
                         0.81815, 0.82616, 0.83205, 0.83553, 0.83669, 0.83721, 0.83542,
                         0.83380, 0.83227, 0.83111, 0.83100, 0.83104, 0.83135, 0.83378, 0.80563],
                        [0.82004, 0.82066, 0.82290, 0.82822, 0.83257, 0.83341, 0.83411,
                         0.83430, 0.83288, 0.83193, 0.83287, 0.83669, 0.84223, 0.84983,
                         0.85785, 0.86448, 0.86950, 0.87264, 0.87356, 0.87349, 0.87210,
                         0.87054, 0.86908, 0.86834, 0.86890, 0.86773, 0.86818, 0.87041, 0.83990],
                        [0.85896, 0.85995, 0.86175, 0.86670, 0.87032, 0.87112, 0.87204,
                         0.87222, 0.87010, 0.86891, 0.87048, 0.87287, 0.87822, 0.88432,
                         0.89100, 0.89622, 0.90091, 0.90297, 0.90451, 0.90344, 0.90252,
                         0.90104, 0.90030, 0.89987, 0.90046, 0.89886, 0.89927, 0.90106, 0.86861],
                        [0.89161, 0.89227, 0.89410, 0.89795, 0.90132, 0.90179, 0.90255,
                         0.90258, 0.90054, 0.89993, 0.90083, 0.90309, 0.90714, 0.91198,
                         0.91740, 0.92153, 0.92542, 0.92658, 0.92836, 0.92689, 0.92640,
                         0.92544, 0.92528, 0.92478, 0.92473, 0.92402, 0.92447, 0.92583, 0.89095],
                        [0.91715, 0.91782, 0.91907, 0.92177, 0.92453, 0.92473, 0.92528,
                         0.92500, 0.92479, 0.92434, 0.92430, 0.92663, 0.92943, 0.93330,
                         0.93756, 0.94093, 0.94337, 0.94437, 0.94521, 0.94497, 0.94416,
                         0.94374, 0.94333, 0.94323, 0.94293, 0.94299, 0.94316, 0.94434, 0.90783],
                        [0.93612, 0.93709, 0.93784, 0.93978, 0.94143, 0.94235, 0.94256,
                         0.94201, 0.94306, 0.94226, 0.94229, 0.94415, 0.94646, 0.94938,
                         0.95236, 0.95505, 0.95626, 0.95730, 0.95696, 0.95834, 0.95743,
                         0.95686, 0.95617, 0.95635, 0.95633, 0.95646, 0.95620, 0.95717, 0.92027],
                        [0.95067, 0.95143, 0.95202, 0.95356, 0.95458, 0.95595, 0.95611,
                         0.95566, 0.95590, 0.95524, 0.95609, 0.95707, 0.95889, 0.96075,
                         0.96294, 0.96455, 0.96585, 0.96666, 0.96625, 0.96760, 0.96704,
                         0.96696, 0.96591, 0.96601, 0.96602, 0.96610, 0.96587, 0.96625, 0.92902],
                        [0.96141, 0.96162, 0.96196, 0.96292, 0.96421, 0.96455, 0.96525,
                         0.96507, 0.96428, 0.96418, 0.96533, 0.96577, 0.96709, 0.96805,
                         0.96958, 0.97034, 0.97210, 0.97269, 0.97290, 0.97326, 0.97265,
                         0.97360, 0.97250, 0.97281, 0.97268, 0.97235, 0.97254, 0.97266, 0.93429],
                        [0.96768, 0.96776, 0.96799, 0.96793, 0.96971, 0.96921, 0.97021,
                         0.97009, 0.96970, 0.96989, 0.97044, 0.97094, 0.97194, 0.97251,
                         0.97340, 0.97403, 0.97557, 0.97594, 0.97587, 0.97594, 0.97550,
                         0.97634, 0.97621, 0.97636, 0.97633, 0.97556, 0.97604, 0.97656, 0.93682],
                        [0.97158, 0.97144, 0.97195, 0.97145, 0.97284, 0.97282, 0.97354,
                         0.97336, 0.97382, 0.97375, 0.97402, 0.97431, 0.97523, 0.97561,
                         0.97642, 0.97700, 0.97811, 0.97829, 0.97752, 0.97786, 0.97812,
                         0.97796, 0.97863, 0.97828, 0.97814, 0.97790, 0.97815, 0.97892, 0.93869],
                        [0.97508, 0.97462, 0.97500, 0.97515, 0.97543, 0.97587, 0.97654,
                         0.97648, 0.97703, 0.97644, 0.97704, 0.97709, 0.97798, 0.97843,
                         0.97908, 0.97949, 0.97996, 0.98034, 0.97996, 0.98035, 0.98053,
                         0.97997, 0.98028, 0.98059, 0.97972, 0.98007, 0.98032, 0.98072, 0.94027],
                        [0.97721, 0.97735, 0.97688, 0.97771, 0.97751, 0.97763, 0.97863,
                         0.97862, 0.97880, 0.97824, 0.97903, 0.97927, 0.97981, 0.98041,
                         0.98066, 0.98086, 0.98106, 0.98124, 0.98196, 0.98184, 0.98155,
                         0.98149, 0.98133, 0.98210, 0.98108, 0.98143, 0.98190, 0.98179, 0.94116],
                        [0.97785, 0.97842, 0.97777, 0.97856, 0.97897, 0.97857, 0.97920,
                         0.97949, 0.97946, 0.97949, 0.97978, 0.98028, 0.98044, 0.98066,
                         0.98093, 0.98082, 0.98116, 0.98089, 0.98212, 0.98144, 0.98147,
                         0.98193, 0.98199, 0.98157, 0.98148, 0.98210, 0.98210, 0.98180, 0.94153],
                        [0.97849, 0.97866, 0.97904, 0.97887, 0.97990, 0.97960, 0.97935,
                         0.98016, 0.97988, 0.98024, 0.97985, 0.98066, 0.98058, 0.98033,
                         0.98071, 0.98051, 0.98065, 0.98043, 0.98116, 0.98099, 0.98115,
                         0.98181, 0.98200, 0.98076, 0.98126, 0.98197, 0.98152, 0.98149, 0.94142],
                        [0.97975, 0.97999, 0.98070, 0.97956, 0.98066, 0.98061, 0.98072,
                         0.98103, 0.98051, 0.98076, 0.98068, 0.98130, 0.98134, 0.98098,
                         0.98097, 0.98115, 0.98111, 0.98104, 0.98085, 0.98149, 0.98135,
                         0.98173, 0.98180, 0.98082, 0.98151, 0.98135, 0.98139, 0.98194, 0.94102],
                        [0.98038, 0.98117, 0.98106, 0.98033, 0.98110, 0.98070, 0.98188,
                         0.98155, 0.98131, 0.98128, 0.98177, 0.98168, 0.98210, 0.98183,
                         0.98141, 0.98147, 0.98169, 0.98170, 0.98155, 0.98197, 0.98185,
                         0.98140, 0.98195, 0.98149, 0.98208, 0.98107, 0.98150, 0.98207, 0.94078],
                        [0.98011, 0.98070, 0.98033, 0.98068, 0.98125, 0.98055, 0.98137,
                         0.98152, 0.98166, 0.98171, 0.98192, 0.98141, 0.98172, 0.98174,
                         0.98151, 0.98076, 0.98108, 0.98105, 0.98171, 0.98171, 0.98173,
                         0.98116, 0.98180, 0.98198, 0.98201, 0.98127, 0.98098, 0.98105, 0.94092],
                        [0.98024, 0.98037, 0.98028, 0.98073, 0.98112, 0.98097, 0.98051,
                         0.98099, 0.98104, 0.98162, 0.98163, 0.98115, 0.98087, 0.98118,
                         0.98113, 0.98031, 0.98046, 0.98010, 0.98112, 0.98101, 0.98093,
                         0.98148, 0.98099, 0.98171, 0.98153, 0.98122, 0.98051, 0.98029, 0.94098],
                        [0.98071, 0.98072, 0.98087, 0.98080, 0.98046, 0.98100, 0.98035,
                         0.98040, 0.98054, 0.98061, 0.98157, 0.98129, 0.98092, 0.98097,
                         0.98054, 0.98016, 0.98065, 0.98026, 0.98071, 0.98057, 0.98055,
                         0.98162, 0.98045, 0.98098, 0.98127, 0.98059, 0.98040, 0.98043, 0.94048],
                        [0.98012, 0.98062, 0.98099, 0.98039, 0.98030, 0.98041, 0.98043,
                         0.98037, 0.98117, 0.98015, 0.98122, 0.98135, 0.98120, 0.98069,
                         0.98004, 0.97988, 0.98079, 0.98045, 0.98025, 0.98033, 0.98062,
                         0.98105, 0.98034, 0.98048, 0.98110, 0.98021, 0.98020, 0.98030, 0.93963],
                        [0.97934, 0.98017, 0.98042, 0.97964, 0.98053, 0.97992, 0.98014,
                         0.98038, 0.98131, 0.98037, 0.98014, 0.98089, 0.98062, 0.97982,
                         0.97949, 0.97996, 0.98011, 0.97999, 0.97960, 0.98000, 0.98027,
                         0.98022, 0.98014, 0.98040, 0.98061, 0.97985, 0.98029, 0.97999, 0.93910],
                        [0.97962, 0.97961, 0.97960, 0.97949, 0.98015, 0.97968, 0.98014,
                         0.98003, 0.98006, 0.97985, 0.97959, 0.98026, 0.98009, 0.97942,
                         0.97935, 0.98022, 0.97963, 0.97993, 0.97964, 0.98011, 0.97997,
                         0.97984, 0.98015, 0.98028, 0.98004, 0.97957, 0.98037, 0.98027, 0.93917],
                        [0.98005, 0.97900, 0.97900, 0.97971, 0.97940, 0.97969, 0.98028,
                         0.97958, 0.97947, 0.97960, 0.98001, 0.98003, 0.98010, 0.97999,
                         0.97977, 0.97987, 0.98030, 0.98054, 0.98054, 0.98050, 0.98041,
                         0.98014, 0.98034, 0.98009, 0.98001, 0.97987, 0.97994, 0.98036, 0.93933],
                        [0.97959, 0.97891, 0.97884, 0.97952, 0.97896, 0.97978, 0.97964,
                         0.97953, 0.97978, 0.97987, 0.98001, 0.98008, 0.98002, 0.97993,
                         0.98014, 0.97960, 0.98097, 0.98073, 0.98080, 0.98031, 0.98066,
                         0.98036, 0.98017, 0.98015, 0.98067, 0.98002, 0.97985, 0.97996, 0.93937],
                        [0.97915, 0.97927, 0.97895, 0.97872, 0.97902, 0.97986, 0.97917,
                         0.97954, 0.97959, 0.97973, 0.97969, 0.98024, 0.97979, 0.97944,
                         0.98026, 0.98005, 0.98087, 0.98016, 0.98021, 0.98005, 0.98016,
                         0.98047, 0.98034, 0.98029, 0.98093, 0.97985, 0.98056, 0.98014, 0.93974],
                        [0.97975, 0.97939, 0.97904, 0.97859, 0.97956, 0.97975, 0.97959,
                         0.97916, 0.97958, 0.97972, 0.98011, 0.98044, 0.97985, 0.97995,
                         0.98047, 0.98063, 0.98079, 0.98005, 0.98012, 0.98049, 0.98020,
                         0.98095, 0.98106, 0.98048, 0.98092, 0.98013, 0.98095, 0.98096, 0.94047],
                        [0.98023, 0.97921, 0.97964, 0.97989, 0.98020, 0.97967, 0.98040,
                         0.97958, 0.98046, 0.98042, 0.98080, 0.98085, 0.98058, 0.98065,
                         0.98083, 0.98091, 0.98124, 0.98109, 0.98068, 0.98138, 0.98114,
                         0.98158, 0.98147, 0.98125, 0.98149, 0.98099, 0.98069, 0.98116, 0.94110],
                        [0.97960, 0.97914, 0.98025, 0.98053, 0.98035, 0.98007, 0.98056,
                         0.98050, 0.98087, 0.98063, 0.98092, 0.98119, 0.98115, 0.98050,
                         0.98086, 0.98074, 0.98139, 0.98185, 0.98121, 0.98169, 0.98153,
                         0.98176, 0.98140, 0.98158, 0.98132, 0.98159, 0.98048, 0.98073, 0.94095],
                        [0.97938, 0.97967, 0.98014, 0.97999, 0.98012, 0.98056, 0.98016,
                         0.98053, 0.98061, 0.98014, 0.98079, 0.98113, 0.98104, 0.98044,
                         0.98086, 0.98068, 0.98133, 0.98144, 0.98147, 0.98142, 0.98148,
                         0.98177, 0.98150, 0.98121, 0.98062, 0.98150, 0.98061, 0.98067, 0.94042],
                        [0.98017, 0.98040, 0.98031, 0.98001, 0.98040, 0.98079, 0.98041,
                         0.98013, 0.98079, 0.98032, 0.98079, 0.98106, 0.98104, 0.98114,
                         0.98127, 0.98123, 0.98169, 0.98084, 0.98116, 0.98145, 0.98154,
                         0.98195, 0.98167, 0.98162, 0.98097, 0.98150, 0.98132, 0.98128, 0.94096],
                        [0.98067, 0.98046, 0.98052, 0.98048, 0.98089, 0.98062, 0.98076,
                         0.98031, 0.98069, 0.98068, 0.98051, 0.98099, 0.98115, 0.98155,
                         0.98152, 0.98137, 0.98151, 0.98047, 0.98038, 0.98134, 0.98094,
                         0.98154, 0.98132, 0.98211, 0.98138, 0.98137, 0.98153, 0.98175, 0.94148],
                        [0.98044, 0.98002, 0.98025, 0.98013, 0.98091, 0.98040, 0.98060,
                         0.98100, 0.98019, 0.98068, 0.98023, 0.98105, 0.98139, 0.98136,
                         0.98110, 0.98091, 0.98087, 0.98008, 0.97988, 0.98073, 0.98031,
                         0.98067, 0.98122, 0.98176, 0.98088, 0.98073, 0.98081, 0.98161, 0.94073],
                        [0.97989, 0.97954, 0.98002, 0.97921, 0.98031, 0.98019, 0.98034,
                         0.98079, 0.98034, 0.98062, 0.98052, 0.98112, 0.98130, 0.98085,
                         0.98020, 0.98045, 0.98032, 0.97990, 0.98005, 0.98035, 0.98043,
                         0.98053, 0.98132, 0.98094, 0.98000, 0.98043, 0.98020, 0.98087, 0.93973],
                        [0.97983, 0.97979, 0.97997, 0.97928, 0.97988, 0.97984, 0.98019,
                         0.98021, 0.98080, 0.98054, 0.98083, 0.98077, 0.98077, 0.98027,
                         0.97989, 0.97997, 0.97996, 0.98017, 0.98060, 0.98038, 0.98090,
                         0.98108, 0.98098, 0.98045, 0.97993, 0.98070, 0.98049, 0.98019, 0.93936],
                        [0.98030, 0.98059, 0.98005, 0.98014, 0.98033, 0.98006, 0.98040,
                         0.98028, 0.98077, 0.98053, 0.98081, 0.98039, 0.98092, 0.98019,
                         0.98056, 0.97982, 0.98029, 0.98066, 0.98092, 0.98071, 0.98126,
                         0.98123, 0.98081, 0.98074, 0.98102, 0.98069, 0.98122, 0.98008, 0.93974],
                        [0.97996, 0.98009, 0.97958, 0.97961, 0.97958, 0.97990, 0.97994,
                         0.97991, 0.98008, 0.97993, 0.98030, 0.98019, 0.98094, 0.97985,
                         0.98018, 0.97976, 0.98036, 0.98010, 0.98023, 0.98057, 0.98062,
                         0.98024, 0.98030, 0.98066, 0.98115, 0.98008, 0.98062, 0.97962, 0.94013],
                        [0.97882, 0.97877, 0.97882, 0.97860, 0.97798, 0.97893, 0.97872,
                         0.97904, 0.97933, 0.97906, 0.97980, 0.97986, 0.98001, 0.97909,
                         0.97895, 0.97928, 0.97975, 0.97894, 0.97932, 0.97953, 0.97946,
                         0.97930, 0.97932, 0.97987, 0.97965, 0.97981, 0.97918, 0.97933, 0.93977],
                        [0.97825, 0.97822, 0.97853, 0.97902, 0.97801, 0.97856, 0.97811,
                         0.97875, 0.97904, 0.97875, 0.97961, 0.97954, 0.97952, 0.97882,
                         0.97862, 0.97886, 0.97934, 0.97871, 0.97929, 0.97889, 0.97917,
                         0.97963, 0.97917, 0.97978, 0.97875, 0.97985, 0.97897, 0.98003, 0.93922],
                        [0.97808, 0.97827, 0.97800, 0.97905, 0.97840, 0.97827, 0.97791,
                         0.97874, 0.97855, 0.97836, 0.97893, 0.97879, 0.97915, 0.97890,
                         0.97871, 0.97895, 0.97884, 0.97918, 0.97936, 0.97896, 0.97941,
                         0.98014, 0.97969, 0.98007, 0.97924, 0.97935, 0.97952, 0.98015, 0.93882],
                        [0.97722, 0.97797, 0.97726, 0.97756, 0.97755, 0.97719, 0.97740,
                         0.97789, 0.97758, 0.97769, 0.97817, 0.97769, 0.97801, 0.97858,
                         0.97833, 0.97863, 0.97820, 0.97882, 0.97867, 0.97878, 0.97888,
                         0.97951, 0.97946, 0.97944, 0.97946, 0.97859, 0.97944, 0.97917, 0.93833],
                        [0.97636, 0.97726, 0.97689, 0.97645, 0.97651, 0.97635, 0.97691,
                         0.97683, 0.97703, 0.97720, 0.97779, 0.97721, 0.97754, 0.97825,
                         0.97757, 0.97757, 0.97818, 0.97777, 0.97799, 0.97837, 0.97811,
                         0.97840, 0.97856, 0.97866, 0.97887, 0.97841, 0.97889, 0.97884, 0.93804],
                        [0.97642, 0.97673, 0.97669, 0.97649, 0.97637, 0.97638, 0.97661,
                         0.97685, 0.97704, 0.97717, 0.97784, 0.97759, 0.97790, 0.97813,
                         0.97722, 0.97717, 0.97831, 0.97766, 0.97837, 0.97829, 0.97832,
                         0.97828, 0.97835, 0.97864, 0.97867, 0.97885, 0.97848, 0.97917, 0.93810],
                        [0.97636, 0.97644, 0.97636, 0.97640, 0.97658, 0.97653, 0.97624,
                         0.97729, 0.97685, 0.97726, 0.97786, 0.97792, 0.97785, 0.97741,
                         0.97750, 0.97759, 0.97761, 0.97828, 0.97896, 0.97816, 0.97869,
                         0.97864, 0.97892, 0.97872, 0.97911, 0.97904, 0.97818, 0.97918, 0.93827],
                        [0.97543, 0.97631, 0.97538, 0.97585, 0.97630, 0.97624, 0.97560,
                         0.97675, 0.97645, 0.97668, 0.97726, 0.97751, 0.97745, 0.97654,
                         0.97761, 0.97762, 0.97690, 0.97803, 0.97840, 0.97754, 0.97853,
                         0.97816, 0.97909, 0.97849, 0.97907, 0.97842, 0.97796, 0.97875, 0.93831],
                        [0.97444, 0.97584, 0.97442, 0.97541, 0.97524, 0.97558, 0.97505,
                         0.97576, 0.97608, 0.97613, 0.97642, 0.97657, 0.97682, 0.97649,
                         0.97727, 0.97674, 0.97698, 0.97729, 0.97702, 0.97716, 0.97799,
                         0.97749, 0.97847, 0.97807, 0.97820, 0.97785, 0.97799, 0.97792, 0.93779],
                        [0.97455, 0.97483, 0.97457, 0.97507, 0.97434, 0.97501, 0.97520,
                         0.97536, 0.97568, 0.97592, 0.97584, 0.97578, 0.97589, 0.97661,
                         0.97688, 0.97617, 0.97685, 0.97696, 0.97632, 0.97720, 0.97724,
                         0.97755, 0.97783, 0.97764, 0.97762, 0.97760, 0.97797, 0.97718, 0.93713],
                        [0.97496, 0.97413, 0.97474, 0.97484, 0.97434, 0.97457, 0.97539,
                         0.97521, 0.97520, 0.97555, 0.97569, 0.97581, 0.97541, 0.97609,
                         0.97654, 0.97663, 0.97629, 0.97652, 0.97662, 0.97690, 0.97665,
                         0.97728, 0.97720, 0.97715, 0.97757, 0.97702, 0.97769, 0.97688, 0.93716],
                        [0.97435, 0.97378, 0.97440, 0.97454, 0.97458, 0.97432, 0.97493,
                         0.97499, 0.97481, 0.97519, 0.97579, 0.97583, 0.97595, 0.97563,
                         0.97630, 0.97682, 0.97602, 0.97609, 0.97702, 0.97625, 0.97655,
                         0.97675, 0.97641, 0.97654, 0.97737, 0.97661, 0.97729, 0.97686, 0.93732],
                        [0.97348, 0.97356, 0.97437, 0.97449, 0.97450, 0.97473, 0.97474,
                         0.97463, 0.97484, 0.97523, 0.97583, 0.97552, 0.97667, 0.97562,
                         0.97596, 0.97630, 0.97627, 0.97581, 0.97715, 0.97618, 0.97713,
                         0.97689, 0.97636, 0.97676, 0.97699, 0.97695, 0.97693, 0.97704, 0.93719],
                        [0.97358, 0.97398, 0.97439, 0.97491, 0.97449, 0.97515, 0.97534,
                         0.97458, 0.97549, 0.97586, 0.97602, 0.97571, 0.97642, 0.97559,
                         0.97574, 0.97593, 0.97663, 0.97602, 0.97681, 0.97690, 0.97753,
                         0.97713, 0.97728, 0.97768, 0.97685, 0.97760, 0.97696, 0.97703, 0.93736],
                        [0.97472, 0.97472, 0.97441, 0.97512, 0.97475, 0.97492, 0.97556,
                         0.97527, 0.97599, 0.97644, 0.97638, 0.97612, 0.97566, 0.97587,
                         0.97624, 0.97605, 0.97642, 0.97688, 0.97641, 0.97772, 0.97718,
                         0.97736, 0.97785, 0.97776, 0.97686, 0.97775, 0.97733, 0.97711, 0.93755],
                        [0.97529, 0.97496, 0.97443, 0.97469, 0.97471, 0.97467, 0.97503,
                         0.97540, 0.97555, 0.97649, 0.97627, 0.97593, 0.97539, 0.97642,
                         0.97663, 0.97666, 0.97608, 0.97697, 0.97650, 0.97744, 0.97690,
                         0.97745, 0.97747, 0.97699, 0.97679, 0.97717, 0.97722, 0.97747, 0.93733],
                        [0.97483, 0.97506, 0.97465, 0.97444, 0.97499, 0.97523, 0.97499,
                         0.97501, 0.97528, 0.97662, 0.97604, 0.97600, 0.97595, 0.97693,
                         0.97668, 0.97755, 0.97636, 0.97678, 0.97705, 0.97654, 0.97733,
                         0.97746, 0.97738, 0.97699, 0.97733, 0.97716, 0.97717, 0.97774, 0.93735],
                        [0.97501, 0.97580, 0.97579, 0.97530, 0.97591, 0.97658, 0.97602,
                         0.97601, 0.97614, 0.97700, 0.97676, 0.97713, 0.97729, 0.97734,
                         0.97720, 0.97811, 0.97737, 0.97772, 0.97787, 0.97713, 0.97832,
                         0.97784, 0.97793, 0.97818, 0.97839, 0.97829, 0.97818, 0.97818, 0.93793],
                        [0.97646, 0.97706, 0.97714, 0.97688, 0.97674, 0.97766, 0.97735,
                         0.97802, 0.97754, 0.97757, 0.97763, 0.97846, 0.97876, 0.97788,
                         0.97796, 0.97860, 0.97866, 0.97925, 0.97885, 0.97866, 0.97928,
                         0.97899, 0.97848, 0.97941, 0.97898, 0.97932, 0.97923, 0.97884, 0.93848],
                        [0.97734, 0.97759, 0.97759, 0.97802, 0.97738, 0.97800, 0.97835,
                         0.97870, 0.97830, 0.97799, 0.97796, 0.97878, 0.97898, 0.97833,
                         0.97846, 0.97912, 0.97901, 0.97967, 0.97919, 0.97921, 0.97952,
                         0.97978, 0.97891, 0.97965, 0.97902, 0.97925, 0.97914, 0.97891, 0.93879],
                        [0.97749, 0.97743, 0.97804, 0.97835, 0.97831, 0.97817, 0.97869,
                         0.97838, 0.97851, 0.97835, 0.97876, 0.97877, 0.97868, 0.97854,
                         0.97887, 0.97937, 0.97890, 0.97898, 0.97903, 0.97930, 0.97926,
                         0.97931, 0.97951, 0.97947, 0.97947, 0.97926, 0.97879, 0.97889, 0.93927],
                        [0.97831, 0.97799, 0.97894, 0.97846, 0.97911, 0.97876, 0.97869,
                         0.97862, 0.97931, 0.97913, 0.97954, 0.97926, 0.97925, 0.97948,
                         0.97952, 0.97972, 0.97948, 0.97923, 0.97949, 0.98002, 0.97936,
                         0.97924, 0.98002, 0.97991, 0.98029, 0.98019, 0.97948, 0.97961, 0.93975],
                        [0.97910, 0.97910, 0.97911, 0.97897, 0.97927, 0.97944, 0.97894,
                         0.97955, 0.98002, 0.97984, 0.97966, 0.97981, 0.97990, 0.98058,
                         0.97997, 0.98010, 0.97994, 0.98040, 0.98027, 0.98067, 0.98010,
                         0.98020, 0.98017, 0.98070, 0.98065, 0.98043, 0.98067, 0.98032, 0.94006],
                        [0.97920, 0.97942, 0.97876, 0.97946, 0.97920, 0.97964, 0.97936,
                         0.98010, 0.97965, 0.98004, 0.97978, 0.97999, 0.98015, 0.98034,
                         0.97991, 0.98012, 0.97990, 0.98064, 0.98012, 0.98088, 0.98102,
                         0.98089, 0.98033, 0.98091, 0.98045, 0.97968, 0.98096, 0.98064, 0.94047],
                        [0.97963, 0.97953, 0.97945, 0.98003, 0.97978, 0.97999, 0.97991,
                         0.98017, 0.97960, 0.98016, 0.98012, 0.98003, 0.98083, 0.98026,
                         0.98019, 0.98006, 0.98042, 0.98070, 0.97998, 0.98107, 0.98150,
                         0.98136, 0.98129, 0.98095, 0.98076, 0.98010, 0.98066, 0.98105, 0.94106],
                        [0.98019, 0.98024, 0.98018, 0.98046, 0.98082, 0.98084, 0.98058,
                         0.98011, 0.98044, 0.98053, 0.98052, 0.98010, 0.98145, 0.98134,
                         0.98067, 0.98031, 0.98126, 0.98138, 0.98075, 0.98109, 0.98134,
                         0.98190, 0.98213, 0.98139, 0.98159, 0.98132, 0.98087, 0.98114, 0.94145],
                        [0.98009, 0.98077, 0.97987, 0.98024, 0.98103, 0.98079, 0.98090,
                         0.98009, 0.98098, 0.98095, 0.98084, 0.98044, 0.98099, 0.98182,
                         0.98063, 0.98076, 0.98137, 0.98157, 0.98129, 0.98099, 0.98079,
                         0.98186, 0.98180, 0.98156, 0.98174, 0.98159, 0.98129, 0.98110, 0.94138],
                        [0.97995, 0.98065, 0.97989, 0.98016, 0.98031, 0.97994, 0.98054,
                         0.98053, 0.98092, 0.98087, 0.98087, 0.98128, 0.98069, 0.98147,
                         0.98063, 0.98100, 0.98103, 0.98109, 0.98111, 0.98126, 0.98041,
                         0.98169, 0.98115, 0.98148, 0.98128, 0.98136, 0.98144, 0.98165, 0.94101],
                        [0.98013, 0.98022, 0.98035, 0.98037, 0.98015, 0.97970, 0.97994,
                         0.98098, 0.98085, 0.98048, 0.98080, 0.98162, 0.98117, 0.98088,
                         0.98099, 0.98091, 0.98071, 0.98060, 0.98088, 0.98158, 0.98089,
                         0.98182, 0.98093, 0.98164, 0.98134, 0.98143, 0.98145, 0.98174, 0.94075],
                        [0.98014, 0.98005, 0.98020, 0.98043, 0.98073, 0.98002, 0.98019,
                         0.98134, 0.98122, 0.98066, 0.98076, 0.98124, 0.98118, 0.98027,
                         0.98126, 0.98065, 0.98051, 0.98045, 0.98085, 0.98151, 0.98196,
                         0.98158, 0.98129, 0.98179, 0.98172, 0.98147, 0.98177, 0.98122, 0.94108],
                        [0.98003, 0.98017, 0.98011, 0.98041, 0.98081, 0.98046, 0.98097,
                         0.98112, 0.98128, 0.98099, 0.98079, 0.98096, 0.98069, 0.98035,
                         0.98097, 0.98074, 0.98070, 0.98071, 0.98070, 0.98105, 0.98216,
                         0.98109, 0.98162, 0.98163, 0.98173, 0.98137, 0.98213, 0.98125, 0.94179],
                        [0.97955, 0.98026, 0.98045, 0.98017, 0.97996, 0.98056, 0.98097,
                         0.98014, 0.98079, 0.98087, 0.98099, 0.98082, 0.98068, 0.98084,
                         0.98024, 0.98066, 0.98072, 0.98064, 0.98073, 0.98046, 0.98118,
                         0.98103, 0.98141, 0.98129, 0.98145, 0.98142, 0.98167, 0.98128, 0.94204],
                        [0.97921, 0.98013, 0.98063, 0.97990, 0.97957, 0.98028, 0.98048,
                         0.97969, 0.98065, 0.98063, 0.98121, 0.98076, 0.98101, 0.98134,
                         0.98020, 0.98032, 0.98060, 0.98042, 0.98107, 0.98056, 0.98063,
                         0.98147, 0.98122, 0.98145, 0.98130, 0.98144, 0.98087, 0.98112, 0.94191],
                        [0.97940, 0.97947, 0.98039, 0.97987, 0.97997, 0.97980, 0.98002,
                         0.97988, 0.98046, 0.98013, 0.98075, 0.98067, 0.98062, 0.98117,
                         0.98050, 0.98000, 0.98069, 0.98036, 0.98079, 0.98106, 0.98058,
                         0.98157, 0.98116, 0.98137, 0.98105, 0.98110, 0.98041, 0.98093, 0.94133],
                        [0.97902, 0.97887, 0.97941, 0.97953, 0.97976, 0.97919, 0.97926,
                         0.97972, 0.97978, 0.97955, 0.97949, 0.98034, 0.97954, 0.98011,
                         0.98003, 0.97967, 0.97986, 0.97986, 0.97988, 0.98085, 0.98018,
                         0.98056, 0.98072, 0.98054, 0.98018, 0.98091, 0.98021, 0.98070, 0.94041],
                        [0.97830, 0.97904, 0.97869, 0.97849, 0.97911, 0.97908, 0.97878,
                         0.97955, 0.97940, 0.97954, 0.97892, 0.97980, 0.97905, 0.97927,
                         0.97970, 0.97984, 0.97895, 0.97953, 0.97954, 0.97986, 0.97982,
                         0.97971, 0.98019, 0.98013, 0.97946, 0.98070, 0.98015, 0.98079, 0.94011],
                        [0.97847, 0.97929, 0.97904, 0.97807, 0.97935, 0.97955, 0.97926,
                         0.97981, 0.97985, 0.98010, 0.97973, 0.97982, 0.97977, 0.97941,
                         0.98010, 0.98034, 0.97955, 0.97976, 0.98014, 0.97938, 0.98023,
                         0.98034, 0.98042, 0.98046, 0.97996, 0.98027, 0.98052, 0.98080, 0.94054],
                        [0.97911, 0.97904, 0.97923, 0.97911, 0.97954, 0.97966, 0.97954,
                         0.97971, 0.98027, 0.98002, 0.98015, 0.98033, 0.98037, 0.97963,
                         0.98005, 0.98020, 0.98015, 0.97963, 0.98029, 0.97992, 0.98070,
                         0.98074, 0.98049, 0.98053, 0.98071, 0.98002, 0.98053, 0.98025, 0.94091],
                        [0.97896, 0.97877, 0.97916, 0.97995, 0.97907, 0.97940, 0.97906,
                         0.97917, 0.98001, 0.97922, 0.97962, 0.98025, 0.97991, 0.97951,
                         0.97980, 0.97991, 0.97987, 0.97947, 0.97987, 0.98065, 0.98023,
                         0.98016, 0.97999, 0.98006, 0.98070, 0.97999, 0.97981, 0.97970, 0.94094],
                        [0.97855, 0.97904, 0.97952, 0.97977, 0.97910, 0.97965, 0.97927,
                         0.97932, 0.97978, 0.97925, 0.97951, 0.97981, 0.97956, 0.97980,
                         0.98008, 0.98035, 0.97999, 0.97992, 0.98024, 0.98102, 0.97997,
                         0.98021, 0.98015, 0.97999, 0.98044, 0.98013, 0.98005, 0.98004, 0.94056],
                        [0.97903, 0.97961, 0.97951, 0.97952, 0.97938, 0.98011, 0.98015,
                         0.97998, 0.97979, 0.97991, 0.98008, 0.97967, 0.98004, 0.98021,
                         0.98043, 0.98076, 0.98023, 0.98038, 0.98106, 0.98077, 0.98065,
                         0.98064, 0.98070, 0.98070, 0.98038, 0.98060, 0.98083, 0.98069, 0.94001],
                        [0.97988, 0.97977, 0.97928, 0.97974, 0.97972, 0.98024, 0.98061,
                         0.98012, 0.98030, 0.98030, 0.98064, 0.98036, 0.98107, 0.98028,
                         0.98071, 0.98104, 0.98018, 0.98024, 0.98125, 0.98044, 0.98114,
                         0.98081, 0.98103, 0.98191, 0.98052, 0.98138, 0.98091, 0.98097, 0.94012],
                        [0.98011, 0.97975, 0.98007, 0.98037, 0.98034, 0.98025, 0.98049,
                         0.98017, 0.98121, 0.98061, 0.98118, 0.98144, 0.98164, 0.98030,
                         0.98094, 0.98141, 0.98076, 0.98029, 0.98109, 0.98078, 0.98119,
                         0.98135, 0.98152, 0.98255, 0.98111, 0.98158, 0.98112, 0.98105, 0.94095],
                        [0.97991, 0.98016, 0.98112, 0.98125, 0.98069, 0.98049, 0.98065,
                         0.98067, 0.98136, 0.98109, 0.98155, 0.98165, 0.98126, 0.98079,
                         0.98120, 0.98146, 0.98157, 0.98095, 0.98144, 0.98170, 0.98165,
                         0.98220, 0.98180, 0.98187, 0.98197, 0.98136, 0.98185, 0.98138, 0.94188],
                        [0.98035, 0.98076, 0.98122, 0.98166, 0.98102, 0.98109, 0.98097,
                         0.98129, 0.98106, 0.98142, 0.98151, 0.98107, 0.98107, 0.98151,
                         0.98143, 0.98138, 0.98200, 0.98172, 0.98212, 0.98236, 0.98224,
                         0.98234, 0.98211, 0.98102, 0.98234, 0.98170, 0.98232, 0.98197, 0.94243],
                        [0.98131, 0.98113, 0.98134, 0.98122, 0.98138, 0.98150, 0.98086,
                         0.98188, 0.98142, 0.98154, 0.98150, 0.98101, 0.98167, 0.98180,
                         0.98164, 0.98185, 0.98247, 0.98239, 0.98247, 0.98236, 0.98245,
                         0.98187, 0.98292, 0.98152, 0.98253, 0.98247, 0.98238, 0.98216, 0.94288],
                        [0.98140, 0.98086, 0.98142, 0.98065, 0.98111, 0.98141, 0.98088,
                         0.98185, 0.98161, 0.98140, 0.98161, 0.98140, 0.98206, 0.98129,
                         0.98170, 0.98235, 0.98235, 0.98226, 0.98217, 0.98224, 0.98241,
                         0.98145, 0.98332, 0.98225, 0.98262, 0.98266, 0.98209, 0.98185, 0.94304],
                        [0.98091, 0.98062, 0.98043, 0.98055, 0.98087, 0.98134, 0.98117,
                         0.98162, 0.98120, 0.98121, 0.98162, 0.98175, 0.98189, 0.98083,
                         0.98155, 0.98184, 0.98153, 0.98153, 0.98175, 0.98217, 0.98193,
                         0.98141, 0.98271, 0.98199, 0.98232, 0.98221, 0.98183, 0.98164, 0.94238],
                        [0.98088, 0.98093, 0.97968, 0.98050, 0.98090, 0.98120, 0.98131,
                         0.98158, 0.98083, 0.98107, 0.98134, 0.98205, 0.98135, 0.98127,
                         0.98127, 0.98107, 0.98113, 0.98131, 0.98168, 0.98179, 0.98120,
                         0.98157, 0.98160, 0.98169, 0.98208, 0.98184, 0.98181, 0.98164, 0.94179],
                        [0.98064, 0.98086, 0.98017, 0.98012, 0.98068, 0.98048, 0.98068,
                         0.98101, 0.98084, 0.98103, 0.98088, 0.98165, 0.98086, 0.98152,
                         0.98095, 0.98083, 0.98122, 0.98135, 0.98153, 0.98144, 0.98103,
                         0.98118, 0.98132, 0.98183, 0.98186, 0.98172, 0.98161, 0.98174, 0.94191],
                        [0.97983, 0.97995, 0.98037, 0.97954, 0.98023, 0.97972, 0.97949,
                         0.97978, 0.98092, 0.98096, 0.98051, 0.98074, 0.98063, 0.98085,
                         0.98051, 0.98066, 0.98062, 0.98107, 0.98114, 0.98104, 0.98120,
                         0.98048, 0.98159, 0.98164, 0.98146, 0.98144, 0.98129, 0.98159, 0.94191],
                        [0.97919, 0.97906, 0.97966, 0.97946, 0.97967, 0.97968, 0.97920,
                         0.97892, 0.98009, 0.98016, 0.98017, 0.98044, 0.98045, 0.98008,
                         0.97979, 0.98008, 0.97943, 0.98052, 0.98058, 0.98049, 0.98063,
                         0.98030, 0.98115, 0.98086, 0.98077, 0.98101, 0.98125, 0.98112, 0.94118],
                        [0.97877, 0.97889, 0.97900, 0.97960, 0.97917, 0.97970, 0.97965,
                         0.97891, 0.97891, 0.97910, 0.97972, 0.97995, 0.97993, 0.97954,
                         0.97911, 0.97920, 0.97899, 0.97968, 0.97972, 0.98004, 0.97982,
                         0.98015, 0.98039, 0.98023, 0.98003, 0.98068, 0.98086, 0.98061, 0.94018],
                        [0.97885, 0.97929, 0.97899, 0.97922, 0.97901, 0.97927, 0.97965,
                         0.97917, 0.97901, 0.97906, 0.97935, 0.97915, 0.97956, 0.97920,
                         0.97931, 0.97901, 0.97956, 0.97945, 0.97938, 0.97999, 0.97979,
                         0.97994, 0.98044, 0.98024, 0.97998, 0.98039, 0.97998, 0.98026, 0.94016],
                        [0.97896, 0.97919, 0.97899, 0.97859, 0.97871, 0.97879, 0.97898,
                         0.97932, 0.97922, 0.97938, 0.97899, 0.97908, 0.97938, 0.97916,
                         0.97960, 0.97918, 0.97983, 0.97961, 0.97939, 0.97998, 0.97997,
                         0.98016, 0.98043, 0.98007, 0.97986, 0.98002, 0.97916, 0.97973, 0.94060],
                        [0.97840, 0.97846, 0.97837, 0.97818, 0.97827, 0.97863, 0.97811,
                         0.97900, 0.97832, 0.97910, 0.97859, 0.97910, 0.97866, 0.97884,
                         0.97907, 0.97908, 0.97915, 0.97874, 0.97890, 0.97924, 0.97949,
                         0.97996, 0.97955, 0.97949, 0.97923, 0.97961, 0.97897, 0.97909, 0.94037],
                        [0.97759, 0.97799, 0.97779, 0.97812, 0.97848, 0.97862, 0.97814,
                         0.97828, 0.97771, 0.97862, 0.97860, 0.97885, 0.97832, 0.97847,
                         0.97862, 0.97899, 0.97875, 0.97790, 0.97860, 0.97863, 0.97887,
                         0.97908, 0.97923, 0.97911, 0.97904, 0.97949, 0.97961, 0.97920, 0.94012],
                        [0.97732, 0.97784, 0.97779, 0.97790, 0.97852, 0.97808, 0.97842,
                         0.97804, 0.97777, 0.97800, 0.97868, 0.97883, 0.97868, 0.97847,
                         0.97855, 0.97848, 0.97862, 0.97817, 0.97888, 0.97862, 0.97866,
                         0.97860, 0.97938, 0.97890, 0.97925, 0.97935, 0.97993, 0.97950, 0.93973],
                        [0.97731, 0.97788, 0.97808, 0.97752, 0.97781, 0.97731, 0.97791,
                         0.97827, 0.97803, 0.97758, 0.97868, 0.97869, 0.97879, 0.97864,
                         0.97837, 0.97784, 0.97817, 0.97865, 0.97900, 0.97849, 0.97864,
                         0.97890, 0.97914, 0.97934, 0.97875, 0.97911, 0.97912, 0.97918, 0.93908],
                        [0.97771, 0.97801, 0.97813, 0.97784, 0.97760, 0.97731, 0.97780,
                         0.97848, 0.97855, 0.97819, 0.97863, 0.97816, 0.97862, 0.97890,
                         0.97824, 0.97840, 0.97824, 0.97861, 0.97912, 0.97837, 0.97886,
                         0.97939, 0.97908, 0.97995, 0.97845, 0.97901, 0.97859, 0.97909, 0.93933],
                        [0.97860, 0.97814, 0.97804, 0.97864, 0.97846, 0.97842, 0.97854,
                         0.97863, 0.97891, 0.97917, 0.97851, 0.97852, 0.97903, 0.97917,
                         0.97881, 0.97962, 0.97932, 0.97898, 0.97943, 0.97904, 0.97955,
                         0.98000, 0.97937, 0.97956, 0.97966, 0.97934, 0.97938, 0.98003, 0.94059],
                        [0.97900, 0.97847, 0.97831, 0.97873, 0.97886, 0.97955, 0.97906,
                         0.97857, 0.97886, 0.97946, 0.97898, 0.97991, 0.97969, 0.97926,
                         0.97940, 0.97980, 0.98013, 0.98017, 0.97973, 0.98024, 0.97977,
                         0.98037, 0.97974, 0.97937, 0.98077, 0.98002, 0.98044, 0.98103, 0.94118],
                        [0.97881, 0.97902, 0.97872, 0.97848, 0.97847, 0.97927, 0.97916,
                         0.97855, 0.97883, 0.97899, 0.97988, 0.98028, 0.97941, 0.97936,
                         0.97957, 0.97922, 0.98000, 0.98043, 0.97998, 0.98062, 0.97946,
                         0.97995, 0.97983, 0.98025, 0.98043, 0.98002, 0.98073, 0.98054, 0.94034],
                        [0.97916, 0.97925, 0.97922, 0.97911, 0.97872, 0.97859, 0.97925,
                         0.97928, 0.97936, 0.97906, 0.98006, 0.97978, 0.97940, 0.97984,
                         0.98033, 0.97942, 0.97994, 0.97969, 0.98018, 0.98052, 0.98017,
                         0.97990, 0.98018, 0.98110, 0.98019, 0.98022, 0.98071, 0.97992, 0.94034],
                        [0.97969, 0.97935, 0.97978, 0.98007, 0.97960, 0.97902, 0.97943,
                         0.98031, 0.98015, 0.97999, 0.98017, 0.98032, 0.98055, 0.98029,
                         0.98088, 0.98029, 0.98002, 0.97987, 0.98056, 0.98075, 0.98139,
                         0.98061, 0.98120, 0.98138, 0.98099, 0.98118, 0.98106, 0.98088, 0.94164],
                        [0.97950, 0.97966, 0.97989, 0.98025, 0.97986, 0.97972, 0.97965,
                         0.98062, 0.98047, 0.98025, 0.98064, 0.98136, 0.98097, 0.98028,
                         0.98027, 0.98053, 0.98015, 0.98069, 0.98096, 0.98077, 0.98133,
                         0.98102, 0.98188, 0.98119, 0.98130, 0.98114, 0.98141, 0.98155, 0.94224],
                        [0.97980, 0.98018, 0.97991, 0.97998, 0.97988, 0.98017, 0.97990,
                         0.98080, 0.98075, 0.97998, 0.98099, 0.98128, 0.98068, 0.98041,
                         0.98001, 0.98066, 0.98094, 0.98127, 0.98125, 0.98080, 0.98082,
                         0.98125, 0.98208, 0.98142, 0.98114, 0.98077, 0.98130, 0.98143, 0.94209],
                        [0.98075, 0.98037, 0.98018, 0.97985, 0.98041, 0.98022, 0.98002,
                         0.98093, 0.98100, 0.98017, 0.98108, 0.98073, 0.98097, 0.98084,
                         0.98077, 0.98117, 0.98165, 0.98179, 0.98137, 0.98128, 0.98120,
                         0.98134, 0.98225, 0.98198, 0.98130, 0.98144, 0.98081, 0.98172, 0.94206],
                        [0.98048, 0.97968, 0.97988, 0.97954, 0.98028, 0.97918, 0.97965,
                         0.98016, 0.98042, 0.98028, 0.98049, 0.98050, 0.98086, 0.98059,
                         0.98089, 0.98066, 0.98086, 0.98106, 0.98085, 0.98113, 0.98132,
                         0.98095, 0.98145, 0.98125, 0.98125, 0.98158, 0.98072, 0.98163, 0.94189],
                        [0.97919, 0.97891, 0.97917, 0.97905, 0.97923, 0.97838, 0.97913,
                         0.97922, 0.97965, 0.97987, 0.97953, 0.98004, 0.97996, 0.97963,
                         0.98022, 0.97938, 0.97932, 0.97978, 0.97995, 0.98029, 0.98067,
                         0.98040, 0.97969, 0.98006, 0.98088, 0.98084, 0.98110, 0.98064, 0.94125],
                        [0.97819, 0.97877, 0.97871, 0.97890, 0.97873, 0.97886, 0.97907,
                         0.97902, 0.97949, 0.97973, 0.97922, 0.97942, 0.97932, 0.97920,
                         0.97977, 0.97904, 0.97902, 0.97976, 0.97954, 0.97986, 0.98042,
                         0.97993, 0.97880, 0.98005, 0.98022, 0.98057, 0.98112, 0.98002, 0.94096],
                        [0.97805, 0.97903, 0.97860, 0.97919, 0.97879, 0.97919, 0.97897,
                         0.97932, 0.97926, 0.98001, 0.97978, 0.97951, 0.97937, 0.97943,
                         0.97967, 0.97942, 0.97974, 0.98004, 0.97978, 0.97993, 0.98021,
                         0.97983, 0.97963, 0.98052, 0.97988, 0.98058, 0.98081, 0.98032, 0.94136],
                        [0.97839, 0.97885, 0.97833, 0.97899, 0.97822, 0.97880, 0.97821,
                         0.97919, 0.97881, 0.97973, 0.97999, 0.98001, 0.97945, 0.97941,
                         0.97960, 0.97947, 0.97953, 0.97949, 0.97984, 0.97975, 0.97938,
                         0.98019, 0.98062, 0.98036, 0.97980, 0.98026, 0.98021, 0.98043, 0.94142],
                        [0.97856, 0.97790, 0.97786, 0.97824, 0.97793, 0.97836, 0.97780,
                         0.97840, 0.97869, 0.97910, 0.97908, 0.97976, 0.97883, 0.97895,
                         0.97913, 0.97923, 0.97899, 0.97866, 0.97938, 0.97929, 0.97879,
                         0.98018, 0.98054, 0.97967, 0.97964, 0.97997, 0.97988, 0.98001, 0.94102],
                        [0.97846, 0.97755, 0.97786, 0.97800, 0.97854, 0.97831, 0.97821,
                         0.97801, 0.97896, 0.97897, 0.97854, 0.97882, 0.97861, 0.97898,
                         0.97849, 0.97912, 0.97920, 0.97855, 0.97902, 0.97915, 0.97926,
                         0.97957, 0.98003, 0.97953, 0.97964, 0.97995, 0.98034, 0.97983, 0.94095],
                        [0.97808, 0.97796, 0.97782, 0.97791, 0.97819, 0.97836, 0.97821,
                         0.97823, 0.97904, 0.97881, 0.97869, 0.97847, 0.97891, 0.97932,
                         0.97847, 0.97898, 0.97905, 0.97892, 0.97889, 0.97910, 0.97983,
                         0.97904, 0.97953, 0.97963, 0.97956, 0.97972, 0.98039, 0.97986, 0.94091],
                        [0.97769, 0.97811, 0.97755, 0.97775, 0.97724, 0.97813, 0.97803,
                         0.97833, 0.97867, 0.97862, 0.97850, 0.97900, 0.97894, 0.97907,
                         0.97865, 0.97898, 0.97876, 0.97910, 0.97900, 0.97916, 0.97945,
                         0.97876, 0.97935, 0.97962, 0.97969, 0.97962, 0.97983, 0.97964, 0.94064],
                        [0.97764, 0.97790, 0.97776, 0.97792, 0.97752, 0.97783, 0.97817,
                         0.97833, 0.97845, 0.97855, 0.97852, 0.97900, 0.97896, 0.97872,
                         0.97835, 0.97900, 0.97924, 0.97895, 0.97934, 0.97938, 0.97875,
                         0.97886, 0.97961, 0.97995, 0.98011, 0.97973, 0.97949, 0.97927, 0.94066],
                        [0.97769, 0.97802, 0.97840, 0.97780, 0.97879, 0.97781, 0.97815,
                         0.97866, 0.97848, 0.97836, 0.97897, 0.97843, 0.97888, 0.97861,
                         0.97861, 0.97871, 0.97955, 0.97872, 0.97928, 0.97937, 0.97896,
                         0.97926, 0.97971, 0.98012, 0.98039, 0.97976, 0.97952, 0.97945, 0.94093],
                        [0.97810, 0.97858, 0.97883, 0.97791, 0.97943, 0.97862, 0.97828,
                         0.97928, 0.97857, 0.97886, 0.97901, 0.97874, 0.97886, 0.97873,
                         0.97963, 0.97876, 0.97955, 0.97905, 0.97944, 0.97952, 0.98000,
                         0.97982, 0.97989, 0.98021, 0.98078, 0.98029, 0.98002, 0.98033, 0.94136],
                        [0.97830, 0.97860, 0.97861, 0.97850, 0.97886, 0.97918, 0.97862,
                         0.97922, 0.97884, 0.97936, 0.97873, 0.97946, 0.97901, 0.97929,
                         0.97969, 0.97942, 0.97971, 0.97965, 0.97981, 0.97980, 0.98068,
                         0.98013, 0.98053, 0.98039, 0.98073, 0.98067, 0.98025, 0.98059, 0.94151],
                        [0.97800, 0.97804, 0.97809, 0.97872, 0.97851, 0.97882, 0.97881,
                         0.97862, 0.97921, 0.97909, 0.97896, 0.97950, 0.97925, 0.97987,
                         0.97928, 0.97994, 0.97971, 0.98002, 0.97961, 0.97995, 0.98050,
                         0.98007, 0.98070, 0.98044, 0.98024, 0.98032, 0.98020, 0.97986, 0.94118],
                        [0.97825, 0.97827, 0.97845, 0.97861, 0.97881, 0.97868, 0.97895,
                         0.97896, 0.97962, 0.97903, 0.97967, 0.97950, 0.97976, 0.97990,
                         0.97969, 0.97997, 0.97993, 0.98028, 0.97968, 0.98014, 0.98001,
                         0.98021, 0.98037, 0.98062, 0.98011, 0.98008, 0.98050, 0.97980, 0.94117],
                        [0.97892, 0.97941, 0.97942, 0.97901, 0.97905, 0.97910, 0.97914,
                         0.97986, 0.97992, 0.97933, 0.97980, 0.97988, 0.98016, 0.97986,
                         0.98016, 0.97999, 0.98049, 0.98015, 0.98033, 0.98063, 0.97993,
                         0.98038, 0.98050, 0.98058, 0.98037, 0.98045, 0.98072, 0.98068, 0.94155],
                        [0.97899, 0.98006, 0.97943, 0.97948, 0.97935, 0.97965, 0.97937,
                         0.97992, 0.97951, 0.97956, 0.97949, 0.98001, 0.97985, 0.98007,
                         0.98021, 0.98001, 0.98039, 0.97987, 0.98031, 0.98074, 0.98024,
                         0.98048, 0.98088, 0.97993, 0.98054, 0.98088, 0.98085, 0.98083, 0.94183],
                        [0.97914, 0.98009, 0.97950, 0.97964, 0.97975, 0.98010, 0.97978,
                         0.97968, 0.97934, 0.98041, 0.98009, 0.98043, 0.97998, 0.98044,
                         0.98073, 0.98036, 0.98033, 0.98054, 0.98044, 0.98066, 0.98100,
                         0.98119, 0.98131, 0.97995, 0.98115, 0.98127, 0.98147, 0.98077, 0.94210],
                        [0.97974, 0.97972, 0.98000, 0.97978, 0.97991, 0.98011, 0.97987,
                         0.97997, 0.97998, 0.98119, 0.98064, 0.98083, 0.98066, 0.98058,
                         0.98104, 0.98094, 0.98085, 0.98122, 0.98132, 0.98111, 0.98136,
                         0.98172, 0.98168, 0.98115, 0.98195, 0.98159, 0.98153, 0.98111, 0.94209],
                        [0.98020, 0.97908, 0.97985, 0.97991, 0.97981, 0.97993, 0.97960,
                         0.98036, 0.98030, 0.98068, 0.98048, 0.98074, 0.98064, 0.98049,
                         0.98052, 0.98107, 0.98103, 0.98079, 0.98133, 0.98170, 0.98082,
                         0.98160, 0.98181, 0.98215, 0.98170, 0.98167, 0.98100, 0.98132, 0.94207],
                        [0.98043, 0.97948, 0.97976, 0.97980, 0.97960, 0.97998, 0.97961,
                         0.98056, 0.98035, 0.98029, 0.98060, 0.98090, 0.98076, 0.98056,
                         0.98037, 0.98128, 0.98085, 0.98060, 0.98071, 0.98192, 0.98060,
                         0.98141, 0.98179, 0.98205, 0.98134, 0.98164, 0.98121, 0.98115, 0.94253],
                        [0.98042, 0.98059, 0.98020, 0.97948, 0.97947, 0.98041, 0.97998,
                         0.98071, 0.98067, 0.98090, 0.98098, 0.98121, 0.98164, 0.98081,
                         0.98107, 0.98175, 0.98096, 0.98137, 0.98073, 0.98185, 0.98117,
                         0.98131, 0.98168, 0.98151, 0.98196, 0.98168, 0.98206, 0.98123, 0.94276],
                        [0.98014, 0.98078, 0.98013, 0.97956, 0.97963, 0.98061, 0.98033,
                         0.98079, 0.98055, 0.98126, 0.98072, 0.98092, 0.98165, 0.98113,
                         0.98154, 0.98156, 0.98105, 0.98158, 0.98125, 0.98158, 0.98172,
                         0.98139, 0.98178, 0.98143, 0.98248, 0.98208, 0.98220, 0.98190, 0.94243],
                        [0.97932, 0.98003, 0.97886, 0.97979, 0.97959, 0.97984, 0.98011,
                         0.98050, 0.97983, 0.98091, 0.97996, 0.98028, 0.98047, 0.98108,
                         0.98104, 0.98058, 0.98062, 0.98059, 0.98129, 0.98095, 0.98160,
                         0.98136, 0.98184, 0.98141, 0.98224, 0.98232, 0.98135, 0.98241, 0.94240],
                        [0.97846, 0.97900, 0.97784, 0.97936, 0.97918, 0.97891, 0.97933,
                         0.97940, 0.97915, 0.97995, 0.97970, 0.97991, 0.97956, 0.98037,
                         0.98020, 0.97947, 0.97985, 0.97995, 0.98051, 0.98011, 0.98093,
                         0.98105, 0.98129, 0.98086, 0.98123, 0.98181, 0.98078, 0.98227, 0.94253],
                        [0.97866, 0.97856, 0.97826, 0.97839, 0.97880, 0.97845, 0.97885,
                         0.97844, 0.97904, 0.97889, 0.97981, 0.97977, 0.97961, 0.97958,
                         0.97969, 0.97905, 0.97966, 0.98000, 0.97968, 0.97959, 0.98061,
                         0.98070, 0.98076, 0.98078, 0.98022, 0.98118, 0.98080, 0.98137, 0.94218],
                        [0.97862, 0.97850, 0.97858, 0.97761, 0.97855, 0.97829, 0.97871,
                         0.97841, 0.97889, 0.97831, 0.97928, 0.97955, 0.97980, 0.97913,
                         0.97923, 0.97949, 0.98001, 0.97957, 0.97924, 0.97943, 0.98032,
                         0.98037, 0.98048, 0.98123, 0.98032, 0.98048, 0.98071, 0.98024, 0.94177],
                        [0.97748, 0.97771, 0.97768, 0.97736, 0.97825, 0.97805, 0.97823,
                         0.97863, 0.97802, 0.97829, 0.97842, 0.97905, 0.97935, 0.97886,
                         0.97895, 0.97977, 0.97994, 0.97873, 0.97945, 0.97973, 0.97967,
                         0.98022, 0.98028, 0.98080, 0.98068, 0.97986, 0.98045, 0.97994, 0.94129],
                        [0.97674, 0.97678, 0.97675, 0.97724, 0.97775, 0.97750, 0.97749,
                         0.97851, 0.97755, 0.97835, 0.97825, 0.97834, 0.97880, 0.97855,
                         0.97913, 0.97940, 0.97930, 0.97893, 0.97974, 0.98021, 0.97961,
                         0.98001, 0.98027, 0.97994, 0.98003, 0.98004, 0.98028, 0.98032, 0.94065],
                        [0.97690, 0.97653, 0.97687, 0.97724, 0.97731, 0.97697, 0.97748,
                         0.97791, 0.97770, 0.97800, 0.97842, 0.97800, 0.97877, 0.97870,
                         0.97917, 0.97924, 0.97869, 0.97995, 0.97947, 0.97986, 0.97995,
                         0.98004, 0.98026, 0.98002, 0.97958, 0.98038, 0.98037, 0.98068, 0.94087],
                        [0.97703, 0.97671, 0.97715, 0.97723, 0.97695, 0.97703, 0.97770,
                         0.97748, 0.97729, 0.97735, 0.97805, 0.97839, 0.97885, 0.97897,
                         0.97866, 0.97933, 0.97855, 0.97965, 0.97910, 0.97896, 0.97973,
                         0.98021, 0.98008, 0.98028, 0.97997, 0.98040, 0.98034, 0.98044, 0.94141],
                        [0.97662, 0.97705, 0.97677, 0.97705, 0.97662, 0.97731, 0.97746,
                         0.97753, 0.97691, 0.97704, 0.97762, 0.97884, 0.97835, 0.97875,
                         0.97827, 0.97880, 0.97869, 0.97850, 0.97907, 0.97863, 0.97928,
                         0.97958, 0.97982, 0.98003, 0.97986, 0.98022, 0.98005, 0.97994, 0.94103],
                        [0.97645, 0.97732, 0.97675, 0.97733, 0.97710, 0.97779, 0.97802,
                         0.97787, 0.97789, 0.97772, 0.97822, 0.97902, 0.97808, 0.97888,
                         0.97887, 0.97858, 0.97900, 0.97875, 0.97956, 0.97922, 0.97957,
                         0.97970, 0.98014, 0.98028, 0.97977, 0.98004, 0.98029, 0.98024, 0.94099],
                        [0.97729, 0.97764, 0.97768, 0.97828, 0.97834, 0.97865, 0.97895,
                         0.97855, 0.97942, 0.97932, 0.97944, 0.97932, 0.97914, 0.97973,
                         0.97999, 0.97937, 0.97943, 0.97988, 0.98031, 0.98034, 0.98072,
                         0.98115, 0.98088, 0.98092, 0.98048, 0.98027, 0.98092, 0.98104, 0.94187],
                        [0.97860, 0.97824, 0.97867, 0.97876, 0.97877, 0.97913, 0.97890,
                         0.97886, 0.97950, 0.97998, 0.97974, 0.97946, 0.98030, 0.97995,
                         0.98016, 0.97995, 0.97998, 0.98049, 0.98034, 0.98076, 0.98138,
                         0.98138, 0.98082, 0.98111, 0.98095, 0.98070, 0.98111, 0.98120, 0.94230],
                        [0.97961, 0.97905, 0.97889, 0.97885, 0.97863, 0.97942, 0.97875,
                         0.97929, 0.97903, 0.97944, 0.97934, 0.97970, 0.98049, 0.97996,
                         0.97981, 0.98028, 0.98082, 0.98086, 0.98032, 0.98064, 0.98108,
                         0.98061, 0.98076, 0.98102, 0.98105, 0.98100, 0.98133, 0.98099, 0.94217],
                        [0.97961, 0.97975, 0.97884, 0.97932, 0.97927, 0.97982, 0.97914,
                         0.98023, 0.97956, 0.97934, 0.97982, 0.98043, 0.98007, 0.98087,
                         0.98002, 0.98106, 0.98140, 0.98107, 0.98090, 0.98083, 0.98095,
                         0.98063, 0.98150, 0.98088, 0.98109, 0.98096, 0.98164, 0.98118, 0.94240],
                        [0.97895, 0.97965, 0.97932, 0.97962, 0.97984, 0.97982, 0.97978,
                         0.98033, 0.98043, 0.97990, 0.98068, 0.98067, 0.98003, 0.98128,
                         0.98087, 0.98152, 0.98137, 0.98108, 0.98118, 0.98125, 0.98094,
                         0.98096, 0.98198, 0.98086, 0.98102, 0.98054, 0.98146, 0.98152, 0.94274],
                        [0.97918, 0.97955, 0.98006, 0.97979, 0.98014, 0.98008, 0.98075,
                         0.98011, 0.98088, 0.98057, 0.98098, 0.98051, 0.98119, 0.98080,
                         0.98186, 0.98105, 0.98135, 0.98130, 0.98115, 0.98173, 0.98110,
                         0.98145, 0.98166, 0.98148, 0.98145, 0.98088, 0.98120, 0.98195, 0.94299],
                        [0.98046, 0.98038, 0.98068, 0.98039, 0.98101, 0.98089, 0.98166,
                         0.98101, 0.98107, 0.98115, 0.98134, 0.98108, 0.98244, 0.98095,
                         0.98221, 0.98097, 0.98145, 0.98177, 0.98189, 0.98216, 0.98201,
                         0.98236, 0.98152, 0.98237, 0.98252, 0.98216, 0.98177, 0.98242, 0.94325],
                        [0.98131, 0.98099, 0.98092, 0.98077, 0.98146, 0.98134, 0.98161,
                         0.98193, 0.98122, 0.98144, 0.98173, 0.98163, 0.98224, 0.98149,
                         0.98172, 0.98184, 0.98129, 0.98228, 0.98277, 0.98228, 0.98261,
                         0.98259, 0.98225, 0.98258, 0.98291, 0.98273, 0.98267, 0.98235, 0.94309],
                        [0.98091, 0.98067, 0.98055, 0.98056, 0.98079, 0.98099, 0.98075,
                         0.98163, 0.98123, 0.98115, 0.98143, 0.98150, 0.98122, 0.98168,
                         0.98112, 0.98199, 0.98133, 0.98230, 0.98234, 0.98205, 0.98216,
                         0.98178, 0.98254, 0.98215, 0.98226, 0.98243, 0.98250, 0.98193, 0.94239],
                        [0.98022, 0.98012, 0.97990, 0.98010, 0.97991, 0.98046, 0.98023,
                         0.98046, 0.98081, 0.98041, 0.98068, 0.98092, 0.98075, 0.98144,
                         0.98108, 0.98086, 0.98144, 0.98152, 0.98098, 0.98166, 0.98135,
                         0.98115, 0.98182, 0.98176, 0.98151, 0.98182, 0.98135, 0.98157, 0.94179],
                        [0.98026, 0.98008, 0.97969, 0.97966, 0.97972, 0.98020, 0.98030,
                         0.97949, 0.98026, 0.98006, 0.98011, 0.98055, 0.98091, 0.98085,
                         0.98118, 0.98023, 0.98123, 0.98063, 0.98037, 0.98112, 0.98113,
                         0.98140, 0.98141, 0.98150, 0.98127, 0.98131, 0.98084, 0.98143, 0.94203],
                        [0.98017, 0.98000, 0.97976, 0.97952, 0.97984, 0.97999, 0.98010,
                         0.97925, 0.97992, 0.98017, 0.98001, 0.98074, 0.98073, 0.98032,
                         0.98074, 0.98050, 0.98093, 0.98024, 0.98110, 0.98058, 0.98127,
                         0.98143, 0.98128, 0.98119, 0.98114, 0.98148, 0.98111, 0.98145, 0.94292],
                        [0.97927, 0.97925, 0.97950, 0.97929, 0.97980, 0.97956, 0.97934,
                         0.97942, 0.97951, 0.97985, 0.98003, 0.98063, 0.98014, 0.98023,
                         0.98021, 0.98022, 0.98065, 0.98033, 0.98166, 0.98039, 0.98098,
                         0.98059, 0.98077, 0.98111, 0.98065, 0.98148, 0.98109, 0.98126, 0.94287],
                        [0.97868, 0.97861, 0.97895, 0.97867, 0.97917, 0.97908, 0.97862,
                         0.98004, 0.97917, 0.97915, 0.97976, 0.98000, 0.97957, 0.98043,
                         0.98008, 0.97982, 0.98014, 0.98044, 0.98084, 0.98044, 0.98076,
                         0.98008, 0.98051, 0.98088, 0.98048, 0.98059, 0.98087, 0.98110, 0.94180],
                        [0.97873, 0.97866, 0.97851, 0.97822, 0.97806, 0.97885, 0.97873,
                         0.98045, 0.97933, 0.97915, 0.97968, 0.97955, 0.97892, 0.97998,
                         0.97994, 0.98002, 0.97951, 0.98035, 0.97995, 0.98052, 0.98085,
                         0.97996, 0.98083, 0.98039, 0.98079, 0.98006, 0.98096, 0.98084, 0.94146],
                        [0.97848, 0.97880, 0.97827, 0.97816, 0.97775, 0.97861, 0.97942,
                         0.97958, 0.97925, 0.97947, 0.97947, 0.97922, 0.97862, 0.97900,
                         0.97929, 0.98018, 0.97949, 0.98012, 0.98009, 0.98055, 0.98043,
                         0.97975, 0.98113, 0.98030, 0.98084, 0.98049, 0.98098, 0.98044, 0.94216],
                        [0.97787, 0.97843, 0.97771, 0.97830, 0.97851, 0.97805, 0.97920,
                         0.97805, 0.97869, 0.97902, 0.97863, 0.97878, 0.97875, 0.97880,
                         0.97870, 0.97980, 0.97991, 0.97994, 0.98020, 0.98025, 0.97962,
                         0.98019, 0.98052, 0.98017, 0.98049, 0.98056, 0.98041, 0.98018, 0.94219],
                        [0.97793, 0.97800, 0.97737, 0.97844, 0.97889, 0.97770, 0.97812,
                         0.97789, 0.97839, 0.97830, 0.97841, 0.97868, 0.97893, 0.97923,
                         0.97885, 0.97928, 0.98010, 0.97968, 0.97966, 0.97986, 0.97965,
                         0.98077, 0.97989, 0.97990, 0.98024, 0.97998, 0.97981, 0.98003, 0.94167],
                        [0.97880, 0.97825, 0.97823, 0.97844, 0.97847, 0.97801, 0.97817,
                         0.97874, 0.97846, 0.97853, 0.97889, 0.97909, 0.97948, 0.97951,
                         0.97933, 0.97938, 0.98015, 0.97943, 0.97953, 0.98002, 0.98018,
                         0.98068, 0.98036, 0.98030, 0.98048, 0.97977, 0.97998, 0.98038, 0.94196],
                        [0.97936, 0.97907, 0.97935, 0.97855, 0.97864, 0.97897, 0.97932,
                         0.97916, 0.97907, 0.97952, 0.97923, 0.97987, 0.98036, 0.97999,
                         0.97999, 0.98039, 0.98057, 0.97999, 0.98032, 0.98081, 0.98048,
                         0.98072, 0.98105, 0.98149, 0.98130, 0.98051, 0.98083, 0.98102, 0.94257],
                        [0.97914, 0.97958, 0.97945, 0.97881, 0.97937, 0.97969, 0.98006,
                         0.97942, 0.97973, 0.98000, 0.97951, 0.98054, 0.98062, 0.98062,
                         0.98078, 0.98105, 0.98112, 0.98108, 0.98103, 0.98136, 0.98101,
                         0.98101, 0.98122, 0.98203, 0.98177, 0.98138, 0.98141, 0.98114, 0.94259],
                        [0.97900, 0.97982, 0.97946, 0.97929, 0.97988, 0.97989, 0.98017,
                         0.98009, 0.98014, 0.98019, 0.98011, 0.98083, 0.98058, 0.98097,
                         0.98107, 0.98094, 0.98149, 0.98177, 0.98142, 0.98137, 0.98179,
                         0.98141, 0.98145, 0.98152, 0.98148, 0.98150, 0.98161, 0.98111, 0.94255],
                        [0.97973, 0.98025, 0.98020, 0.98014, 0.98046, 0.98043, 0.98044,
                         0.98100, 0.98102, 0.98069, 0.98116, 0.98098, 0.98117, 0.98151,
                         0.98121, 0.98127, 0.98189, 0.98223, 0.98216, 0.98178, 0.98226,
                         0.98212, 0.98202, 0.98135, 0.98162, 0.98182, 0.98193, 0.98167, 0.94305],
                        [0.98054, 0.98079, 0.98074, 0.98074, 0.98125, 0.98103, 0.98078,
                         0.98138, 0.98160, 0.98084, 0.98172, 0.98114, 0.98168, 0.98199,
                         0.98181, 0.98183, 0.98224, 0.98235, 0.98244, 0.98210, 0.98211,
                         0.98235, 0.98226, 0.98194, 0.98204, 0.98223, 0.98203, 0.98206, 0.94348],
                        [0.98086, 0.98146, 0.98091, 0.98072, 0.98151, 0.98127, 0.98104,
                         0.98134, 0.98141, 0.98090, 0.98136, 0.98135, 0.98141, 0.98185,
                         0.98211, 0.98180, 0.98215, 0.98163, 0.98188, 0.98151, 0.98179,
                         0.98234, 0.98205, 0.98226, 0.98176, 0.98180, 0.98178, 0.98184, 0.94326],
                        [0.98129, 0.98197, 0.98149, 0.98105, 0.98121, 0.98168, 0.98180,
                         0.98178, 0.98144, 0.98160, 0.98131, 0.98192, 0.98130, 0.98165,
                         0.98168, 0.98170, 0.98193, 0.98138, 0.98167, 0.98157, 0.98206,
                         0.98265, 0.98220, 0.98188, 0.98175, 0.98169, 0.98185, 0.98185, 0.94308],
                        [0.98178, 0.98197, 0.98194, 0.98191, 0.98130, 0.98198, 0.98238,
                         0.98212, 0.98195, 0.98225, 0.98207, 0.98255, 0.98175, 0.98198,
                         0.98149, 0.98201, 0.98218, 0.98232, 0.98193, 0.98237, 0.98275,
                         0.98255, 0.98258, 0.98162, 0.98231, 0.98213, 0.98233, 0.98242, 0.94348],
                        [0.98197, 0.98166, 0.98166, 0.98208, 0.98168, 0.98177, 0.98183,
                         0.98179, 0.98237, 0.98202, 0.98246, 0.98222, 0.98196, 0.98230,
                         0.98171, 0.98186, 0.98239, 0.98279, 0.98172, 0.98253, 0.98268,
                         0.98176, 0.98256, 0.98195, 0.98247, 0.98219, 0.98244, 0.98248, 0.94365],
                        [0.98186, 0.98136, 0.98138, 0.98132, 0.98160, 0.98190, 0.98135,
                         0.98170, 0.98226, 0.98177, 0.98206, 0.98138, 0.98190, 0.98220,
                         0.98175, 0.98122, 0.98197, 0.98227, 0.98127, 0.98229, 0.98163,
                         0.98131, 0.98200, 0.98207, 0.98230, 0.98188, 0.98192, 0.98154, 0.94337],
                        [0.98160, 0.98125, 0.98135, 0.98057, 0.98130, 0.98187, 0.98158,
                         0.98192, 0.98179, 0.98211, 0.98159, 0.98130, 0.98196, 0.98191,
                         0.98178, 0.98109, 0.98115, 0.98176, 0.98142, 0.98204, 0.98118,
                         0.98175, 0.98123, 0.98172, 0.98226, 0.98142, 0.98152, 0.98096, 0.94324],
                        [0.98122, 0.98120, 0.98097, 0.98031, 0.98119, 0.98103, 0.98130,
                         0.98172, 0.98137, 0.98200, 0.98124, 0.98167, 0.98172, 0.98159,
                         0.98164, 0.98117, 0.98085, 0.98123, 0.98153, 0.98122, 0.98136,
                         0.98191, 0.98069, 0.98151, 0.98167, 0.98091, 0.98165, 0.98148, 0.94325],
                        [0.98100, 0.98131, 0.98050, 0.98064, 0.98125, 0.98090, 0.98094,
                         0.98147, 0.98102, 0.98150, 0.98120, 0.98174, 0.98162, 0.98133,
                         0.98127, 0.98126, 0.98115, 0.98066, 0.98112, 0.98070, 0.98115,
                         0.98121, 0.98068, 0.98147, 0.98076, 0.98078, 0.98162, 0.98193, 0.94313],
                        [0.98099, 0.98129, 0.98059, 0.98101, 0.98134, 0.98145, 0.98113,
                         0.98117, 0.98080, 0.98126, 0.98154, 0.98135, 0.98191, 0.98114,
                         0.98072, 0.98144, 0.98131, 0.98066, 0.98100, 0.98104, 0.98118,
                         0.98095, 0.98123, 0.98120, 0.98073, 0.98106, 0.98112, 0.98146, 0.94291],
                        [0.98087, 0.98087, 0.98099, 0.98083, 0.98122, 0.98132, 0.98135,
                         0.98072, 0.98073, 0.98094, 0.98168, 0.98104, 0.98174, 0.98099,
                         0.98026, 0.98121, 0.98129, 0.98111, 0.98123, 0.98102, 0.98129,
                         0.98137, 0.98166, 0.98119, 0.98128, 0.98092, 0.98071, 0.98081, 0.94281],
                        [0.98060, 0.98042, 0.98102, 0.98056, 0.98077, 0.98105, 0.98148,
                         0.98067, 0.98077, 0.98073, 0.98133, 0.98111, 0.98121, 0.98070,
                         0.98043, 0.98092, 0.98093, 0.98108, 0.98119, 0.98071, 0.98088,
                         0.98139, 0.98146, 0.98133, 0.98142, 0.98032, 0.98049, 0.98065, 0.94273],
                        [0.98018, 0.98020, 0.98045, 0.98046, 0.98017, 0.98078, 0.98113,
                         0.98052, 0.98053, 0.98093, 0.98091, 0.98121, 0.98063, 0.98030,
                         0.98093, 0.98083, 0.98029, 0.98043, 0.98080, 0.98079, 0.98075,
                         0.98053, 0.98091, 0.98068, 0.98108, 0.97989, 0.98035, 0.98045, 0.94243],
                        [0.97985, 0.98026, 0.98016, 0.98048, 0.98006, 0.98029, 0.98033,
                         0.98008, 0.98035, 0.98106, 0.98079, 0.98117, 0.98029, 0.97994,
                         0.98089, 0.98066, 0.98038, 0.98041, 0.98024, 0.98085, 0.98095,
                         0.97999, 0.98051, 0.97986, 0.98078, 0.97980, 0.98023, 0.98010, 0.94218],
                        [0.98027, 0.98060, 0.98075, 0.98052, 0.98051, 0.98028, 0.98031,
                         0.98041, 0.98097, 0.98112, 0.98074, 0.98091, 0.98090, 0.98018,
                         0.98045, 0.98064, 0.98113, 0.98141, 0.98025, 0.98090, 0.98091,
                         0.98063, 0.98062, 0.98035, 0.98088, 0.98024, 0.98038, 0.98034, 0.94224],
                        [0.98131, 0.98089, 0.98131, 0.98039, 0.98100, 0.98074, 0.98111,
                         0.98145, 0.98153, 0.98104, 0.98074, 0.98082, 0.98171, 0.98103,
                         0.98054, 0.98093, 0.98152, 0.98185, 0.98072, 0.98107, 0.98095,
                         0.98132, 0.98101, 0.98138, 0.98111, 0.98089, 0.98063, 0.98090, 0.94241],
                        [0.98142, 0.98081, 0.98104, 0.98032, 0.98086, 0.98118, 0.98108,
                         0.98170, 0.98104, 0.98045, 0.98079, 0.98107, 0.98124, 0.98137,
                         0.98073, 0.98095, 0.98118, 0.98110, 0.98092, 0.98136, 0.98105,
                         0.98143, 0.98124, 0.98126, 0.98115, 0.98115, 0.98087, 0.98113, 0.94258],
                        [0.98027, 0.98023, 0.98038, 0.97999, 0.98000, 0.98113, 0.98042,
                         0.98078, 0.98050, 0.97999, 0.98075, 0.98089, 0.98033, 0.98092,
                         0.98052, 0.98053, 0.98070, 0.98061, 0.98094, 0.98133, 0.98097,
                         0.98120, 0.98110, 0.98049, 0.98095, 0.98089, 0.98098, 0.98098, 0.94264],
                        [0.97974, 0.97997, 0.97982, 0.98014, 0.97974, 0.98061, 0.98044,
                         0.98016, 0.98077, 0.98037, 0.98067, 0.98062, 0.98041, 0.98092,
                         0.98077, 0.98058, 0.98090, 0.98065, 0.98080, 0.98079, 0.98102,
                         0.98078, 0.98090, 0.98059, 0.98080, 0.98053, 0.98063, 0.98097, 0.94250],
                        [0.98005, 0.98046, 0.97947, 0.98078, 0.98023, 0.98003, 0.98053,
                         0.98040, 0.98080, 0.98050, 0.98070, 0.98069, 0.98079, 0.98114,
                         0.98082, 0.98086, 0.98114, 0.98048, 0.98056, 0.98026, 0.98085,
                         0.98065, 0.98088, 0.98111, 0.98076, 0.98036, 0.98033, 0.98080, 0.94234],
                        [0.97981, 0.98030, 0.97906, 0.98014, 0.98012, 0.97940, 0.97987,
                         0.98016, 0.98005, 0.97995, 0.98032, 0.98037, 0.98033, 0.98050,
                         0.97999, 0.98031, 0.98032, 0.97993, 0.98062, 0.98015, 0.98021,
                         0.98043, 0.98053, 0.98106, 0.98050, 0.98022, 0.98060, 0.98024, 0.94204],
                        [0.97950, 0.97917, 0.97900, 0.97906, 0.97961, 0.97928, 0.97940,
                         0.97946, 0.97948, 0.98002, 0.97983, 0.98011, 0.97998, 0.97983,
                         0.97980, 0.97964, 0.97956, 0.97973, 0.98097, 0.98063, 0.98014,
                         0.98014, 0.98026, 0.98085, 0.98044, 0.98017, 0.98121, 0.98019, 0.94197],
                        [0.97978, 0.97895, 0.97965, 0.97900, 0.97945, 0.97982, 0.97959,
                         0.97959, 0.97960, 0.98019, 0.97995, 0.98050, 0.98059, 0.97975,
                         0.98025, 0.97975, 0.98004, 0.98044, 0.98095, 0.98104, 0.98064,
                         0.98034, 0.98058, 0.98075, 0.98052, 0.98038, 0.98136, 0.98068, 0.94251],
                        [0.97979, 0.97953, 0.97961, 0.97925, 0.97916, 0.97980, 0.97947,
                         0.97981, 0.97974, 0.97950, 0.97979, 0.98048, 0.98070, 0.97959,
                         0.97997, 0.97976, 0.98052, 0.98081, 0.98018, 0.98043, 0.98062,
                         0.98049, 0.98062, 0.98022, 0.98034, 0.98061, 0.98071, 0.98088, 0.94254],
                        [0.97918, 0.97961, 0.97874, 0.97949, 0.97891, 0.97923, 0.97902,
                         0.97955, 0.97964, 0.97907, 0.97946, 0.97996, 0.97995, 0.97954,
                         0.97962, 0.97964, 0.98010, 0.98014, 0.97970, 0.97992, 0.98018,
                         0.98054, 0.98044, 0.97983, 0.98054, 0.98074, 0.98035, 0.98069, 0.94208],
                        [0.97867, 0.97900, 0.97842, 0.97920, 0.97906, 0.97867, 0.97881,
                         0.97924, 0.97940, 0.97937, 0.97954, 0.97966, 0.97943, 0.97982,
                         0.97966, 0.97983, 0.97945, 0.97938, 0.97991, 0.98012, 0.97961,
                         0.98034, 0.98040, 0.98037, 0.98082, 0.98059, 0.98040, 0.98037, 0.94190],
                        [0.97867, 0.97826, 0.97869, 0.97822, 0.97887, 0.97830, 0.97876,
                         0.97873, 0.97900, 0.97936, 0.97953, 0.97915, 0.97923, 0.97964,
                         0.97971, 0.97992, 0.97925, 0.97930, 0.97993, 0.98007, 0.97938,
                         0.97983, 0.97998, 0.98061, 0.98048, 0.98003, 0.98023, 0.98032, 0.94175],
                        [0.97861, 0.97820, 0.97853, 0.97782, 0.97867, 0.97838, 0.97874,
                         0.97847, 0.97856, 0.97890, 0.97923, 0.97874, 0.97909, 0.97917,
                         0.97958, 0.97958, 0.97955, 0.97954, 0.97977, 0.97994, 0.97997,
                         0.97987, 0.97986, 0.98004, 0.98027, 0.97973, 0.98009, 0.98036, 0.94154],
                        [0.97814, 0.97806, 0.97787, 0.97839, 0.97871, 0.97821, 0.97872,
                         0.97845, 0.97822, 0.97855, 0.97884, 0.97869, 0.97908, 0.97923,
                         0.97898, 0.97900, 0.97972, 0.97958, 0.97945, 0.97963, 0.98031,
                         0.98008, 0.98008, 0.97989, 0.98003, 0.97982, 0.97991, 0.97992, 0.94159],
                        [0.97799, 0.97769, 0.97772, 0.97871, 0.97858, 0.97817, 0.97881,
                         0.97853, 0.97844, 0.97861, 0.97910, 0.97890, 0.97916, 0.97972,
                         0.97881, 0.97892, 0.97980, 0.97981, 0.97917, 0.97953, 0.98009,
                         0.97993, 0.98013, 0.98035, 0.97962, 0.97997, 0.97978, 0.97982, 0.94208],
                        [0.97870, 0.97822, 0.97833, 0.97841, 0.97868, 0.97899, 0.97901,
                         0.97909, 0.97943, 0.97945, 0.97991, 0.97960, 0.97952, 0.97989,
                         0.97978, 0.97950, 0.98024, 0.98033, 0.97997, 0.98028, 0.98033,
                         0.98027, 0.98050, 0.98059, 0.98012, 0.98045, 0.98027, 0.98047, 0.94276],
                        [0.97963, 0.97902, 0.97892, 0.97852, 0.97915, 0.97986, 0.97938,
                         0.97953, 0.98010, 0.98043, 0.98041, 0.98019, 0.97983, 0.97983,
                         0.98067, 0.98023, 0.98072, 0.98059, 0.98114, 0.98099, 0.98073,
                         0.98114, 0.98119, 0.98079, 0.98104, 0.98132, 0.98124, 0.98123, 0.94317],
                        [0.97953, 0.97910, 0.97897, 0.97941, 0.97957, 0.97992, 0.97968,
                         0.97948, 0.97974, 0.98047, 0.98035, 0.98016, 0.98018, 0.97984,
                         0.98044, 0.98036, 0.98093, 0.98046, 0.98110, 0.98102, 0.98078,
                         0.98119, 0.98130, 0.98103, 0.98109, 0.98135, 0.98159, 0.98137, 0.94281],
                        [0.97911, 0.97940, 0.97932, 0.98023, 0.98020, 0.97980, 0.98007,
                         0.98003, 0.97974, 0.98008, 0.98058, 0.98041, 0.98083, 0.98031,
                         0.98029, 0.98029, 0.98121, 0.98073, 0.98081, 0.98119, 0.98143,
                         0.98082, 0.98146, 0.98128, 0.98105, 0.98081, 0.98150, 0.98145, 0.94258],
                        [0.97987, 0.98001, 0.98026, 0.98063, 0.98064, 0.98038, 0.98094,
                         0.98094, 0.98083, 0.98049, 0.98113, 0.98104, 0.98131, 0.98132,
                         0.98119, 0.98085, 0.98149, 0.98141, 0.98174, 0.98186, 0.98204,
                         0.98123, 0.98198, 0.98170, 0.98170, 0.98125, 0.98189, 0.98195, 0.94340],
                        [0.98074, 0.98016, 0.98069, 0.98054, 0.98036, 0.98107, 0.98144,
                         0.98110, 0.98146, 0.98161, 0.98115, 0.98122, 0.98132, 0.98187,
                         0.98166, 0.98162, 0.98144, 0.98178, 0.98251, 0.98213, 0.98177,
                         0.98180, 0.98195, 0.98214, 0.98198, 0.98233, 0.98207, 0.98229, 0.94417],
                        [0.98047, 0.98048, 0.98041, 0.98010, 0.97998, 0.98089, 0.98103,
                         0.98076, 0.98135, 0.98194, 0.98086, 0.98106, 0.98095, 0.98133,
                         0.98125, 0.98188, 0.98107, 0.98161, 0.98201, 0.98175, 0.98174,
                         0.98171, 0.98145, 0.98217, 0.98170, 0.98280, 0.98147, 0.98229, 0.94387],
                        [0.98006, 0.98089, 0.97993, 0.97997, 0.97998, 0.98025, 0.98054,
                         0.98044, 0.98089, 0.98105, 0.98068, 0.98073, 0.98061, 0.98076,
                         0.98098, 0.98122, 0.98073, 0.98097, 0.98122, 0.98135, 0.98198,
                         0.98129, 0.98121, 0.98160, 0.98145, 0.98201, 0.98112, 0.98180, 0.94303],
                        [0.97990, 0.98038, 0.97946, 0.97976, 0.98013, 0.98008, 0.98002,
                         0.97993, 0.97984, 0.98010, 0.98033, 0.98030, 0.98055, 0.98061,
                         0.98055, 0.97998, 0.98060, 0.98037, 0.98064, 0.98103, 0.98137,
                         0.98118, 0.98113, 0.98107, 0.98083, 0.98069, 0.98125, 0.98095, 0.94271],
                        [0.97975, 0.97946, 0.97917, 0.97945, 0.98023, 0.98016, 0.97941,
                         0.97951, 0.97956, 0.97989, 0.97988, 0.98024, 0.98034, 0.98026,
                         0.97998, 0.97989, 0.98038, 0.98064, 0.98046, 0.98071, 0.98080,
                         0.98103, 0.98111, 0.98098, 0.98058, 0.98051, 0.98112, 0.98092, 0.94274],
                        [0.97972, 0.97941, 0.97893, 0.97944, 0.98007, 0.97968, 0.97946,
                         0.97971, 0.98053, 0.98004, 0.97990, 0.98028, 0.98005, 0.97982,
                         0.97995, 0.98088, 0.98025, 0.98099, 0.98061, 0.98049, 0.98085,
                         0.98081, 0.98121, 0.98096, 0.98124, 0.98116, 0.98089, 0.98133, 0.94283],
                        [0.97925, 0.97972, 0.97898, 0.97927, 0.97947, 0.97889, 0.98006,
                         0.97960, 0.98049, 0.97981, 0.98000, 0.98019, 0.97987, 0.97958,
                         0.98011, 0.98096, 0.98042, 0.98021, 0.98057, 0.98032, 0.98061,
                         0.98093, 0.98102, 0.98053, 0.98141, 0.98106, 0.98098, 0.98114, 0.94308],
                        [0.97840, 0.97931, 0.97903, 0.97858, 0.97877, 0.97845, 0.97973,
                         0.97873, 0.97897, 0.97922, 0.97950, 0.97988, 0.97933, 0.97967,
                         0.97952, 0.98007, 0.98033, 0.97946, 0.98021, 0.97998, 0.98001,
                         0.98088, 0.98033, 0.98006, 0.98065, 0.98038, 0.98084, 0.98056, 0.94291],
                        [0.97815, 0.97830, 0.97848, 0.97795, 0.97842, 0.97824, 0.97813,
                         0.97802, 0.97816, 0.97864, 0.97882, 0.97911, 0.97878, 0.97957,
                         0.97864, 0.97921, 0.97964, 0.97942, 0.97950, 0.97971, 0.97965,
                         0.98030, 0.97973, 0.98019, 0.98004, 0.98009, 0.98022, 0.98015, 0.94208],
                        [0.97829, 0.97740, 0.97801, 0.97775, 0.97807, 0.97780, 0.97713,
                         0.97778, 0.97821, 0.97824, 0.97849, 0.97844, 0.97863, 0.97857,
                         0.97846, 0.97842, 0.97864, 0.97916, 0.97899, 0.97957, 0.97966,
                         0.97955, 0.97960, 0.98048, 0.97977, 0.97994, 0.97981, 0.97997, 0.94154],
                        [0.97775, 0.97720, 0.97773, 0.97730, 0.97751, 0.97741, 0.97739,
                         0.97754, 0.97796, 0.97787, 0.97815, 0.97833, 0.97823, 0.97796,
                         0.97852, 0.97773, 0.97824, 0.97879, 0.97904, 0.97919, 0.97952,
                         0.97918, 0.97965, 0.98005, 0.97967, 0.97964, 0.97984, 0.97991, 0.94179],
                        [0.97712, 0.97715, 0.97701, 0.97696, 0.97715, 0.97751, 0.97772,
                         0.97719, 0.97751, 0.97767, 0.97770, 0.97843, 0.97774, 0.97825,
                         0.97822, 0.97808, 0.97828, 0.97866, 0.97894, 0.97893, 0.97923,
                         0.97922, 0.97960, 0.97925, 0.97993, 0.97927, 0.97987, 0.97965, 0.94193],
                        [0.97720, 0.97661, 0.97636, 0.97697, 0.97689, 0.97751, 0.97744,
                         0.97696, 0.97708, 0.97752, 0.97758, 0.97814, 0.97785, 0.97825,
                         0.97772, 0.97900, 0.97811, 0.97847, 0.97864, 0.97881, 0.97897,
                         0.97929, 0.97935, 0.97903, 0.98003, 0.97893, 0.97949, 0.97928, 0.94169],
                        [0.97738, 0.97644, 0.97640, 0.97682, 0.97669, 0.97725, 0.97720,
                         0.97710, 0.97708, 0.97745, 0.97781, 0.97761, 0.97811, 0.97825,
                         0.97785, 0.97888, 0.97840, 0.97834, 0.97886, 0.97856, 0.97900,
                         0.97921, 0.97938, 0.97946, 0.97956, 0.97907, 0.97901, 0.97942, 0.94170],
                        [0.97726, 0.97706, 0.97690, 0.97701, 0.97722, 0.97748, 0.97759,
                         0.97754, 0.97793, 0.97783, 0.97814, 0.97802, 0.97847, 0.97874,
                         0.97889, 0.97828, 0.97922, 0.97883, 0.97948, 0.97911, 0.97969,
                         0.97953, 0.97988, 0.98002, 0.97966, 0.97988, 0.97931, 0.98008, 0.94211],
                        [0.97741, 0.97783, 0.97775, 0.97786, 0.97806, 0.97811, 0.97844,
                         0.97825, 0.97875, 0.97842, 0.97871, 0.97887, 0.97925, 0.97896,
                         0.97943, 0.97883, 0.97984, 0.97980, 0.97994, 0.98026, 0.98021,
                         0.98036, 0.98036, 0.98045, 0.98053, 0.98056, 0.98048, 0.98064, 0.94240],
                        [0.97826, 0.97822, 0.97880, 0.97885, 0.97838, 0.97870, 0.97932,
                         0.97914, 0.97923, 0.97905, 0.97961, 0.97932, 0.97974, 0.97929,
                         0.97936, 0.98015, 0.98031, 0.98062, 0.98045, 0.98098, 0.98044,
                         0.98122, 0.98085, 0.98094, 0.98116, 0.98069, 0.98158, 0.98113, 0.94268],
                        [0.97912, 0.97839, 0.97921, 0.97908, 0.97837, 0.97910, 0.97949,
                         0.97948, 0.97960, 0.97949, 0.98003, 0.97976, 0.97953, 0.97993,
                         0.98017, 0.98082, 0.98073, 0.98106, 0.98100, 0.98112, 0.98114,
                         0.98160, 0.98132, 0.98131, 0.98129, 0.98056, 0.98181, 0.98148, 0.94334],
                        [0.97934, 0.97867, 0.97926, 0.97892, 0.97891, 0.97969, 0.97928,
                         0.97955, 0.97982, 0.97974, 0.98007, 0.98027, 0.97983, 0.98015,
                         0.98149, 0.98111, 0.98098, 0.98117, 0.98112, 0.98126, 0.98191,
                         0.98133, 0.98159, 0.98160, 0.98162, 0.98095, 0.98135, 0.98161, 0.94425],
                        [0.97910, 0.97903, 0.97954, 0.97899, 0.97992, 0.98008, 0.97951,
                         0.97998, 0.98002, 0.97974, 0.98003, 0.98059, 0.98084, 0.98019,
                         0.98160, 0.98119, 0.98096, 0.98120, 0.98092, 0.98139, 0.98186,
                         0.98096, 0.98176, 0.98188, 0.98178, 0.98185, 0.98106, 0.98154, 0.94442],
                        [0.97943, 0.97969, 0.97991, 0.97925, 0.98037, 0.97994, 0.98000,
                         0.98021, 0.98025, 0.97996, 0.98024, 0.98075, 0.98126, 0.98094,
                         0.98087, 0.98091, 0.98103, 0.98139, 0.98100, 0.98154, 0.98149,
                         0.98121, 0.98186, 0.98199, 0.98145, 0.98224, 0.98157, 0.98143, 0.94388],
                        [0.98040, 0.98024, 0.98006, 0.97999, 0.98025, 0.98030, 0.98037,
                         0.98036, 0.98060, 0.98099, 0.98078, 0.98099, 0.98094, 0.98179,
                         0.98068, 0.98111, 0.98162, 0.98174, 0.98156, 0.98205, 0.98156,
                         0.98198, 0.98216, 0.98233, 0.98165, 0.98198, 0.98210, 0.98189, 0.94379],
                        [0.98064, 0.98024, 0.98005, 0.98074, 0.98012, 0.98097, 0.98064,
                         0.98077, 0.98081, 0.98137, 0.98104, 0.98084, 0.98054, 0.98136,
                         0.98097, 0.98172, 0.98202, 0.98179, 0.98203, 0.98216, 0.98154,
                         0.98249, 0.98240, 0.98256, 0.98220, 0.98170, 0.98191, 0.98266, 0.94415],
                        [0.98043, 0.98047, 0.98046, 0.98073, 0.98014, 0.98096, 0.98074,
                         0.98112, 0.98089, 0.98096, 0.98103, 0.98065, 0.98083, 0.98067,
                         0.98139, 0.98182, 0.98200, 0.98180, 0.98184, 0.98187, 0.98128,
                         0.98265, 0.98222, 0.98232, 0.98223, 0.98177, 0.98194, 0.98272, 0.94453],
                        [0.98005, 0.98068, 0.98057, 0.98010, 0.98045, 0.98035, 0.98042,
                         0.98092, 0.98103, 0.98093, 0.98087, 0.98123, 0.98137, 0.98095,
                         0.98155, 0.98133, 0.98173, 0.98188, 0.98130, 0.98196, 0.98133,
                         0.98241, 0.98182, 0.98183, 0.98187, 0.98178, 0.98203, 0.98194, 0.94451],
                        [0.97946, 0.98033, 0.98003, 0.97979, 0.98079, 0.97982, 0.98018,
                         0.98049, 0.98116, 0.98112, 0.98066, 0.98156, 0.98155, 0.98181,
                         0.98140, 0.98150, 0.98132, 0.98170, 0.98154, 0.98188, 0.98177,
                         0.98219, 0.98186, 0.98173, 0.98187, 0.98189, 0.98176, 0.98161, 0.94429],
                        [0.97955, 0.97984, 0.97986, 0.98001, 0.98045, 0.97981, 0.98043,
                         0.98044, 0.98095, 0.98092, 0.98075, 0.98110, 0.98130, 0.98197,
                         0.98106, 0.98207, 0.98098, 0.98157, 0.98207, 0.98140, 0.98191,
                         0.98212, 0.98202, 0.98197, 0.98216, 0.98195, 0.98166, 0.98208, 0.94431],
                        [0.98007, 0.97961, 0.97997, 0.97997, 0.97939, 0.98012, 0.98070,
                         0.98047, 0.98048, 0.98043, 0.98107, 0.98089, 0.98097, 0.98097,
                         0.98076, 0.98154, 0.98121, 0.98140, 0.98168, 0.98120, 0.98161,
                         0.98171, 0.98154, 0.98177, 0.98202, 0.98141, 0.98184, 0.98237, 0.94428],
                        [0.98012, 0.97951, 0.97977, 0.97964, 0.97896, 0.98012, 0.98040,
                         0.98006, 0.98010, 0.98015, 0.98094, 0.98085, 0.98076, 0.98014,
                         0.98051, 0.98072, 0.98138, 0.98078, 0.98108, 0.98117, 0.98151,
                         0.98121, 0.98133, 0.98135, 0.98154, 0.98095, 0.98187, 0.98188, 0.94391],
                        [0.97962, 0.97909, 0.97963, 0.97937, 0.97951, 0.97969, 0.97982,
                         0.97966, 0.97980, 0.98018, 0.98036, 0.98039, 0.98019, 0.98022,
                         0.98023, 0.98073, 0.98075, 0.98041, 0.98072, 0.98099, 0.98163,
                         0.98085, 0.98171, 0.98099, 0.98125, 0.98101, 0.98162, 0.98137, 0.94361],
                        [0.97891, 0.97866, 0.97939, 0.97903, 0.97986, 0.97941, 0.97943,
                         0.97948, 0.97999, 0.98000, 0.98004, 0.98007, 0.97979, 0.98029,
                         0.98031, 0.98093, 0.98048, 0.98061, 0.98054, 0.98083, 0.98131,
                         0.98061, 0.98157, 0.98113, 0.98112, 0.98108, 0.98100, 0.98145, 0.94349],
                        [0.97915, 0.97889, 0.97925, 0.97909, 0.98009, 0.97975, 0.97951,
                         0.97969, 0.98089, 0.97979, 0.98019, 0.98059, 0.98036, 0.98032,
                         0.98084, 0.98099, 0.98108, 0.98103, 0.98101, 0.98100, 0.98073,
                         0.98108, 0.98114, 0.98182, 0.98126, 0.98116, 0.98090, 0.98143, 0.94347],
                        [0.97970, 0.97904, 0.97915, 0.97971, 0.97994, 0.97983, 0.97993,
                         0.98022, 0.98098, 0.97991, 0.98029, 0.98082, 0.98094, 0.98059,
                         0.98130, 0.98077, 0.98131, 0.98124, 0.98131, 0.98103, 0.98080,
                         0.98156, 0.98103, 0.98184, 0.98119, 0.98147, 0.98162, 0.98096, 0.94357],
                        [0.97960, 0.97898, 0.97916, 0.97999, 0.97949, 0.97943, 0.98015,
                         0.98033, 0.98005, 0.98025, 0.98025, 0.98065, 0.98082, 0.98066,
                         0.98120, 0.98041, 0.98105, 0.98119, 0.98135, 0.98091, 0.98143,
                         0.98128, 0.98119, 0.98129, 0.98102, 0.98200, 0.98194, 0.98092, 0.94356],
                        [0.97962, 0.97945, 0.97950, 0.97977, 0.97974, 0.97975, 0.98015,
                         0.98024, 0.97990, 0.98063, 0.98045, 0.98113, 0.98052, 0.98076,
                         0.98097, 0.98057, 0.98101, 0.98127, 0.98170, 0.98126, 0.98183,
                         0.98126, 0.98162, 0.98130, 0.98157, 0.98207, 0.98179, 0.98144, 0.94373],
                        [0.97977, 0.98010, 0.97956, 0.97989, 0.98039, 0.98041, 0.98032,
                         0.98063, 0.98074, 0.98075, 0.98081, 0.98136, 0.98078, 0.98121,
                         0.98106, 0.98119, 0.98119, 0.98155, 0.98177, 0.98186, 0.98198,
                         0.98152, 0.98187, 0.98168, 0.98195, 0.98153, 0.98175, 0.98179, 0.94438],
                        [0.97985, 0.98015, 0.97956, 0.98049, 0.98050, 0.98047, 0.98055,
                         0.98086, 0.98122, 0.98051, 0.98104, 0.98085, 0.98142, 0.98163,
                         0.98118, 0.98165, 0.98149, 0.98151, 0.98161, 0.98213, 0.98211,
                         0.98144, 0.98186, 0.98185, 0.98153, 0.98121, 0.98183, 0.98196, 0.94464],
                        [0.98038, 0.98021, 0.98029, 0.98094, 0.98043, 0.98045, 0.98105,
                         0.98088, 0.98125, 0.98085, 0.98146, 0.98113, 0.98190, 0.98164,
                         0.98142, 0.98196, 0.98203, 0.98147, 0.98208, 0.98212, 0.98252,
                         0.98172, 0.98214, 0.98237, 0.98161, 0.98177, 0.98234, 0.98245, 0.94441],
                        [0.98091, 0.98094, 0.98105, 0.98136, 0.98113, 0.98102, 0.98175,
                         0.98140, 0.98162, 0.98186, 0.98209, 0.98229, 0.98232, 0.98152,
                         0.98181, 0.98232, 0.98263, 0.98204, 0.98273, 0.98212, 0.98312,
                         0.98264, 0.98301, 0.98311, 0.98252, 0.98283, 0.98273, 0.98313, 0.94470],
                        [0.98088, 0.98140, 0.98091, 0.98176, 0.98187, 0.98178, 0.98223,
                         0.98184, 0.98209, 0.98233, 0.98222, 0.98294, 0.98239, 0.98172,
                         0.98216, 0.98262, 0.98290, 0.98261, 0.98304, 0.98242, 0.98331,
                         0.98345, 0.98370, 0.98311, 0.98305, 0.98310, 0.98255, 0.98305, 0.94514],
                        [0.98100, 0.98121, 0.98093, 0.98176, 0.98192, 0.98199, 0.98219,
                         0.98182, 0.98230, 0.98224, 0.98228, 0.98279, 0.98212, 0.98240,
                         0.98266, 0.98291, 0.98304, 0.98282, 0.98307, 0.98332, 0.98319,
                         0.98361, 0.98352, 0.98290, 0.98297, 0.98248, 0.98258, 0.98283, 0.94514],
                        [0.98162, 0.98133, 0.98174, 0.98167, 0.98185, 0.98180, 0.98190,
                         0.98203, 0.98243, 0.98222, 0.98282, 0.98238, 0.98243, 0.98309,
                         0.98295, 0.98313, 0.98311, 0.98280, 0.98288, 0.98403, 0.98294,
                         0.98327, 0.98285, 0.98301, 0.98271, 0.98230, 0.98286, 0.98307, 0.94537],
                        [0.98225, 0.98196, 0.98253, 0.98230, 0.98217, 0.98212, 0.98235,
                         0.98259, 0.98289, 0.98244, 0.98324, 0.98259, 0.98350, 0.98337,
                         0.98307, 0.98331, 0.98299, 0.98270, 0.98309, 0.98381, 0.98330,
                         0.98332, 0.98287, 0.98332, 0.98289, 0.98311, 0.98327, 0.98310, 0.94602],
                        [0.98210, 0.98222, 0.98240, 0.98279, 0.98225, 0.98276, 0.98325,
                         0.98278, 0.98335, 0.98276, 0.98299, 0.98344, 0.98374, 0.98347,
                         0.98335, 0.98352, 0.98331, 0.98328, 0.98361, 0.98336, 0.98369,
                         0.98360, 0.98371, 0.98371, 0.98357, 0.98398, 0.98366, 0.98327, 0.94628],
                        [0.98158, 0.98201, 0.98178, 0.98210, 0.98208, 0.98278, 0.98317,
                         0.98264, 0.98306, 0.98321, 0.98250, 0.98361, 0.98302, 0.98334,
                         0.98360, 0.98345, 0.98391, 0.98393, 0.98374, 0.98340, 0.98321,
                         0.98338, 0.98411, 0.98388, 0.98382, 0.98411, 0.98364, 0.98382, 0.94604],
                        [0.98190, 0.98217, 0.98175, 0.98150, 0.98251, 0.98244, 0.98247,
                         0.98272, 0.98264, 0.98340, 0.98249, 0.98274, 0.98272, 0.98294,
                         0.98321, 0.98292, 0.98354, 0.98355, 0.98354, 0.98358, 0.98291,
                         0.98320, 0.98374, 0.98365, 0.98336, 0.98328, 0.98336, 0.98379, 0.94579],
                        [0.98280, 0.98291, 0.98243, 0.98210, 0.98321, 0.98282, 0.98292,
                         0.98333, 0.98323, 0.98330, 0.98325, 0.98261, 0.98357, 0.98316,
                         0.98270, 0.98310, 0.98307, 0.98356, 0.98369, 0.98348, 0.98369,
                         0.98376, 0.98369, 0.98370, 0.98334, 0.98308, 0.98368, 0.98370, 0.94625],
                        [0.98300, 0.98291, 0.98279, 0.98274, 0.98315, 0.98309, 0.98383,
                         0.98344, 0.98382, 0.98321, 0.98381, 0.98346, 0.98426, 0.98377,
                         0.98319, 0.98409, 0.98348, 0.98389, 0.98395, 0.98351, 0.98436,
                         0.98431, 0.98392, 0.98407, 0.98395, 0.98399, 0.98419, 0.98389, 0.94700],
                        [0.98235, 0.98231, 0.98260, 0.98299, 0.98294, 0.98291, 0.98370,
                         0.98279, 0.98360, 0.98315, 0.98352, 0.98376, 0.98382, 0.98394,
                         0.98380, 0.98430, 0.98425, 0.98361, 0.98365, 0.98368, 0.98398,
                         0.98429, 0.98378, 0.98414, 0.98399, 0.98433, 0.98429, 0.98386, 0.94675],
                        [0.98202, 0.98276, 0.98271, 0.98320, 0.98318, 0.98307, 0.98329,
                         0.98284, 0.98333, 0.98346, 0.98324, 0.98346, 0.98341, 0.98362,
                         0.98379, 0.98374, 0.98452, 0.98367, 0.98360, 0.98402, 0.98371,
                         0.98420, 0.98385, 0.98403, 0.98387, 0.98410, 0.98464, 0.98389, 0.94628],
                        [0.98252, 0.98354, 0.98327, 0.98323, 0.98330, 0.98334, 0.98317,
                         0.98348, 0.98331, 0.98379, 0.98360, 0.98331, 0.98358, 0.98347,
                         0.98396, 0.98361, 0.98382, 0.98427, 0.98406, 0.98457, 0.98438,
                         0.98416, 0.98419, 0.98418, 0.98416, 0.98424, 0.98474, 0.98430, 0.94648],
                        [0.98288, 0.98332, 0.98345, 0.98291, 0.98294, 0.98317, 0.98293,
                         0.98346, 0.98326, 0.98320, 0.98390, 0.98317, 0.98347, 0.98368,
                         0.98395, 0.98353, 0.98312, 0.98403, 0.98395, 0.98414, 0.98463,
                         0.98399, 0.98402, 0.98431, 0.98378, 0.98419, 0.98383, 0.98443, 0.94667],
                        [0.98283, 0.98283, 0.98298, 0.98239, 0.98290, 0.98297, 0.98270,
                         0.98325, 0.98317, 0.98244, 0.98372, 0.98335, 0.98325, 0.98375,
                         0.98318, 0.98340, 0.98338, 0.98332, 0.98363, 0.98341, 0.98392,
                         0.98399, 0.98387, 0.98416, 0.98339, 0.98408, 0.98360, 0.98425, 0.94687],
                        [0.98278, 0.98277, 0.98254, 0.98229, 0.98318, 0.98297, 0.98286,
                         0.98334, 0.98302, 0.98285, 0.98337, 0.98375, 0.98343, 0.98364,
                         0.98267, 0.98370, 0.98373, 0.98350, 0.98370, 0.98358, 0.98340,
                         0.98449, 0.98397, 0.98403, 0.98391, 0.98436, 0.98456, 0.98394, 0.94701],
                        [0.98288, 0.98273, 0.98251, 0.98256, 0.98305, 0.98282, 0.98326,
                         0.98334, 0.98331, 0.98362, 0.98315, 0.98374, 0.98347, 0.98342,
                         0.98299, 0.98386, 0.98340, 0.98386, 0.98354, 0.98368, 0.98337,
                         0.98444, 0.98396, 0.98396, 0.98427, 0.98411, 0.98476, 0.98369, 0.94674],
                        [0.98289, 0.98253, 0.98261, 0.98287, 0.98245, 0.98275, 0.98335,
                         0.98323, 0.98383, 0.98352, 0.98316, 0.98352, 0.98351, 0.98324,
                         0.98357, 0.98364, 0.98314, 0.98375, 0.98313, 0.98314, 0.98351,
                         0.98365, 0.98372, 0.98358, 0.98427, 0.98354, 0.98379, 0.98387, 0.94651],
                        [0.98255, 0.98237, 0.98264, 0.98306, 0.98197, 0.98302, 0.98290,
                         0.98318, 0.98350, 0.98302, 0.98327, 0.98328, 0.98342, 0.98323,
                         0.98364, 0.98351, 0.98332, 0.98339, 0.98292, 0.98271, 0.98373,
                         0.98346, 0.98351, 0.98339, 0.98392, 0.98339, 0.98308, 0.98382, 0.94630],
                        [0.98220, 0.98225, 0.98245, 0.98279, 0.98236, 0.98328, 0.98222,
                         0.98297, 0.98268, 0.98266, 0.98324, 0.98292, 0.98281, 0.98302,
                         0.98314, 0.98337, 0.98313, 0.98267, 0.98303, 0.98294, 0.98373,
                         0.98360, 0.98365, 0.98384, 0.98325, 0.98353, 0.98316, 0.98356, 0.94606],
                        [0.98196, 0.98203, 0.98200, 0.98181, 0.98281, 0.98262, 0.98190,
                         0.98233, 0.98217, 0.98228, 0.98264, 0.98245, 0.98241, 0.98265,
                         0.98255, 0.98268, 0.98255, 0.98191, 0.98291, 0.98321, 0.98296,
                         0.98313, 0.98352, 0.98369, 0.98288, 0.98355, 0.98314, 0.98373, 0.94596],
                        [0.98171, 0.98208, 0.98154, 0.98105, 0.98249, 0.98174, 0.98224,
                         0.98179, 0.98200, 0.98193, 0.98205, 0.98234, 0.98241, 0.98243,
                         0.98230, 0.98245, 0.98261, 0.98224, 0.98270, 0.98290, 0.98229,
                         0.98285, 0.98303, 0.98279, 0.98293, 0.98330, 0.98284, 0.98381, 0.94589],
                        [0.98175, 0.98261, 0.98140, 0.98184, 0.98228, 0.98171, 0.98242,
                         0.98195, 0.98231, 0.98227, 0.98250, 0.98270, 0.98234, 0.98244,
                         0.98253, 0.98314, 0.98305, 0.98314, 0.98309, 0.98234, 0.98277,
                         0.98318, 0.98295, 0.98229, 0.98289, 0.98306, 0.98298, 0.98319, 0.94613],
                        [0.98181, 0.98252, 0.98181, 0.98273, 0.98245, 0.98173, 0.98186,
                         0.98229, 0.98274, 0.98272, 0.98268, 0.98292, 0.98222, 0.98246,
                         0.98253, 0.98318, 0.98279, 0.98307, 0.98340, 0.98224, 0.98312,
                         0.98326, 0.98292, 0.98228, 0.98268, 0.98301, 0.98339, 0.98243, 0.94624],
                        [0.98157, 0.98162, 0.98230, 0.98250, 0.98223, 0.98184, 0.98166,
                         0.98235, 0.98248, 0.98232, 0.98211, 0.98273, 0.98212, 0.98260,
                         0.98251, 0.98253, 0.98246, 0.98263, 0.98277, 0.98280, 0.98280,
                         0.98288, 0.98261, 0.98271, 0.98272, 0.98304, 0.98346, 0.98256, 0.94591],
                        [0.98149, 0.98138, 0.98211, 0.98216, 0.98183, 0.98241, 0.98215,
                         0.98228, 0.98175, 0.98201, 0.98216, 0.98250, 0.98214, 0.98276,
                         0.98284, 0.98245, 0.98271, 0.98247, 0.98232, 0.98321, 0.98269,
                         0.98257, 0.98261, 0.98304, 0.98290, 0.98283, 0.98329, 0.98325, 0.94559],
                        [0.98175, 0.98184, 0.98149, 0.98203, 0.98185, 0.98247, 0.98230,
                         0.98214, 0.98154, 0.98221, 0.98252, 0.98243, 0.98234, 0.98224,
                         0.98290, 0.98263, 0.98280, 0.98250, 0.98247, 0.98261, 0.98287,
                         0.98253, 0.98286, 0.98294, 0.98281, 0.98282, 0.98313, 0.98352, 0.94549],
                        [0.98183, 0.98216, 0.98123, 0.98182, 0.98218, 0.98191, 0.98215,
                         0.98217, 0.98231, 0.98235, 0.98248, 0.98270, 0.98266, 0.98184,
                         0.98270, 0.98251, 0.98259, 0.98285, 0.98254, 0.98227, 0.98307,
                         0.98278, 0.98341, 0.98331, 0.98284, 0.98318, 0.98303, 0.98352, 0.94591],
                        [0.98200, 0.98218, 0.98188, 0.98182, 0.98246, 0.98192, 0.98237,
                         0.98249, 0.98304, 0.98224, 0.98264, 0.98328, 0.98319, 0.98259,
                         0.98263, 0.98276, 0.98268, 0.98307, 0.98282, 0.98319, 0.98345,
                         0.98318, 0.98390, 0.98378, 0.98341, 0.98347, 0.98324, 0.98368, 0.94645],
                        [0.98257, 0.98220, 0.98270, 0.98239, 0.98255, 0.98249, 0.98253,
                         0.98302, 0.98296, 0.98254, 0.98296, 0.98350, 0.98357, 0.98327,
                         0.98268, 0.98335, 0.98309, 0.98319, 0.98338, 0.98376, 0.98366,
                         0.98354, 0.98371, 0.98360, 0.98365, 0.98352, 0.98349, 0.98375, 0.94612],
                        [0.98274, 0.98219, 0.98259, 0.98299, 0.98263, 0.98275, 0.98250,
                         0.98325, 0.98285, 0.98319, 0.98296, 0.98319, 0.98336, 0.98327,
                         0.98298, 0.98339, 0.98343, 0.98365, 0.98373, 0.98344, 0.98362,
                         0.98359, 0.98366, 0.98356, 0.98331, 0.98356, 0.98333, 0.98340, 0.94546],
                        [0.98213, 0.98220, 0.98228, 0.98328, 0.98271, 0.98279, 0.98276,
                         0.98318, 0.98295, 0.98337, 0.98304, 0.98319, 0.98286, 0.98346,
                         0.98361, 0.98327, 0.98363, 0.98364, 0.98398, 0.98369, 0.98398,
                         0.98355, 0.98391, 0.98402, 0.98345, 0.98392, 0.98340, 0.98327, 0.94592],
                        [0.98193, 0.98274, 0.98270, 0.98341, 0.98272, 0.98293, 0.98305,
                         0.98312, 0.98288, 0.98309, 0.98334, 0.98334, 0.98272, 0.98344,
                         0.98397, 0.98357, 0.98375, 0.98322, 0.98418, 0.98445, 0.98419,
                         0.98373, 0.98396, 0.98430, 0.98380, 0.98414, 0.98387, 0.98383, 0.94679],
                        [0.98283, 0.98325, 0.98329, 0.98338, 0.98299, 0.98298, 0.98341,
                         0.98325, 0.98334, 0.98319, 0.98359, 0.98364, 0.98364, 0.98330,
                         0.98409, 0.98379, 0.98395, 0.98360, 0.98435, 0.98481, 0.98396,
                         0.98432, 0.98427, 0.98435, 0.98394, 0.98430, 0.98432, 0.98462, 0.94711],
                        [0.98312, 0.98282, 0.98301, 0.98295, 0.98309, 0.98281, 0.98339,
                         0.98315, 0.98381, 0.98340, 0.98348, 0.98381, 0.98426, 0.98354,
                         0.98373, 0.98353, 0.98365, 0.98405, 0.98422, 0.98427, 0.98394,
                         0.98445, 0.98433, 0.98396, 0.98410, 0.98449, 0.98415, 0.98441, 0.94703],
                        [0.98220, 0.98230, 0.98256, 0.98243, 0.98244, 0.98264, 0.98264,
                         0.98260, 0.98325, 0.98314, 0.98341, 0.98325, 0.98344, 0.98383,
                         0.98350, 0.98324, 0.98325, 0.98373, 0.98376, 0.98337, 0.98366,
                         0.98388, 0.98393, 0.98360, 0.98396, 0.98423, 0.98372, 0.98337, 0.94661],
                        [0.98154, 0.98244, 0.98273, 0.98224, 0.98193, 0.98268, 0.98219,
                         0.98237, 0.98266, 0.98304, 0.98347, 0.98297, 0.98295, 0.98368,
                         0.98388, 0.98346, 0.98336, 0.98323, 0.98363, 0.98311, 0.98329,
                         0.98365, 0.98369, 0.98420, 0.98347, 0.98398, 0.98391, 0.98302, 0.94635],
                        [0.98181, 0.98225, 0.98242, 0.98181, 0.98196, 0.98253, 0.98203,
                         0.98239, 0.98241, 0.98290, 0.98269, 0.98298, 0.98273, 0.98299,
                         0.98348, 0.98361, 0.98303, 0.98285, 0.98351, 0.98341, 0.98339,
                         0.98353, 0.98340, 0.98432, 0.98344, 0.98379, 0.98390, 0.98357, 0.94669],
                        [0.98218, 0.98152, 0.98147, 0.98124, 0.98178, 0.98201, 0.98176,
                         0.98191, 0.98200, 0.98219, 0.98167, 0.98250, 0.98192, 0.98237,
                         0.98243, 0.98295, 0.98241, 0.98283, 0.98289, 0.98359, 0.98341,
                         0.98332, 0.98318, 0.98331, 0.98375, 0.98343, 0.98345, 0.98389, 0.94696],
                        [0.98156, 0.98126, 0.98066, 0.98117, 0.98135, 0.98127, 0.98127,
                         0.98115, 0.98156, 0.98143, 0.98162, 0.98208, 0.98170, 0.98206,
                         0.98195, 0.98193, 0.98230, 0.98286, 0.98239, 0.98326, 0.98296,
                         0.98326, 0.98294, 0.98281, 0.98338, 0.98325, 0.98319, 0.98349, 0.94657],
                        [0.98085, 0.98134, 0.98038, 0.98114, 0.98111, 0.98090, 0.98083,
                         0.98102, 0.98103, 0.98123, 0.98201, 0.98204, 0.98199, 0.98198,
                         0.98198, 0.98167, 0.98231, 0.98247, 0.98234, 0.98269, 0.98230,
                         0.98313, 0.98267, 0.98299, 0.98279, 0.98327, 0.98287, 0.98313, 0.94591],
                        [0.98052, 0.98087, 0.98051, 0.98046, 0.98068, 0.98088, 0.98060,
                         0.98131, 0.98070, 0.98130, 0.98171, 0.98155, 0.98205, 0.98173,
                         0.98188, 0.98219, 0.98191, 0.98191, 0.98226, 0.98207, 0.98187,
                         0.98273, 0.98266, 0.98294, 0.98279, 0.98317, 0.98246, 0.98312, 0.94562],
                        [0.97979, 0.97990, 0.98048, 0.97969, 0.97981, 0.98043, 0.98033,
                         0.98102, 0.98061, 0.98133, 0.98117, 0.98080, 0.98183, 0.98112,
                         0.98149, 0.98235, 0.98150, 0.98162, 0.98204, 0.98160, 0.98203,
                         0.98225, 0.98270, 0.98291, 0.98289, 0.98283, 0.98246, 0.98300, 0.94575],
                        [0.97941, 0.97946, 0.98004, 0.97974, 0.97948, 0.97984, 0.98026,
                         0.98039, 0.98076, 0.98135, 0.98111, 0.98085, 0.98163, 0.98096,
                         0.98111, 0.98172, 0.98141, 0.98181, 0.98237, 0.98171, 0.98272,
                         0.98223, 0.98281, 0.98286, 0.98241, 0.98243, 0.98279, 0.98287, 0.94581],
                        [0.97954, 0.97948, 0.97923, 0.98006, 0.97984, 0.97969, 0.98035,
                         0.98012, 0.98068, 0.98094, 0.98107, 0.98110, 0.98136, 0.98123,
                         0.98093, 0.98099, 0.98154, 0.98188, 0.98237, 0.98196, 0.98274,
                         0.98202, 0.98260, 0.98225, 0.98178, 0.98211, 0.98259, 0.98304, 0.94585],
                        [0.97947, 0.97945, 0.97906, 0.98029, 0.97994, 0.97997, 0.98036,
                         0.98032, 0.98027, 0.98057, 0.98084, 0.98116, 0.98097, 0.98143,
                         0.98118, 0.98120, 0.98186, 0.98171, 0.98171, 0.98213, 0.98199,
                         0.98180, 0.98197, 0.98170, 0.98200, 0.98237, 0.98248, 0.98314, 0.94575],
                        [0.97951, 0.97961, 0.97989, 0.98049, 0.97986, 0.98027, 0.98021,
                         0.98039, 0.98019, 0.98073, 0.98086, 0.98122, 0.98094, 0.98151,
                         0.98177, 0.98187, 0.98189, 0.98182, 0.98173, 0.98225, 0.98200,
                         0.98240, 0.98192, 0.98196, 0.98251, 0.98283, 0.98269, 0.98262, 0.94552],
                        [0.98000, 0.97970, 0.98045, 0.98049, 0.98000, 0.98033, 0.98040,
                         0.98027, 0.98047, 0.98101, 0.98106, 0.98119, 0.98136, 0.98141,
                         0.98184, 0.98179, 0.98186, 0.98192, 0.98224, 0.98215, 0.98246,
                         0.98294, 0.98239, 0.98241, 0.98259, 0.98276, 0.98262, 0.98228, 0.94583],
                        [0.98066, 0.97995, 0.98041, 0.98053, 0.98024, 0.98055, 0.98090,
                         0.98045, 0.98089, 0.98120, 0.98120, 0.98116, 0.98191, 0.98124,
                         0.98151, 0.98156, 0.98215, 0.98201, 0.98228, 0.98199, 0.98242,
                         0.98299, 0.98242, 0.98237, 0.98282, 0.98272, 0.98276, 0.98252, 0.94619],
                        [0.98111, 0.98082, 0.98031, 0.98076, 0.98069, 0.98086, 0.98109,
                         0.98075, 0.98126, 0.98129, 0.98141, 0.98142, 0.98215, 0.98162,
                         0.98150, 0.98207, 0.98237, 0.98237, 0.98228, 0.98239, 0.98277,
                         0.98315, 0.98258, 0.98247, 0.98324, 0.98271, 0.98307, 0.98272, 0.94591],
                        [0.98112, 0.98139, 0.98036, 0.98096, 0.98109, 0.98096, 0.98131,
                         0.98105, 0.98126, 0.98135, 0.98171, 0.98196, 0.98205, 0.98242,
                         0.98181, 0.98245, 0.98239, 0.98266, 0.98253, 0.98323, 0.98326,
                         0.98299, 0.98309, 0.98285, 0.98328, 0.98240, 0.98303, 0.98286, 0.94567],
                        [0.98107, 0.98132, 0.98105, 0.98144, 0.98152, 0.98137, 0.98200,
                         0.98178, 0.98160, 0.98162, 0.98214, 0.98252, 0.98214, 0.98311,
                         0.98257, 0.98263, 0.98291, 0.98294, 0.98293, 0.98380, 0.98313,
                         0.98279, 0.98355, 0.98320, 0.98346, 0.98269, 0.98326, 0.98314, 0.94637],
                        [0.98137, 0.98111, 0.98186, 0.98206, 0.98181, 0.98185, 0.98251,
                         0.98231, 0.98228, 0.98208, 0.98252, 0.98292, 0.98255, 0.98313,
                         0.98297, 0.98294, 0.98361, 0.98317, 0.98300, 0.98381, 0.98304,
                         0.98308, 0.98364, 0.98345, 0.98387, 0.98349, 0.98370, 0.98320, 0.94697],
                        [0.98159, 0.98100, 0.98193, 0.98206, 0.98164, 0.98167, 0.98208,
                         0.98198, 0.98226, 0.98259, 0.98253, 0.98286, 0.98282, 0.98221,
                         0.98268, 0.98307, 0.98346, 0.98281, 0.98273, 0.98344, 0.98341,
                         0.98351, 0.98317, 0.98347, 0.98387, 0.98384, 0.98344, 0.98296, 0.94660],
                        [0.98143, 0.98142, 0.98162, 0.98155, 0.98135, 0.98151, 0.98121,
                         0.98169, 0.98172, 0.98263, 0.98214, 0.98219, 0.98266, 0.98173,
                         0.98256, 0.98308, 0.98267, 0.98256, 0.98305, 0.98309, 0.98331,
                         0.98350, 0.98297, 0.98332, 0.98326, 0.98339, 0.98283, 0.98262, 0.94604],
                        [0.98144, 0.98191, 0.98162, 0.98139, 0.98139, 0.98166, 0.98096,
                         0.98206, 0.98172, 0.98225, 0.98189, 0.98190, 0.98221, 0.98240,
                         0.98259, 0.98298, 0.98218, 0.98287, 0.98344, 0.98281, 0.98287,
                         0.98306, 0.98336, 0.98291, 0.98269, 0.98260, 0.98254, 0.98246, 0.94570],
                        [0.98158, 0.98159, 0.98152, 0.98146, 0.98160, 0.98172, 0.98146,
                         0.98219, 0.98214, 0.98199, 0.98231, 0.98234, 0.98169, 0.98295,
                         0.98222, 0.98256, 0.98237, 0.98292, 0.98313, 0.98245, 0.98321,
                         0.98315, 0.98329, 0.98271, 0.98289, 0.98251, 0.98253, 0.98290, 0.94575],
                        [0.98130, 0.98127, 0.98118, 0.98132, 0.98154, 0.98160, 0.98188,
                         0.98180, 0.98202, 0.98205, 0.98266, 0.98249, 0.98187, 0.98261,
                         0.98196, 0.98230, 0.98294, 0.98249, 0.98270, 0.98236, 0.98371,
                         0.98364, 0.98287, 0.98276, 0.98331, 0.98300, 0.98285, 0.98356, 0.94615],
                        [0.98080, 0.98143, 0.98115, 0.98093, 0.98109, 0.98130, 0.98155,
                         0.98136, 0.98116, 0.98202, 0.98205, 0.98193, 0.98234, 0.98173,
                         0.98198, 0.98242, 0.98259, 0.98196, 0.98215, 0.98268, 0.98296,
                         0.98307, 0.98261, 0.98246, 0.98309, 0.98310, 0.98302, 0.98301, 0.94611],
                        [0.98072, 0.98143, 0.98131, 0.98073, 0.98096, 0.98130, 0.98126,
                         0.98132, 0.98059, 0.98163, 0.98120, 0.98148, 0.98227, 0.98149,
                         0.98200, 0.98253, 0.98178, 0.98226, 0.98198, 0.98288, 0.98180,
                         0.98204, 0.98232, 0.98241, 0.98268, 0.98268, 0.98274, 0.98205, 0.94557],
                        [0.98119, 0.98137, 0.98121, 0.98123, 0.98135, 0.98175, 0.98158,
                         0.98188, 0.98115, 0.98155, 0.98146, 0.98180, 0.98209, 0.98231,
                         0.98231, 0.98252, 0.98217, 0.98327, 0.98287, 0.98271, 0.98204,
                         0.98200, 0.98263, 0.98286, 0.98279, 0.98269, 0.98268, 0.98246, 0.94552],
                        [0.98130, 0.98104, 0.98054, 0.98162, 0.98155, 0.98162, 0.98158,
                         0.98182, 0.98212, 0.98171, 0.98211, 0.98199, 0.98202, 0.98242,
                         0.98230, 0.98236, 0.98270, 0.98316, 0.98346, 0.98239, 0.98292,
                         0.98280, 0.98325, 0.98298, 0.98304, 0.98306, 0.98294, 0.98308, 0.94582],
                        [0.98066, 0.98040, 0.98009, 0.98107, 0.98151, 0.98090, 0.98109,
                         0.98092, 0.98226, 0.98175, 0.98199, 0.98174, 0.98178, 0.98151,
                         0.98192, 0.98206, 0.98239, 0.98220, 0.98293, 0.98234, 0.98295,
                         0.98328, 0.98317, 0.98277, 0.98300, 0.98273, 0.98300, 0.98277, 0.94585],
                        [0.98042, 0.98072, 0.98073, 0.98067, 0.98138, 0.98121, 0.98100,
                         0.98065, 0.98171, 0.98185, 0.98189, 0.98182, 0.98174, 0.98146,
                         0.98205, 0.98186, 0.98230, 0.98223, 0.98246, 0.98253, 0.98238,
                         0.98293, 0.98262, 0.98273, 0.98326, 0.98258, 0.98292, 0.98259, 0.94604],
                        [0.98088, 0.98161, 0.98138, 0.98118, 0.98107, 0.98197, 0.98120,
                         0.98116, 0.98133, 0.98190, 0.98174, 0.98196, 0.98211, 0.98234,
                         0.98238, 0.98213, 0.98271, 0.98307, 0.98234, 0.98252, 0.98225,
                         0.98261, 0.98238, 0.98286, 0.98365, 0.98333, 0.98306, 0.98329, 0.94641],
                        [0.98113, 0.98159, 0.98135, 0.98135, 0.98100, 0.98188, 0.98130,
                         0.98153, 0.98121, 0.98169, 0.98143, 0.98197, 0.98219, 0.98264,
                         0.98239, 0.98250, 0.98286, 0.98343, 0.98224, 0.98240, 0.98269,
                         0.98286, 0.98265, 0.98296, 0.98330, 0.98342, 0.98321, 0.98357, 0.94611],
                        [0.98115, 0.98118, 0.98124, 0.98108, 0.98167, 0.98151, 0.98159,
                         0.98153, 0.98125, 0.98150, 0.98181, 0.98214, 0.98206, 0.98236,
                         0.98224, 0.98242, 0.98264, 0.98308, 0.98242, 0.98278, 0.98300,
                         0.98325, 0.98311, 0.98282, 0.98271, 0.98271, 0.98317, 0.98300, 0.94575],
                        [0.98146, 0.98125, 0.98120, 0.98138, 0.98236, 0.98169, 0.98197,
                         0.98163, 0.98155, 0.98196, 0.98254, 0.98220, 0.98206, 0.98227,
                         0.98219, 0.98265, 0.98274, 0.98264, 0.98272, 0.98331, 0.98308,
                         0.98300, 0.98310, 0.98282, 0.98256, 0.98267, 0.98293, 0.98262, 0.94608],
                        [0.98194, 0.98175, 0.98143, 0.98199, 0.98253, 0.98248, 0.98225,
                         0.98216, 0.98223, 0.98288, 0.98271, 0.98243, 0.98227, 0.98261,
                         0.98275, 0.98332, 0.98341, 0.98287, 0.98295, 0.98345, 0.98320,
                         0.98267, 0.98333, 0.98343, 0.98284, 0.98336, 0.98282, 0.98295, 0.94679],
                        [0.98226, 0.98218, 0.98218, 0.98229, 0.98222, 0.98276, 0.98249,
                         0.98254, 0.98306, 0.98302, 0.98253, 0.98289, 0.98285, 0.98307,
                         0.98342, 0.98325, 0.98383, 0.98345, 0.98344, 0.98352, 0.98334,
                         0.98330, 0.98388, 0.98366, 0.98327, 0.98355, 0.98316, 0.98330, 0.94696],
                        [0.98223, 0.98216, 0.98254, 0.98220, 0.98180, 0.98226, 0.98247,
                         0.98235, 0.98318, 0.98239, 0.98279, 0.98296, 0.98304, 0.98315,
                         0.98308, 0.98269, 0.98337, 0.98343, 0.98380, 0.98331, 0.98339,
                         0.98359, 0.98349, 0.98287, 0.98348, 0.98306, 0.98356, 0.98322, 0.94615],
                        [0.98205, 0.98216, 0.98223, 0.98208, 0.98213, 0.98214, 0.98225,
                         0.98213, 0.98285, 0.98233, 0.98322, 0.98303, 0.98271, 0.98297,
                         0.98253, 0.98277, 0.98301, 0.98299, 0.98329, 0.98296, 0.98335,
                         0.98288, 0.98290, 0.98269, 0.98362, 0.98314, 0.98347, 0.98303, 0.94554],
                        [0.98187, 0.98225, 0.98202, 0.98198, 0.98241, 0.98226, 0.98214,
                         0.98211, 0.98260, 0.98277, 0.98296, 0.98292, 0.98251, 0.98282,
                         0.98260, 0.98305, 0.98321, 0.98294, 0.98208, 0.98298, 0.98327,
                         0.98237, 0.98278, 0.98320, 0.98332, 0.98338, 0.98264, 0.98258, 0.94549],
                        [0.98161, 0.98187, 0.98184, 0.98161, 0.98178, 0.98177, 0.98204,
                         0.98199, 0.98192, 0.98258, 0.98209, 0.98229, 0.98234, 0.98257,
                         0.98267, 0.98268, 0.98300, 0.98292, 0.98197, 0.98299, 0.98295,
                         0.98231, 0.98262, 0.98300, 0.98267, 0.98256, 0.98150, 0.98187, 0.94544],
                        [0.98187, 0.98172, 0.98177, 0.98178, 0.98149, 0.98159, 0.98200,
                         0.98229, 0.98171, 0.98195, 0.98191, 0.98211, 0.98222, 0.98246,
                         0.98254, 0.98230, 0.98260, 0.98257, 0.98331, 0.98312, 0.98289,
                         0.98265, 0.98271, 0.98257, 0.98268, 0.98194, 0.98124, 0.98191, 0.94549],
                        [0.98249, 0.98222, 0.98199, 0.98234, 0.98218, 0.98235, 0.98216,
                         0.98287, 0.98266, 0.98201, 0.98248, 0.98269, 0.98232, 0.98259,
                         0.98241, 0.98263, 0.98274, 0.98257, 0.98385, 0.98337, 0.98332,
                         0.98314, 0.98321, 0.98268, 0.98305, 0.98248, 0.98222, 0.98280, 0.94564],
                        [0.98266, 0.98250, 0.98229, 0.98231, 0.98278, 0.98283, 0.98265,
                         0.98307, 0.98337, 0.98259, 0.98280, 0.98327, 0.98262, 0.98263,
                         0.98290, 0.98343, 0.98323, 0.98295, 0.98323, 0.98313, 0.98330,
                         0.98348, 0.98341, 0.98317, 0.98304, 0.98307, 0.98311, 0.98300, 0.94572],
                        [0.98235, 0.98227, 0.98225, 0.98220, 0.98251, 0.98215, 0.98287,
                         0.98272, 0.98268, 0.98252, 0.98278, 0.98316, 0.98275, 0.98271,
                         0.98343, 0.98351, 0.98309, 0.98294, 0.98274, 0.98269, 0.98292,
                         0.98351, 0.98291, 0.98320, 0.98272, 0.98286, 0.98283, 0.98227, 0.94563],
                        [0.98196, 0.98222, 0.98197, 0.98240, 0.98234, 0.98146, 0.98235,
                         0.98223, 0.98206, 0.98216, 0.98262, 0.98257, 0.98286, 0.98281,
                         0.98303, 0.98291, 0.98259, 0.98276, 0.98266, 0.98284, 0.98301,
                         0.98304, 0.98230, 0.98268, 0.98258, 0.98253, 0.98238, 0.98177, 0.94545],
                        [0.98163, 0.98211, 0.98156, 0.98200, 0.98235, 0.98155, 0.98171,
                         0.98184, 0.98232, 0.98199, 0.98214, 0.98210, 0.98289, 0.98233,
                         0.98244, 0.98246, 0.98237, 0.98257, 0.98253, 0.98284, 0.98291,
                         0.98246, 0.98215, 0.98223, 0.98242, 0.98204, 0.98224, 0.98167, 0.94523],
                        [0.98156, 0.98178, 0.98139, 0.98127, 0.98198, 0.98200, 0.98156,
                         0.98188, 0.98248, 0.98198, 0.98184, 0.98224, 0.98283, 0.98186,
                         0.98220, 0.98237, 0.98249, 0.98244, 0.98258, 0.98258, 0.98248,
                         0.98234, 0.98254, 0.98228, 0.98241, 0.98141, 0.98208, 0.98196, 0.94532],
                        [0.98199, 0.98180, 0.98203, 0.98114, 0.98212, 0.98265, 0.98205,
                         0.98246, 0.98246, 0.98254, 0.98239, 0.98300, 0.98285, 0.98229,
                         0.98239, 0.98284, 0.98294, 0.98282, 0.98302, 0.98267, 0.98277,
                         0.98274, 0.98299, 0.98280, 0.98302, 0.98189, 0.98228, 0.98257, 0.94582],
                        [0.98226, 0.98197, 0.98252, 0.98155, 0.98245, 0.98283, 0.98263,
                         0.98257, 0.98250, 0.98291, 0.98296, 0.98333, 0.98236, 0.98293,
                         0.98255, 0.98309, 0.98309, 0.98300, 0.98321, 0.98281, 0.98323,
                         0.98328, 0.98285, 0.98312, 0.98341, 0.98281, 0.98271, 0.98265, 0.94579],
                        [0.98181, 0.98166, 0.98186, 0.98174, 0.98212, 0.98215, 0.98248,
                         0.98203, 0.98228, 0.98212, 0.98253, 0.98267, 0.98168, 0.98281,
                         0.98219, 0.98247, 0.98287, 0.98246, 0.98263, 0.98276, 0.98280,
                         0.98347, 0.98230, 0.98278, 0.98287, 0.98253, 0.98257, 0.98191, 0.94508],
                        [0.98129, 0.98137, 0.98105, 0.98132, 0.98180, 0.98167, 0.98195,
                         0.98168, 0.98207, 0.98116, 0.98163, 0.98187, 0.98174, 0.98240,
                         0.98196, 0.98206, 0.98253, 0.98230, 0.98218, 0.98267, 0.98211,
                         0.98313, 0.98234, 0.98234, 0.98196, 0.98169, 0.98186, 0.98113, 0.94457],
                        [0.98142, 0.98165, 0.98111, 0.98085, 0.98168, 0.98163, 0.98167,
                         0.98179, 0.98236, 0.98128, 0.98140, 0.98157, 0.98197, 0.98222,
                         0.98202, 0.98227, 0.98194, 0.98244, 0.98224, 0.98260, 0.98180,
                         0.98254, 0.98261, 0.98205, 0.98151, 0.98143, 0.98150, 0.98105, 0.94432],
                        [0.98211, 0.98221, 0.98176, 0.98132, 0.98174, 0.98178, 0.98178,
                         0.98223, 0.98279, 0.98206, 0.98218, 0.98188, 0.98247, 0.98234,
                         0.98239, 0.98238, 0.98218, 0.98220, 0.98249, 0.98242, 0.98194,
                         0.98257, 0.98229, 0.98201, 0.98210, 0.98168, 0.98198, 0.98164, 0.94428],
                        [0.98246, 0.98209, 0.98224, 0.98220, 0.98174, 0.98218, 0.98235,
                         0.98229, 0.98266, 0.98228, 0.98290, 0.98227, 0.98310, 0.98269,
                         0.98267, 0.98200, 0.98262, 0.98205, 0.98245, 0.98224, 0.98220,
                         0.98241, 0.98209, 0.98218, 0.98260, 0.98191, 0.98226, 0.98170, 0.94404],
                        [0.98189, 0.98165, 0.98193, 0.98222, 0.98145, 0.98216, 0.98248,
                         0.98146, 0.98213, 0.98181, 0.98236, 0.98214, 0.98260, 0.98249,
                         0.98207, 0.98131, 0.98181, 0.98197, 0.98161, 0.98185, 0.98200,
                         0.98153, 0.98203, 0.98185, 0.98173, 0.98150, 0.98137, 0.98046, 0.94296],
                        [0.98071, 0.98173, 0.98101, 0.98143, 0.98125, 0.98127, 0.98138,
                         0.98087, 0.98169, 0.98151, 0.98115, 0.98171, 0.98136, 0.98140,
                         0.98102, 0.98047, 0.98066, 0.98123, 0.98048, 0.98092, 0.98112,
                         0.98090, 0.98113, 0.98055, 0.98046, 0.98031, 0.97992, 0.97908, 0.94134],
                        [0.97974, 0.98123, 0.98027, 0.98047, 0.98067, 0.98003, 0.97991,
                         0.98037, 0.98063, 0.98087, 0.98002, 0.98101, 0.98024, 0.97973,
                         0.97978, 0.97924, 0.97936, 0.97944, 0.97897, 0.97945, 0.97919,
                         0.97971, 0.97932, 0.97876, 0.97937, 0.97860, 0.97822, 0.97761, 0.93876],
                        [0.97933, 0.97937, 0.97942, 0.97900, 0.97890, 0.97863, 0.97834,
                         0.97859, 0.97875, 0.97899, 0.97872, 0.97963, 0.97885, 0.97781,
                         0.97797, 0.97750, 0.97711, 0.97676, 0.97653, 0.97705, 0.97620,
                         0.97719, 0.97688, 0.97669, 0.97744, 0.97644, 0.97600, 0.97473, 0.93465],
                        [0.97799, 0.97690, 0.97744, 0.97646, 0.97580, 0.97617, 0.97576,
                         0.97580, 0.97676, 0.97632, 0.97648, 0.97683, 0.97635, 0.97528,
                         0.97520, 0.97456, 0.97360, 0.97323, 0.97335, 0.97317, 0.97252,
                         0.97383, 0.97352, 0.97348, 0.97394, 0.97311, 0.97268, 0.97025, 0.92941],
                        [0.97446, 0.97396, 0.97383, 0.97277, 0.97200, 0.97242, 0.97201,
                         0.97238, 0.97362, 0.97284, 0.97272, 0.97277, 0.97235, 0.97149,
                         0.97076, 0.96962, 0.96865, 0.96825, 0.96865, 0.96799, 0.96785,
                         0.96936, 0.96887, 0.96851, 0.96875, 0.96798, 0.96739, 0.96457, 0.92279],
                        [0.96938, 0.96993, 0.96909, 0.96820, 0.96773, 0.96758, 0.96735,
                         0.96746, 0.96797, 0.96798, 0.96819, 0.96795, 0.96722, 0.96626,
                         0.96470, 0.96344, 0.96241, 0.96187, 0.96213, 0.96187, 0.96217,
                         0.96291, 0.96270, 0.96233, 0.96205, 0.96137, 0.96023, 0.95727, 0.91401],
                        [0.96339, 0.96412, 0.96316, 0.96235, 0.96160, 0.96082, 0.96107,
                         0.96037, 0.96048, 0.96145, 0.96260, 0.96153, 0.96067, 0.95939,
                         0.95716, 0.95594, 0.95465, 0.95404, 0.95376, 0.95421, 0.95473,
                         0.95428, 0.95473, 0.95451, 0.95387, 0.95334, 0.95155, 0.94755, 0.90265],
                        [0.95580, 0.95603, 0.95514, 0.95404, 0.95258, 0.95180, 0.95192,
                         0.95147, 0.95225, 0.95262, 0.95429, 0.95274, 0.95167, 0.95035,
                         0.94775, 0.94585, 0.94440, 0.94357, 0.94261, 0.94360, 0.94399,
                         0.94366, 0.94436, 0.94396, 0.94369, 0.94301, 0.94040, 0.93524, 0.88892],
                        [0.94605, 0.94564, 0.94483, 0.94323, 0.94134, 0.94085, 0.94011,
                         0.94094, 0.94229, 0.94172, 0.94324, 0.94214, 0.94030, 0.93882,
                         0.93610, 0.93339, 0.93129, 0.92998, 0.92905, 0.92980, 0.93026,
                         0.93071, 0.93141, 0.93082, 0.93093, 0.92938, 0.92627, 0.92028, 0.87277],
                        [0.93377, 0.93291, 0.93205, 0.92997, 0.92790, 0.92711, 0.92647,
                         0.92747, 0.92866, 0.92900, 0.92972, 0.92910, 0.92701, 0.92437,
                         0.92137, 0.91843, 0.91558, 0.91368, 0.91315, 0.91344, 0.91424,
                         0.91481, 0.91576, 0.91516, 0.91479, 0.91241, 0.90946, 0.90235, 0.85338],
                        [0.91857, 0.91793, 0.91640, 0.91378, 0.91165, 0.90988, 0.91040,
                         0.91069, 0.91165, 0.91350, 0.91337, 0.91269, 0.91107, 0.90691,
                         0.90366, 0.90016, 0.89744, 0.89507, 0.89436, 0.89472, 0.89560,
                         0.89649, 0.89697, 0.89677, 0.89540, 0.89305, 0.88996, 0.88129, 0.83069],
                        [0.90021, 0.89996, 0.89748, 0.89440, 0.89219, 0.88986, 0.89069,
                         0.89110, 0.89215, 0.89429, 0.89436, 0.89312, 0.89141, 0.88676,
                         0.88293, 0.87870, 0.87593, 0.87366, 0.87245, 0.87287, 0.87376,
                         0.87558, 0.87492, 0.87488, 0.87338, 0.87124, 0.86707, 0.85686, 0.80517],
                        [0.87876, 0.87837, 0.87547, 0.87208, 0.86942, 0.86749, 0.86752,
                         0.86811, 0.86992, 0.87163, 0.87279, 0.87092, 0.86849, 0.86416,
                         0.85893, 0.85439, 0.85069, 0.84888, 0.84744, 0.84771, 0.84890,
                         0.85083, 0.84990, 0.84956, 0.84847, 0.84606, 0.84037, 0.82954, 0.77682],
                        [0.85435, 0.85389, 0.85091, 0.84732, 0.84371, 0.84239, 0.84167,
                         0.84222, 0.84479, 0.84629, 0.84833, 0.84633, 0.84300, 0.83886,
                         0.83274, 0.82756, 0.82334, 0.82107, 0.81992, 0.82021, 0.82145,
                         0.82278, 0.82228, 0.82181, 0.82036, 0.81725, 0.81080, 0.79972, 0.74550],
                        [0.82753, 0.82683, 0.82341, 0.81994, 0.81542, 0.81398, 0.81326,
                         0.81460, 0.81682, 0.81893, 0.82087, 0.81928, 0.81509, 0.81072,
                         0.80449, 0.79870, 0.79414, 0.79102, 0.79014, 0.79039, 0.79128,
                         0.79254, 0.79225, 0.79170, 0.78967, 0.78545, 0.77922, 0.76676, 0.71175],
                        [0.79803, 0.79646, 0.79270, 0.78911, 0.78437, 0.78226, 0.78217,
                         0.78412, 0.78584, 0.78912, 0.79022, 0.78931, 0.78463, 0.77956,
                         0.77296, 0.76696, 0.76165, 0.75887, 0.75745, 0.75738, 0.75842,
                         0.75976, 0.75964, 0.75882, 0.75628, 0.75120, 0.74516, 0.73098, 0.67604],
                        [0.76534, 0.76339, 0.75988, 0.75525, 0.75114, 0.74837, 0.74883,
                         0.75061, 0.75270, 0.75600, 0.75725, 0.75629, 0.75170, 0.74576,
                         0.73859, 0.73213, 0.72659, 0.72421, 0.72242, 0.72210, 0.72359,
                         0.72443, 0.72458, 0.72334, 0.72021, 0.71539, 0.70852, 0.69365, 0.63913],
                        [0.73066, 0.72903, 0.72541, 0.72009, 0.71620, 0.71340, 0.71394,
                         0.71566, 0.71833, 0.72082, 0.72300, 0.72131, 0.71696, 0.71047,
                         0.70306, 0.69635, 0.69080, 0.68742, 0.68599, 0.68600, 0.68721,
                         0.68790, 0.68795, 0.68643, 0.68323, 0.67846, 0.67045, 0.65542, 0.60169],
                        [0.69463, 0.69332, 0.68910, 0.68362, 0.67923, 0.67731, 0.67742,
                         0.67928, 0.68212, 0.68484, 0.68701, 0.68508, 0.68076, 0.67400,
                         0.66653, 0.66004, 0.65400, 0.64951, 0.64847, 0.64911, 0.64955,
                         0.65054, 0.65017, 0.64867, 0.64567, 0.64005, 0.63157, 0.61617, 0.56333],
                        [0.65660, 0.65597, 0.65139, 0.64546, 0.64093, 0.63957, 0.63927,
                         0.64124, 0.64399, 0.64752, 0.64951, 0.64775, 0.64347, 0.63599,
                         0.62869, 0.62198, 0.61577, 0.61150, 0.61028, 0.61089, 0.61113,
                         0.61198, 0.61129, 0.60965, 0.60655, 0.60055, 0.59189, 0.57609, 0.52422],
                        [0.61752, 0.61737, 0.61250, 0.60654, 0.60215, 0.60025, 0.60042,
                         0.60213, 0.60536, 0.60909, 0.61117, 0.60979, 0.60518, 0.59716,
                         0.59027, 0.58265, 0.57697, 0.57328, 0.57142, 0.57150, 0.57214,
                         0.57280, 0.57197, 0.57009, 0.56637, 0.56085, 0.55198, 0.53593, 0.48569],
                        [0.57872, 0.57841, 0.57346, 0.56788, 0.56332, 0.56079, 0.56166,
                         0.56327, 0.56722, 0.57056, 0.57246, 0.57126, 0.56629, 0.55884,
                         0.55183, 0.54385, 0.53819, 0.53458, 0.53260, 0.53226, 0.53322,
                         0.53389, 0.53304, 0.53129, 0.52694, 0.52161, 0.51251, 0.49645, 0.44844],
                        [0.54002, 0.53940, 0.53485, 0.52926, 0.52471, 0.52239, 0.52293,
                         0.52512, 0.52888, 0.53216, 0.53385, 0.53234, 0.52755, 0.52061,
                         0.51328, 0.50590, 0.49971, 0.49621, 0.49426, 0.49384, 0.49477,
                         0.49540, 0.49446, 0.49281, 0.48880, 0.48307, 0.47387, 0.45826, 0.41231],
                        [0.50150, 0.50071, 0.49631, 0.49056, 0.48649, 0.48457, 0.48449,
                         0.48696, 0.49033, 0.49382, 0.49565, 0.49398, 0.48922, 0.48239,
                         0.47500, 0.46794, 0.46206, 0.45816, 0.45623, 0.45601, 0.45692,
                         0.45736, 0.45634, 0.45440, 0.45086, 0.44515, 0.43622, 0.42137, 0.37744],
                        [0.46372, 0.46287, 0.45817, 0.45251, 0.44867, 0.44660, 0.44673,
                         0.44908, 0.45254, 0.45589, 0.45764, 0.45649, 0.45143, 0.44475,
                         0.43740, 0.43033, 0.42518, 0.42055, 0.41892, 0.41888, 0.41981,
                         0.42008, 0.41953, 0.41718, 0.41343, 0.40810, 0.39975, 0.38542, 0.34402],
                        [0.42635, 0.42540, 0.42088, 0.41547, 0.41114, 0.40922, 0.40967,
                         0.41201, 0.41536, 0.41864, 0.41977, 0.41935, 0.41408, 0.40755,
                         0.40036, 0.39344, 0.38845, 0.38409, 0.38224, 0.38242, 0.38310,
                         0.38351, 0.38347, 0.38110, 0.37732, 0.37224, 0.36436, 0.35047, 0.31187],
                        [0.38926, 0.38815, 0.38401, 0.37898, 0.37417, 0.37271, 0.37302,
                         0.37535, 0.37844, 0.38188, 0.38301, 0.38226, 0.37712, 0.37080,
                         0.36367, 0.35679, 0.35194, 0.34826, 0.34612, 0.34638, 0.34695,
                         0.34773, 0.34735, 0.34553, 0.34217, 0.33740, 0.32981, 0.31662, 0.28062],
                        [0.35306, 0.35198, 0.34774, 0.34271, 0.33821, 0.33671, 0.33686,
                         0.33893, 0.34224, 0.34570, 0.34741, 0.34572, 0.34107, 0.33481,
                         0.32785, 0.32095, 0.31620, 0.31287, 0.31119, 0.31121, 0.31201,
                         0.31301, 0.31255, 0.31117, 0.30808, 0.30379, 0.29647, 0.28395, 0.25058],
                        [0.31802, 0.31708, 0.31280, 0.30742, 0.30354, 0.30187, 0.30200,
                         0.30354, 0.30714, 0.31044, 0.31232, 0.31053, 0.30623, 0.29975,
                         0.29331, 0.28686, 0.28172, 0.27851, 0.27756, 0.27748, 0.27869,
                         0.27953, 0.27964, 0.27843, 0.27548, 0.27157, 0.26482, 0.25309, 0.22236],
                        [0.28418, 0.28308, 0.27928, 0.27385, 0.27020, 0.26862, 0.26868,
                         0.26991, 0.27330, 0.27631, 0.27810, 0.27677, 0.27251, 0.26593,
                         0.26011, 0.25439, 0.24912, 0.24587, 0.24532, 0.24554, 0.24689,
                         0.24770, 0.24796, 0.24691, 0.24441, 0.24073, 0.23474, 0.22414, 0.19614],
                        [0.25146, 0.25029, 0.24689, 0.24174, 0.23798, 0.23657, 0.23648,
                         0.23788, 0.24074, 0.24368, 0.24523, 0.24413, 0.24011, 0.23406,
                         0.22849, 0.22310, 0.21857, 0.21548, 0.21478, 0.21529, 0.21646,
                         0.21756, 0.21775, 0.21691, 0.21501, 0.21154, 0.20634, 0.19677, 0.17172],
                        [0.21999, 0.21916, 0.21572, 0.21107, 0.20716, 0.20568, 0.20581,
                         0.20740, 0.20974, 0.21300, 0.21411, 0.21293, 0.20947, 0.20429,
                         0.19872, 0.19338, 0.18974, 0.18709, 0.18620, 0.18680, 0.18783,
                         0.18914, 0.18953, 0.18889, 0.18749, 0.18435, 0.17993, 0.17122, 0.14901],
                        [0.19068, 0.18984, 0.18648, 0.18212, 0.17861, 0.17685, 0.17735,
                         0.17885, 0.18112, 0.18419, 0.18514, 0.18424, 0.18088, 0.17626,
                         0.17102, 0.16617, 0.16296, 0.16083, 0.16010, 0.16059, 0.16157,
                         0.16284, 0.16356, 0.16301, 0.16183, 0.15946, 0.15552, 0.14776, 0.12812],
                        [0.16384, 0.16285, 0.15988, 0.15565, 0.15273, 0.15116, 0.15142,
                         0.15287, 0.15522, 0.15754, 0.15880, 0.15828, 0.15475, 0.15048,
                         0.14605, 0.14181, 0.13895, 0.13721, 0.13683, 0.13711, 0.13828,
                         0.13913, 0.13996, 0.13978, 0.13853, 0.13679, 0.13331, 0.12661, 0.10936],
                        [0.13925, 0.13865, 0.13613, 0.13250, 0.12972, 0.12872, 0.12862,
                         0.12995, 0.13196, 0.13400, 0.13533, 0.13475, 0.13169, 0.12784,
                         0.12422, 0.12043, 0.11813, 0.11640, 0.11620, 0.11645, 0.11782,
                         0.11846, 0.11909, 0.11935, 0.11827, 0.11649, 0.11376, 0.10815, 0.09307],
                        [0.11789, 0.11759, 0.11541, 0.11264, 0.10989, 0.10907, 0.10911,
                         0.11021, 0.11165, 0.11368, 0.11479, 0.11410, 0.11180, 0.10856,
                         0.10535, 0.10234, 0.10026, 0.09872, 0.09841, 0.09882, 0.09986,
                         0.10080, 0.10127, 0.10145, 0.10079, 0.09912, 0.09700, 0.09216, 0.07938],
                        [0.10003, 0.09962, 0.09776, 0.09538, 0.09300, 0.09209, 0.09237,
                         0.09325, 0.09439, 0.09607, 0.09720, 0.09648, 0.09465, 0.09220,
                         0.08922, 0.08703, 0.08494, 0.08389, 0.08344, 0.08404, 0.08464,
                         0.08567, 0.08609, 0.08611, 0.08561, 0.08442, 0.08257, 0.07830, 0.06776],
                        [0.08466, 0.08430, 0.08262, 0.08041, 0.07867, 0.07789, 0.07803,
                         0.07871, 0.08003, 0.08118, 0.08221, 0.08170, 0.08012, 0.07813,
                         0.07568, 0.07367, 0.07211, 0.07134, 0.07097, 0.07160, 0.07204,
                         0.07282, 0.07324, 0.07332, 0.07278, 0.07191, 0.07017, 0.06671, 0.05774],
                        [0.07156, 0.07112, 0.06982, 0.06796, 0.06669, 0.06620, 0.06614,
                         0.06663, 0.06810, 0.06895, 0.06960, 0.06950, 0.06826, 0.06628,
                         0.06440, 0.06245, 0.06151, 0.06088, 0.06074, 0.06103, 0.06161,
                         0.06207, 0.06248, 0.06252, 0.06213, 0.06143, 0.05979, 0.05718, 0.04935],
                        [0.06076, 0.06019, 0.05935, 0.05789, 0.05672, 0.05648, 0.05644,
                         0.05691, 0.05809, 0.05876, 0.05919, 0.05937, 0.05837, 0.05661,
                         0.05502, 0.05349, 0.05270, 0.05214, 0.05212, 0.05213, 0.05284,
                         0.05314, 0.05353, 0.05331, 0.05314, 0.05255, 0.05117, 0.04910, 0.04256],
                        [0.05205, 0.05179, 0.05098, 0.04981, 0.04876, 0.04846, 0.04858,
                         0.04914, 0.04987, 0.05050, 0.05087, 0.05106, 0.05007, 0.04877,
                         0.04744, 0.04629, 0.04549, 0.04495, 0.04497, 0.04505, 0.04552,
                         0.04584, 0.04624, 0.04595, 0.04574, 0.04522, 0.04404, 0.04236, 0.03707],
                        [0.04508, 0.04504, 0.04415, 0.04318, 0.04250, 0.04208, 0.04226,
                         0.04272, 0.04323, 0.04395, 0.04432, 0.04424, 0.04350, 0.04238,
                         0.04140, 0.04037, 0.03981, 0.03930, 0.03930, 0.03953, 0.03966,
                         0.03992, 0.04030, 0.04020, 0.03989, 0.03940, 0.03841, 0.03694, 0.03254],
                        [0.03934, 0.03925, 0.03853, 0.03778, 0.03723, 0.03702, 0.03715,
                         0.03736, 0.03791, 0.03846, 0.03892, 0.03858, 0.03833, 0.03715,
                         0.03644, 0.03562, 0.03536, 0.03480, 0.03481, 0.03500, 0.03498,
                         0.03517, 0.03539, 0.03547, 0.03516, 0.03474, 0.03396, 0.03258, 0.02873],
                        [0.03456, 0.03452, 0.03400, 0.03342, 0.03274, 0.03276, 0.03293,
                         0.03294, 0.03352, 0.03379, 0.03441, 0.03396, 0.03395, 0.03289,
                         0.03238, 0.03178, 0.03150, 0.03110, 0.03096, 0.03114, 0.03115,
                         0.03131, 0.03138, 0.03147, 0.03108, 0.03080, 0.03014, 0.02901, 0.02557],
                        [0.03074, 0.03063, 0.03020, 0.02981, 0.02919, 0.02923, 0.02927,
                         0.02935, 0.02981, 0.03012, 0.03061, 0.03037, 0.03017, 0.02946,
                         0.02898, 0.02846, 0.02798, 0.02801, 0.02755, 0.02786, 0.02796,
                         0.02812, 0.02819, 0.02801, 0.02771, 0.02737, 0.02685, 0.02605, 0.02308],
                        [0.02756, 0.02737, 0.02697, 0.02671, 0.02642, 0.02632, 0.02615,
                         0.02636, 0.02680, 0.02723, 0.02735, 0.02742, 0.02690, 0.02651,
                         0.02607, 0.02553, 0.02506, 0.02517, 0.02480, 0.02510, 0.02515,
                         0.02526, 0.02543, 0.02504, 0.02505, 0.02455, 0.02413, 0.02348, 0.02086],
                        [0.02482, 0.02472, 0.02449, 0.02398, 0.02398, 0.02380, 0.02376,
                         0.02393, 0.02428, 0.02469, 0.02464, 0.02475, 0.02431, 0.02397,
                         0.02366, 0.02315, 0.02276, 0.02267, 0.02275, 0.02279, 0.02281,
                         0.02275, 0.02288, 0.02277, 0.02283, 0.02238, 0.02191, 0.02125, 0.01879],
                        [0.02257, 0.02245, 0.02245, 0.02187, 0.02176, 0.02171, 0.02191,
                         0.02198, 0.02219, 0.02247, 0.02247, 0.02244, 0.02234, 0.02183,
                         0.02159, 0.02131, 0.02095, 0.02073, 0.02100, 0.02091, 0.02092,
                         0.02083, 0.02076, 0.02099, 0.02087, 0.02057, 0.02014, 0.01944, 0.01728],
                        [0.02067, 0.02051, 0.02053, 0.02032, 0.01997, 0.01998, 0.02017,
                         0.02032, 0.02043, 0.02057, 0.02077, 0.02056, 0.02052, 0.02006,
                         0.01974, 0.01973, 0.01934, 0.01923, 0.01926, 0.01936, 0.01920,
                         0.01928, 0.01917, 0.01936, 0.01917, 0.01884, 0.01852, 0.01791, 0.01616],
                        [0.01909, 0.01907, 0.01889, 0.01885, 0.01854, 0.01846, 0.01857,
                         0.01876, 0.01885, 0.01900, 0.01928, 0.01897, 0.01880, 0.01859,
                         0.01833, 0.01827, 0.01790, 0.01798, 0.01765, 0.01792, 0.01772,
                         0.01788, 0.01786, 0.01783, 0.01764, 0.01738, 0.01702, 0.01651, 0.01505],
                        [0.01778, 0.01780, 0.01755, 0.01741, 0.01723, 0.01717, 0.01721,
                         0.01733, 0.01749, 0.01764, 0.01768, 0.01760, 0.01739, 0.01725,
                         0.01718, 0.01695, 0.01670, 0.01676, 0.01635, 0.01649, 0.01652,
                         0.01660, 0.01653, 0.01643, 0.01613, 0.01616, 0.01578, 0.01539, 0.01395],
                        [0.01650, 0.01652, 0.01636, 0.01616, 0.01600, 0.01608, 0.01606,
                         0.01614, 0.01632, 0.01633, 0.01626, 0.01643, 0.01629, 0.01600,
                         0.01596, 0.01571, 0.01560, 0.01541, 0.01529, 0.01526, 0.01549,
                         0.01543, 0.01520, 0.01517, 0.01492, 0.01494, 0.01477, 0.01440, 0.01293],
                        [0.01530, 0.01535, 0.01517, 0.01499, 0.01485, 0.01495, 0.01492,
                         0.01501, 0.01517, 0.01524, 0.01518, 0.01529, 0.01525, 0.01479,
                         0.01484, 0.01446, 0.01452, 0.01412, 0.01421, 0.01427, 0.01441,
                         0.01431, 0.01402, 0.01412, 0.01405, 0.01383, 0.01375, 0.01333, 0.01197],
                        [0.01427, 0.01428, 0.01397, 0.01390, 0.01381, 0.01384, 0.01371,
                         0.01395, 0.01404, 0.01421, 0.01424, 0.01420, 0.01413, 0.01367,
                         0.01383, 0.01334, 0.01344, 0.01313, 0.01313, 0.01328, 0.01328,
                         0.01326, 0.01310, 0.01330, 0.01318, 0.01294, 0.01267, 0.01236, 0.01113],
                        [0.01330, 0.01326, 0.01298, 0.01294, 0.01280, 0.01287, 0.01275,
                         0.01300, 0.01307, 0.01311, 0.01335, 0.01323, 0.01302, 0.01284,
                         0.01266, 0.01243, 0.01239, 0.01236, 0.01223, 0.01220, 0.01232,
                         0.01228, 0.01233, 0.01237, 0.01223, 0.01207, 0.01167, 0.01150, 0.01045],
                        [0.01238, 0.01230, 0.01223, 0.01215, 0.01197, 0.01206, 0.01200,
                         0.01213, 0.01225, 0.01219, 0.01245, 0.01239, 0.01210, 0.01209,
                         0.01156, 0.01164, 0.01157, 0.01158, 0.01143, 0.01133, 0.01145,
                         0.01150, 0.01146, 0.01136, 0.01124, 0.01123, 0.01099, 0.01075, 0.00982],
                        [0.01158, 0.01144, 0.01157, 0.01144, 0.01125, 0.01130, 0.01120,
                         0.01124, 0.01143, 0.01147, 0.01155, 0.01150, 0.01141, 0.01117,
                         0.01088, 0.01086, 0.01088, 0.01068, 0.01063, 0.01072, 0.01057,
                         0.01090, 0.01053, 0.01051, 0.01042, 0.01044, 0.01038, 0.01007, 0.00921],
                        [0.01079, 0.01080, 0.01089, 0.01068, 0.01044, 0.01045, 0.01050,
                         0.01039, 0.01065, 0.01068, 0.01066, 0.01057, 0.01068, 0.01025,
                         0.01038, 0.01012, 0.01008, 0.00975, 0.00990, 0.01007, 0.00984,
                         0.01021, 0.00987, 0.00990, 0.00985, 0.00977, 0.00956, 0.00930, 0.00858],
                        [0.00994, 0.01022, 0.01004, 0.00988, 0.00969, 0.00967, 0.00984,
                         0.00961, 0.00990, 0.00980, 0.00998, 0.00981, 0.00978, 0.00952,
                         0.00974, 0.00939, 0.00918, 0.00893, 0.00917, 0.00931, 0.00916,
                         0.00936, 0.00934, 0.00934, 0.00931, 0.00911, 0.00886, 0.00858, 0.00789],
                        [0.00911, 0.00951, 0.00915, 0.00915, 0.00909, 0.00901, 0.00903,
                         0.00891, 0.00912, 0.00908, 0.00931, 0.00920, 0.00899, 0.00897,
                         0.00895, 0.00860, 0.00846, 0.00832, 0.00838, 0.00856, 0.00846,
                         0.00860, 0.00858, 0.00859, 0.00861, 0.00842, 0.00839, 0.00808, 0.00729],
                        [0.00845, 0.00876, 0.00842, 0.00844, 0.00842, 0.00827, 0.00821,
                         0.00828, 0.00843, 0.00847, 0.00836, 0.00853, 0.00839, 0.00835,
                         0.00816, 0.00791, 0.00801, 0.00791, 0.00766, 0.00785, 0.00784,
                         0.00798, 0.00780, 0.00789, 0.00786, 0.00780, 0.00781, 0.00757, 0.00683],
                        [0.00793, 0.00793, 0.00786, 0.00773, 0.00771, 0.00756, 0.00755,
                         0.00772, 0.00784, 0.00782, 0.00759, 0.00786, 0.00774, 0.00766,
                         0.00751, 0.00734, 0.00741, 0.00730, 0.00707, 0.00711, 0.00729,
                         0.00735, 0.00726, 0.00732, 0.00722, 0.00724, 0.00714, 0.00696, 0.00638],
                        [0.00744, 0.00723, 0.00731, 0.00718, 0.00716, 0.00694, 0.00706,
                         0.00720, 0.00721, 0.00725, 0.00721, 0.00731, 0.00713, 0.00707,
                         0.00692, 0.00679, 0.00661, 0.00650, 0.00657, 0.00651, 0.00678,
                         0.00674, 0.00678, 0.00676, 0.00665, 0.00678, 0.00663, 0.00637, 0.00599],
                        [0.00691, 0.00678, 0.00673, 0.00675, 0.00666, 0.00651, 0.00666,
                         0.00662, 0.00663, 0.00676, 0.00679, 0.00683, 0.00667, 0.00651,
                         0.00626, 0.00631, 0.00610, 0.00603, 0.00611, 0.00618, 0.00633,
                         0.00621, 0.00620, 0.00620, 0.00615, 0.00628, 0.00618, 0.00592, 0.00564],
                        [0.00634, 0.00628, 0.00622, 0.00619, 0.00604, 0.00607, 0.00619,
                         0.00594, 0.00614, 0.00624, 0.00627, 0.00631, 0.00620, 0.00590,
                         0.00570, 0.00589, 0.00582, 0.00580, 0.00570, 0.00581, 0.00585,
                         0.00578, 0.00563, 0.00568, 0.00569, 0.00573, 0.00560, 0.00553, 0.00517],
                        [0.00581, 0.00583, 0.00575, 0.00564, 0.00554, 0.00549, 0.00562,
                         0.00537, 0.00575, 0.00581, 0.00574, 0.00569, 0.00571, 0.00537,
                         0.00538, 0.00541, 0.00536, 0.00537, 0.00536, 0.00535, 0.00541,
                         0.00546, 0.00523, 0.00531, 0.00535, 0.00536, 0.00515, 0.00514, 0.00461],
                        [0.00532, 0.00548, 0.00534, 0.00532, 0.00527, 0.00513, 0.00512,
                         0.00519, 0.00541, 0.00547, 0.00527, 0.00516, 0.00521, 0.00516,
                         0.00521, 0.00492, 0.00498, 0.00492, 0.00510, 0.00494, 0.00507,
                         0.00514, 0.00496, 0.00507, 0.00512, 0.00515, 0.00491, 0.00480, 0.00432],
                        [0.00489, 0.00501, 0.00510, 0.00502, 0.00502, 0.00499, 0.00486,
                         0.00517, 0.00509, 0.00503, 0.00492, 0.00484, 0.00479, 0.00500,
                         0.00499, 0.00463, 0.00480, 0.00470, 0.00478, 0.00476, 0.00482,
                         0.00478, 0.00478, 0.00483, 0.00478, 0.00487, 0.00464, 0.00456, 0.00426],
                        [0.00461, 0.00458, 0.00489, 0.00466, 0.00469, 0.00470, 0.00465,
                         0.00486, 0.00479, 0.00458, 0.00462, 0.00470, 0.00460, 0.00462,
                         0.00457, 0.00449, 0.00455, 0.00438, 0.00443, 0.00464, 0.00461,
                         0.00444, 0.00467, 0.00460, 0.00445, 0.00447, 0.00437, 0.00439, 0.00409],
                        [0.00438, 0.00438, 0.00454, 0.00439, 0.00442, 0.00440, 0.00437,
                         0.00440, 0.00442, 0.00435, 0.00439, 0.00459, 0.00445, 0.00433,
                         0.00418, 0.00431, 0.00429, 0.00395, 0.00418, 0.00430, 0.00430,
                         0.00416, 0.00443, 0.00431, 0.00424, 0.00425, 0.00426, 0.00427, 0.00380],
                        [0.00423, 0.00428, 0.00421, 0.00417, 0.00422, 0.00422, 0.00412,
                         0.00415, 0.00412, 0.00432, 0.00421, 0.00433, 0.00425, 0.00420,
                         0.00407, 0.00411, 0.00413, 0.00379, 0.00402, 0.00397, 0.00395,
                         0.00403, 0.00402, 0.00398, 0.00405, 0.00417, 0.00410, 0.00402, 0.00360],
                        [0.00416, 0.00408, 0.00416, 0.00385, 0.00394, 0.00407, 0.00392,
                         0.00398, 0.00401, 0.00426, 0.00401, 0.00398, 0.00401, 0.00406,
                         0.00408, 0.00393, 0.00394, 0.00382, 0.00388, 0.00379, 0.00375,
                         0.00396, 0.00379, 0.00378, 0.00390, 0.00392, 0.00386, 0.00365, 0.00354],
                        [0.00406, 0.00372, 0.00415, 0.00371, 0.00370, 0.00398, 0.00383,
                         0.00374, 0.00388, 0.00398, 0.00381, 0.00378, 0.00380, 0.00392,
                         0.00400, 0.00382, 0.00374, 0.00379, 0.00381, 0.00364, 0.00367,
                         0.00384, 0.00380, 0.00380, 0.00377, 0.00370, 0.00368, 0.00349, 0.00351],
                        [0.00380, 0.00357, 0.00384, 0.00379, 0.00359, 0.00373, 0.00372,
                         0.00360, 0.00370, 0.00359, 0.00369, 0.00369, 0.00367, 0.00377,
                         0.00382, 0.00369, 0.00362, 0.00369, 0.00372, 0.00354, 0.00359,
                         0.00364, 0.00370, 0.00380, 0.00359, 0.00358, 0.00352, 0.00361, 0.00342],
                        [0.00350, 0.00369, 0.00347, 0.00372, 0.00348, 0.00340, 0.00352,
                         0.00359, 0.00356, 0.00345, 0.00361, 0.00356, 0.00360, 0.00365,
                         0.00359, 0.00355, 0.00355, 0.00359, 0.00351, 0.00355, 0.00355,
                         0.00349, 0.00351, 0.00363, 0.00345, 0.00350, 0.00340, 0.00371, 0.00333],
                        [0.00343, 0.00370, 0.00340, 0.00354, 0.00336, 0.00336, 0.00345,
                         0.00359, 0.00347, 0.00356, 0.00352, 0.00345, 0.00351, 0.00352,
                         0.00347, 0.00348, 0.00350, 0.00345, 0.00340, 0.00350, 0.00356,
                         0.00335, 0.00346, 0.00341, 0.00340, 0.00353, 0.00344, 0.00354, 0.00327],
                        [0.00344, 0.00359, 0.00356, 0.00347, 0.00342, 0.00347, 0.00356,
                         0.00361, 0.00342, 0.00352, 0.00347, 0.00346, 0.00346, 0.00335,
                         0.00343, 0.00347, 0.00348, 0.00332, 0.00353, 0.00339, 0.00352,
                         0.00326, 0.00345, 0.00334, 0.00333, 0.00349, 0.00353, 0.00332, 0.00321],
                        [0.00338, 0.00349, 0.00370, 0.00341, 0.00354, 0.00347, 0.00353,
                         0.00355, 0.00338, 0.00337, 0.00350, 0.00340, 0.00351, 0.00331,
                         0.00333, 0.00344, 0.00337, 0.00330, 0.00353, 0.00338, 0.00339,
                         0.00333, 0.00335, 0.00335, 0.00320, 0.00327, 0.00350, 0.00338, 0.00308],
                        [0.00331, 0.00331, 0.00356, 0.00325, 0.00342, 0.00338, 0.00325,
                         0.00334, 0.00337, 0.00341, 0.00348, 0.00318, 0.00348, 0.00337,
                         0.00325, 0.00334, 0.00309, 0.00330, 0.00329, 0.00333, 0.00326,
                         0.00335, 0.00320, 0.00322, 0.00315, 0.00315, 0.00338, 0.00341, 0.00300],
                        [0.00322, 0.00320, 0.00325, 0.00323, 0.00326, 0.00328, 0.00310,
                         0.00318, 0.00337, 0.00351, 0.00338, 0.00305, 0.00330, 0.00334,
                         0.00328, 0.00329, 0.00298, 0.00323, 0.00317, 0.00320, 0.00321,
                         0.00325, 0.00323, 0.00321, 0.00327, 0.00323, 0.00332, 0.00332, 0.00305],
                        [0.00310, 0.00325, 0.00309, 0.00333, 0.00319, 0.00316, 0.00306,
                         0.00317, 0.00332, 0.00330, 0.00324, 0.00314, 0.00316, 0.00316,
                         0.00318, 0.00328, 0.00316, 0.00312, 0.00323, 0.00319, 0.00317,
                         0.00317, 0.00335, 0.00337, 0.00331, 0.00325, 0.00323, 0.00325, 0.00311],
                        [0.00304, 0.00322, 0.00322, 0.00329, 0.00315, 0.00311, 0.00296,
                         0.00317, 0.00323, 0.00302, 0.00312, 0.00326, 0.00317, 0.00305,
                         0.00306, 0.00310, 0.00322, 0.00310, 0.00315, 0.00321, 0.00322,
                         0.00305, 0.00325, 0.00331, 0.00325, 0.00316, 0.00312, 0.00310, 0.00297],
                        [0.00305, 0.00317, 0.00327, 0.00317, 0.00319, 0.00314, 0.00296,
                         0.00308, 0.00314, 0.00308, 0.00309, 0.00326, 0.00309, 0.00307,
                         0.00309, 0.00299, 0.00308, 0.00309, 0.00300, 0.00310, 0.00323,
                         0.00293, 0.00305, 0.00304, 0.00311, 0.00308, 0.00306, 0.00293, 0.00265],
                        [0.00302, 0.00318, 0.00312, 0.00312, 0.00311, 0.00314, 0.00301,
                         0.00302, 0.00309, 0.00323, 0.00316, 0.00319, 0.00290, 0.00306,
                         0.00301, 0.00317, 0.00297, 0.00303, 0.00295, 0.00305, 0.00312,
                         0.00309, 0.00305, 0.00290, 0.00302, 0.00306, 0.00304, 0.00293, 0.00264],
                        [0.00297, 0.00309, 0.00312, 0.00306, 0.00284, 0.00300, 0.00289,
                         0.00298, 0.00314, 0.00313, 0.00318, 0.00306, 0.00293, 0.00306,
                         0.00288, 0.00324, 0.00291, 0.00298, 0.00293, 0.00311, 0.00300,
                         0.00334, 0.00304, 0.00297, 0.00306, 0.00307, 0.00298, 0.00306, 0.00292],
                        [0.00306, 0.00302, 0.00320, 0.00302, 0.00285, 0.00293, 0.00283,
                         0.00300, 0.00313, 0.00301, 0.00309, 0.00300, 0.00304, 0.00311,
                         0.00293, 0.00311, 0.00300, 0.00305, 0.00298, 0.00318, 0.00299,
                         0.00323, 0.00296, 0.00303, 0.00308, 0.00310, 0.00301, 0.00317, 0.00300],
                        [0.00307, 0.00303, 0.00303, 0.00307, 0.00319, 0.00300, 0.00296,
                         0.00306, 0.00308, 0.00312, 0.00298, 0.00301, 0.00290, 0.00305,
                         0.00301, 0.00301, 0.00309, 0.00307, 0.00306, 0.00322, 0.00303,
                         0.00284, 0.00296, 0.00300, 0.00293, 0.00304, 0.00314, 0.00315, 0.00291],
                        [0.00295, 0.00301, 0.00289, 0.00311, 0.00327, 0.00300, 0.00303,
                         0.00308, 0.00314, 0.00322, 0.00297, 0.00303, 0.00285, 0.00300,
                         0.00286, 0.00298, 0.00294, 0.00288, 0.00301, 0.00311, 0.00293,
                         0.00278, 0.00301, 0.00295, 0.00280, 0.00298, 0.00300, 0.00303, 0.00283],
                        [0.00289, 0.00298, 0.00301, 0.00301, 0.00301, 0.00306, 0.00298,
                         0.00304, 0.00317, 0.00302, 0.00304, 0.00309, 0.00304, 0.00303,
                         0.00282, 0.00299, 0.00283, 0.00278, 0.00297, 0.00290, 0.00289,
                         0.00301, 0.00303, 0.00288, 0.00286, 0.00297, 0.00280, 0.00292, 0.00269],
                        [0.00287, 0.00296, 0.00312, 0.00294, 0.00287, 0.00315, 0.00298,
                         0.00299, 0.00302, 0.00278, 0.00301, 0.00310, 0.00313, 0.00301,
                         0.00298, 0.00296, 0.00282, 0.00288, 0.00300, 0.00284, 0.00296,
                         0.00298, 0.00296, 0.00286, 0.00299, 0.00293, 0.00293, 0.00286, 0.00267],
                        [0.00284, 0.00294, 0.00308, 0.00295, 0.00287, 0.00291, 0.00301,
                         0.00298, 0.00282, 0.00285, 0.00290, 0.00305, 0.00306, 0.00296,
                         0.00301, 0.00296, 0.00280, 0.00296, 0.00288, 0.00289, 0.00294,
                         0.00284, 0.00282, 0.00291, 0.00300, 0.00287, 0.00304, 0.00283, 0.00285],
                        [0.00280, 0.00296, 0.00294, 0.00292, 0.00284, 0.00270, 0.00290,
                         0.00293, 0.00277, 0.00291, 0.00292, 0.00298, 0.00303, 0.00290,
                         0.00288, 0.00296, 0.00284, 0.00297, 0.00269, 0.00287, 0.00283,
                         0.00292, 0.00271, 0.00294, 0.00289, 0.00286, 0.00284, 0.00284, 0.00292],
                        [0.00282, 0.00299, 0.00280, 0.00285, 0.00284, 0.00288, 0.00284,
                         0.00286, 0.00286, 0.00282, 0.00303, 0.00283, 0.00295, 0.00283,
                         0.00283, 0.00289, 0.00286, 0.00289, 0.00277, 0.00276, 0.00280,
                         0.00297, 0.00274, 0.00289, 0.00286, 0.00287, 0.00266, 0.00294, 0.00280],
                        [0.00291, 0.00289, 0.00274, 0.00285, 0.00283, 0.00301, 0.00290,
                         0.00281, 0.00290, 0.00281, 0.00305, 0.00276, 0.00285, 0.00277,
                         0.00300, 0.00288, 0.00277, 0.00278, 0.00294, 0.00276, 0.00287,
                         0.00283, 0.00285, 0.00281, 0.00283, 0.00285, 0.00282, 0.00295, 0.00265],
                        [0.00285, 0.00281, 0.00277, 0.00290, 0.00279, 0.00282, 0.00291,
                         0.00276, 0.00292, 0.00283, 0.00294, 0.00297, 0.00282, 0.00278,
                         0.00299, 0.00294, 0.00278, 0.00275, 0.00283, 0.00286, 0.00290,
                         0.00276, 0.00299, 0.00286, 0.00268, 0.00288, 0.00303, 0.00283, 0.00259],
                        [0.00272, 0.00287, 0.00280, 0.00283, 0.00281, 0.00263, 0.00279,
                         0.00276, 0.00293, 0.00276, 0.00282, 0.00306, 0.00281, 0.00284,
                         0.00266, 0.00287, 0.00291, 0.00276, 0.00268, 0.00271, 0.00278,
                         0.00283, 0.00292, 0.00291, 0.00261, 0.00283, 0.00290, 0.00278, 0.00257],
                        [0.00270, 0.00286, 0.00284, 0.00265, 0.00286, 0.00274, 0.00266,
                         0.00295, 0.00284, 0.00276, 0.00279, 0.00283, 0.00286, 0.00280,
                         0.00256, 0.00269, 0.00297, 0.00281, 0.00268, 0.00253, 0.00260,
                         0.00281, 0.00278, 0.00277, 0.00275, 0.00275, 0.00262, 0.00278, 0.00256],
                        [0.00272, 0.00269, 0.00282, 0.00256, 0.00283, 0.00287, 0.00270,
                         0.00302, 0.00270, 0.00284, 0.00275, 0.00265, 0.00288, 0.00270,
                         0.00270, 0.00260, 0.00283, 0.00279, 0.00272, 0.00265, 0.00261,
                         0.00264, 0.00284, 0.00267, 0.00279, 0.00281, 0.00264, 0.00271, 0.00260],
                        [0.00274, 0.00263, 0.00272, 0.00265, 0.00268, 0.00279, 0.00282,
                         0.00282, 0.00266, 0.00285, 0.00270, 0.00268, 0.00278, 0.00274,
                         0.00269, 0.00275, 0.00265, 0.00266, 0.00277, 0.00280, 0.00277,
                         0.00259, 0.00284, 0.00272, 0.00262, 0.00286, 0.00284, 0.00259, 0.00264],
                        [0.00269, 0.00262, 0.00270, 0.00278, 0.00253, 0.00267, 0.00277,
                         0.00271, 0.00271, 0.00285, 0.00267, 0.00279, 0.00267, 0.00273,
                         0.00264, 0.00288, 0.00272, 0.00255, 0.00277, 0.00278, 0.00280,
                         0.00271, 0.00272, 0.00270, 0.00259, 0.00277, 0.00286, 0.00250, 0.00264],
                        [0.00250, 0.00267, 0.00278, 0.00278, 0.00253, 0.00266, 0.00259,
                         0.00271, 0.00267, 0.00287, 0.00268, 0.00288, 0.00261, 0.00257,
                         0.00274, 0.00270, 0.00284, 0.00259, 0.00269, 0.00273, 0.00270,
                         0.00271, 0.00272, 0.00265, 0.00273, 0.00265, 0.00273, 0.00255, 0.00257],
                        [0.00244, 0.00274, 0.00279, 0.00272, 0.00272, 0.00272, 0.00255,
                         0.00265, 0.00263, 0.00280, 0.00271, 0.00289, 0.00256, 0.00257,
                         0.00281, 0.00256, 0.00276, 0.00273, 0.00264, 0.00267, 0.00267,
                         0.00262, 0.00276, 0.00274, 0.00273, 0.00260, 0.00267, 0.00273, 0.00244],
                        [0.00261, 0.00264, 0.00270, 0.00273, 0.00284, 0.00272, 0.00273,
                         0.00258, 0.00270, 0.00265, 0.00271, 0.00273, 0.00254, 0.00270,
                         0.00276, 0.00268, 0.00264, 0.00282, 0.00267, 0.00254, 0.00268,
                         0.00269, 0.00268, 0.00275, 0.00268, 0.00259, 0.00266, 0.00274, 0.00235],
                        [0.00275, 0.00264, 0.00266, 0.00263, 0.00272, 0.00267, 0.00279,
                         0.00259, 0.00268, 0.00260, 0.00273, 0.00258, 0.00269, 0.00269,
                         0.00268, 0.00282, 0.00263, 0.00269, 0.00270, 0.00251, 0.00262,
                         0.00285, 0.00258, 0.00259, 0.00275, 0.00261, 0.00256, 0.00261, 0.00237],
                        [0.00268, 0.00278, 0.00264, 0.00255, 0.00264, 0.00271, 0.00261,
                         0.00258, 0.00253, 0.00269, 0.00270, 0.00259, 0.00272, 0.00265,
                         0.00270, 0.00280, 0.00264, 0.00250, 0.00269, 0.00261, 0.00261,
                         0.00292, 0.00265, 0.00251, 0.00268, 0.00266, 0.00249, 0.00251, 0.00241],
                        [0.00262, 0.00278, 0.00263, 0.00267, 0.00274, 0.00273, 0.00251,
                         0.00260, 0.00241, 0.00273, 0.00258, 0.00263, 0.00252, 0.00261,
                         0.00272, 0.00263, 0.00261, 0.00254, 0.00268, 0.00262, 0.00275,
                         0.00285, 0.00270, 0.00257, 0.00249, 0.00272, 0.00259, 0.00255, 0.00245],
                        [0.00267, 0.00266, 0.00266, 0.00275, 0.00280, 0.00263, 0.00267,
                         0.00268, 0.00241, 0.00266, 0.00252, 0.00270, 0.00249, 0.00255,
                         0.00266, 0.00249, 0.00258, 0.00263, 0.00262, 0.00250, 0.00290,
                         0.00263, 0.00259, 0.00255, 0.00247, 0.00268, 0.00265, 0.00263, 0.00247],
                        [0.00267, 0.00249, 0.00264, 0.00266, 0.00272, 0.00259, 0.00277,
                         0.00266, 0.00244, 0.00265, 0.00255, 0.00273, 0.00265, 0.00258,
                         0.00250, 0.00249, 0.00257, 0.00259, 0.00254, 0.00245, 0.00279,
                         0.00246, 0.00249, 0.00249, 0.00258, 0.00258, 0.00258, 0.00261, 0.00247],
                        [0.00264, 0.00243, 0.00263, 0.00259, 0.00254, 0.00263, 0.00260,
                         0.00260, 0.00245, 0.00270, 0.00256, 0.00258, 0.00275, 0.00273,
                         0.00241, 0.00257, 0.00249, 0.00247, 0.00263, 0.00254, 0.00254,
                         0.00251, 0.00257, 0.00260, 0.00264, 0.00259, 0.00254, 0.00243, 0.00249],
                        [0.00256, 0.00246, 0.00263, 0.00259, 0.00242, 0.00253, 0.00242,
                         0.00255, 0.00239, 0.00259, 0.00254, 0.00240, 0.00266, 0.00278,
                         0.00247, 0.00261, 0.00245, 0.00246, 0.00275, 0.00255, 0.00247,
                         0.00253, 0.00268, 0.00268, 0.00256, 0.00258, 0.00250, 0.00234, 0.00242],
                        [0.00240, 0.00243, 0.00254, 0.00251, 0.00247, 0.00237, 0.00241,
                         0.00248, 0.00250, 0.00241, 0.00248, 0.00237, 0.00254, 0.00267,
                         0.00251, 0.00263, 0.00254, 0.00262, 0.00263, 0.00248, 0.00251,
                         0.00253, 0.00256, 0.00254, 0.00246, 0.00248, 0.00252, 0.00254, 0.00232],
                        [0.00238, 0.00239, 0.00247, 0.00258, 0.00258, 0.00244, 0.00255,
                         0.00245, 0.00269, 0.00248, 0.00243, 0.00255, 0.00261, 0.00260,
                         0.00256, 0.00267, 0.00266, 0.00260, 0.00246, 0.00257, 0.00253,
                         0.00261, 0.00231, 0.00252, 0.00251, 0.00254, 0.00249, 0.00262, 0.00230],
                        [0.00252, 0.00255, 0.00246, 0.00279, 0.00264, 0.00272, 0.00265,
                         0.00253, 0.00260, 0.00261, 0.00249, 0.00264, 0.00274, 0.00258,
                         0.00267, 0.00262, 0.00267, 0.00240, 0.00247, 0.00275, 0.00253,
                         0.00258, 0.00232, 0.00264, 0.00252, 0.00261, 0.00242, 0.00247, 0.00239],
                        [0.00258, 0.00269, 0.00243, 0.00266, 0.00257, 0.00282, 0.00244,
                         0.00273, 0.00247, 0.00256, 0.00257, 0.00257, 0.00273, 0.00251,
                         0.00260, 0.00249, 0.00253, 0.00243, 0.00259, 0.00277, 0.00249,
                         0.00245, 0.00255, 0.00261, 0.00239, 0.00251, 0.00247, 0.00246, 0.00250],
                        [0.00256, 0.00254, 0.00241, 0.00247, 0.00241, 0.00266, 0.00220,
                         0.00280, 0.00239, 0.00245, 0.00258, 0.00255, 0.00253, 0.00249,
                         0.00251, 0.00251, 0.00240, 0.00259, 0.00265, 0.00265, 0.00250,
                         0.00246, 0.00262, 0.00246, 0.00232, 0.00240, 0.00259, 0.00253, 0.00240],
                        [0.00253, 0.00246, 0.00253, 0.00250, 0.00238, 0.00245, 0.00236,
                         0.00266, 0.00239, 0.00247, 0.00251, 0.00259, 0.00251, 0.00252,
                         0.00259, 0.00260, 0.00241, 0.00257, 0.00252, 0.00249, 0.00258,
                         0.00255, 0.00247, 0.00245, 0.00243, 0.00240, 0.00258, 0.00250, 0.00231],
                        [0.00250, 0.00262, 0.00259, 0.00250, 0.00248, 0.00237, 0.00254,
                         0.00240, 0.00257, 0.00255, 0.00246, 0.00257, 0.00269, 0.00255,
                         0.00255, 0.00256, 0.00245, 0.00249, 0.00228, 0.00241, 0.00256,
                         0.00252, 0.00235, 0.00254, 0.00256, 0.00251, 0.00251, 0.00234, 0.00244],
                        [0.00249, 0.00272, 0.00254, 0.00246, 0.00251, 0.00240, 0.00248,
                         0.00230, 0.00259, 0.00259, 0.00249, 0.00240, 0.00265, 0.00257,
                         0.00239, 0.00246, 0.00239, 0.00250, 0.00232, 0.00250, 0.00237,
                         0.00238, 0.00237, 0.00250, 0.00254, 0.00266, 0.00247, 0.00227, 0.00248],
                        [0.00242, 0.00260, 0.00253, 0.00239, 0.00247, 0.00244, 0.00247,
                         0.00253, 0.00232, 0.00255, 0.00246, 0.00219, 0.00242, 0.00254,
                         0.00243, 0.00247, 0.00233, 0.00248, 0.00255, 0.00254, 0.00231,
                         0.00236, 0.00239, 0.00239, 0.00236, 0.00264, 0.00248, 0.00235, 0.00241],
                        ])),
    i=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                            100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                            180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                            260.0, 270.0, 280.0]),
           lam=np.array([625.18, 625.61, 626.04, 626.47, 626.90, 627.33, 627.76, 628.19,
                         628.62, 629.05, 629.48, 629.91, 630.34, 630.77, 631.20, 631.63,
                         632.06, 632.50, 632.93, 633.36, 633.79, 634.22, 634.65, 635.08,
                         635.51, 635.94, 636.37, 636.81, 637.24, 637.67, 638.10, 638.53,
                         638.96, 639.39, 639.82, 640.26, 640.69, 641.12, 641.55, 641.98,
                         642.41, 642.85, 643.28, 643.71, 644.14, 644.57, 645.00, 645.44,
                         645.87, 646.30, 646.73, 647.16, 647.60, 648.03, 648.46, 648.89,
                         649.33, 649.76, 650.19, 650.62, 651.05, 651.49, 651.92, 652.35,
                         652.78, 653.22, 653.65, 654.08, 654.52, 654.95, 655.38, 655.81,
                         656.25, 656.68, 657.11, 657.55, 657.98, 658.41, 658.84, 659.28,
                         659.71, 660.14, 660.58, 661.01, 661.44, 661.88, 662.31, 662.74,
                         663.18, 663.61, 664.04, 664.48, 664.91, 665.35, 665.78, 666.21,
                         666.65, 667.08, 667.51, 667.95, 668.38, 668.82, 669.25, 669.68,
                         670.12, 670.55, 670.99, 671.42, 671.85, 672.29, 672.72, 673.16,
                         673.59, 674.03, 674.46, 674.89, 675.33, 675.76, 676.20, 676.63,
                         677.07, 677.50, 677.94, 678.37, 678.81, 679.24, 679.68, 680.11,
                         680.55, 680.98, 681.42, 681.85, 682.29, 682.72, 683.16, 683.59,
                         684.03, 684.46, 684.90, 685.33, 685.77, 686.20, 686.64, 687.07,
                         687.51, 687.95, 688.38, 688.82, 689.25, 689.69, 690.12, 690.56,
                         691.00, 691.43, 691.87, 692.30, 692.74, 693.18, 693.61, 694.05,
                         694.48, 694.92, 695.36, 695.79, 696.23, 696.66, 697.10, 697.54,
                         697.97, 698.41, 698.85, 699.28, 699.72, 700.16, 700.59, 701.03,
                         701.47, 701.90, 702.34, 702.78, 703.21, 703.65, 704.09, 704.52,
                         704.96, 705.40, 705.83, 706.27, 706.71, 707.15, 707.58, 708.02,
                         708.46, 708.89, 709.33, 709.77, 710.21, 710.64, 711.08, 711.52,
                         711.96, 712.39, 712.83, 713.27, 713.71, 714.14, 714.58, 715.02,
                         715.46, 715.90, 716.33, 716.77, 717.21, 717.65, 718.09, 718.52,
                         718.96, 719.40, 719.84, 720.28, 720.71, 721.15, 721.59, 722.03,
                         722.47, 722.91, 723.34, 723.78, 724.22, 724.66, 725.10, 725.54,
                         725.97, 726.41, 726.85, 727.29, 727.73, 728.17, 728.61, 729.05,
                         729.49, 729.92, 730.36, 730.80, 731.24, 731.68, 732.12, 732.56,
                         733.00, 733.44, 733.88, 734.31, 734.75, 735.19, 735.63, 736.07,
                         736.51, 736.95, 737.39, 737.83, 738.27, 738.71, 739.15, 739.59,
                         740.03, 740.47, 740.91, 741.35, 741.79, 742.23, 742.67, 743.11,
                         743.55, 743.99, 744.43, 744.87, 745.31, 745.75, 746.19, 746.63,
                         747.07, 747.51, 747.95, 748.39, 748.83, 749.27, 749.71, 750.15,
                         750.59, 751.03, 751.47, 751.91, 752.35, 752.79, 753.23, 753.68,
                         754.12, 754.56, 755.00, 755.44, 755.88, 756.32, 756.76, 757.20,
                         757.64, 758.08, 758.53, 758.97, 759.41, 759.85, 760.29, 760.73,
                         761.17, 761.61, 762.06, 762.50, 762.94, 763.38, 763.82, 764.26,
                         764.70, 765.15, 765.59, 766.03, 766.47, 766.91, 767.35, 767.80,
                         768.24, 768.68, 769.12, 769.56, 770.00, 770.45, 770.89, 771.33,
                         771.77, 772.21, 772.66, 773.10, 773.54, 773.98, 774.43, 774.87,
                         775.31, 775.75, 776.19, 776.64, 777.08, 777.52, 777.96, 778.41,
                         778.85, 779.29, 779.73, 780.18, 780.62, 781.06, 781.50, 781.95,
                         782.39, 782.83, 783.28, 783.72, 784.16, 784.60, 785.05, 785.49,
                         785.93, 786.38, 786.82, 787.26, 787.71, 788.15, 788.59, 789.04,
                         789.48, 789.92, 790.37, 790.81, 791.25, 791.70, 792.14, 792.58,
                         793.03, 793.47, 793.91, 794.36, 794.80, 795.24, 795.69, 796.13,
                         796.57, 797.02, 797.46, 797.91, 798.35, 798.79, 799.24, 799.68,
                         800.13, 800.57, 801.01, 801.46, 801.90, 802.35, 802.79, 803.23,
                         803.68, 804.12, 804.57, 805.01, 805.46, 805.90, 806.34, 806.79,
                         807.23, 807.68, 808.12, 808.57, 809.01, 809.46, 809.90, 810.35,
                         810.79, 811.23, 811.68, 812.12, 812.57, 813.01, 813.46, 813.90,
                         814.35, 814.79, 815.24, 815.68, 816.13, 816.57, 817.02, 817.46,
                         817.91, 818.35, 818.80, 819.24, 819.69, 820.14, 820.58, 821.03,
                         821.47, 821.92, 822.36, 822.81, 823.25, 823.70, 824.14, 824.59,
                         825.03, 825.48, 825.93, 826.37, 826.82, 827.26, 827.71, 828.15,
                         828.60, 829.05, 829.49, 829.94, 830.38, 830.83, 831.28, 831.72,
                         832.17, 832.61, 833.06, 833.51, 833.95, 834.40, 834.84, 835.29,
                         835.74, 836.18, 836.63, 837.08, 837.52, 837.97, 838.42, 838.86,
                         839.31, 839.75, 840.20, 840.65, 841.09, 841.54, 841.99, 842.43,
                         842.88, 843.33, 843.77, 844.22, 844.67, 845.11, 845.56, 846.01,
                         846.46, 846.90, 847.35, 847.80, 848.24, 848.69, 849.14, 849.58,
                         850.03, 850.48, 850.93, 851.37, 851.82, 852.27, 852.71, 853.16,
                         853.61, 854.06, 854.50, 854.95, 855.40, 855.85, 856.29, 856.74,
                         857.19, 857.64, 858.08, 858.53, 858.98, 859.43, 859.87, 860.32,
                         860.77, 861.22, 861.67, 862.11, 862.56, 863.01, 863.46, 863.90,
                         864.35, 864.80, 865.25, 865.70, 866.14, 866.59, 867.04, 867.49,
                         867.94, 868.38, 868.83, 869.28, 869.73, 870.18, 870.63, 871.07,
                         871.52, 871.97, 872.42, 872.87, 873.32, 873.76, 874.21, 874.66,
                         875.11, 875.56, 876.01, 876.46, 876.90, 877.35, 877.80, 878.25,
                         878.70, 879.15, 879.60]),
           T=np.array([[0.00247, 0.00230, 0.00243, 0.00241, 0.00248, 0.00241, 0.00232,
                        0.00241, 0.00227, 0.00250, 0.00249, 0.00246, 0.00246, 0.00241,
                        0.00244, 0.00244, 0.00263, 0.00255, 0.00274, 0.00272, 0.00265,
                        0.00251, 0.00250, 0.00274, 0.00256, 0.00242, 0.00235, 0.00241, 0.00205],
                       [0.00245, 0.00234, 0.00258, 0.00232, 0.00244, 0.00257, 0.00231,
                        0.00241, 0.00233, 0.00238, 0.00248, 0.00256, 0.00252, 0.00239,
                        0.00251, 0.00237, 0.00255, 0.00237, 0.00268, 0.00280, 0.00273,
                        0.00263, 0.00264, 0.00270, 0.00259, 0.00245, 0.00235, 0.00240, 0.00224],
                       [0.00253, 0.00244, 0.00270, 0.00229, 0.00240, 0.00264, 0.00248,
                        0.00234, 0.00246, 0.00234, 0.00235, 0.00259, 0.00272, 0.00254,
                        0.00250, 0.00254, 0.00265, 0.00253, 0.00271, 0.00273, 0.00279,
                        0.00272, 0.00270, 0.00266, 0.00265, 0.00256, 0.00234, 0.00244, 0.00222],
                       [0.00255, 0.00252, 0.00263, 0.00246, 0.00236, 0.00264, 0.00254,
                        0.00233, 0.00250, 0.00234, 0.00231, 0.00250, 0.00273, 0.00262,
                        0.00248, 0.00264, 0.00269, 0.00279, 0.00276, 0.00268, 0.00283,
                        0.00272, 0.00275, 0.00266, 0.00268, 0.00259, 0.00240, 0.00249, 0.00188],
                       [0.00250, 0.00256, 0.00246, 0.00262, 0.00242, 0.00264, 0.00251,
                        0.00242, 0.00252, 0.00243, 0.00247, 0.00260, 0.00256, 0.00260,
                        0.00249, 0.00263, 0.00259, 0.00286, 0.00273, 0.00276, 0.00285,
                        0.00273, 0.00281, 0.00270, 0.00278, 0.00256, 0.00256, 0.00251, 0.00183],
                       [0.00248, 0.00249, 0.00248, 0.00250, 0.00255, 0.00254, 0.00250,
                        0.00254, 0.00256, 0.00254, 0.00259, 0.00276, 0.00261, 0.00262,
                        0.00257, 0.00260, 0.00256, 0.00282, 0.00279, 0.00276, 0.00278,
                        0.00275, 0.00284, 0.00280, 0.00289, 0.00252, 0.00255, 0.00243, 0.00209],
                       [0.00252, 0.00240, 0.00261, 0.00238, 0.00266, 0.00250, 0.00253,
                        0.00256, 0.00246, 0.00259, 0.00263, 0.00272, 0.00277, 0.00269,
                        0.00266, 0.00267, 0.00270, 0.00278, 0.00285, 0.00267, 0.00278,
                        0.00282, 0.00283, 0.00291, 0.00286, 0.00256, 0.00243, 0.00245, 0.00218],
                       [0.00255, 0.00247, 0.00256, 0.00250, 0.00270, 0.00250, 0.00262,
                        0.00246, 0.00239, 0.00261, 0.00257, 0.00255, 0.00275, 0.00270,
                        0.00269, 0.00274, 0.00275, 0.00276, 0.00276, 0.00271, 0.00287,
                        0.00294, 0.00273, 0.00290, 0.00278, 0.00261, 0.00243, 0.00249, 0.00211],
                       [0.00253, 0.00270, 0.00257, 0.00264, 0.00266, 0.00252, 0.00268,
                        0.00249, 0.00256, 0.00254, 0.00250, 0.00251, 0.00266, 0.00275,
                        0.00265, 0.00274, 0.00273, 0.00274, 0.00269, 0.00279, 0.00295,
                        0.00296, 0.00273, 0.00285, 0.00275, 0.00263, 0.00253, 0.00247, 0.00204],
                       [0.00251, 0.00274, 0.00275, 0.00261, 0.00260, 0.00263, 0.00258,
                        0.00261, 0.00269, 0.00250, 0.00254, 0.00273, 0.00261, 0.00277,
                        0.00264, 0.00265, 0.00280, 0.00276, 0.00270, 0.00279, 0.00301,
                        0.00285, 0.00283, 0.00279, 0.00275, 0.00268, 0.00260, 0.00258, 0.00217],
                       [0.00253, 0.00251, 0.00277, 0.00254, 0.00261, 0.00273, 0.00260,
                        0.00260, 0.00265, 0.00254, 0.00265, 0.00289, 0.00253, 0.00270,
                        0.00273, 0.00263, 0.00281, 0.00285, 0.00277, 0.00277, 0.00299,
                        0.00279, 0.00290, 0.00279, 0.00287, 0.00275, 0.00265, 0.00275, 0.00234],
                       [0.00248, 0.00239, 0.00261, 0.00248, 0.00273, 0.00267, 0.00278,
                        0.00255, 0.00256, 0.00255, 0.00275, 0.00277, 0.00259, 0.00262,
                        0.00272, 0.00262, 0.00266, 0.00289, 0.00285, 0.00268, 0.00283,
                        0.00286, 0.00298, 0.00291, 0.00293, 0.00272, 0.00267, 0.00266, 0.00227],
                       [0.00244, 0.00264, 0.00254, 0.00243, 0.00277, 0.00269, 0.00290,
                        0.00264, 0.00248, 0.00258, 0.00284, 0.00271, 0.00277, 0.00274,
                        0.00264, 0.00272, 0.00262, 0.00287, 0.00298, 0.00262, 0.00283,
                        0.00298, 0.00303, 0.00307, 0.00286, 0.00273, 0.00276, 0.00255, 0.00219],
                       [0.00249, 0.00281, 0.00258, 0.00254, 0.00264, 0.00279, 0.00272,
                        0.00268, 0.00250, 0.00261, 0.00278, 0.00270, 0.00279, 0.00278,
                        0.00269, 0.00299, 0.00270, 0.00279, 0.00294, 0.00269, 0.00291,
                        0.00298, 0.00290, 0.00296, 0.00282, 0.00289, 0.00272, 0.00259, 0.00228],
                       [0.00263, 0.00273, 0.00267, 0.00273, 0.00269, 0.00282, 0.00253,
                        0.00269, 0.00272, 0.00270, 0.00270, 0.00272, 0.00279, 0.00267,
                        0.00279, 0.00303, 0.00283, 0.00277, 0.00284, 0.00295, 0.00286,
                        0.00299, 0.00288, 0.00274, 0.00293, 0.00300, 0.00277, 0.00270, 0.00238],
                       [0.00268, 0.00272, 0.00272, 0.00278, 0.00274, 0.00268, 0.00259,
                        0.00271, 0.00271, 0.00275, 0.00270, 0.00286, 0.00282, 0.00259,
                        0.00276, 0.00276, 0.00287, 0.00274, 0.00280, 0.00298, 0.00283,
                        0.00301, 0.00302, 0.00270, 0.00291, 0.00282, 0.00291, 0.00271, 0.00236],
                       [0.00263, 0.00288, 0.00280, 0.00275, 0.00267, 0.00260, 0.00281,
                        0.00272, 0.00252, 0.00272, 0.00276, 0.00291, 0.00278, 0.00268,
                        0.00279, 0.00274, 0.00278, 0.00277, 0.00286, 0.00272, 0.00289,
                        0.00300, 0.00306, 0.00285, 0.00278, 0.00271, 0.00289, 0.00282, 0.00232],
                       [0.00249, 0.00284, 0.00281, 0.00268, 0.00256, 0.00263, 0.00283,
                        0.00265, 0.00257, 0.00269, 0.00282, 0.00282, 0.00275, 0.00280,
                        0.00288, 0.00291, 0.00280, 0.00285, 0.00294, 0.00262, 0.00291,
                        0.00301, 0.00292, 0.00302, 0.00278, 0.00288, 0.00277, 0.00295, 0.00226],
                       [0.00249, 0.00267, 0.00265, 0.00265, 0.00264, 0.00272, 0.00267,
                        0.00261, 0.00274, 0.00271, 0.00275, 0.00282, 0.00290, 0.00279,
                        0.00294, 0.00289, 0.00291, 0.00293, 0.00293, 0.00279, 0.00291,
                        0.00307, 0.00282, 0.00300, 0.00286, 0.00302, 0.00277, 0.00279, 0.00236],
                       [0.00273, 0.00264, 0.00255, 0.00260, 0.00283, 0.00271, 0.00262,
                        0.00269, 0.00271, 0.00274, 0.00269, 0.00293, 0.00305, 0.00276,
                        0.00288, 0.00271, 0.00291, 0.00303, 0.00293, 0.00297, 0.00294,
                        0.00308, 0.00287, 0.00291, 0.00293, 0.00293, 0.00289, 0.00256, 0.00253],
                       [0.00286, 0.00277, 0.00262, 0.00260, 0.00285, 0.00264, 0.00275,
                        0.00279, 0.00262, 0.00276, 0.00280, 0.00297, 0.00294, 0.00288,
                        0.00278, 0.00269, 0.00289, 0.00306, 0.00293, 0.00303, 0.00296,
                        0.00299, 0.00294, 0.00285, 0.00297, 0.00290, 0.00294, 0.00262, 0.00254],
                       [0.00280, 0.00277, 0.00263, 0.00266, 0.00274, 0.00269, 0.00288,
                        0.00276, 0.00264, 0.00274, 0.00277, 0.00283, 0.00278, 0.00297,
                        0.00274, 0.00285, 0.00291, 0.00299, 0.00291, 0.00289, 0.00295,
                        0.00280, 0.00289, 0.00276, 0.00292, 0.00298, 0.00285, 0.00282, 0.00243],
                       [0.00271, 0.00269, 0.00260, 0.00267, 0.00273, 0.00278, 0.00280,
                        0.00265, 0.00271, 0.00276, 0.00276, 0.00267, 0.00278, 0.00286,
                        0.00275, 0.00298, 0.00287, 0.00287, 0.00300, 0.00279, 0.00285,
                        0.00280, 0.00292, 0.00278, 0.00286, 0.00291, 0.00280, 0.00280, 0.00230],
                       [0.00263, 0.00272, 0.00272, 0.00274, 0.00279, 0.00291, 0.00264,
                        0.00268, 0.00279, 0.00281, 0.00286, 0.00276, 0.00289, 0.00271,
                        0.00279, 0.00302, 0.00290, 0.00284, 0.00302, 0.00287, 0.00292,
                        0.00306, 0.00300, 0.00298, 0.00292, 0.00272, 0.00285, 0.00279, 0.00234],
                       [0.00265, 0.00279, 0.00286, 0.00282, 0.00281, 0.00296, 0.00264,
                        0.00279, 0.00278, 0.00271, 0.00287, 0.00293, 0.00290, 0.00268,
                        0.00283, 0.00289, 0.00299, 0.00292, 0.00296, 0.00294, 0.00311,
                        0.00316, 0.00301, 0.00301, 0.00302, 0.00269, 0.00299, 0.00292, 0.00249],
                       [0.00274, 0.00285, 0.00293, 0.00271, 0.00282, 0.00287, 0.00272,
                        0.00281, 0.00266, 0.00268, 0.00285, 0.00293, 0.00274, 0.00276,
                        0.00286, 0.00275, 0.00295, 0.00299, 0.00294, 0.00300, 0.00303,
                        0.00306, 0.00291, 0.00281, 0.00304, 0.00279, 0.00309, 0.00291, 0.00250],
                       [0.00283, 0.00290, 0.00283, 0.00255, 0.00284, 0.00283, 0.00288,
                        0.00283, 0.00267, 0.00281, 0.00282, 0.00280, 0.00269, 0.00272,
                        0.00279, 0.00287, 0.00291, 0.00299, 0.00301, 0.00302, 0.00291,
                        0.00299, 0.00278, 0.00283, 0.00291, 0.00282, 0.00296, 0.00284, 0.00241],
                       [0.00288, 0.00288, 0.00276, 0.00259, 0.00275, 0.00278, 0.00292,
                        0.00281, 0.00283, 0.00285, 0.00280, 0.00274, 0.00276, 0.00269,
                        0.00277, 0.00304, 0.00294, 0.00288, 0.00302, 0.00301, 0.00295,
                        0.00295, 0.00280, 0.00304, 0.00281, 0.00295, 0.00287, 0.00296, 0.00237],
                       [0.00278, 0.00283, 0.00284, 0.00276, 0.00265, 0.00273, 0.00273,
                        0.00274, 0.00298, 0.00285, 0.00288, 0.00280, 0.00284, 0.00286,
                        0.00287, 0.00298, 0.00289, 0.00289, 0.00296, 0.00299, 0.00312,
                        0.00286, 0.00291, 0.00304, 0.00294, 0.00311, 0.00305, 0.00304, 0.00248],
                       [0.00270, 0.00283, 0.00285, 0.00278, 0.00275, 0.00281, 0.00269,
                        0.00275, 0.00296, 0.00287, 0.00288, 0.00284, 0.00288, 0.00299,
                        0.00293, 0.00288, 0.00283, 0.00307, 0.00305, 0.00301, 0.00317,
                        0.00300, 0.00287, 0.00305, 0.00304, 0.00304, 0.00309, 0.00297, 0.00259],
                       [0.00275, 0.00290, 0.00284, 0.00277, 0.00288, 0.00294, 0.00282,
                        0.00283, 0.00278, 0.00283, 0.00286, 0.00290, 0.00287, 0.00290,
                        0.00296, 0.00291, 0.00290, 0.00311, 0.00319, 0.00311, 0.00303,
                        0.00324, 0.00282, 0.00313, 0.00298, 0.00283, 0.00294, 0.00286, 0.00253],
                       [0.00278, 0.00292, 0.00293, 0.00285, 0.00294, 0.00294, 0.00292,
                        0.00288, 0.00275, 0.00279, 0.00284, 0.00302, 0.00291, 0.00281,
                        0.00295, 0.00299, 0.00305, 0.00298, 0.00311, 0.00317, 0.00291,
                        0.00314, 0.00300, 0.00309, 0.00297, 0.00277, 0.00292, 0.00284, 0.00249],
                       [0.00287, 0.00287, 0.00310, 0.00293, 0.00297, 0.00286, 0.00297,
                        0.00296, 0.00299, 0.00286, 0.00290, 0.00306, 0.00294, 0.00291,
                        0.00294, 0.00306, 0.00312, 0.00304, 0.00304, 0.00319, 0.00300,
                        0.00292, 0.00321, 0.00305, 0.00305, 0.00304, 0.00308, 0.00293, 0.00256],
                       [0.00300, 0.00297, 0.00322, 0.00298, 0.00301, 0.00287, 0.00306,
                        0.00306, 0.00306, 0.00294, 0.00304, 0.00298, 0.00309, 0.00302,
                        0.00300, 0.00315, 0.00309, 0.00321, 0.00313, 0.00312, 0.00321,
                        0.00296, 0.00324, 0.00307, 0.00307, 0.00319, 0.00310, 0.00291, 0.00274],
                       [0.00300, 0.00316, 0.00313, 0.00300, 0.00302, 0.00300, 0.00308,
                        0.00295, 0.00292, 0.00302, 0.00300, 0.00293, 0.00318, 0.00306,
                        0.00310, 0.00314, 0.00317, 0.00326, 0.00311, 0.00305, 0.00325,
                        0.00315, 0.00316, 0.00312, 0.00306, 0.00300, 0.00301, 0.00291, 0.00281],
                       [0.00296, 0.00317, 0.00295, 0.00301, 0.00296, 0.00309, 0.00299,
                        0.00286, 0.00297, 0.00308, 0.00285, 0.00299, 0.00310, 0.00303,
                        0.00315, 0.00304, 0.00325, 0.00316, 0.00304, 0.00309, 0.00315,
                        0.00319, 0.00307, 0.00322, 0.00307, 0.00294, 0.00297, 0.00310, 0.00255],
                       [0.00304, 0.00304, 0.00299, 0.00300, 0.00299, 0.00313, 0.00296,
                        0.00299, 0.00310, 0.00300, 0.00284, 0.00309, 0.00304, 0.00297,
                        0.00308, 0.00308, 0.00316, 0.00308, 0.00317, 0.00315, 0.00315,
                        0.00320, 0.00303, 0.00324, 0.00304, 0.00311, 0.00309, 0.00323, 0.00240],
                       [0.00314, 0.00290, 0.00321, 0.00294, 0.00314, 0.00321, 0.00305,
                        0.00308, 0.00306, 0.00293, 0.00303, 0.00306, 0.00310, 0.00303,
                        0.00306, 0.00317, 0.00307, 0.00315, 0.00333, 0.00324, 0.00323,
                        0.00324, 0.00306, 0.00319, 0.00306, 0.00316, 0.00317, 0.00315, 0.00266],
                       [0.00309, 0.00288, 0.00333, 0.00303, 0.00313, 0.00322, 0.00309,
                        0.00306, 0.00303, 0.00301, 0.00316, 0.00294, 0.00317, 0.00305,
                        0.00307, 0.00308, 0.00302, 0.00321, 0.00328, 0.00330, 0.00324,
                        0.00318, 0.00313, 0.00324, 0.00302, 0.00301, 0.00305, 0.00308, 0.00282],
                       [0.00305, 0.00311, 0.00315, 0.00313, 0.00298, 0.00315, 0.00312,
                        0.00304, 0.00304, 0.00316, 0.00319, 0.00302, 0.00317, 0.00297,
                        0.00305, 0.00311, 0.00303, 0.00325, 0.00315, 0.00329, 0.00321,
                        0.00320, 0.00320, 0.00331, 0.00308, 0.00299, 0.00305, 0.00309, 0.00270],
                       [0.00303, 0.00316, 0.00299, 0.00313, 0.00302, 0.00302, 0.00317,
                        0.00308, 0.00301, 0.00320, 0.00315, 0.00316, 0.00320, 0.00305,
                        0.00308, 0.00330, 0.00311, 0.00326, 0.00315, 0.00326, 0.00322,
                        0.00328, 0.00316, 0.00321, 0.00319, 0.00313, 0.00319, 0.00316, 0.00261],
                       [0.00298, 0.00303, 0.00307, 0.00313, 0.00317, 0.00298, 0.00316,
                        0.00307, 0.00306, 0.00312, 0.00307, 0.00311, 0.00328, 0.00322,
                        0.00328, 0.00328, 0.00331, 0.00325, 0.00330, 0.00331, 0.00335,
                        0.00331, 0.00312, 0.00322, 0.00314, 0.00323, 0.00322, 0.00317, 0.00259],
                       [0.00291, 0.00307, 0.00319, 0.00311, 0.00315, 0.00311, 0.00315,
                        0.00298, 0.00312, 0.00302, 0.00307, 0.00312, 0.00328, 0.00324,
                        0.00327, 0.00305, 0.00336, 0.00327, 0.00346, 0.00329, 0.00346,
                        0.00332, 0.00327, 0.00337, 0.00308, 0.00327, 0.00311, 0.00311, 0.00265],
                       [0.00295, 0.00318, 0.00319, 0.00316, 0.00308, 0.00320, 0.00312,
                        0.00304, 0.00313, 0.00305, 0.00322, 0.00318, 0.00319, 0.00309,
                        0.00303, 0.00296, 0.00320, 0.00326, 0.00342, 0.00319, 0.00337,
                        0.00326, 0.00341, 0.00339, 0.00313, 0.00332, 0.00312, 0.00315, 0.00272],
                       [0.00312, 0.00318, 0.00314, 0.00327, 0.00298, 0.00313, 0.00301,
                        0.00317, 0.00308, 0.00321, 0.00326, 0.00306, 0.00317, 0.00303,
                        0.00299, 0.00313, 0.00315, 0.00320, 0.00326, 0.00318, 0.00321,
                        0.00324, 0.00333, 0.00323, 0.00320, 0.00330, 0.00319, 0.00322, 0.00270],
                       [0.00328, 0.00320, 0.00316, 0.00332, 0.00302, 0.00309, 0.00300,
                        0.00322, 0.00305, 0.00321, 0.00316, 0.00298, 0.00331, 0.00314,
                        0.00322, 0.00333, 0.00322, 0.00326, 0.00324, 0.00324, 0.00321,
                        0.00340, 0.00331, 0.00315, 0.00319, 0.00317, 0.00316, 0.00322, 0.00262],
                       [0.00328, 0.00322, 0.00321, 0.00321, 0.00324, 0.00315, 0.00312,
                        0.00316, 0.00312, 0.00315, 0.00310, 0.00302, 0.00330, 0.00325,
                        0.00332, 0.00334, 0.00319, 0.00327, 0.00327, 0.00332, 0.00326,
                        0.00340, 0.00334, 0.00320, 0.00314, 0.00317, 0.00313, 0.00311, 0.00265],
                       [0.00314, 0.00324, 0.00314, 0.00318, 0.00330, 0.00317, 0.00324,
                        0.00315, 0.00316, 0.00313, 0.00318, 0.00315, 0.00324, 0.00327,
                        0.00328, 0.00324, 0.00323, 0.00330, 0.00333, 0.00340, 0.00333,
                        0.00323, 0.00330, 0.00318, 0.00323, 0.00329, 0.00322, 0.00304, 0.00276],
                       [0.00308, 0.00319, 0.00295, 0.00319, 0.00312, 0.00310, 0.00316,
                        0.00318, 0.00311, 0.00309, 0.00318, 0.00321, 0.00325, 0.00319,
                        0.00324, 0.00311, 0.00338, 0.00331, 0.00337, 0.00336, 0.00330,
                        0.00323, 0.00326, 0.00315, 0.00330, 0.00324, 0.00326, 0.00314, 0.00284],
                       [0.00321, 0.00307, 0.00298, 0.00315, 0.00306, 0.00320, 0.00304,
                        0.00319, 0.00319, 0.00312, 0.00315, 0.00310, 0.00327, 0.00317,
                        0.00326, 0.00309, 0.00337, 0.00327, 0.00335, 0.00334, 0.00314,
                        0.00338, 0.00330, 0.00330, 0.00322, 0.00318, 0.00322, 0.00330, 0.00278],
                       [0.00317, 0.00304, 0.00326, 0.00321, 0.00314, 0.00338, 0.00307,
                        0.00319, 0.00325, 0.00315, 0.00313, 0.00300, 0.00326, 0.00326,
                        0.00321, 0.00314, 0.00324, 0.00327, 0.00332, 0.00343, 0.00318,
                        0.00341, 0.00334, 0.00333, 0.00319, 0.00322, 0.00318, 0.00327, 0.00265],
                       [0.00308, 0.00300, 0.00338, 0.00328, 0.00320, 0.00335, 0.00316,
                        0.00321, 0.00316, 0.00317, 0.00318, 0.00308, 0.00323, 0.00322,
                        0.00323, 0.00316, 0.00319, 0.00328, 0.00340, 0.00347, 0.00338,
                        0.00329, 0.00340, 0.00322, 0.00324, 0.00328, 0.00324, 0.00310, 0.00269],
                       [0.00314, 0.00305, 0.00322, 0.00322, 0.00324, 0.00318, 0.00314,
                        0.00333, 0.00312, 0.00320, 0.00319, 0.00323, 0.00323, 0.00312,
                        0.00322, 0.00314, 0.00327, 0.00338, 0.00344, 0.00336, 0.00342,
                        0.00325, 0.00345, 0.00326, 0.00320, 0.00330, 0.00320, 0.00311, 0.00281],
                       [0.00319, 0.00320, 0.00313, 0.00316, 0.00325, 0.00308, 0.00311,
                        0.00344, 0.00315, 0.00316, 0.00321, 0.00328, 0.00315, 0.00323,
                        0.00313, 0.00310, 0.00335, 0.00342, 0.00341, 0.00331, 0.00340,
                        0.00330, 0.00336, 0.00327, 0.00314, 0.00323, 0.00311, 0.00319, 0.00282],
                       [0.00321, 0.00322, 0.00323, 0.00328, 0.00323, 0.00302, 0.00312,
                        0.00326, 0.00318, 0.00311, 0.00328, 0.00319, 0.00314, 0.00337,
                        0.00318, 0.00315, 0.00330, 0.00333, 0.00332, 0.00333, 0.00346,
                        0.00331, 0.00329, 0.00324, 0.00315, 0.00333, 0.00315, 0.00307, 0.00270],
                       [0.00328, 0.00316, 0.00329, 0.00333, 0.00319, 0.00310, 0.00311,
                        0.00312, 0.00323, 0.00309, 0.00324, 0.00317, 0.00326, 0.00332,
                        0.00329, 0.00320, 0.00326, 0.00330, 0.00332, 0.00338, 0.00337,
                        0.00329, 0.00335, 0.00331, 0.00331, 0.00346, 0.00320, 0.00296, 0.00269],
                       [0.00330, 0.00322, 0.00318, 0.00319, 0.00317, 0.00324, 0.00312,
                        0.00322, 0.00326, 0.00313, 0.00315, 0.00332, 0.00330, 0.00317,
                        0.00333, 0.00322, 0.00329, 0.00327, 0.00350, 0.00341, 0.00322,
                        0.00331, 0.00341, 0.00326, 0.00337, 0.00329, 0.00316, 0.00306, 0.00278],
                       [0.00323, 0.00325, 0.00314, 0.00317, 0.00322, 0.00327, 0.00308,
                        0.00330, 0.00327, 0.00319, 0.00313, 0.00334, 0.00319, 0.00310,
                        0.00332, 0.00329, 0.00338, 0.00333, 0.00359, 0.00333, 0.00324,
                        0.00324, 0.00335, 0.00320, 0.00322, 0.00310, 0.00316, 0.00317, 0.00273],
                       [0.00316, 0.00317, 0.00327, 0.00326, 0.00326, 0.00320, 0.00304,
                        0.00325, 0.00327, 0.00325, 0.00314, 0.00316, 0.00314, 0.00314,
                        0.00323, 0.00339, 0.00337, 0.00340, 0.00345, 0.00329, 0.00339,
                        0.00314, 0.00332, 0.00329, 0.00317, 0.00311, 0.00323, 0.00320, 0.00265],
                       [0.00316, 0.00316, 0.00336, 0.00320, 0.00330, 0.00317, 0.00316,
                        0.00319, 0.00313, 0.00327, 0.00316, 0.00309, 0.00315, 0.00316,
                        0.00319, 0.00334, 0.00326, 0.00337, 0.00332, 0.00337, 0.00337,
                        0.00323, 0.00343, 0.00337, 0.00327, 0.00325, 0.00323, 0.00316, 0.00269],
                       [0.00321, 0.00326, 0.00319, 0.00313, 0.00336, 0.00321, 0.00334,
                        0.00319, 0.00300, 0.00325, 0.00328, 0.00320, 0.00323, 0.00321,
                        0.00324, 0.00317, 0.00330, 0.00342, 0.00338, 0.00342, 0.00332,
                        0.00344, 0.00340, 0.00335, 0.00333, 0.00336, 0.00317, 0.00314, 0.00272],
                       [0.00321, 0.00328, 0.00301, 0.00316, 0.00333, 0.00316, 0.00342,
                        0.00317, 0.00311, 0.00327, 0.00331, 0.00327, 0.00332, 0.00326,
                        0.00329, 0.00324, 0.00337, 0.00349, 0.00350, 0.00336, 0.00343,
                        0.00354, 0.00320, 0.00334, 0.00336, 0.00326, 0.00320, 0.00317, 0.00274],
                       [0.00322, 0.00323, 0.00303, 0.00319, 0.00324, 0.00315, 0.00337,
                        0.00322, 0.00332, 0.00337, 0.00327, 0.00330, 0.00340, 0.00318,
                        0.00338, 0.00341, 0.00330, 0.00344, 0.00349, 0.00336, 0.00350,
                        0.00353, 0.00329, 0.00340, 0.00339, 0.00312, 0.00331, 0.00313, 0.00281],
                       [0.00321, 0.00312, 0.00315, 0.00325, 0.00317, 0.00326, 0.00318,
                        0.00331, 0.00329, 0.00337, 0.00333, 0.00332, 0.00345, 0.00311,
                        0.00345, 0.00336, 0.00325, 0.00333, 0.00339, 0.00345, 0.00356,
                        0.00354, 0.00355, 0.00340, 0.00335, 0.00317, 0.00335, 0.00309, 0.00285],
                       [0.00318, 0.00311, 0.00324, 0.00333, 0.00311, 0.00334, 0.00307,
                        0.00329, 0.00312, 0.00323, 0.00341, 0.00327, 0.00337, 0.00320,
                        0.00342, 0.00327, 0.00328, 0.00333, 0.00348, 0.00344, 0.00359,
                        0.00350, 0.00362, 0.00334, 0.00329, 0.00328, 0.00326, 0.00316, 0.00283],
                       [0.00326, 0.00320, 0.00329, 0.00344, 0.00313, 0.00328, 0.00321,
                        0.00332, 0.00308, 0.00314, 0.00334, 0.00320, 0.00325, 0.00335,
                        0.00333, 0.00335, 0.00336, 0.00350, 0.00370, 0.00346, 0.00359,
                        0.00341, 0.00358, 0.00335, 0.00334, 0.00335, 0.00319, 0.00328, 0.00280],
                       [0.00333, 0.00323, 0.00321, 0.00344, 0.00328, 0.00326, 0.00335,
                        0.00330, 0.00317, 0.00324, 0.00319, 0.00328, 0.00320, 0.00344,
                        0.00329, 0.00345, 0.00344, 0.00363, 0.00376, 0.00351, 0.00350,
                        0.00341, 0.00359, 0.00341, 0.00342, 0.00346, 0.00333, 0.00334, 0.00277],
                       [0.00329, 0.00317, 0.00313, 0.00336, 0.00343, 0.00329, 0.00327,
                        0.00319, 0.00330, 0.00338, 0.00324, 0.00332, 0.00323, 0.00342,
                        0.00333, 0.00351, 0.00349, 0.00365, 0.00361, 0.00351, 0.00346,
                        0.00358, 0.00357, 0.00350, 0.00346, 0.00352, 0.00347, 0.00337, 0.00276],
                       [0.00321, 0.00316, 0.00322, 0.00334, 0.00340, 0.00333, 0.00321,
                        0.00321, 0.00348, 0.00334, 0.00334, 0.00326, 0.00331, 0.00334,
                        0.00336, 0.00358, 0.00353, 0.00357, 0.00356, 0.00361, 0.00356,
                        0.00369, 0.00354, 0.00358, 0.00347, 0.00351, 0.00342, 0.00336, 0.00285],
                       [0.00331, 0.00333, 0.00338, 0.00336, 0.00327, 0.00338, 0.00335,
                        0.00344, 0.00354, 0.00331, 0.00340, 0.00332, 0.00352, 0.00343,
                        0.00343, 0.00360, 0.00366, 0.00357, 0.00369, 0.00376, 0.00370,
                        0.00375, 0.00365, 0.00366, 0.00354, 0.00353, 0.00336, 0.00330, 0.00293],
                       [0.00349, 0.00343, 0.00335, 0.00331, 0.00322, 0.00335, 0.00348,
                        0.00354, 0.00338, 0.00331, 0.00336, 0.00343, 0.00362, 0.00354,
                        0.00352, 0.00354, 0.00364, 0.00366, 0.00377, 0.00373, 0.00375,
                        0.00378, 0.00370, 0.00368, 0.00357, 0.00349, 0.00337, 0.00322, 0.00287],
                       [0.00354, 0.00341, 0.00333, 0.00339, 0.00335, 0.00335, 0.00350,
                        0.00345, 0.00335, 0.00331, 0.00334, 0.00347, 0.00350, 0.00354,
                        0.00358, 0.00365, 0.00356, 0.00379, 0.00384, 0.00373, 0.00381,
                        0.00380, 0.00375, 0.00374, 0.00362, 0.00350, 0.00345, 0.00338, 0.00291],
                       [0.00339, 0.00339, 0.00337, 0.00354, 0.00345, 0.00333, 0.00336,
                        0.00330, 0.00339, 0.00332, 0.00338, 0.00340, 0.00334, 0.00339,
                        0.00351, 0.00375, 0.00360, 0.00383, 0.00384, 0.00384, 0.00388,
                        0.00374, 0.00379, 0.00386, 0.00369, 0.00361, 0.00350, 0.00361, 0.00290],
                       [0.00343, 0.00337, 0.00336, 0.00357, 0.00348, 0.00335, 0.00326,
                        0.00334, 0.00333, 0.00340, 0.00346, 0.00336, 0.00339, 0.00339,
                        0.00357, 0.00371, 0.00373, 0.00384, 0.00384, 0.00392, 0.00391,
                        0.00383, 0.00372, 0.00390, 0.00374, 0.00379, 0.00354, 0.00359, 0.00287],
                       [0.00356, 0.00345, 0.00342, 0.00344, 0.00344, 0.00344, 0.00346,
                        0.00344, 0.00328, 0.00346, 0.00345, 0.00345, 0.00351, 0.00358,
                        0.00363, 0.00367, 0.00390, 0.00383, 0.00385, 0.00384, 0.00389,
                        0.00401, 0.00371, 0.00376, 0.00382, 0.00387, 0.00352, 0.00346, 0.00301],
                       [0.00355, 0.00354, 0.00354, 0.00337, 0.00347, 0.00346, 0.00368,
                        0.00346, 0.00339, 0.00344, 0.00344, 0.00368, 0.00358, 0.00368,
                        0.00360, 0.00374, 0.00396, 0.00389, 0.00388, 0.00390, 0.00392,
                        0.00414, 0.00392, 0.00375, 0.00394, 0.00372, 0.00348, 0.00348, 0.00316],
                       [0.00350, 0.00353, 0.00355, 0.00349, 0.00356, 0.00344, 0.00365,
                        0.00338, 0.00360, 0.00341, 0.00353, 0.00375, 0.00359, 0.00362,
                        0.00362, 0.00371, 0.00398, 0.00401, 0.00394, 0.00411, 0.00398,
                        0.00419, 0.00408, 0.00393, 0.00390, 0.00363, 0.00351, 0.00357, 0.00305],
                       [0.00359, 0.00355, 0.00360, 0.00365, 0.00364, 0.00354, 0.00352,
                        0.00341, 0.00365, 0.00347, 0.00364, 0.00365, 0.00362, 0.00358,
                        0.00368, 0.00366, 0.00405, 0.00406, 0.00413, 0.00414, 0.00410,
                        0.00423, 0.00413, 0.00406, 0.00378, 0.00368, 0.00368, 0.00359, 0.00292],
                       [0.00375, 0.00362, 0.00360, 0.00369, 0.00359, 0.00362, 0.00349,
                        0.00346, 0.00355, 0.00358, 0.00373, 0.00372, 0.00371, 0.00363,
                        0.00371, 0.00375, 0.00403, 0.00408, 0.00433, 0.00416, 0.00437,
                        0.00422, 0.00423, 0.00408, 0.00386, 0.00375, 0.00378, 0.00353, 0.00306],
                       [0.00381, 0.00367, 0.00356, 0.00362, 0.00362, 0.00366, 0.00354,
                        0.00352, 0.00355, 0.00361, 0.00377, 0.00383, 0.00381, 0.00360,
                        0.00384, 0.00395, 0.00401, 0.00411, 0.00436, 0.00433, 0.00455,
                        0.00428, 0.00436, 0.00413, 0.00414, 0.00394, 0.00376, 0.00353, 0.00326],
                       [0.00382, 0.00369, 0.00367, 0.00365, 0.00373, 0.00373, 0.00360,
                        0.00376, 0.00357, 0.00355, 0.00368, 0.00380, 0.00388, 0.00359,
                        0.00394, 0.00414, 0.00412, 0.00424, 0.00437, 0.00439, 0.00447,
                        0.00441, 0.00428, 0.00427, 0.00434, 0.00405, 0.00378, 0.00369, 0.00330],
                       [0.00384, 0.00376, 0.00379, 0.00373, 0.00371, 0.00379, 0.00358,
                        0.00389, 0.00355, 0.00357, 0.00364, 0.00384, 0.00387, 0.00371,
                        0.00390, 0.00413, 0.00427, 0.00436, 0.00449, 0.00439, 0.00449,
                        0.00449, 0.00427, 0.00436, 0.00438, 0.00407, 0.00389, 0.00386, 0.00327],
                       [0.00377, 0.00387, 0.00382, 0.00374, 0.00372, 0.00380, 0.00366,
                        0.00374, 0.00369, 0.00360, 0.00379, 0.00398, 0.00383, 0.00388,
                        0.00398, 0.00410, 0.00433, 0.00441, 0.00462, 0.00452, 0.00467,
                        0.00456, 0.00454, 0.00430, 0.00427, 0.00418, 0.00397, 0.00383, 0.00329],
                       [0.00380, 0.00392, 0.00380, 0.00380, 0.00389, 0.00380, 0.00383,
                        0.00357, 0.00385, 0.00365, 0.00398, 0.00399, 0.00389, 0.00402,
                        0.00417, 0.00418, 0.00439, 0.00461, 0.00472, 0.00473, 0.00479,
                        0.00476, 0.00466, 0.00448, 0.00424, 0.00428, 0.00402, 0.00386, 0.00334],
                       [0.00396, 0.00388, 0.00377, 0.00394, 0.00400, 0.00384, 0.00391,
                        0.00365, 0.00385, 0.00381, 0.00395, 0.00409, 0.00403, 0.00410,
                        0.00421, 0.00427, 0.00445, 0.00482, 0.00481, 0.00491, 0.00484,
                        0.00498, 0.00465, 0.00475, 0.00442, 0.00431, 0.00409, 0.00397, 0.00333],
                       [0.00404, 0.00380, 0.00390, 0.00412, 0.00400, 0.00394, 0.00397,
                        0.00384, 0.00387, 0.00397, 0.00382, 0.00424, 0.00423, 0.00416,
                        0.00420, 0.00440, 0.00448, 0.00490, 0.00491, 0.00501, 0.00485,
                        0.00506, 0.00490, 0.00479, 0.00477, 0.00444, 0.00410, 0.00404, 0.00341],
                       [0.00401, 0.00386, 0.00406, 0.00418, 0.00400, 0.00403, 0.00408,
                        0.00395, 0.00403, 0.00389, 0.00385, 0.00411, 0.00432, 0.00425,
                        0.00418, 0.00443, 0.00450, 0.00485, 0.00500, 0.00511, 0.00489,
                        0.00502, 0.00513, 0.00475, 0.00496, 0.00462, 0.00412, 0.00405, 0.00355],
                       [0.00405, 0.00410, 0.00404, 0.00406, 0.00410, 0.00398, 0.00413,
                        0.00395, 0.00403, 0.00382, 0.00405, 0.00400, 0.00421, 0.00432,
                        0.00418, 0.00444, 0.00466, 0.00480, 0.00512, 0.00518, 0.00509,
                        0.00513, 0.00516, 0.00494, 0.00486, 0.00466, 0.00436, 0.00407, 0.00357],
                       [0.00424, 0.00426, 0.00412, 0.00405, 0.00419, 0.00410, 0.00419,
                        0.00393, 0.00398, 0.00399, 0.00424, 0.00419, 0.00422, 0.00440,
                        0.00439, 0.00467, 0.00495, 0.00497, 0.00530, 0.00518, 0.00539,
                        0.00548, 0.00529, 0.00523, 0.00478, 0.00467, 0.00457, 0.00408, 0.00362],
                       [0.00435, 0.00426, 0.00425, 0.00409, 0.00415, 0.00427, 0.00422,
                        0.00393, 0.00401, 0.00410, 0.00422, 0.00447, 0.00435, 0.00441,
                        0.00461, 0.00487, 0.00510, 0.00514, 0.00537, 0.00526, 0.00541,
                        0.00572, 0.00542, 0.00534, 0.00491, 0.00466, 0.00452, 0.00414, 0.00363],
                       [0.00428, 0.00434, 0.00420, 0.00413, 0.00424, 0.00438, 0.00426,
                        0.00404, 0.00402, 0.00408, 0.00415, 0.00461, 0.00437, 0.00442,
                        0.00464, 0.00480, 0.00507, 0.00532, 0.00540, 0.00556, 0.00544,
                        0.00575, 0.00549, 0.00534, 0.00519, 0.00481, 0.00453, 0.00443, 0.00355],
                       [0.00414, 0.00441, 0.00420, 0.00421, 0.00440, 0.00439, 0.00422,
                        0.00416, 0.00395, 0.00410, 0.00418, 0.00456, 0.00443, 0.00451,
                        0.00459, 0.00473, 0.00506, 0.00545, 0.00555, 0.00580, 0.00567,
                        0.00574, 0.00560, 0.00545, 0.00537, 0.00507, 0.00477, 0.00459, 0.00366],
                       [0.00420, 0.00444, 0.00441, 0.00434, 0.00446, 0.00436, 0.00420,
                        0.00428, 0.00399, 0.00424, 0.00431, 0.00459, 0.00466, 0.00457,
                        0.00473, 0.00498, 0.00531, 0.00549, 0.00579, 0.00585, 0.00588,
                        0.00582, 0.00586, 0.00567, 0.00538, 0.00520, 0.00500, 0.00449, 0.00388],
                       [0.00449, 0.00449, 0.00458, 0.00453, 0.00447, 0.00443, 0.00435,
                        0.00441, 0.00417, 0.00445, 0.00451, 0.00473, 0.00484, 0.00474,
                        0.00496, 0.00527, 0.00555, 0.00566, 0.00597, 0.00593, 0.00608,
                        0.00606, 0.00609, 0.00597, 0.00548, 0.00532, 0.00505, 0.00452, 0.00403],
                       [0.00471, 0.00457, 0.00462, 0.00469, 0.00449, 0.00456, 0.00461,
                        0.00441, 0.00435, 0.00457, 0.00470, 0.00483, 0.00487, 0.00502,
                        0.00508, 0.00536, 0.00568, 0.00585, 0.00602, 0.00613, 0.00628,
                        0.00634, 0.00627, 0.00619, 0.00579, 0.00540, 0.00504, 0.00477, 0.00411],
                       [0.00477, 0.00466, 0.00464, 0.00472, 0.00452, 0.00462, 0.00472,
                        0.00444, 0.00442, 0.00451, 0.00481, 0.00490, 0.00485, 0.00506,
                        0.00514, 0.00542, 0.00580, 0.00599, 0.00618, 0.00637, 0.00642,
                        0.00651, 0.00640, 0.00622, 0.00597, 0.00542, 0.00517, 0.00496, 0.00402],
                       [0.00488, 0.00474, 0.00473, 0.00471, 0.00462, 0.00475, 0.00473,
                        0.00455, 0.00458, 0.00451, 0.00486, 0.00501, 0.00497, 0.00506,
                        0.00531, 0.00556, 0.00589, 0.00619, 0.00647, 0.00661, 0.00655,
                        0.00672, 0.00651, 0.00629, 0.00601, 0.00560, 0.00532, 0.00498, 0.00410],
                       [0.00489, 0.00476, 0.00478, 0.00467, 0.00469, 0.00476, 0.00470,
                        0.00461, 0.00463, 0.00461, 0.00481, 0.00507, 0.00511, 0.00531,
                        0.00547, 0.00569, 0.00589, 0.00627, 0.00669, 0.00672, 0.00676,
                        0.00695, 0.00666, 0.00644, 0.00614, 0.00594, 0.00539, 0.00499, 0.00442],
                       [0.00485, 0.00483, 0.00484, 0.00478, 0.00476, 0.00475, 0.00472,
                        0.00480, 0.00458, 0.00478, 0.00484, 0.00524, 0.00525, 0.00556,
                        0.00559, 0.00582, 0.00604, 0.00643, 0.00680, 0.00688, 0.00709,
                        0.00713, 0.00697, 0.00670, 0.00643, 0.00617, 0.00557, 0.00525, 0.00464],
                       [0.00483, 0.00496, 0.00504, 0.00495, 0.00491, 0.00495, 0.00480,
                        0.00497, 0.00463, 0.00498, 0.00496, 0.00538, 0.00547, 0.00555,
                        0.00573, 0.00587, 0.00631, 0.00672, 0.00694, 0.00720, 0.00726,
                        0.00722, 0.00729, 0.00693, 0.00666, 0.00619, 0.00571, 0.00545, 0.00468],
                       [0.00498, 0.00518, 0.00530, 0.00502, 0.00508, 0.00522, 0.00503,
                        0.00507, 0.00484, 0.00501, 0.00515, 0.00547, 0.00566, 0.00565,
                        0.00593, 0.00600, 0.00658, 0.00704, 0.00726, 0.00758, 0.00742,
                        0.00758, 0.00754, 0.00718, 0.00686, 0.00634, 0.00579, 0.00556, 0.00480],
                       [0.00525, 0.00532, 0.00536, 0.00509, 0.00516, 0.00530, 0.00520,
                        0.00515, 0.00498, 0.00493, 0.00524, 0.00555, 0.00582, 0.00587,
                        0.00607, 0.00626, 0.00678, 0.00733, 0.00754, 0.00794, 0.00782,
                        0.00798, 0.00771, 0.00754, 0.00709, 0.00659, 0.00593, 0.00570, 0.00483],
                       [0.00538, 0.00537, 0.00529, 0.00530, 0.00522, 0.00536, 0.00535,
                        0.00513, 0.00508, 0.00512, 0.00534, 0.00576, 0.00598, 0.00598,
                        0.00618, 0.00657, 0.00699, 0.00753, 0.00782, 0.00828, 0.00826,
                        0.00820, 0.00800, 0.00790, 0.00728, 0.00682, 0.00614, 0.00588, 0.00478],
                       [0.00544, 0.00536, 0.00533, 0.00545, 0.00536, 0.00536, 0.00548,
                        0.00510, 0.00521, 0.00534, 0.00558, 0.00602, 0.00604, 0.00612,
                        0.00635, 0.00680, 0.00721, 0.00767, 0.00816, 0.00855, 0.00849,
                        0.00859, 0.00839, 0.00821, 0.00746, 0.00706, 0.00635, 0.00603, 0.00497],
                       [0.00562, 0.00546, 0.00550, 0.00546, 0.00549, 0.00544, 0.00546,
                        0.00528, 0.00532, 0.00544, 0.00583, 0.00614, 0.00615, 0.00632,
                        0.00660, 0.00698, 0.00750, 0.00796, 0.00855, 0.00886, 0.00883,
                        0.00905, 0.00872, 0.00849, 0.00782, 0.00729, 0.00657, 0.00619, 0.00536],
                       [0.00579, 0.00575, 0.00570, 0.00542, 0.00560, 0.00571, 0.00551,
                        0.00555, 0.00545, 0.00550, 0.00592, 0.00616, 0.00635, 0.00651,
                        0.00679, 0.00721, 0.00787, 0.00843, 0.00891, 0.00926, 0.00943,
                        0.00936, 0.00909, 0.00875, 0.00822, 0.00763, 0.00673, 0.00639, 0.00552],
                       [0.00595, 0.00602, 0.00596, 0.00559, 0.00582, 0.00593, 0.00575,
                        0.00574, 0.00557, 0.00566, 0.00609, 0.00626, 0.00656, 0.00663,
                        0.00698, 0.00751, 0.00826, 0.00897, 0.00922, 0.00969, 0.00997,
                        0.00981, 0.00966, 0.00911, 0.00859, 0.00799, 0.00694, 0.00662, 0.00561],
                       [0.00602, 0.00617, 0.00608, 0.00589, 0.00604, 0.00604, 0.00591,
                        0.00579, 0.00567, 0.00586, 0.00632, 0.00653, 0.00677, 0.00686,
                        0.00724, 0.00780, 0.00860, 0.00929, 0.00959, 0.01011, 0.01039,
                        0.01034, 0.01018, 0.00955, 0.00890, 0.00816, 0.00725, 0.00675, 0.00587],
                       [0.00616, 0.00628, 0.00615, 0.00608, 0.00611, 0.00623, 0.00604,
                        0.00592, 0.00584, 0.00596, 0.00644, 0.00683, 0.00701, 0.00717,
                        0.00749, 0.00812, 0.00883, 0.00948, 0.01022, 0.01065, 0.01087,
                        0.01084, 0.01065, 0.01016, 0.00926, 0.00832, 0.00763, 0.00687, 0.00610],
                       [0.00649, 0.00637, 0.00637, 0.00626, 0.00622, 0.00651, 0.00625,
                        0.00614, 0.00599, 0.00616, 0.00662, 0.00717, 0.00730, 0.00740,
                        0.00770, 0.00847, 0.00916, 0.01003, 0.01087, 0.01128, 0.01145,
                        0.01146, 0.01118, 0.01073, 0.00972, 0.00870, 0.00798, 0.00722, 0.00613],
                       [0.00674, 0.00658, 0.00662, 0.00651, 0.00653, 0.00674, 0.00649,
                        0.00631, 0.00624, 0.00646, 0.00684, 0.00757, 0.00765, 0.00770,
                        0.00807, 0.00883, 0.00972, 0.01073, 0.01147, 0.01193, 0.01226,
                        0.01224, 0.01185, 0.01117, 0.01025, 0.00920, 0.00823, 0.00761, 0.00619],
                       [0.00695, 0.00691, 0.00677, 0.00675, 0.00685, 0.00681, 0.00674,
                        0.00646, 0.00653, 0.00658, 0.00711, 0.00784, 0.00798, 0.00813,
                        0.00850, 0.00927, 0.01034, 0.01138, 0.01223, 0.01264, 0.01319,
                        0.01308, 0.01272, 0.01179, 0.01087, 0.00973, 0.00851, 0.00789, 0.00651],
                       [0.00723, 0.00723, 0.00690, 0.00694, 0.00704, 0.00698, 0.00704,
                        0.00666, 0.00673, 0.00663, 0.00749, 0.00802, 0.00829, 0.00847,
                        0.00879, 0.00974, 0.01093, 0.01213, 0.01306, 0.01354, 0.01399,
                        0.01394, 0.01354, 0.01272, 0.01150, 0.01020, 0.00887, 0.00817, 0.00685],
                       [0.00751, 0.00755, 0.00722, 0.00716, 0.00731, 0.00739, 0.00732,
                        0.00700, 0.00681, 0.00692, 0.00780, 0.00830, 0.00877, 0.00878,
                        0.00919, 0.01017, 0.01152, 0.01291, 0.01388, 0.01460, 0.01485,
                        0.01493, 0.01433, 0.01360, 0.01221, 0.01071, 0.00925, 0.00845, 0.00714],
                       [0.00783, 0.00777, 0.00778, 0.00752, 0.00758, 0.00785, 0.00755,
                        0.00734, 0.00698, 0.00731, 0.00804, 0.00870, 0.00924, 0.00922,
                        0.00968, 0.01075, 0.01212, 0.01362, 0.01486, 0.01573, 0.01596,
                        0.01607, 0.01538, 0.01438, 0.01303, 0.01129, 0.00964, 0.00882, 0.00737],
                       [0.00830, 0.00805, 0.00820, 0.00786, 0.00781, 0.00809, 0.00780,
                        0.00756, 0.00738, 0.00759, 0.00846, 0.00918, 0.00954, 0.00975,
                        0.01018, 0.01148, 0.01279, 0.01460, 0.01598, 0.01699, 0.01730,
                        0.01733, 0.01658, 0.01538, 0.01386, 0.01202, 0.01023, 0.00932, 0.00770],
                       [0.00864, 0.00846, 0.00830, 0.00815, 0.00814, 0.00827, 0.00810,
                        0.00786, 0.00776, 0.00786, 0.00891, 0.00965, 0.00988, 0.01032,
                        0.01079, 0.01220, 0.01378, 0.01576, 0.01728, 0.01835, 0.01873,
                        0.01870, 0.01785, 0.01657, 0.01479, 0.01278, 0.01090, 0.00970, 0.00819],
                       [0.00886, 0.00885, 0.00858, 0.00851, 0.00862, 0.00873, 0.00858,
                        0.00827, 0.00801, 0.00829, 0.00921, 0.01018, 0.01051, 0.01093,
                        0.01154, 0.01284, 0.01493, 0.01705, 0.01884, 0.01982, 0.02033,
                        0.02022, 0.01927, 0.01781, 0.01592, 0.01352, 0.01148, 0.01017, 0.00861],
                       [0.00930, 0.00935, 0.00919, 0.00890, 0.00907, 0.00927, 0.00913,
                        0.00869, 0.00826, 0.00868, 0.00965, 0.01079, 0.01130, 0.01152,
                        0.01227, 0.01361, 0.01593, 0.01851, 0.02041, 0.02145, 0.02210,
                        0.02192, 0.02090, 0.01925, 0.01720, 0.01434, 0.01207, 0.01088, 0.00887],
                       [0.00996, 0.01004, 0.00980, 0.00943, 0.00952, 0.00981, 0.00959,
                        0.00907, 0.00861, 0.00894, 0.01035, 0.01145, 0.01207, 0.01220,
                        0.01302, 0.01478, 0.01709, 0.02004, 0.02202, 0.02333, 0.02402,
                        0.02393, 0.02287, 0.02102, 0.01857, 0.01534, 0.01279, 0.01160, 0.00927],
                       [0.01054, 0.01057, 0.01034, 0.00997, 0.01003, 0.01029, 0.01009,
                        0.00947, 0.00905, 0.00944, 0.01098, 0.01207, 0.01279, 0.01304,
                        0.01388, 0.01607, 0.01860, 0.02166, 0.02395, 0.02546, 0.02612,
                        0.02618, 0.02497, 0.02289, 0.02004, 0.01649, 0.01370, 0.01225, 0.00993],
                       [0.01117, 0.01104, 0.01086, 0.01048, 0.01060, 0.01091, 0.01067,
                        0.01014, 0.00961, 0.01016, 0.01161, 0.01289, 0.01360, 0.01397,
                        0.01490, 0.01728, 0.02023, 0.02355, 0.02616, 0.02794, 0.02860,
                        0.02870, 0.02719, 0.02489, 0.02174, 0.01783, 0.01476, 0.01304, 0.01060],
                       [0.01209, 0.01183, 0.01148, 0.01116, 0.01126, 0.01179, 0.01135,
                        0.01085, 0.01028, 0.01076, 0.01238, 0.01393, 0.01455, 0.01489,
                        0.01602, 0.01862, 0.02194, 0.02581, 0.02867, 0.03057, 0.03152,
                        0.03144, 0.02978, 0.02714, 0.02367, 0.01935, 0.01585, 0.01385, 0.01127],
                       [0.01310, 0.01287, 0.01235, 0.01199, 0.01212, 0.01268, 0.01214,
                        0.01129, 0.01098, 0.01129, 0.01323, 0.01494, 0.01576, 0.01607,
                        0.01735, 0.02024, 0.02393, 0.02830, 0.03150, 0.03344, 0.03464,
                        0.03441, 0.03269, 0.02981, 0.02585, 0.02103, 0.01691, 0.01465, 0.01211],
                       [0.01405, 0.01395, 0.01336, 0.01289, 0.01306, 0.01348, 0.01299,
                        0.01191, 0.01167, 0.01200, 0.01411, 0.01613, 0.01717, 0.01755,
                        0.01886, 0.02201, 0.02631, 0.03099, 0.03466, 0.03676, 0.03798,
                        0.03773, 0.03587, 0.03275, 0.02832, 0.02295, 0.01816, 0.01574, 0.01309],
                       [0.01507, 0.01503, 0.01433, 0.01382, 0.01402, 0.01441, 0.01387,
                        0.01284, 0.01239, 0.01290, 0.01509, 0.01755, 0.01852, 0.01905,
                        0.02050, 0.02399, 0.02889, 0.03406, 0.03804, 0.04047, 0.04171,
                        0.04146, 0.03941, 0.03584, 0.03102, 0.02510, 0.01979, 0.01705, 0.01408],
                       [0.01623, 0.01614, 0.01539, 0.01486, 0.01504, 0.01557, 0.01491,
                        0.01386, 0.01316, 0.01387, 0.01632, 0.01896, 0.01998, 0.02064,
                        0.02241, 0.02627, 0.03168, 0.03746, 0.04169, 0.04463, 0.04591,
                        0.04559, 0.04336, 0.03938, 0.03395, 0.02738, 0.02152, 0.01840, 0.01513],
                       [0.01747, 0.01742, 0.01673, 0.01605, 0.01616, 0.01680, 0.01622,
                        0.01485, 0.01409, 0.01490, 0.01771, 0.02046, 0.02175, 0.02245,
                        0.02449, 0.02879, 0.03474, 0.04127, 0.04590, 0.04918, 0.05064,
                        0.05020, 0.04776, 0.04336, 0.03715, 0.02988, 0.02336, 0.01983, 0.01630],
                       [0.01892, 0.01893, 0.01814, 0.01740, 0.01764, 0.01820, 0.01767,
                        0.01599, 0.01528, 0.01617, 0.01918, 0.02226, 0.02380, 0.02453,
                        0.02678, 0.03146, 0.03816, 0.04548, 0.05076, 0.05403, 0.05586,
                        0.05541, 0.05271, 0.04762, 0.04083, 0.03275, 0.02549, 0.02149, 0.01759],
                       [0.02069, 0.02070, 0.01956, 0.01896, 0.01927, 0.01998, 0.01911,
                        0.01742, 0.01652, 0.01756, 0.02081, 0.02438, 0.02608, 0.02689,
                        0.02937, 0.03438, 0.04203, 0.05005, 0.05612, 0.05948, 0.06160,
                        0.06116, 0.05803, 0.05245, 0.04509, 0.03590, 0.02795, 0.02337, 0.01914],
                       [0.02270, 0.02262, 0.02127, 0.02061, 0.02090, 0.02183, 0.02065,
                        0.01898, 0.01784, 0.01900, 0.02270, 0.02682, 0.02862, 0.02951,
                        0.03214, 0.03781, 0.04648, 0.05511, 0.06181, 0.06565, 0.06786,
                        0.06752, 0.06379, 0.05788, 0.04963, 0.03929, 0.03058, 0.02545, 0.02098],
                       [0.02479, 0.02458, 0.02338, 0.02237, 0.02274, 0.02370, 0.02259,
                        0.02053, 0.01947, 0.02054, 0.02487, 0.02945, 0.03135, 0.03234,
                        0.03525, 0.04189, 0.05132, 0.06074, 0.06802, 0.07243, 0.07483,
                        0.07454, 0.07041, 0.06372, 0.05451, 0.04317, 0.03337, 0.02775, 0.02291],
                       [0.02697, 0.02677, 0.02572, 0.02437, 0.02487, 0.02589, 0.02488,
                        0.02239, 0.02133, 0.02230, 0.02724, 0.03215, 0.03443, 0.03548,
                        0.03883, 0.04630, 0.05622, 0.06693, 0.07509, 0.07994, 0.08269,
                        0.08213, 0.07787, 0.07013, 0.05993, 0.04761, 0.03653, 0.03039, 0.02496],
                       [0.02961, 0.02937, 0.02816, 0.02660, 0.02722, 0.02838, 0.02719,
                        0.02448, 0.02316, 0.02448, 0.02981, 0.03528, 0.03791, 0.03895,
                        0.04282, 0.05087, 0.06164, 0.07393, 0.08295, 0.08829, 0.09108,
                        0.09055, 0.08580, 0.07724, 0.06596, 0.05231, 0.04014, 0.03329, 0.02732],
                       [0.03264, 0.03226, 0.03077, 0.02912, 0.02977, 0.03112, 0.02967,
                        0.02670, 0.02517, 0.02695, 0.03267, 0.03901, 0.04162, 0.04282,
                        0.04719, 0.05592, 0.06829, 0.08171, 0.09157, 0.09742, 0.10022,
                        0.09998, 0.09439, 0.08513, 0.07275, 0.05746, 0.04423, 0.03646, 0.02988],
                       [0.03575, 0.03535, 0.03364, 0.03189, 0.03261, 0.03409, 0.03260,
                        0.02921, 0.02751, 0.02943, 0.03590, 0.04295, 0.04575, 0.04708,
                        0.05190, 0.06156, 0.07566, 0.09006, 0.10094, 0.10735, 0.11046,
                        0.11017, 0.10396, 0.09394, 0.08017, 0.06327, 0.04860, 0.03998, 0.03268],
                       [0.03918, 0.03886, 0.03694, 0.03507, 0.03597, 0.03740, 0.03583,
                        0.03208, 0.03016, 0.03217, 0.03949, 0.04716, 0.05054, 0.05197,
                        0.05700, 0.06791, 0.08337, 0.09924, 0.11124, 0.11825, 0.12198,
                        0.12113, 0.11454, 0.10356, 0.08826, 0.06965, 0.05333, 0.04393, 0.03596],
                       [0.04314, 0.04275, 0.04059, 0.03860, 0.03968, 0.04117, 0.03925,
                        0.03516, 0.03311, 0.03540, 0.04343, 0.05189, 0.05580, 0.05747,
                        0.06283, 0.07503, 0.09181, 0.10947, 0.12274, 0.13040, 0.13452,
                        0.13341, 0.12617, 0.11380, 0.09721, 0.07664, 0.05860, 0.04828, 0.03954],
                       [0.04751, 0.04689, 0.04470, 0.04238, 0.04345, 0.04534, 0.04311,
                        0.03853, 0.03648, 0.03907, 0.04784, 0.05730, 0.06144, 0.06343,
                        0.06955, 0.08289, 0.10127, 0.12090, 0.13544, 0.14380, 0.14810,
                        0.14719, 0.13904, 0.12524, 0.10698, 0.08442, 0.06439, 0.05300, 0.04338],
                       [0.05214, 0.05167, 0.04923, 0.04654, 0.04748, 0.04982, 0.04747,
                        0.04248, 0.04011, 0.04289, 0.05274, 0.06343, 0.06765, 0.06982,
                        0.07673, 0.09140, 0.11170, 0.13326, 0.14927, 0.15843, 0.16305,
                        0.16216, 0.15309, 0.13810, 0.11755, 0.09298, 0.07084, 0.05813, 0.04760],
                       [0.05726, 0.05703, 0.05400, 0.05120, 0.05228, 0.05480, 0.05232,
                        0.04685, 0.04408, 0.04691, 0.05814, 0.07009, 0.07479, 0.07690,
                        0.08454, 0.10069, 0.12301, 0.14676, 0.16445, 0.17445, 0.17956,
                        0.17831, 0.16845, 0.15216, 0.12940, 0.10234, 0.07807, 0.06387, 0.05225],
                       [0.06320, 0.06270, 0.05925, 0.05627, 0.05789, 0.06032, 0.05771,
                        0.05145, 0.04854, 0.05159, 0.06405, 0.07710, 0.08265, 0.08486,
                        0.09323, 0.11088, 0.13553, 0.16185, 0.18105, 0.19205, 0.19777,
                        0.19608, 0.18551, 0.16739, 0.14274, 0.11252, 0.08605, 0.07027, 0.05731],
                       [0.06992, 0.06896, 0.06535, 0.06197, 0.06375, 0.06643, 0.06362,
                        0.05661, 0.05343, 0.05703, 0.07064, 0.08471, 0.09094, 0.09358,
                        0.10269, 0.12219, 0.14953, 0.17824, 0.19925, 0.21152, 0.21752,
                        0.21575, 0.20420, 0.18407, 0.15716, 0.12370, 0.09460, 0.07733, 0.06294],
                       [0.07712, 0.07601, 0.07228, 0.06835, 0.06988, 0.07326, 0.06999,
                        0.06251, 0.05874, 0.06302, 0.07798, 0.09335, 0.09988, 0.10311,
                        0.11332, 0.13478, 0.16463, 0.19617, 0.21931, 0.23293, 0.23888,
                        0.23728, 0.22446, 0.20243, 0.17277, 0.13611, 0.10383, 0.08501, 0.06936],
                       [0.08481, 0.08379, 0.07969, 0.07539, 0.07688, 0.08072, 0.07710,
                        0.06879, 0.06467, 0.06946, 0.08604, 0.10305, 0.11011, 0.11364,
                        0.12508, 0.14860, 0.18102, 0.21599, 0.24115, 0.25579, 0.26249,
                        0.26061, 0.24653, 0.22245, 0.19004, 0.14990, 0.11416, 0.09356, 0.07642],
                       [0.09331, 0.09233, 0.08758, 0.08299, 0.08488, 0.08884, 0.08499,
                        0.07550, 0.07138, 0.07638, 0.09477, 0.11371, 0.12176, 0.12529,
                        0.13769, 0.16364, 0.19940, 0.23742, 0.26481, 0.27988, 0.28825,
                        0.28572, 0.27059, 0.24430, 0.20881, 0.16519, 0.12575, 0.10306, 0.08403],
                       [0.10280, 0.10179, 0.09642, 0.09124, 0.09367, 0.09797, 0.09361,
                        0.08318, 0.07877, 0.08416, 0.10433, 0.12546, 0.13442, 0.13817,
                        0.15158, 0.18017, 0.21966, 0.26083, 0.29047, 0.30650, 0.31570,
                        0.31312, 0.29673, 0.26819, 0.22945, 0.18173, 0.13838, 0.11329, 0.09242],
                       [0.11345, 0.11201, 0.10640, 0.10064, 0.10325, 0.10807, 0.10312,
                        0.09184, 0.08674, 0.09290, 0.11505, 0.13827, 0.14796, 0.15231,
                        0.16705, 0.19846, 0.24154, 0.28634, 0.31798, 0.33599, 0.34466,
                        0.34278, 0.32471, 0.29407, 0.25241, 0.19971, 0.15216, 0.12443, 0.10169],
                       [0.12530, 0.12310, 0.11740, 0.11123, 0.11375, 0.11920, 0.11364,
                        0.10132, 0.09532, 0.10232, 0.12693, 0.15212, 0.16285, 0.16758,
                        0.18394, 0.21844, 0.26520, 0.31357, 0.34744, 0.36681, 0.37552,
                        0.37375, 0.35439, 0.32195, 0.27699, 0.21947, 0.16754, 0.13704, 0.11177],
                       [0.13836, 0.13589, 0.12949, 0.12286, 0.12539, 0.13169, 0.12542,
                        0.11174, 0.10508, 0.11252, 0.13996, 0.16759, 0.17948, 0.18436,
                        0.20248, 0.24005, 0.29103, 0.34267, 0.37894, 0.39870, 0.40861,
                        0.40612, 0.38620, 0.35170, 0.30315, 0.24099, 0.18458, 0.15115, 0.12295],
                       [0.15254, 0.15030, 0.14287, 0.13549, 0.13823, 0.14526, 0.13832,
                        0.12307, 0.11601, 0.12386, 0.15406, 0.18492, 0.19772, 0.20303,
                        0.22289, 0.26354, 0.31867, 0.37362, 0.41192, 0.43230, 0.44318,
                        0.44009, 0.41960, 0.38302, 0.33139, 0.26429, 0.20284, 0.16640, 0.13544],
                       [0.16803, 0.16599, 0.15755, 0.14919, 0.15240, 0.15988, 0.15250,
                        0.13562, 0.12785, 0.13652, 0.16941, 0.20378, 0.21779, 0.22378,
                        0.24487, 0.28906, 0.34781, 0.40624, 0.44645, 0.46757, 0.47857,
                        0.47556, 0.45414, 0.41608, 0.36181, 0.28964, 0.22277, 0.18297, 0.14929],
                       [0.18529, 0.18304, 0.17365, 0.16423, 0.16790, 0.17621, 0.16814,
                        0.14956, 0.14081, 0.15047, 0.18635, 0.22397, 0.23954, 0.24614,
                        0.26860, 0.31619, 0.37871, 0.44038, 0.48212, 0.50364, 0.51472,
                        0.51235, 0.49002, 0.45092, 0.39389, 0.31699, 0.24482, 0.20114, 0.16440],
                       [0.20436, 0.20172, 0.19162, 0.18093, 0.18504, 0.19442, 0.18530,
                        0.16484, 0.15534, 0.16601, 0.20528, 0.24628, 0.26295, 0.27000,
                        0.29472, 0.34520, 0.41140, 0.47560, 0.51833, 0.54016, 0.55153,
                        0.54971, 0.52668, 0.48697, 0.42725, 0.34608, 0.26863, 0.22133, 0.18077],
                       [0.22515, 0.22224, 0.21116, 0.19955, 0.20409, 0.21417, 0.20396,
                        0.18172, 0.17134, 0.18312, 0.22592, 0.27084, 0.28850, 0.29573,
                        0.32285, 0.37632, 0.44550, 0.51154, 0.55502, 0.57714, 0.58835,
                        0.58655, 0.56352, 0.52355, 0.46212, 0.37674, 0.29409, 0.24349, 0.19863],
                       [0.24777, 0.24456, 0.23240, 0.22017, 0.22494, 0.23574, 0.22456,
                        0.20027, 0.18864, 0.20155, 0.24826, 0.29703, 0.31630, 0.32391,
                        0.35253, 0.40886, 0.48069, 0.54812, 0.59170, 0.61402, 0.62495,
                        0.62289, 0.60054, 0.56032, 0.49828, 0.40872, 0.32150, 0.26738, 0.21838],
                       [0.27226, 0.26879, 0.25561, 0.24244, 0.24736, 0.25931, 0.24724,
                        0.22025, 0.20741, 0.22147, 0.27252, 0.32495, 0.34571, 0.35411,
                        0.38356, 0.44252, 0.51654, 0.58482, 0.62762, 0.64952, 0.66092,
                        0.65888, 0.63712, 0.59699, 0.53502, 0.44222, 0.35089, 0.29307, 0.23999],
                       [0.29875, 0.29515, 0.28085, 0.26622, 0.27181, 0.28477, 0.27166,
                        0.24217, 0.22803, 0.24352, 0.29865, 0.35493, 0.37659, 0.38564,
                        0.41601, 0.47758, 0.55260, 0.62097, 0.66298, 0.68384, 0.69556,
                        0.69388, 0.67251, 0.63356, 0.57183, 0.47734, 0.38199, 0.32095, 0.26335],
                       [0.32720, 0.32348, 0.30809, 0.29166, 0.29828, 0.31214, 0.29770,
                        0.26604, 0.25059, 0.26761, 0.32634, 0.38686, 0.40924, 0.41849,
                        0.45002, 0.51356, 0.58864, 0.65659, 0.69731, 0.71721, 0.72812,
                        0.72715, 0.70663, 0.66929, 0.60829, 0.51329, 0.41429, 0.35084, 0.28813],
                       [0.35761, 0.35353, 0.33709, 0.31902, 0.32653, 0.34171, 0.32582,
                        0.29151, 0.27494, 0.29327, 0.35560, 0.42046, 0.44367, 0.45235,
                        0.48527, 0.54949, 0.62455, 0.69084, 0.72951, 0.74865, 0.75829,
                        0.75816, 0.73902, 0.70362, 0.64434, 0.54945, 0.44818, 0.38231, 0.31413],
                       [0.38964, 0.38523, 0.36770, 0.34842, 0.35645, 0.37297, 0.35601,
                        0.31887, 0.30124, 0.32062, 0.38681, 0.45506, 0.47913, 0.48693,
                        0.52099, 0.58516, 0.65963, 0.72264, 0.75938, 0.77753, 0.78671,
                        0.78680, 0.76886, 0.73612, 0.67947, 0.58551, 0.48353, 0.41540, 0.34164],
                       [0.42301, 0.41819, 0.40005, 0.37960, 0.38786, 0.40525, 0.38774,
                        0.34834, 0.32952, 0.35010, 0.41979, 0.49036, 0.51499, 0.52231,
                        0.55711, 0.62064, 0.69313, 0.75270, 0.78731, 0.80374, 0.81279,
                        0.81285, 0.79635, 0.76616, 0.71304, 0.62127, 0.51935, 0.44983, 0.37073],
                       [0.45785, 0.45248, 0.43390, 0.41244, 0.42105, 0.43906, 0.42085,
                        0.37951, 0.35953, 0.38145, 0.45381, 0.52653, 0.55150, 0.55864,
                        0.59343, 0.65579, 0.72503, 0.78150, 0.81302, 0.82766, 0.83600,
                        0.83604, 0.82155, 0.79420, 0.74484, 0.65665, 0.55534, 0.48530, 0.40111],
                       [0.49399, 0.48816, 0.46912, 0.44675, 0.45575, 0.47482, 0.45550,
                        0.41208, 0.39141, 0.41425, 0.48864, 0.56317, 0.58830, 0.59538,
                        0.62944, 0.69022, 0.75540, 0.80805, 0.83614, 0.84960, 0.85704,
                        0.85713, 0.84429, 0.81996, 0.77486, 0.69125, 0.59142, 0.52198, 0.43257],
                       [0.53036, 0.52449, 0.50512, 0.48166, 0.49122, 0.51130, 0.49110,
                        0.44593, 0.42477, 0.44830, 0.52413, 0.59962, 0.62427, 0.63076,
                        0.66402, 0.72253, 0.78338, 0.83136, 0.85649, 0.86884, 0.87544,
                        0.87582, 0.86426, 0.84254, 0.80218, 0.72391, 0.62732, 0.55894, 0.46414],
                       [0.56639, 0.56077, 0.54108, 0.51680, 0.52706, 0.54749, 0.52679,
                        0.48078, 0.45880, 0.48321, 0.55970, 0.63560, 0.65910, 0.66458,
                        0.69681, 0.75202, 0.80843, 0.85144, 0.87400, 0.88491, 0.89098,
                        0.89125, 0.88151, 0.86221, 0.82643, 0.75410, 0.66286, 0.59515, 0.49521],
                       [0.60241, 0.59672, 0.57704, 0.55259, 0.56292, 0.58368, 0.56281,
                        0.51650, 0.49353, 0.51879, 0.59516, 0.67070, 0.69294, 0.69793,
                        0.72866, 0.77976, 0.83148, 0.86941, 0.88955, 0.89900, 0.90422,
                        0.90446, 0.89657, 0.87968, 0.84809, 0.78231, 0.69683, 0.63102, 0.52639],
                       [0.63777, 0.63218, 0.61277, 0.58879, 0.59854, 0.61970, 0.59903,
                        0.55258, 0.52920, 0.55469, 0.63048, 0.70417, 0.72527, 0.73006,
                        0.75850, 0.80563, 0.85259, 0.88582, 0.90307, 0.91147, 0.91540,
                        0.91604, 0.90914, 0.89479, 0.86702, 0.80839, 0.72842, 0.66628, 0.55744],
                       [0.67188, 0.66678, 0.64780, 0.62428, 0.63387, 0.65480, 0.63438,
                        0.58829, 0.56552, 0.59095, 0.66476, 0.73549, 0.75527, 0.75916,
                        0.78557, 0.82881, 0.87043, 0.89979, 0.91426, 0.92160, 0.92479,
                        0.92550, 0.91945, 0.90700, 0.88313, 0.83177, 0.75822, 0.70033, 0.58712],
                       [0.70456, 0.69972, 0.68163, 0.65831, 0.66827, 0.68859, 0.66869,
                        0.62347, 0.60138, 0.62663, 0.69739, 0.76487, 0.78255, 0.78550,
                        0.81046, 0.84940, 0.88517, 0.91114, 0.92359, 0.92939, 0.93240,
                        0.93316, 0.92787, 0.91700, 0.89684, 0.85241, 0.78622, 0.73264, 0.61496],
                       [0.73502, 0.73059, 0.71360, 0.69105, 0.70074, 0.72063, 0.70179,
                        0.65791, 0.63586, 0.66061, 0.72832, 0.79190, 0.80736, 0.81030,
                        0.83266, 0.86729, 0.89805, 0.92080, 0.93157, 0.93588, 0.93872,
                        0.93918, 0.93427, 0.92555, 0.90824, 0.87003, 0.81143, 0.76211, 0.64133],
                       [0.76343, 0.75929, 0.74341, 0.72200, 0.73129, 0.75059, 0.73247,
                        0.69113, 0.66930, 0.69335, 0.75708, 0.81592, 0.83008, 0.83269,
                        0.85214, 0.88274, 0.90963, 0.92914, 0.93822, 0.94186, 0.94419,
                        0.94367, 0.93957, 0.93220, 0.91776, 0.88480, 0.83349, 0.78879, 0.66593],
                       [0.78989, 0.78577, 0.77103, 0.75082, 0.75997, 0.77805, 0.76063,
                        0.72240, 0.70180, 0.72470, 0.78352, 0.83704, 0.85018, 0.85210,
                        0.86953, 0.89585, 0.91981, 0.93556, 0.94327, 0.94651, 0.94814,
                        0.94696, 0.94388, 0.93700, 0.92541, 0.89727, 0.85288, 0.81330, 0.68822],
                       [0.81383, 0.80998, 0.79665, 0.77800, 0.78649, 0.80281, 0.78718,
                        0.75146, 0.73267, 0.75379, 0.80814, 0.85611, 0.86753, 0.86912,
                        0.88465, 0.90699, 0.92816, 0.94056, 0.94732, 0.94970, 0.95055,
                        0.94941, 0.94704, 0.94115, 0.93148, 0.90786, 0.86997, 0.83537, 0.70809],
                       [0.83510, 0.83184, 0.82025, 0.80341, 0.81091, 0.82554, 0.81233,
                        0.77882, 0.76157, 0.78091, 0.83073, 0.87356, 0.88283, 0.88431,
                        0.89767, 0.91716, 0.93477, 0.94523, 0.95086, 0.95244, 0.95251,
                        0.95150, 0.94939, 0.94500, 0.93693, 0.91721, 0.88527, 0.85500, 0.72563],
                       [0.85351, 0.85094, 0.84113, 0.82576, 0.83261, 0.84570, 0.83435,
                        0.80390, 0.78826, 0.80626, 0.85025, 0.88824, 0.89586, 0.89737,
                        0.90866, 0.92581, 0.94006, 0.94924, 0.95327, 0.95442, 0.95418,
                        0.95292, 0.95088, 0.94725, 0.94071, 0.92460, 0.89808, 0.87205, 0.74066],
                       [0.86956, 0.86765, 0.85914, 0.84519, 0.85142, 0.86303, 0.85269,
                        0.82644, 0.81255, 0.82893, 0.86721, 0.90010, 0.90709, 0.90851,
                        0.91776, 0.93239, 0.94445, 0.95233, 0.95481, 0.95568, 0.95534,
                        0.95359, 0.95178, 0.94811, 0.94301, 0.93024, 0.90785, 0.88619, 0.75382],
                       [0.88414, 0.88233, 0.87476, 0.86269, 0.86804, 0.87841, 0.86886,
                        0.84663, 0.83383, 0.84852, 0.88232, 0.91039, 0.91689, 0.91792,
                        0.92575, 0.93803, 0.94822, 0.95461, 0.95639, 0.95672, 0.95590,
                        0.95397, 0.95218, 0.94937, 0.94570, 0.93535, 0.91606, 0.89800, 0.76541],
                       [0.89697, 0.89484, 0.88848, 0.87790, 0.88257, 0.89217, 0.88344,
                        0.86406, 0.85251, 0.86578, 0.89517, 0.91951, 0.92488, 0.92567,
                        0.93276, 0.94312, 0.95144, 0.95597, 0.95782, 0.95718, 0.95569,
                        0.95401, 0.95219, 0.95085, 0.94799, 0.93935, 0.92360, 0.90813, 0.77502],
                       [0.90767, 0.90556, 0.90027, 0.89122, 0.89513, 0.90369, 0.89622,
                        0.87941, 0.86952, 0.88107, 0.90596, 0.92692, 0.93115, 0.93211,
                        0.93840, 0.94708, 0.95383, 0.95719, 0.95837, 0.95723, 0.95543,
                        0.95375, 0.95200, 0.95147, 0.94866, 0.94205, 0.92994, 0.91710, 0.78323],
                       [0.91658, 0.91484, 0.90975, 0.90308, 0.90619, 0.91292, 0.90728,
                        0.89293, 0.88425, 0.89399, 0.91536, 0.93274, 0.93618, 0.93715,
                        0.94267, 0.95022, 0.95552, 0.95831, 0.95831, 0.95717, 0.95524,
                        0.95369, 0.95188, 0.95133, 0.94909, 0.94456, 0.93486, 0.92467, 0.79039],
                       [0.92374, 0.92250, 0.91761, 0.91287, 0.91544, 0.92077, 0.91652,
                        0.90381, 0.89646, 0.90453, 0.92339, 0.93790, 0.94107, 0.94143,
                        0.94618, 0.95276, 0.95687, 0.95876, 0.95800, 0.95643, 0.95439,
                        0.95354, 0.95200, 0.95084, 0.94981, 0.94670, 0.93885, 0.93045, 0.79601],
                       [0.92978, 0.92906, 0.92531, 0.92057, 0.92318, 0.92782, 0.92423,
                        0.91313, 0.90722, 0.91425, 0.93012, 0.94269, 0.94564, 0.94567,
                        0.94960, 0.95484, 0.95805, 0.95898, 0.95739, 0.95539, 0.95346,
                        0.95296, 0.95209, 0.95099, 0.95063, 0.94820, 0.94234, 0.93543, 0.80046],
                       [0.93530, 0.93487, 0.93218, 0.92680, 0.92988, 0.93372, 0.93042,
                        0.92187, 0.91671, 0.92310, 0.93569, 0.94645, 0.94886, 0.94939,
                        0.95263, 0.95656, 0.95883, 0.95892, 0.95670, 0.95456, 0.95276,
                        0.95202, 0.95177, 0.95182, 0.95180, 0.94956, 0.94506, 0.93984, 0.80458],
                       [0.93999, 0.93948, 0.93704, 0.93254, 0.93518, 0.93840, 0.93538,
                        0.92880, 0.92430, 0.92982, 0.94011, 0.94905, 0.95130, 0.95219,
                        0.95446, 0.95767, 0.95922, 0.95846, 0.95647, 0.95363, 0.95226,
                        0.95114, 0.95140, 0.95222, 0.95290, 0.95091, 0.94707, 0.94345, 0.80841],
                       [0.94356, 0.94299, 0.94094, 0.93796, 0.93933, 0.94224, 0.93996,
                        0.93379, 0.93020, 0.93500, 0.94388, 0.95094, 0.95345, 0.95422,
                        0.95576, 0.95839, 0.95931, 0.95797, 0.95634, 0.95275, 0.95187,
                        0.95081, 0.95162, 0.95225, 0.95350, 0.95196, 0.94883, 0.94672, 0.81146],
                       [0.94630, 0.94610, 0.94486, 0.94247, 0.94308, 0.94551, 0.94398,
                        0.93833, 0.93537, 0.93961, 0.94757, 0.95298, 0.95541, 0.95586,
                        0.95737, 0.95908, 0.95955, 0.95762, 0.95554, 0.95246, 0.95179,
                        0.95123, 0.95205, 0.95277, 0.95395, 0.95300, 0.95086, 0.94963, 0.81390],
                       [0.94869, 0.94868, 0.94783, 0.94562, 0.94641, 0.94853, 0.94701,
                        0.94255, 0.94027, 0.94368, 0.95081, 0.95510, 0.95697, 0.95716,
                        0.95865, 0.95976, 0.95962, 0.95730, 0.95467, 0.95250, 0.95198,
                        0.95203, 0.95227, 0.95349, 0.95407, 0.95421, 0.95286, 0.95165, 0.81624],
                       [0.95074, 0.95026, 0.94945, 0.94786, 0.94892, 0.95083, 0.94926,
                        0.94589, 0.94415, 0.94691, 0.95255, 0.95662, 0.95788, 0.95806,
                        0.95941, 0.95994, 0.95865, 0.95644, 0.95397, 0.95216, 0.95171,
                        0.95233, 0.95261, 0.95364, 0.95398, 0.95514, 0.95396, 0.95330, 0.81791],
                       [0.95244, 0.95162, 0.95115, 0.94995, 0.95068, 0.95230, 0.95125,
                        0.94857, 0.94694, 0.94929, 0.95349, 0.95785, 0.95868, 0.95891,
                        0.95998, 0.95967, 0.95758, 0.95532, 0.95332, 0.95207, 0.95168,
                        0.95268, 0.95336, 0.95408, 0.95481, 0.95551, 0.95475, 0.95506, 0.81923],
                       [0.95390, 0.95348, 0.95320, 0.95175, 0.95229, 0.95375, 0.95319,
                        0.95068, 0.94951, 0.95165, 0.95518, 0.95897, 0.95972, 0.95969,
                        0.96024, 0.95964, 0.95760, 0.95495, 0.95287, 0.95245, 0.95272,
                        0.95355, 0.95429, 0.95527, 0.95604, 0.95605, 0.95601, 0.95658, 0.82080],
                       [0.95478, 0.95503, 0.95471, 0.95296, 0.95388, 0.95514, 0.95425,
                        0.95221, 0.95193, 0.95406, 0.95692, 0.95932, 0.96058, 0.96022,
                        0.96017, 0.95960, 0.95772, 0.95492, 0.95276, 0.95276, 0.95405,
                        0.95459, 0.95519, 0.95637, 0.95647, 0.95716, 0.95718, 0.95750, 0.82164],
                       [0.95548, 0.95580, 0.95552, 0.95413, 0.95503, 0.95615, 0.95488,
                        0.95389, 0.95336, 0.95564, 0.95781, 0.95913, 0.96077, 0.96075,
                        0.96011, 0.95910, 0.95715, 0.95495, 0.95338, 0.95335, 0.95495,
                        0.95572, 0.95628, 0.95699, 0.95687, 0.95774, 0.95773, 0.95806, 0.82188],
                       [0.95618, 0.95595, 0.95610, 0.95530, 0.95594, 0.95656, 0.95638,
                        0.95537, 0.95428, 0.95595, 0.95822, 0.95965, 0.96069, 0.96077,
                        0.95982, 0.95831, 0.95659, 0.95475, 0.95425, 0.95441, 0.95553,
                        0.95683, 0.95760, 0.95738, 0.95751, 0.95742, 0.95744, 0.95830, 0.82211],
                       [0.95704, 0.95652, 0.95684, 0.95624, 0.95694, 0.95693, 0.95789,
                        0.95611, 0.95581, 0.95616, 0.95894, 0.96087, 0.96110, 0.96068,
                        0.95980, 0.95797, 0.95622, 0.95435, 0.95506, 0.95575, 0.95659,
                        0.95794, 0.95865, 0.95784, 0.95761, 0.95698, 0.95747, 0.95844, 0.82239],
                       [0.95814, 0.95802, 0.95768, 0.95700, 0.95799, 0.95815, 0.95830,
                        0.95688, 0.95725, 0.95736, 0.96039, 0.96181, 0.96154, 0.96103,
                        0.96019, 0.95816, 0.95604, 0.95478, 0.95605, 0.95727, 0.95851,
                        0.95943, 0.95930, 0.95826, 0.95745, 0.95705, 0.95802, 0.95864, 0.82266],
                       [0.95890, 0.95927, 0.95818, 0.95763, 0.95869, 0.95930, 0.95831,
                        0.95806, 0.95790, 0.95872, 0.96143, 0.96226, 0.96196, 0.96111,
                        0.96003, 0.95824, 0.95622, 0.95592, 0.95705, 0.95877, 0.96034,
                        0.96080, 0.96014, 0.95851, 0.95720, 0.95733, 0.95760, 0.95827, 0.82240],
                       [0.95954, 0.95991, 0.95879, 0.95878, 0.95911, 0.95976, 0.95926,
                        0.95929, 0.95870, 0.95978, 0.96153, 0.96267, 0.96272, 0.96119,
                        0.95945, 0.95799, 0.95667, 0.95705, 0.95842, 0.96024, 0.96166,
                        0.96177, 0.96066, 0.95894, 0.95728, 0.95698, 0.95687, 0.95768, 0.82175],
                       [0.96048, 0.96057, 0.95996, 0.96010, 0.95992, 0.96050, 0.96097,
                        0.95986, 0.95978, 0.96062, 0.96176, 0.96291, 0.96281, 0.96111,
                        0.95926, 0.95780, 0.95732, 0.95812, 0.96028, 0.96198, 0.96295,
                        0.96271, 0.96100, 0.95964, 0.95761, 0.95628, 0.95684, 0.95716, 0.82114],
                       [0.96143, 0.96150, 0.96097, 0.96071, 0.96086, 0.96170, 0.96192,
                        0.95994, 0.96068, 0.96117, 0.96222, 0.96293, 0.96227, 0.96052,
                        0.95923, 0.95789, 0.95774, 0.95942, 0.96207, 0.96361, 0.96407,
                        0.96342, 0.96127, 0.95962, 0.95760, 0.95591, 0.95674, 0.95598, 0.82039],
                       [0.96242, 0.96268, 0.96206, 0.96131, 0.96196, 0.96286, 0.96225,
                        0.96079, 0.96141, 0.96188, 0.96295, 0.96332, 0.96246, 0.96059,
                        0.95939, 0.95820, 0.95841, 0.96119, 0.96373, 0.96480, 0.96490,
                        0.96400, 0.96154, 0.95907, 0.95764, 0.95594, 0.95588, 0.95495, 0.81946],
                       [0.96372, 0.96367, 0.96365, 0.96259, 0.96330, 0.96384, 0.96311,
                        0.96203, 0.96181, 0.96270, 0.96374, 0.96406, 0.96333, 0.96138,
                        0.95989, 0.95875, 0.95989, 0.96301, 0.96501, 0.96591, 0.96566,
                        0.96465, 0.96190, 0.95890, 0.95739, 0.95579, 0.95470, 0.95476, 0.81872],
                       [0.96465, 0.96433, 0.96478, 0.96367, 0.96404, 0.96456, 0.96421,
                        0.96276, 0.96203, 0.96303, 0.96374, 0.96460, 0.96376, 0.96166,
                        0.95995, 0.95942, 0.96126, 0.96414, 0.96596, 0.96692, 0.96590,
                        0.96447, 0.96147, 0.95868, 0.95629, 0.95523, 0.95392, 0.95434, 0.81780],
                       [0.96546, 0.96520, 0.96520, 0.96442, 0.96450, 0.96510, 0.96497,
                        0.96333, 0.96265, 0.96304, 0.96383, 0.96453, 0.96347, 0.96130,
                        0.95956, 0.96001, 0.96192, 0.96498, 0.96694, 0.96717, 0.96563,
                        0.96321, 0.96048, 0.95794, 0.95521, 0.95453, 0.95323, 0.95305, 0.81671],
                       [0.96670, 0.96660, 0.96591, 0.96540, 0.96558, 0.96593, 0.96558,
                        0.96417, 0.96359, 0.96343, 0.96471, 0.96415, 0.96299, 0.96117,
                        0.95949, 0.96097, 0.96271, 0.96624, 0.96783, 0.96682, 0.96519,
                        0.96215, 0.95995, 0.95719, 0.95493, 0.95372, 0.95244, 0.95172, 0.81617],
                       [0.96806, 0.96831, 0.96731, 0.96641, 0.96694, 0.96735, 0.96616,
                        0.96521, 0.96458, 0.96446, 0.96530, 0.96417, 0.96304, 0.96164,
                        0.96011, 0.96210, 0.96447, 0.96789, 0.96863, 0.96670, 0.96485,
                        0.96210, 0.95962, 0.95692, 0.95502, 0.95338, 0.95242, 0.95140, 0.81606],
                       [0.96901, 0.96953, 0.96871, 0.96743, 0.96805, 0.96873, 0.96712,
                        0.96623, 0.96541, 0.96533, 0.96542, 0.96449, 0.96350, 0.96224,
                        0.96128, 0.96273, 0.96648, 0.96918, 0.96874, 0.96706, 0.96438,
                        0.96207, 0.95900, 0.95702, 0.95515, 0.95377, 0.95283, 0.95152, 0.81612],
                       [0.96967, 0.97011, 0.96937, 0.96842, 0.96885, 0.96948, 0.96818,
                        0.96688, 0.96584, 0.96575, 0.96558, 0.96500, 0.96368, 0.96253,
                        0.96269, 0.96380, 0.96781, 0.96950, 0.96827, 0.96647, 0.96311,
                        0.96084, 0.95816, 0.95696, 0.95526, 0.95413, 0.95282, 0.95126, 0.81618],
                       [0.97083, 0.97094, 0.97007, 0.96961, 0.96983, 0.97018, 0.96903,
                        0.96756, 0.96662, 0.96647, 0.96612, 0.96567, 0.96409, 0.96302,
                        0.96382, 0.96574, 0.96854, 0.96951, 0.96800, 0.96512, 0.96200,
                        0.95915, 0.95778, 0.95662, 0.95591, 0.95439, 0.95295, 0.95158, 0.81660],
                       [0.97214, 0.97195, 0.97146, 0.97086, 0.97087, 0.97082, 0.96994,
                        0.96866, 0.96767, 0.96752, 0.96707, 0.96576, 0.96478, 0.96400,
                        0.96463, 0.96705, 0.96900, 0.96958, 0.96753, 0.96447, 0.96124,
                        0.95858, 0.95778, 0.95695, 0.95724, 0.95491, 0.95382, 0.95248, 0.81764],
                       [0.97271, 0.97226, 0.97200, 0.97108, 0.97095, 0.97084, 0.97020,
                        0.96913, 0.96796, 0.96763, 0.96724, 0.96539, 0.96466, 0.96459,
                        0.96520, 0.96699, 0.96943, 0.96920, 0.96673, 0.96349, 0.96006,
                        0.95834, 0.95735, 0.95779, 0.95772, 0.95557, 0.95448, 0.95276, 0.81818],
                       [0.97254, 0.97198, 0.97162, 0.97092, 0.97103, 0.97075, 0.96992,
                        0.96903, 0.96795, 0.96714, 0.96681, 0.96572, 0.96463, 0.96507,
                        0.96587, 0.96731, 0.97010, 0.96872, 0.96589, 0.96183, 0.95917,
                        0.95770, 0.95743, 0.95809, 0.95727, 0.95640, 0.95486, 0.95335, 0.81858],
                       [0.97210, 0.97179, 0.97167, 0.97130, 0.97143, 0.97103, 0.96991,
                        0.96906, 0.96803, 0.96706, 0.96671, 0.96624, 0.96560, 0.96570,
                        0.96715, 0.96862, 0.97027, 0.96825, 0.96454, 0.96047, 0.95841,
                        0.95768, 0.95794, 0.95789, 0.95748, 0.95731, 0.95569, 0.95499, 0.81965],
                       [0.97223, 0.97184, 0.97206, 0.97173, 0.97131, 0.97123, 0.97016,
                        0.96917, 0.96824, 0.96714, 0.96687, 0.96625, 0.96662, 0.96646,
                        0.96859, 0.96973, 0.97005, 0.96718, 0.96275, 0.95944, 0.95774,
                        0.95787, 0.95789, 0.95823, 0.95903, 0.95858, 0.95697, 0.95650, 0.82114],
                       [0.97267, 0.97188, 0.97209, 0.97179, 0.97140, 0.97093, 0.97030,
                        0.96923, 0.96846, 0.96751, 0.96707, 0.96659, 0.96727, 0.96723,
                        0.96937, 0.96990, 0.96953, 0.96567, 0.96125, 0.95858, 0.95740,
                        0.95722, 0.95817, 0.95953, 0.96090, 0.96002, 0.95859, 0.95761, 0.82251],
                       [0.97220, 0.97214, 0.97208, 0.97172, 0.97156, 0.97067, 0.97008,
                        0.96925, 0.96847, 0.96831, 0.96746, 0.96747, 0.96808, 0.96811,
                        0.96948, 0.96975, 0.96865, 0.96465, 0.96051, 0.95835, 0.95745,
                        0.95726, 0.95932, 0.96109, 0.96198, 0.96125, 0.96010, 0.95905, 0.82362],
                       [0.97100, 0.97210, 0.97196, 0.97153, 0.97092, 0.97045, 0.96986,
                        0.96943, 0.96853, 0.96838, 0.96749, 0.96824, 0.96880, 0.96909,
                        0.96952, 0.96982, 0.96799, 0.96380, 0.95981, 0.95806, 0.95762,
                        0.95852, 0.96056, 0.96202, 0.96242, 0.96201, 0.96087, 0.96071, 0.82492],
                       [0.97021, 0.97081, 0.97116, 0.97107, 0.97028, 0.96976, 0.96962,
                        0.96936, 0.96861, 0.96780, 0.96710, 0.96866, 0.96935, 0.96963,
                        0.96999, 0.96973, 0.96720, 0.96222, 0.95844, 0.95725, 0.95778,
                        0.95931, 0.96124, 0.96238, 0.96304, 0.96251, 0.96178, 0.96196, 0.82621],
                       [0.96996, 0.96970, 0.97067, 0.97092, 0.97065, 0.96928, 0.96923,
                        0.96914, 0.96828, 0.96794, 0.96725, 0.96898, 0.97039, 0.97014,
                        0.97051, 0.96932, 0.96617, 0.96091, 0.95767, 0.95706, 0.95855,
                        0.96004, 0.96192, 0.96297, 0.96418, 0.96358, 0.96331, 0.96296, 0.82716],
                       [0.96970, 0.96941, 0.97018, 0.97071, 0.97066, 0.96917, 0.96889,
                        0.96865, 0.96779, 0.96822, 0.96818, 0.96936, 0.97106, 0.97086,
                        0.97039, 0.96866, 0.96492, 0.96027, 0.95791, 0.95776, 0.95937,
                        0.96129, 0.96290, 0.96371, 0.96487, 0.96473, 0.96422, 0.96401, 0.82815],
                       [0.96955, 0.96937, 0.96947, 0.96994, 0.96953, 0.96906, 0.96897,
                        0.96819, 0.96823, 0.96810, 0.96937, 0.97007, 0.97106, 0.97120,
                        0.97009, 0.96782, 0.96331, 0.95951, 0.95837, 0.95887, 0.96015,
                        0.96254, 0.96392, 0.96454, 0.96499, 0.96547, 0.96494, 0.96485, 0.82953],
                       [0.96917, 0.96909, 0.96911, 0.96891, 0.96874, 0.96872, 0.96912,
                        0.96863, 0.96884, 0.96841, 0.96958, 0.97076, 0.97101, 0.97095,
                        0.96989, 0.96678, 0.96200, 0.95872, 0.95868, 0.95933, 0.96103,
                        0.96347, 0.96456, 0.96528, 0.96521, 0.96582, 0.96582, 0.96529, 0.82988],
                       [0.96816, 0.96840, 0.96903, 0.96861, 0.96881, 0.96825, 0.96874,
                        0.96879, 0.96836, 0.96872, 0.96907, 0.97069, 0.97095, 0.97062,
                        0.96912, 0.96540, 0.96146, 0.95816, 0.95862, 0.95934, 0.96175,
                        0.96399, 0.96470, 0.96524, 0.96505, 0.96529, 0.96601, 0.96553, 0.82879],
                       [0.96773, 0.96800, 0.96875, 0.96880, 0.96877, 0.96812, 0.96826,
                        0.96804, 0.96776, 0.96839, 0.96916, 0.97026, 0.97097, 0.96996,
                        0.96794, 0.96423, 0.96060, 0.95802, 0.95855, 0.96034, 0.96296,
                        0.96423, 0.96484, 0.96450, 0.96438, 0.96452, 0.96554, 0.96560, 0.82829],
                       [0.96846, 0.96840, 0.96857, 0.96895, 0.96846, 0.96834, 0.96837,
                        0.96819, 0.96854, 0.96882, 0.96984, 0.97057, 0.97100, 0.96952,
                        0.96735, 0.96397, 0.95961, 0.95884, 0.95971, 0.96229, 0.96475,
                        0.96516, 0.96541, 0.96457, 0.96439, 0.96447, 0.96502, 0.96572, 0.82886],
                       [0.96908, 0.96885, 0.96892, 0.96920, 0.96862, 0.96897, 0.96913,
                        0.96926, 0.96947, 0.97000, 0.97049, 0.97113, 0.97047, 0.96946,
                        0.96721, 0.96336, 0.95946, 0.96001, 0.96174, 0.96397, 0.96596,
                        0.96668, 0.96604, 0.96525, 0.96482, 0.96433, 0.96479, 0.96576, 0.82892],
                       [0.96905, 0.96882, 0.96907, 0.96902, 0.96906, 0.96973, 0.96940,
                        0.96945, 0.96934, 0.97010, 0.97084, 0.97100, 0.96949, 0.96861,
                        0.96570, 0.96180, 0.95979, 0.96072, 0.96300, 0.96482, 0.96633,
                        0.96695, 0.96579, 0.96468, 0.96387, 0.96307, 0.96430, 0.96464, 0.82769],
                       [0.96948, 0.96933, 0.96930, 0.96882, 0.96950, 0.97014, 0.96951,
                        0.96939, 0.96969, 0.96984, 0.97109, 0.97086, 0.96950, 0.96755,
                        0.96386, 0.96098, 0.96023, 0.96167, 0.96415, 0.96580, 0.96688,
                        0.96664, 0.96526, 0.96378, 0.96223, 0.96201, 0.96307, 0.96320, 0.82658],
                       [0.96996, 0.97022, 0.96979, 0.96928, 0.96990, 0.97003, 0.97029,
                        0.96997, 0.97048, 0.97051, 0.97123, 0.97073, 0.96929, 0.96668,
                        0.96338, 0.96117, 0.96049, 0.96257, 0.96552, 0.96696, 0.96758,
                        0.96697, 0.96484, 0.96359, 0.96119, 0.96142, 0.96164, 0.96252, 0.82571],
                       [0.96987, 0.97042, 0.97007, 0.97001, 0.97036, 0.97029, 0.97109,
                        0.97074, 0.97085, 0.97117, 0.97113, 0.97008, 0.96776, 0.96560,
                        0.96315, 0.96141, 0.96071, 0.96338, 0.96675, 0.96774, 0.96776,
                        0.96727, 0.96445, 0.96323, 0.96066, 0.96068, 0.96099, 0.96169, 0.82440],
                       [0.97009, 0.97026, 0.97012, 0.97018, 0.97081, 0.97089, 0.97139,
                        0.97072, 0.97085, 0.97101, 0.97062, 0.96916, 0.96669, 0.96456,
                        0.96232, 0.96131, 0.96135, 0.96490, 0.96771, 0.96847, 0.96776,
                        0.96673, 0.96394, 0.96229, 0.96035, 0.95967, 0.96045, 0.96049, 0.82359],
                       [0.97096, 0.97081, 0.97047, 0.97029, 0.97101, 0.97157, 0.97140,
                        0.97037, 0.97102, 0.97086, 0.96997, 0.96872, 0.96655, 0.96390,
                        0.96187, 0.96132, 0.96305, 0.96689, 0.96867, 0.96937, 0.96817,
                        0.96580, 0.96335, 0.96121, 0.96031, 0.95889, 0.95974, 0.95971, 0.82356],
                       [0.97112, 0.97128, 0.97121, 0.97062, 0.97084, 0.97206, 0.97105,
                        0.97087, 0.97104, 0.97079, 0.96941, 0.96790, 0.96546, 0.96308,
                        0.96194, 0.96124, 0.96458, 0.96801, 0.96966, 0.96988, 0.96801,
                        0.96519, 0.96260, 0.96024, 0.95962, 0.95847, 0.95870, 0.95863, 0.82326],
                       [0.97086, 0.97117, 0.97151, 0.97107, 0.97071, 0.97182, 0.97099,
                        0.97163, 0.97083, 0.97070, 0.96898, 0.96638, 0.96421, 0.96237,
                        0.96186, 0.96138, 0.96536, 0.96840, 0.97011, 0.96975, 0.96712,
                        0.96474, 0.96197, 0.95998, 0.95834, 0.95778, 0.95759, 0.95717, 0.82213],
                       [0.97128, 0.97172, 0.97159, 0.97143, 0.97143, 0.97144, 0.97176,
                        0.97168, 0.97131, 0.97082, 0.96867, 0.96567, 0.96408, 0.96256,
                        0.96189, 0.96271, 0.96661, 0.96943, 0.97057, 0.96910, 0.96652,
                        0.96408, 0.96181, 0.96044, 0.95818, 0.95760, 0.95743, 0.95670, 0.82087],
                       [0.97201, 0.97271, 0.97217, 0.97154, 0.97246, 0.97182, 0.97239,
                        0.97125, 0.97179, 0.97070, 0.96848, 0.96590, 0.96384, 0.96313,
                        0.96252, 0.96446, 0.96818, 0.97080, 0.97110, 0.96872, 0.96615,
                        0.96350, 0.96163, 0.96097, 0.95925, 0.95821, 0.95786, 0.95724, 0.82115],
                       [0.97198, 0.97227, 0.97230, 0.97165, 0.97203, 0.97171, 0.97180,
                        0.97085, 0.97092, 0.97002, 0.96771, 0.96542, 0.96294, 0.96302,
                        0.96300, 0.96538, 0.96899, 0.97128, 0.97063, 0.96837, 0.96533,
                        0.96302, 0.96146, 0.96092, 0.95965, 0.95827, 0.95746, 0.95712, 0.82202],
                       [0.97099, 0.97136, 0.97198, 0.97142, 0.97104, 0.97087, 0.97047,
                        0.97089, 0.96976, 0.96904, 0.96670, 0.96436, 0.96271, 0.96282,
                        0.96328, 0.96601, 0.96953, 0.97128, 0.96970, 0.96777, 0.96463,
                        0.96291, 0.96152, 0.96058, 0.95944, 0.95814, 0.95688, 0.95672, 0.82206],
                       [0.97042, 0.97128, 0.97168, 0.97085, 0.97098, 0.97029, 0.96957,
                        0.97070, 0.96947, 0.96829, 0.96614, 0.96407, 0.96353, 0.96329,
                        0.96421, 0.96711, 0.97048, 0.97111, 0.96930, 0.96692, 0.96426,
                        0.96259, 0.96170, 0.96084, 0.95999, 0.95867, 0.95735, 0.95672, 0.82230],
                       [0.97068, 0.97107, 0.97109, 0.97041, 0.97103, 0.96969, 0.96940,
                        0.96977, 0.96932, 0.96779, 0.96562, 0.96420, 0.96393, 0.96399,
                        0.96555, 0.96823, 0.97116, 0.97079, 0.96925, 0.96546, 0.96335,
                        0.96196, 0.96181, 0.96142, 0.96093, 0.95942, 0.95841, 0.95680, 0.82304],
                       [0.97066, 0.97031, 0.97045, 0.97036, 0.97060, 0.96913, 0.96951,
                        0.96897, 0.96873, 0.96735, 0.96523, 0.96420, 0.96406, 0.96464,
                        0.96689, 0.96931, 0.97145, 0.97065, 0.96870, 0.96460, 0.96275,
                        0.96206, 0.96195, 0.96189, 0.96193, 0.96062, 0.95947, 0.95760, 0.82380],
                       [0.97006, 0.96971, 0.96993, 0.97036, 0.96957, 0.96883, 0.96884,
                        0.96861, 0.96787, 0.96705, 0.96525, 0.96471, 0.96510, 0.96560,
                        0.96842, 0.97047, 0.97174, 0.97045, 0.96753, 0.96479, 0.96344,
                        0.96254, 0.96267, 0.96267, 0.96292, 0.96181, 0.96037, 0.95913, 0.82454],
                       [0.96948, 0.96910, 0.96947, 0.97003, 0.96863, 0.96848, 0.96793,
                        0.96826, 0.96740, 0.96656, 0.96541, 0.96545, 0.96636, 0.96707,
                        0.96964, 0.97138, 0.97216, 0.96977, 0.96631, 0.96461, 0.96375,
                        0.96306, 0.96352, 0.96360, 0.96380, 0.96280, 0.96114, 0.96060, 0.82551],
                       [0.96879, 0.96853, 0.96916, 0.96960, 0.96849, 0.96792, 0.96780,
                        0.96769, 0.96698, 0.96591, 0.96581, 0.96576, 0.96712, 0.96844,
                        0.96996, 0.97171, 0.97211, 0.96869, 0.96524, 0.96362, 0.96282,
                        0.96331, 0.96386, 0.96426, 0.96475, 0.96402, 0.96222, 0.96197, 0.82681],
                       [0.96849, 0.96871, 0.96906, 0.96929, 0.96882, 0.96786, 0.96782,
                        0.96743, 0.96670, 0.96595, 0.96646, 0.96644, 0.96812, 0.96924,
                        0.97050, 0.97208, 0.97162, 0.96794, 0.96485, 0.96324, 0.96266,
                        0.96354, 0.96454, 0.96547, 0.96579, 0.96527, 0.96371, 0.96362, 0.82805],
                       [0.96872, 0.96868, 0.96871, 0.96916, 0.96889, 0.96831, 0.96751,
                        0.96699, 0.96677, 0.96648, 0.96696, 0.96788, 0.96941, 0.96980,
                        0.97191, 0.97265, 0.97073, 0.96735, 0.96478, 0.96344, 0.96333,
                        0.96416, 0.96561, 0.96674, 0.96676, 0.96627, 0.96482, 0.96474, 0.82879],
                       [0.96856, 0.96826, 0.96853, 0.96895, 0.96845, 0.96817, 0.96722,
                        0.96624, 0.96665, 0.96671, 0.96720, 0.96923, 0.97052, 0.97093,
                        0.97288, 0.97256, 0.96978, 0.96674, 0.96458, 0.96339, 0.96363,
                        0.96461, 0.96634, 0.96703, 0.96752, 0.96690, 0.96576, 0.96504, 0.82974],
                       [0.96795, 0.96770, 0.96860, 0.96790, 0.96787, 0.96718, 0.96701,
                        0.96610, 0.96612, 0.96657, 0.96731, 0.96955, 0.97148, 0.97209,
                        0.97243, 0.97163, 0.96905, 0.96596, 0.96395, 0.96335, 0.96372,
                        0.96488, 0.96671, 0.96714, 0.96818, 0.96725, 0.96658, 0.96556, 0.83075],
                       [0.96771, 0.96736, 0.96847, 0.96736, 0.96767, 0.96666, 0.96721,
                        0.96650, 0.96603, 0.96637, 0.96796, 0.96999, 0.97203, 0.97264,
                        0.97174, 0.97072, 0.96833, 0.96471, 0.96316, 0.96351, 0.96420,
                        0.96572, 0.96704, 0.96805, 0.96858, 0.96786, 0.96730, 0.96679, 0.83150],
                       [0.96840, 0.96799, 0.96859, 0.96862, 0.96851, 0.96765, 0.96809,
                        0.96708, 0.96702, 0.96699, 0.96926, 0.97153, 0.97240, 0.97321,
                        0.97249, 0.97054, 0.96777, 0.96411, 0.96338, 0.96426, 0.96495,
                        0.96688, 0.96765, 0.96886, 0.96869, 0.96869, 0.96846, 0.96835, 0.83250],
                       [0.96914, 0.96849, 0.96873, 0.96977, 0.96911, 0.96861, 0.96864,
                        0.96748, 0.96779, 0.96824, 0.97015, 0.97247, 0.97276, 0.97303,
                        0.97311, 0.97019, 0.96674, 0.96396, 0.96391, 0.96481, 0.96551,
                        0.96715, 0.96759, 0.96810, 0.96867, 0.96843, 0.96902, 0.96892, 0.83266],
                       [0.96923, 0.96889, 0.96867, 0.96966, 0.96864, 0.96855, 0.96858,
                        0.96790, 0.96767, 0.96868, 0.97048, 0.97253, 0.97300, 0.97226,
                        0.97171, 0.96889, 0.96537, 0.96325, 0.96376, 0.96468, 0.96603,
                        0.96677, 0.96674, 0.96696, 0.96801, 0.96779, 0.96850, 0.96834, 0.83229],
                       [0.96975, 0.96988, 0.96900, 0.96969, 0.96888, 0.96916, 0.96928,
                        0.96900, 0.96804, 0.96903, 0.97123, 0.97302, 0.97320, 0.97223,
                        0.96997, 0.96769, 0.96479, 0.96277, 0.96382, 0.96503, 0.96650,
                        0.96692, 0.96657, 0.96705, 0.96711, 0.96819, 0.96814, 0.96829, 0.83264],
                       [0.97021, 0.97075, 0.96973, 0.97034, 0.97007, 0.97051, 0.97020,
                        0.97010, 0.96893, 0.97011, 0.97223, 0.97349, 0.97303, 0.97251,
                        0.96937, 0.96728, 0.96449, 0.96294, 0.96439, 0.96539, 0.96625,
                        0.96714, 0.96689, 0.96734, 0.96688, 0.96827, 0.96812, 0.96885, 0.83272],
                       [0.97028, 0.97071, 0.97029, 0.97064, 0.97071, 0.97135, 0.97052,
                        0.97046, 0.96978, 0.97086, 0.97257, 0.97300, 0.97266, 0.97199,
                        0.96914, 0.96665, 0.96378, 0.96318, 0.96458, 0.96512, 0.96555,
                        0.96644, 0.96639, 0.96641, 0.96664, 0.96710, 0.96770, 0.96861, 0.83184],
                       [0.97107, 0.97065, 0.97096, 0.97090, 0.97110, 0.97175, 0.97114,
                        0.97077, 0.97092, 0.97139, 0.97266, 0.97264, 0.97238, 0.97097,
                        0.96860, 0.96544, 0.96333, 0.96339, 0.96422, 0.96529, 0.96571,
                        0.96563, 0.96542, 0.96509, 0.96581, 0.96612, 0.96718, 0.96785, 0.83117],
                       [0.97235, 0.97172, 0.97192, 0.97173, 0.97189, 0.97244, 0.97227,
                        0.97165, 0.97168, 0.97260, 0.97307, 0.97301, 0.97161, 0.97020,
                        0.96778, 0.96487, 0.96349, 0.96381, 0.96452, 0.96590, 0.96672,
                        0.96518, 0.96478, 0.96455, 0.96451, 0.96572, 0.96696, 0.96767, 0.83112],
                       [0.97281, 0.97274, 0.97258, 0.97231, 0.97262, 0.97310, 0.97276,
                        0.97240, 0.97166, 0.97324, 0.97312, 0.97269, 0.97066, 0.96915,
                        0.96662, 0.96448, 0.96374, 0.96416, 0.96525, 0.96570, 0.96655,
                        0.96460, 0.96432, 0.96402, 0.96314, 0.96480, 0.96659, 0.96722, 0.83093],
                       [0.97263, 0.97305, 0.97332, 0.97280, 0.97335, 0.97349, 0.97304,
                        0.97290, 0.97217, 0.97284, 0.97294, 0.97185, 0.97001, 0.96777,
                        0.96609, 0.96383, 0.96389, 0.96447, 0.96557, 0.96530, 0.96516,
                        0.96420, 0.96369, 0.96306, 0.96248, 0.96342, 0.96576, 0.96584, 0.83071],
                       [0.97289, 0.97350, 0.97393, 0.97340, 0.97359, 0.97369, 0.97385,
                        0.97344, 0.97286, 0.97291, 0.97281, 0.97133, 0.96891, 0.96695,
                        0.96576, 0.96359, 0.96379, 0.96479, 0.96545, 0.96507, 0.96403,
                        0.96356, 0.96246, 0.96205, 0.96195, 0.96250, 0.96457, 0.96475, 0.83012],
                       [0.97327, 0.97389, 0.97378, 0.97335, 0.97305, 0.97372, 0.97413,
                        0.97360, 0.97286, 0.97339, 0.97210, 0.97025, 0.96737, 0.96648,
                        0.96427, 0.96335, 0.96365, 0.96470, 0.96486, 0.96447, 0.96304,
                        0.96210, 0.96091, 0.96046, 0.96070, 0.96179, 0.96300, 0.96418, 0.82864],
                       [0.97344, 0.97357, 0.97356, 0.97320, 0.97291, 0.97398, 0.97371,
                        0.97321, 0.97306, 0.97339, 0.97107, 0.96869, 0.96630, 0.96577,
                        0.96313, 0.96312, 0.96411, 0.96472, 0.96442, 0.96415, 0.96235,
                        0.96078, 0.96008, 0.95921, 0.95960, 0.96094, 0.96180, 0.96348, 0.82752],
                       [0.97331, 0.97271, 0.97294, 0.97311, 0.97311, 0.97379, 0.97305,
                        0.97284, 0.97344, 0.97262, 0.97003, 0.96745, 0.96553, 0.96491,
                        0.96308, 0.96288, 0.96440, 0.96500, 0.96398, 0.96360, 0.96148,
                        0.96009, 0.95976, 0.95900, 0.95880, 0.96007, 0.96098, 0.96253, 0.82698],
                       [0.97278, 0.97208, 0.97216, 0.97278, 0.97321, 0.97283, 0.97270,
                        0.97297, 0.97323, 0.97192, 0.96938, 0.96674, 0.96494, 0.96433,
                        0.96320, 0.96292, 0.96419, 0.96495, 0.96376, 0.96243, 0.96019,
                        0.95952, 0.95917, 0.95875, 0.95807, 0.95946, 0.96037, 0.96162, 0.82671],
                       [0.97203, 0.97196, 0.97226, 0.97220, 0.97227, 0.97186, 0.97236,
                        0.97252, 0.97244, 0.97166, 0.96919, 0.96639, 0.96424, 0.96369,
                        0.96303, 0.96341, 0.96404, 0.96431, 0.96328, 0.96145, 0.95914,
                        0.95859, 0.95835, 0.95805, 0.95773, 0.95893, 0.96024, 0.96074, 0.82645],
                       [0.97121, 0.97193, 0.97226, 0.97160, 0.97100, 0.97134, 0.97140,
                        0.97155, 0.97154, 0.97084, 0.96852, 0.96551, 0.96344, 0.96311,
                        0.96269, 0.96386, 0.96416, 0.96343, 0.96214, 0.96079, 0.95848,
                        0.95760, 0.95741, 0.95712, 0.95736, 0.95810, 0.95999, 0.96014, 0.82582],
                       [0.97021, 0.97095, 0.97102, 0.97109, 0.97070, 0.97052, 0.97021,
                        0.97068, 0.97068, 0.96917, 0.96702, 0.96414, 0.96291, 0.96293,
                        0.96253, 0.96362, 0.96417, 0.96289, 0.96106, 0.95964, 0.95799,
                        0.95654, 0.95624, 0.95622, 0.95646, 0.95742, 0.95898, 0.95969, 0.82491],
                       [0.96916, 0.96942, 0.96960, 0.97035, 0.97013, 0.96899, 0.96911,
                        0.96993, 0.96948, 0.96786, 0.96546, 0.96306, 0.96275, 0.96264,
                        0.96271, 0.96306, 0.96392, 0.96271, 0.96005, 0.95823, 0.95728,
                        0.95581, 0.95586, 0.95551, 0.95564, 0.95730, 0.95805, 0.95901, 0.82432],
                       [0.96800, 0.96853, 0.96921, 0.96987, 0.96895, 0.96800, 0.96785,
                        0.96911, 0.96823, 0.96752, 0.96467, 0.96258, 0.96269, 0.96244,
                        0.96305, 0.96339, 0.96364, 0.96243, 0.95948, 0.95764, 0.95629,
                        0.95580, 0.95608, 0.95535, 0.95579, 0.95730, 0.95801, 0.95860, 0.82470],
                       [0.96702, 0.96775, 0.96943, 0.96958, 0.96833, 0.96791, 0.96683,
                        0.96813, 0.96780, 0.96741, 0.96458, 0.96294, 0.96244, 0.96279,
                        0.96352, 0.96450, 0.96344, 0.96192, 0.95977, 0.95728, 0.95559,
                        0.95540, 0.95600, 0.95593, 0.95675, 0.95720, 0.95815, 0.95863, 0.82546],
                       [0.96675, 0.96697, 0.96849, 0.96868, 0.96793, 0.96742, 0.96671,
                        0.96715, 0.96799, 0.96661, 0.96459, 0.96352, 0.96236, 0.96334,
                        0.96391, 0.96498, 0.96321, 0.96119, 0.95963, 0.95665, 0.95570,
                        0.95521, 0.95568, 0.95643, 0.95732, 0.95739, 0.95787, 0.95878, 0.82575],
                       [0.96651, 0.96634, 0.96617, 0.96742, 0.96685, 0.96606, 0.96667,
                        0.96637, 0.96735, 0.96539, 0.96428, 0.96335, 0.96309, 0.96408,
                        0.96382, 0.96414, 0.96281, 0.96028, 0.95812, 0.95639, 0.95597,
                        0.95580, 0.95535, 0.95647, 0.95692, 0.95727, 0.95783, 0.95906, 0.82519],
                       [0.96568, 0.96539, 0.96475, 0.96635, 0.96549, 0.96458, 0.96567,
                        0.96570, 0.96562, 0.96443, 0.96338, 0.96251, 0.96377, 0.96429,
                        0.96342, 0.96319, 0.96235, 0.95968, 0.95649, 0.95612, 0.95596,
                        0.95603, 0.95556, 0.95666, 0.95671, 0.95700, 0.95803, 0.95895, 0.82464],
                       [0.96469, 0.96472, 0.96495, 0.96554, 0.96455, 0.96411, 0.96435,
                        0.96509, 0.96428, 0.96404, 0.96252, 0.96245, 0.96359, 0.96350,
                        0.96347, 0.96322, 0.96197, 0.95947, 0.95615, 0.95576, 0.95588,
                        0.95577, 0.95620, 0.95695, 0.95717, 0.95770, 0.95815, 0.95857, 0.82518],
                       [0.96393, 0.96448, 0.96475, 0.96457, 0.96392, 0.96415, 0.96343,
                        0.96436, 0.96401, 0.96387, 0.96237, 0.96297, 0.96348, 0.96310,
                        0.96377, 0.96335, 0.96140, 0.95895, 0.95641, 0.95566, 0.95540,
                        0.95532, 0.95663, 0.95685, 0.95742, 0.95830, 0.95804, 0.95856, 0.82576],
                       [0.96333, 0.96362, 0.96361, 0.96405, 0.96351, 0.96349, 0.96282,
                        0.96350, 0.96386, 0.96355, 0.96276, 0.96326, 0.96374, 0.96394,
                        0.96338, 0.96282, 0.96032, 0.95794, 0.95636, 0.95590, 0.95511,
                        0.95543, 0.95705, 0.95665, 0.95773, 0.95791, 0.95808, 0.95868, 0.82547],
                       [0.96301, 0.96279, 0.96302, 0.96447, 0.96353, 0.96295, 0.96301,
                        0.96316, 0.96342, 0.96340, 0.96334, 0.96365, 0.96412, 0.96473,
                        0.96302, 0.96230, 0.95941, 0.95767, 0.95651, 0.95643, 0.95594,
                        0.95668, 0.95791, 0.95725, 0.95827, 0.95812, 0.95871, 0.95915, 0.82542],
                       [0.96298, 0.96276, 0.96321, 0.96407, 0.96361, 0.96298, 0.96353,
                        0.96326, 0.96299, 0.96309, 0.96328, 0.96390, 0.96422, 0.96437,
                        0.96312, 0.96202, 0.95921, 0.95794, 0.95683, 0.95685, 0.95710,
                        0.95789, 0.95844, 0.95833, 0.95846, 0.95867, 0.95907, 0.95959, 0.82578],
                       [0.96312, 0.96303, 0.96350, 0.96308, 0.96342, 0.96275, 0.96341,
                        0.96341, 0.96286, 0.96275, 0.96319, 0.96401, 0.96418, 0.96378,
                        0.96308, 0.96153, 0.95949, 0.95785, 0.95724, 0.95712, 0.95768,
                        0.95864, 0.95851, 0.95915, 0.95863, 0.95865, 0.95908, 0.95966, 0.82597],
                       [0.96338, 0.96349, 0.96369, 0.96316, 0.96361, 0.96266, 0.96302,
                        0.96359, 0.96322, 0.96306, 0.96408, 0.96457, 0.96467, 0.96396,
                        0.96308, 0.96094, 0.95965, 0.95806, 0.95813, 0.95795, 0.95840,
                        0.95953, 0.95940, 0.95983, 0.95943, 0.95914, 0.95932, 0.96024, 0.82621],
                       [0.96362, 0.96384, 0.96360, 0.96373, 0.96402, 0.96343, 0.96309,
                        0.96356, 0.96366, 0.96357, 0.96473, 0.96506, 0.96499, 0.96418,
                        0.96283, 0.96068, 0.95932, 0.95852, 0.95907, 0.95920, 0.95947,
                        0.96024, 0.96049, 0.96019, 0.96023, 0.95992, 0.95954, 0.96073, 0.82623],
                       [0.96344, 0.96369, 0.96331, 0.96379, 0.96367, 0.96415, 0.96371,
                        0.96343, 0.96334, 0.96337, 0.96452, 0.96465, 0.96439, 0.96364,
                        0.96162, 0.96038, 0.95863, 0.95850, 0.95937, 0.95978, 0.96013,
                        0.96087, 0.96064, 0.96004, 0.96052, 0.96001, 0.95952, 0.96031, 0.82576],
                       [0.96335, 0.96383, 0.96350, 0.96377, 0.96342, 0.96446, 0.96402,
                        0.96377, 0.96299, 0.96322, 0.96454, 0.96443, 0.96433, 0.96304,
                        0.96088, 0.95995, 0.95838, 0.95850, 0.95958, 0.96025, 0.96114,
                        0.96209, 0.96114, 0.96059, 0.96075, 0.95997, 0.95950, 0.95999, 0.82574],
                       [0.96384, 0.96446, 0.96396, 0.96419, 0.96393, 0.96481, 0.96412,
                        0.96422, 0.96355, 0.96407, 0.96488, 0.96498, 0.96467, 0.96279,
                        0.96101, 0.95956, 0.95902, 0.95924, 0.96029, 0.96147, 0.96272,
                        0.96328, 0.96238, 0.96210, 0.96081, 0.96037, 0.95988, 0.96000, 0.82615],
                       [0.96476, 0.96494, 0.96466, 0.96465, 0.96462, 0.96529, 0.96483,
                        0.96452, 0.96448, 0.96527, 0.96518, 0.96528, 0.96406, 0.96273,
                        0.96125, 0.95967, 0.95978, 0.96029, 0.96142, 0.96284, 0.96406,
                        0.96405, 0.96336, 0.96354, 0.96124, 0.96113, 0.96050, 0.96005, 0.82619],
                       [0.96532, 0.96485, 0.96534, 0.96456, 0.96514, 0.96528, 0.96520,
                        0.96468, 0.96500, 0.96559, 0.96535, 0.96513, 0.96340, 0.96272,
                        0.96134, 0.95990, 0.96019, 0.96126, 0.96248, 0.96362, 0.96463,
                        0.96488, 0.96366, 0.96397, 0.96201, 0.96139, 0.96060, 0.96013, 0.82593],
                       [0.96516, 0.96485, 0.96541, 0.96436, 0.96527, 0.96522, 0.96475,
                        0.96449, 0.96480, 0.96507, 0.96491, 0.96464, 0.96333, 0.96241,
                        0.96067, 0.95946, 0.96010, 0.96213, 0.96325, 0.96428, 0.96501,
                        0.96548, 0.96397, 0.96352, 0.96203, 0.96076, 0.96011, 0.96019, 0.82572],
                       [0.96502, 0.96504, 0.96524, 0.96466, 0.96504, 0.96549, 0.96454,
                        0.96428, 0.96415, 0.96439, 0.96445, 0.96384, 0.96326, 0.96138,
                        0.95997, 0.95904, 0.95966, 0.96276, 0.96392, 0.96513, 0.96558,
                        0.96545, 0.96463, 0.96308, 0.96168, 0.96031, 0.95967, 0.96007, 0.82554],
                       [0.96575, 0.96563, 0.96565, 0.96540, 0.96554, 0.96618, 0.96571,
                        0.96485, 0.96441, 0.96454, 0.96474, 0.96365, 0.96304, 0.96104,
                        0.96011, 0.95979, 0.96074, 0.96362, 0.96485, 0.96612, 0.96631,
                        0.96579, 0.96559, 0.96403, 0.96241, 0.96120, 0.96028, 0.96018, 0.82583],
                       [0.96654, 0.96653, 0.96656, 0.96591, 0.96649, 0.96678, 0.96687,
                        0.96605, 0.96548, 0.96518, 0.96495, 0.96421, 0.96265, 0.96155,
                        0.96044, 0.96103, 0.96290, 0.96457, 0.96606, 0.96695, 0.96720,
                        0.96660, 0.96635, 0.96542, 0.96375, 0.96243, 0.96108, 0.96039, 0.82654],
                       [0.96633, 0.96685, 0.96684, 0.96633, 0.96654, 0.96649, 0.96650,
                        0.96653, 0.96555, 0.96534, 0.96469, 0.96426, 0.96206, 0.96181,
                        0.96070, 0.96156, 0.96386, 0.96536, 0.96704, 0.96738, 0.96770,
                        0.96706, 0.96642, 0.96523, 0.96417, 0.96245, 0.96100, 0.96029, 0.82681],
                       [0.96605, 0.96646, 0.96666, 0.96683, 0.96610, 0.96613, 0.96629,
                        0.96612, 0.96525, 0.96561, 0.96456, 0.96378, 0.96211, 0.96200,
                        0.96122, 0.96196, 0.96445, 0.96642, 0.96792, 0.96828, 0.96802,
                        0.96763, 0.96680, 0.96498, 0.96414, 0.96230, 0.96130, 0.96020, 0.82660],
                       [0.96656, 0.96627, 0.96676, 0.96690, 0.96620, 0.96663, 0.96668,
                        0.96597, 0.96572, 0.96566, 0.96486, 0.96397, 0.96299, 0.96229,
                        0.96218, 0.96290, 0.96545, 0.96748, 0.96905, 0.96944, 0.96821,
                        0.96829, 0.96728, 0.96569, 0.96451, 0.96270, 0.96199, 0.96049, 0.82637],
                       [0.96742, 0.96693, 0.96703, 0.96681, 0.96684, 0.96749, 0.96671,
                        0.96641, 0.96602, 0.96506, 0.96500, 0.96456, 0.96375, 0.96246,
                        0.96295, 0.96392, 0.96629, 0.96810, 0.96957, 0.96947, 0.96813,
                        0.96823, 0.96722, 0.96629, 0.96499, 0.96312, 0.96238, 0.96109, 0.82681],
                       [0.96724, 0.96727, 0.96670, 0.96667, 0.96691, 0.96690, 0.96611,
                        0.96616, 0.96543, 0.96469, 0.96418, 0.96423, 0.96360, 0.96256,
                        0.96276, 0.96438, 0.96688, 0.96851, 0.96893, 0.96842, 0.96826,
                        0.96742, 0.96669, 0.96614, 0.96498, 0.96323, 0.96250, 0.96110, 0.82712],
                       [0.96592, 0.96644, 0.96596, 0.96646, 0.96613, 0.96563, 0.96554,
                        0.96533, 0.96496, 0.96483, 0.96345, 0.96350, 0.96312, 0.96287,
                        0.96258, 0.96474, 0.96758, 0.96885, 0.96813, 0.96777, 0.96836,
                        0.96672, 0.96569, 0.96533, 0.96409, 0.96288, 0.96220, 0.96064, 0.82688],
                       [0.96526, 0.96576, 0.96601, 0.96645, 0.96572, 0.96565, 0.96592,
                        0.96540, 0.96544, 0.96481, 0.96361, 0.96389, 0.96334, 0.96347,
                        0.96346, 0.96548, 0.96830, 0.96870, 0.96820, 0.96826, 0.96773,
                        0.96661, 0.96532, 0.96516, 0.96390, 0.96311, 0.96227, 0.96098, 0.82689],
                       [0.96581, 0.96605, 0.96652, 0.96643, 0.96628, 0.96629, 0.96654,
                        0.96588, 0.96592, 0.96462, 0.96394, 0.96469, 0.96411, 0.96443,
                        0.96483, 0.96659, 0.96851, 0.96854, 0.96859, 0.96866, 0.96688,
                        0.96667, 0.96597, 0.96584, 0.96501, 0.96430, 0.96321, 0.96189, 0.82743],
                       [0.96603, 0.96590, 0.96636, 0.96609, 0.96665, 0.96599, 0.96619,
                        0.96555, 0.96558, 0.96469, 0.96427, 0.96438, 0.96472, 0.96503,
                        0.96565, 0.96757, 0.96837, 0.96862, 0.96860, 0.96763, 0.96646,
                        0.96596, 0.96619, 0.96591, 0.96552, 0.96476, 0.96360, 0.96233, 0.82801],
                       [0.96532, 0.96513, 0.96586, 0.96519, 0.96567, 0.96488, 0.96490,
                        0.96490, 0.96496, 0.96433, 0.96436, 0.96373, 0.96484, 0.96496,
                        0.96567, 0.96754, 0.96828, 0.96807, 0.96801, 0.96568, 0.96567,
                        0.96460, 0.96521, 0.96481, 0.96477, 0.96386, 0.96291, 0.96222, 0.82785],
                       [0.96479, 0.96512, 0.96551, 0.96478, 0.96475, 0.96435, 0.96416,
                        0.96467, 0.96476, 0.96386, 0.96412, 0.96417, 0.96497, 0.96528,
                        0.96571, 0.96735, 0.96851, 0.96737, 0.96678, 0.96483, 0.96470,
                        0.96367, 0.96359, 0.96398, 0.96412, 0.96348, 0.96270, 0.96241, 0.82786],
                       [0.96438, 0.96493, 0.96490, 0.96511, 0.96463, 0.96468, 0.96440,
                        0.96475, 0.96481, 0.96418, 0.96386, 0.96493, 0.96537, 0.96619,
                        0.96637, 0.96774, 0.96832, 0.96696, 0.96526, 0.96476, 0.96364,
                        0.96280, 0.96197, 0.96364, 0.96390, 0.96385, 0.96337, 0.96320, 0.82866],
                       [0.96355, 0.96403, 0.96394, 0.96472, 0.96462, 0.96502, 0.96440,
                        0.96441, 0.96435, 0.96416, 0.96355, 0.96485, 0.96541, 0.96640,
                        0.96720, 0.96772, 0.96700, 0.96581, 0.96370, 0.96320, 0.96172,
                        0.96125, 0.96117, 0.96229, 0.96334, 0.96356, 0.96352, 0.96371, 0.82921],
                       [0.96325, 0.96344, 0.96344, 0.96409, 0.96466, 0.96449, 0.96387,
                        0.96376, 0.96400, 0.96402, 0.96359, 0.96447, 0.96523, 0.96581,
                        0.96754, 0.96731, 0.96584, 0.96464, 0.96248, 0.96133, 0.96005,
                        0.95972, 0.96068, 0.96090, 0.96275, 0.96325, 0.96343, 0.96371, 0.82971],
                       [0.96356, 0.96352, 0.96376, 0.96401, 0.96434, 0.96363, 0.96365,
                        0.96366, 0.96437, 0.96473, 0.96432, 0.96427, 0.96548, 0.96577,
                        0.96742, 0.96691, 0.96584, 0.96373, 0.96152, 0.96025, 0.95902,
                        0.95840, 0.95968, 0.96083, 0.96248, 0.96359, 0.96396, 0.96356, 0.83032],
                       [0.96336, 0.96329, 0.96339, 0.96341, 0.96336, 0.96307, 0.96335,
                        0.96370, 0.96407, 0.96438, 0.96458, 0.96419, 0.96562, 0.96634,
                        0.96661, 0.96632, 0.96534, 0.96194, 0.95963, 0.95824, 0.95734,
                        0.95695, 0.95849, 0.96021, 0.96170, 0.96339, 0.96404, 0.96358, 0.83047],
                       [0.96256, 0.96254, 0.96239, 0.96279, 0.96267, 0.96265, 0.96290,
                        0.96351, 0.96350, 0.96315, 0.96399, 0.96444, 0.96526, 0.96613,
                        0.96555, 0.96542, 0.96361, 0.95997, 0.95719, 0.95587, 0.95570,
                        0.95585, 0.95746, 0.95833, 0.96049, 0.96258, 0.96341, 0.96412, 0.83036],
                       [0.96194, 0.96210, 0.96218, 0.96283, 0.96252, 0.96237, 0.96278,
                        0.96331, 0.96341, 0.96342, 0.96360, 0.96439, 0.96456, 0.96515,
                        0.96493, 0.96430, 0.96197, 0.95839, 0.95558, 0.95423, 0.95462,
                        0.95446, 0.95625, 0.95671, 0.95944, 0.96179, 0.96310, 0.96459, 0.83028],
                       [0.96147, 0.96149, 0.96209, 0.96264, 0.96226, 0.96216, 0.96280,
                        0.96298, 0.96312, 0.96401, 0.96351, 0.96347, 0.96397, 0.96449,
                        0.96429, 0.96335, 0.96041, 0.95683, 0.95417, 0.95285, 0.95311,
                        0.95237, 0.95473, 0.95597, 0.95855, 0.96122, 0.96345, 0.96441, 0.83031],
                       [0.96096, 0.96072, 0.96136, 0.96215, 0.96160, 0.96205, 0.96249,
                        0.96257, 0.96295, 0.96368, 0.96334, 0.96285, 0.96377, 0.96423,
                        0.96399, 0.96221, 0.95843, 0.95516, 0.95241, 0.95159, 0.95112,
                        0.95096, 0.95323, 0.95572, 0.95766, 0.96093, 0.96337, 0.96410, 0.83053],
                       [0.96055, 0.96051, 0.96086, 0.96150, 0.96111, 0.96150, 0.96176,
                        0.96256, 0.96315, 0.96327, 0.96292, 0.96278, 0.96338, 0.96362,
                        0.96344, 0.96075, 0.95666, 0.95313, 0.95107, 0.94997, 0.94929,
                        0.95012, 0.95168, 0.95453, 0.95690, 0.96019, 0.96269, 0.96421, 0.83047],
                       [0.96002, 0.96051, 0.96067, 0.96095, 0.96097, 0.96038, 0.96122,
                        0.96243, 0.96313, 0.96306, 0.96210, 0.96226, 0.96221, 0.96292,
                        0.96154, 0.95900, 0.95529, 0.95100, 0.94953, 0.94803, 0.94778,
                        0.94902, 0.95007, 0.95254, 0.95609, 0.95904, 0.96241, 0.96418, 0.83008],
                       [0.95962, 0.95957, 0.95997, 0.96031, 0.96025, 0.95967, 0.96074,
                        0.96164, 0.96275, 0.96268, 0.96147, 0.96136, 0.96096, 0.96211,
                        0.95955, 0.95694, 0.95381, 0.94925, 0.94720, 0.94628, 0.94642,
                        0.94778, 0.94896, 0.95108, 0.95471, 0.95840, 0.96201, 0.96358, 0.82991],
                       [0.95889, 0.95826, 0.95936, 0.95985, 0.95955, 0.95975, 0.96032,
                        0.96129, 0.96219, 0.96232, 0.96184, 0.96071, 0.96016, 0.96067,
                        0.95854, 0.95568, 0.95223, 0.94805, 0.94560, 0.94488, 0.94546,
                        0.94655, 0.94843, 0.95055, 0.95343, 0.95780, 0.96136, 0.96336, 0.82988],
                       [0.95776, 0.95757, 0.95881, 0.95985, 0.95933, 0.95998, 0.95998,
                        0.96129, 0.96179, 0.96222, 0.96182, 0.95995, 0.95894, 0.95896,
                        0.95783, 0.95482, 0.95061, 0.94698, 0.94495, 0.94374, 0.94464,
                        0.94539, 0.94751, 0.94975, 0.95264, 0.95674, 0.96061, 0.96353, 0.82964],
                       [0.95741, 0.95709, 0.95797, 0.95933, 0.95853, 0.95902, 0.95902,
                        0.96061, 0.96127, 0.96193, 0.96023, 0.95854, 0.95727, 0.95742,
                        0.95652, 0.95283, 0.94875, 0.94570, 0.94363, 0.94276, 0.94350,
                        0.94424, 0.94605, 0.94800, 0.95140, 0.95541, 0.95927, 0.96268, 0.82914],
                       [0.95704, 0.95638, 0.95747, 0.95801, 0.95766, 0.95746, 0.95787,
                        0.95960, 0.96021, 0.96073, 0.95855, 0.95684, 0.95602, 0.95594,
                        0.95412, 0.95033, 0.94681, 0.94388, 0.94186, 0.94173, 0.94222,
                        0.94333, 0.94500, 0.94649, 0.94957, 0.95363, 0.95777, 0.96084, 0.82828],
                       [0.95557, 0.95569, 0.95691, 0.95653, 0.95714, 0.95642, 0.95712,
                        0.95863, 0.95955, 0.95912, 0.95745, 0.95501, 0.95468, 0.95429,
                        0.95151, 0.94862, 0.94550, 0.94188, 0.94081, 0.94089, 0.94120,
                        0.94264, 0.94416, 0.94540, 0.94823, 0.95199, 0.95670, 0.95929, 0.82728],
                       [0.95450, 0.95507, 0.95561, 0.95585, 0.95643, 0.95558, 0.95657,
                        0.95810, 0.95915, 0.95812, 0.95679, 0.95356, 0.95312, 0.95252,
                        0.95031, 0.94756, 0.94460, 0.94092, 0.94005, 0.94047, 0.94070,
                        0.94220, 0.94309, 0.94427, 0.94757, 0.95111, 0.95588, 0.95852, 0.82637],
                       [0.95440, 0.95452, 0.95444, 0.95596, 0.95560, 0.95528, 0.95606,
                        0.95771, 0.95823, 0.95750, 0.95605, 0.95273, 0.95146, 0.95109,
                        0.94990, 0.94649, 0.94290, 0.94101, 0.93947, 0.94034, 0.94087,
                        0.94182, 0.94238, 0.94334, 0.94654, 0.95002, 0.95482, 0.95780, 0.82538],
                       [0.95398, 0.95410, 0.95392, 0.95547, 0.95455, 0.95481, 0.95496,
                        0.95658, 0.95711, 0.95669, 0.95431, 0.95153, 0.94979, 0.94996,
                        0.94847, 0.94502, 0.94114, 0.94079, 0.93942, 0.94031, 0.94077,
                        0.94098, 0.94208, 0.94274, 0.94467, 0.94790, 0.95300, 0.95663, 0.82393],
                       [0.95311, 0.95348, 0.95379, 0.95459, 0.95384, 0.95368, 0.95386,
                        0.95552, 0.95660, 0.95623, 0.95281, 0.94996, 0.94899, 0.94886,
                        0.94660, 0.94378, 0.94081, 0.93988, 0.93995, 0.94034, 0.94035,
                        0.94044, 0.94162, 0.94240, 0.94311, 0.94634, 0.95136, 0.95497, 0.82227],
                       [0.95233, 0.95290, 0.95323, 0.95373, 0.95361, 0.95290, 0.95357,
                        0.95476, 0.95607, 0.95544, 0.95215, 0.94856, 0.94831, 0.94739,
                        0.94503, 0.94281, 0.94087, 0.93934, 0.94082, 0.94027, 0.94052,
                        0.94069, 0.94101, 0.94167, 0.94263, 0.94571, 0.95002, 0.95267, 0.82092],
                       [0.95193, 0.95234, 0.95229, 0.95284, 0.95292, 0.95232, 0.95324,
                        0.95390, 0.95487, 0.95383, 0.95162, 0.94759, 0.94699, 0.94594,
                        0.94375, 0.94177, 0.94061, 0.93960, 0.94093, 0.94028, 0.94124,
                        0.94095, 0.94058, 0.94085, 0.94236, 0.94451, 0.94815, 0.95077, 0.81982],
                       [0.95114, 0.95077, 0.95130, 0.95201, 0.95197, 0.95140, 0.95176,
                        0.95288, 0.95325, 0.95237, 0.95025, 0.94690, 0.94527, 0.94500,
                        0.94281, 0.94084, 0.94034, 0.93984, 0.94028, 0.94089, 0.94141,
                        0.94072, 0.94022, 0.94012, 0.94128, 0.94262, 0.94645, 0.94961, 0.81808],
                       [0.95020, 0.94953, 0.95037, 0.95138, 0.95104, 0.95036, 0.95031,
                        0.95202, 0.95192, 0.95138, 0.94854, 0.94591, 0.94383, 0.94405,
                        0.94217, 0.94026, 0.94021, 0.94057, 0.94056, 0.94182, 0.94155,
                        0.94080, 0.93997, 0.93955, 0.93967, 0.94141, 0.94544, 0.94844, 0.81617],
                       [0.95003, 0.94995, 0.95046, 0.95141, 0.95017, 0.94977, 0.94975,
                        0.95179, 0.95135, 0.95065, 0.94803, 0.94502, 0.94340, 0.94302,
                        0.94168, 0.93989, 0.94088, 0.94202, 0.94219, 0.94281, 0.94239,
                        0.94143, 0.94012, 0.93958, 0.93901, 0.94074, 0.94409, 0.94693, 0.81492],
                       [0.94971, 0.95014, 0.95067, 0.95120, 0.94983, 0.94949, 0.94956,
                        0.95125, 0.95107, 0.94983, 0.94787, 0.94487, 0.94301, 0.94226,
                        0.94114, 0.93988, 0.94151, 0.94282, 0.94380, 0.94320, 0.94315,
                        0.94198, 0.94068, 0.93970, 0.93887, 0.93974, 0.94214, 0.94456, 0.81382],
                       [0.94907, 0.94945, 0.94982, 0.95025, 0.94958, 0.94891, 0.94931,
                        0.94961, 0.95036, 0.94877, 0.94673, 0.94454, 0.94253, 0.94210,
                        0.94095, 0.94063, 0.94148, 0.94321, 0.94458, 0.94336, 0.94399,
                        0.94267, 0.94138, 0.93948, 0.93839, 0.93913, 0.94098, 0.94243, 0.81262],
                       [0.94843, 0.94870, 0.94856, 0.94911, 0.94873, 0.94821, 0.94868,
                        0.94789, 0.94923, 0.94778, 0.94542, 0.94370, 0.94246, 0.94196,
                        0.94098, 0.94110, 0.94187, 0.94401, 0.94518, 0.94474, 0.94499,
                        0.94326, 0.94166, 0.93943, 0.93793, 0.93875, 0.94005, 0.94151, 0.81114],
                       [0.94782, 0.94841, 0.94826, 0.94824, 0.94794, 0.94756, 0.94812,
                        0.94716, 0.94801, 0.94695, 0.94482, 0.94318, 0.94241, 0.94161,
                        0.94113, 0.94149, 0.94307, 0.94554, 0.94638, 0.94652, 0.94578,
                        0.94373, 0.94198, 0.94003, 0.93793, 0.93802, 0.93857, 0.94065, 0.80938],
                       [0.94793, 0.94844, 0.94837, 0.94796, 0.94797, 0.94728, 0.94764,
                        0.94732, 0.94715, 0.94648, 0.94464, 0.94283, 0.94251, 0.94179,
                        0.94167, 0.94243, 0.94469, 0.94741, 0.94803, 0.94764, 0.94653,
                        0.94484, 0.94294, 0.94046, 0.93843, 0.93721, 0.93763, 0.93899, 0.80819],
                       [0.94829, 0.94843, 0.94803, 0.94848, 0.94831, 0.94758, 0.94699,
                        0.94767, 0.94682, 0.94624, 0.94465, 0.94313, 0.94301, 0.94280,
                        0.94243, 0.94363, 0.94632, 0.94886, 0.94976, 0.94855, 0.94774,
                        0.94655, 0.94406, 0.94092, 0.93900, 0.93696, 0.93747, 0.93761, 0.80771],
                       [0.94855, 0.94858, 0.94796, 0.94863, 0.94813, 0.94756, 0.94669,
                        0.94704, 0.94661, 0.94545, 0.94481, 0.94407, 0.94346, 0.94366,
                        0.94325, 0.94489, 0.94757, 0.94950, 0.95094, 0.94996, 0.94920,
                        0.94791, 0.94490, 0.94174, 0.93959, 0.93715, 0.93686, 0.93703, 0.80708],
                       [0.94887, 0.94870, 0.94821, 0.94778, 0.94752, 0.94734, 0.94674,
                        0.94593, 0.94607, 0.94467, 0.94483, 0.94477, 0.94396, 0.94383,
                        0.94407, 0.94606, 0.94871, 0.95023, 0.95141, 0.95170, 0.95008,
                        0.94871, 0.94549, 0.94275, 0.94019, 0.93734, 0.93562, 0.93631, 0.80623],
                       [0.94882, 0.94862, 0.94823, 0.94735, 0.94729, 0.94766, 0.94662,
                        0.94569, 0.94536, 0.94473, 0.94467, 0.94526, 0.94495, 0.94410,
                        0.94485, 0.94705, 0.95010, 0.95211, 0.95229, 0.95289, 0.95069,
                        0.94928, 0.94630, 0.94436, 0.94046, 0.93772, 0.93532, 0.93556, 0.80568],
                       [0.94825, 0.94874, 0.94853, 0.94750, 0.94795, 0.94769, 0.94683,
                        0.94657, 0.94507, 0.94503, 0.94487, 0.94607, 0.94600, 0.94537,
                        0.94602, 0.94833, 0.95162, 0.95418, 0.95392, 0.95381, 0.95190,
                        0.94995, 0.94755, 0.94558, 0.94130, 0.93838, 0.93613, 0.93531, 0.80600],
                       [0.94828, 0.94895, 0.94912, 0.94790, 0.94897, 0.94779, 0.94732,
                        0.94730, 0.94553, 0.94532, 0.94573, 0.94730, 0.94707, 0.94717,
                        0.94770, 0.95022, 0.95325, 0.95570, 0.95546, 0.95494, 0.95323,
                        0.95139, 0.94888, 0.94627, 0.94327, 0.93935, 0.93672, 0.93553, 0.80651],
                       [0.94945, 0.94929, 0.94945, 0.94862, 0.94936, 0.94871, 0.94751,
                        0.94686, 0.94640, 0.94594, 0.94683, 0.94860, 0.94870, 0.94868,
                        0.94926, 0.95211, 0.95497, 0.95671, 0.95689, 0.95605, 0.95407,
                        0.95317, 0.95016, 0.94743, 0.94518, 0.94039, 0.93691, 0.93591, 0.80635],
                       [0.94999, 0.94995, 0.94968, 0.94942, 0.94913, 0.94956, 0.94808,
                        0.94655, 0.94655, 0.94630, 0.94795, 0.95005, 0.95028, 0.94963,
                        0.95059, 0.95367, 0.95635, 0.95744, 0.95802, 0.95677, 0.95507,
                        0.95403, 0.95149, 0.94890, 0.94588, 0.94128, 0.93730, 0.93605, 0.80631],
                       [0.95044, 0.95115, 0.95046, 0.95050, 0.94949, 0.95066, 0.94919,
                        0.94800, 0.94670, 0.94691, 0.94923, 0.95161, 0.95182, 0.95117,
                        0.95243, 0.95531, 0.95770, 0.95886, 0.95922, 0.95781, 0.95675,
                        0.95474, 0.95335, 0.95049, 0.94665, 0.94286, 0.93898, 0.93664, 0.80689],
                       [0.95198, 0.95244, 0.95199, 0.95115, 0.95072, 0.95194, 0.95048,
                        0.94963, 0.94803, 0.94786, 0.95023, 0.95277, 0.95357, 0.95348,
                        0.95472, 0.95668, 0.95938, 0.96045, 0.96085, 0.95912, 0.95829,
                        0.95610, 0.95536, 0.95213, 0.94846, 0.94471, 0.94121, 0.93805, 0.80794],
                       [0.95328, 0.95303, 0.95286, 0.95124, 0.95177, 0.95216, 0.95121,
                        0.94977, 0.94862, 0.94822, 0.95091, 0.95343, 0.95491, 0.95466,
                        0.95612, 0.95753, 0.96044, 0.96112, 0.96132, 0.95973, 0.95861,
                        0.95723, 0.95630, 0.95372, 0.95003, 0.94568, 0.94184, 0.93889, 0.80894],
                       [0.95413, 0.95345, 0.95266, 0.95190, 0.95238, 0.95205, 0.95145,
                        0.95002, 0.94844, 0.94905, 0.95200, 0.95481, 0.95605, 0.95517,
                        0.95678, 0.95906, 0.96095, 0.96144, 0.96068, 0.96002, 0.95859,
                        0.95811, 0.95675, 0.95485, 0.95159, 0.94666, 0.94198, 0.93935, 0.80987],
                       [0.95491, 0.95482, 0.95359, 0.95329, 0.95352, 0.95347, 0.95245,
                        0.95147, 0.95000, 0.95099, 0.95371, 0.95700, 0.95776, 0.95709,
                        0.95835, 0.96134, 0.96218, 0.96238, 0.96116, 0.96077, 0.95976,
                        0.95946, 0.95819, 0.95591, 0.95384, 0.94880, 0.94388, 0.94112, 0.81143],
                       [0.95576, 0.95603, 0.95569, 0.95433, 0.95486, 0.95532, 0.95383,
                        0.95248, 0.95149, 0.95221, 0.95498, 0.95839, 0.95941, 0.95964,
                        0.96004, 0.96209, 0.96345, 0.96315, 0.96228, 0.96124, 0.96102,
                        0.96033, 0.95911, 0.95720, 0.95527, 0.95124, 0.94616, 0.94329, 0.81319],
                       [0.95681, 0.95651, 0.95669, 0.95487, 0.95569, 0.95600, 0.95517,
                        0.95275, 0.95162, 0.95248, 0.95580, 0.95929, 0.96030, 0.96091,
                        0.96078, 0.96187, 0.96336, 0.96311, 0.96242, 0.96152, 0.96113,
                        0.96018, 0.95931, 0.95809, 0.95565, 0.95253, 0.94740, 0.94459, 0.81422],
                       [0.95787, 0.95739, 0.95727, 0.95581, 0.95642, 0.95675, 0.95646,
                        0.95377, 0.95280, 0.95358, 0.95774, 0.96091, 0.96115, 0.96141,
                        0.96193, 0.96293, 0.96294, 0.96330, 0.96237, 0.96231, 0.96126,
                        0.96066, 0.96049, 0.95941, 0.95695, 0.95330, 0.94899, 0.94583, 0.81515],
                       [0.95937, 0.95901, 0.95889, 0.95752, 0.95786, 0.95858, 0.95774,
                        0.95577, 0.95483, 0.95595, 0.96005, 0.96296, 0.96301, 0.96248,
                        0.96361, 0.96443, 0.96378, 0.96395, 0.96257, 0.96293, 0.96208,
                        0.96203, 0.96171, 0.96115, 0.95878, 0.95488, 0.95107, 0.94747, 0.81699],
                       [0.96099, 0.96091, 0.96057, 0.95900, 0.95947, 0.96062, 0.95946,
                        0.95760, 0.95625, 0.95783, 0.96095, 0.96417, 0.96486, 0.96406,
                        0.96431, 0.96520, 0.96465, 0.96407, 0.96257, 0.96277, 0.96272,
                        0.96276, 0.96206, 0.96203, 0.95981, 0.95678, 0.95264, 0.94933, 0.81902],
                       [0.96216, 0.96219, 0.96132, 0.95994, 0.96050, 0.96159, 0.96107,
                        0.95900, 0.95745, 0.95878, 0.96156, 0.96455, 0.96539, 0.96510,
                        0.96450, 0.96525, 0.96478, 0.96402, 0.96294, 0.96246, 0.96271,
                        0.96276, 0.96280, 0.96201, 0.96062, 0.95836, 0.95445, 0.95162, 0.82073],
                       [0.96270, 0.96245, 0.96135, 0.96129, 0.96142, 0.96159, 0.96181,
                        0.95992, 0.95855, 0.95958, 0.96255, 0.96489, 0.96535, 0.96523,
                        0.96514, 0.96468, 0.96407, 0.96378, 0.96305, 0.96233, 0.96205,
                        0.96271, 0.96335, 0.96156, 0.96157, 0.95970, 0.95606, 0.95350, 0.82189],
                       [0.96312, 0.96267, 0.96235, 0.96267, 0.96246, 0.96261, 0.96290,
                        0.96075, 0.96002, 0.96083, 0.96357, 0.96564, 0.96622, 0.96548,
                        0.96549, 0.96450, 0.96350, 0.96313, 0.96254, 0.96258, 0.96179,
                        0.96284, 0.96309, 0.96178, 0.96256, 0.96078, 0.95703, 0.95518, 0.82295],
                       [0.96420, 0.96363, 0.96449, 0.96326, 0.96313, 0.96445, 0.96379,
                        0.96226, 0.96173, 0.96234, 0.96453, 0.96655, 0.96722, 0.96587,
                        0.96522, 0.96451, 0.96365, 0.96270, 0.96222, 0.96247, 0.96223,
                        0.96280, 0.96270, 0.96296, 0.96296, 0.96082, 0.95809, 0.95666, 0.82440],
                       [0.96560, 0.96504, 0.96554, 0.96357, 0.96367, 0.96555, 0.96409,
                        0.96334, 0.96274, 0.96318, 0.96526, 0.96721, 0.96721, 0.96604,
                        0.96495, 0.96456, 0.96338, 0.96259, 0.96187, 0.96162, 0.96211,
                        0.96215, 0.96201, 0.96336, 0.96269, 0.96067, 0.95938, 0.95697, 0.82555],
                       [0.96689, 0.96614, 0.96556, 0.96431, 0.96498, 0.96626, 0.96519,
                        0.96377, 0.96343, 0.96385, 0.96599, 0.96786, 0.96690, 0.96613,
                        0.96546, 0.96493, 0.96313, 0.96213, 0.96125, 0.96116, 0.96144,
                        0.96132, 0.96165, 0.96265, 0.96277, 0.96181, 0.96047, 0.95746, 0.82643],
                       [0.96719, 0.96688, 0.96628, 0.96582, 0.96681, 0.96663, 0.96667,
                        0.96505, 0.96398, 0.96516, 0.96666, 0.96778, 0.96687, 0.96652,
                        0.96604, 0.96457, 0.96322, 0.96132, 0.96063, 0.96099, 0.96088,
                        0.96072, 0.96174, 0.96224, 0.96288, 0.96272, 0.96110, 0.95940, 0.82739],
                       [0.96682, 0.96744, 0.96750, 0.96717, 0.96768, 0.96664, 0.96745,
                        0.96640, 0.96433, 0.96637, 0.96692, 0.96649, 0.96680, 0.96672,
                        0.96534, 0.96361, 0.96259, 0.96088, 0.96024, 0.96011, 0.95991,
                        0.96017, 0.96126, 0.96193, 0.96253, 0.96244, 0.96160, 0.96147, 0.82801],
                       [0.96729, 0.96770, 0.96816, 0.96773, 0.96718, 0.96701, 0.96771,
                        0.96682, 0.96571, 0.96708, 0.96726, 0.96597, 0.96638, 0.96571,
                        0.96431, 0.96318, 0.96189, 0.96075, 0.96006, 0.95927, 0.95912,
                        0.96006, 0.96051, 0.96144, 0.96258, 0.96270, 0.96238, 0.96222, 0.82891],
                       [0.96827, 0.96806, 0.96845, 0.96785, 0.96715, 0.96779, 0.96780,
                        0.96728, 0.96766, 0.96742, 0.96756, 0.96649, 0.96575, 0.96487,
                        0.96409, 0.96305, 0.96163, 0.96044, 0.95947, 0.95920, 0.95930,
                        0.95981, 0.95998, 0.96105, 0.96261, 0.96337, 0.96300, 0.96259, 0.83005],
                       [0.96868, 0.96849, 0.96853, 0.96781, 0.96802, 0.96836, 0.96797,
                        0.96769, 0.96830, 0.96734, 0.96715, 0.96644, 0.96513, 0.96494,
                        0.96393, 0.96260, 0.96066, 0.95961, 0.95841, 0.95879, 0.95870,
                        0.95843, 0.95907, 0.96055, 0.96161, 0.96290, 0.96300, 0.96338, 0.83044],
                       [0.96837, 0.96834, 0.96851, 0.96762, 0.96831, 0.96833, 0.96808,
                        0.96734, 0.96764, 0.96717, 0.96639, 0.96543, 0.96467, 0.96423,
                        0.96296, 0.96162, 0.95950, 0.95841, 0.95707, 0.95740, 0.95693,
                        0.95674, 0.95773, 0.95962, 0.96032, 0.96182, 0.96287, 0.96371, 0.83050],
                       [0.96787, 0.96796, 0.96849, 0.96780, 0.96797, 0.96792, 0.96761,
                        0.96702, 0.96699, 0.96772, 0.96591, 0.96472, 0.96421, 0.96299,
                        0.96177, 0.96041, 0.95898, 0.95760, 0.95603, 0.95593, 0.95556,
                        0.95579, 0.95687, 0.95842, 0.95977, 0.96123, 0.96287, 0.96345, 0.83079],
                       [0.96758, 0.96751, 0.96813, 0.96798, 0.96746, 0.96747, 0.96679,
                        0.96730, 0.96729, 0.96763, 0.96552, 0.96415, 0.96307, 0.96213,
                        0.96070, 0.95930, 0.95823, 0.95680, 0.95580, 0.95489, 0.95450,
                        0.95539, 0.95651, 0.95742, 0.95916, 0.96091, 0.96263, 0.96299, 0.83100],
                       [0.96758, 0.96678, 0.96822, 0.96742, 0.96711, 0.96757, 0.96661,
                        0.96761, 0.96778, 0.96667, 0.96509, 0.96307, 0.96191, 0.96166,
                        0.96000, 0.95889, 0.95768, 0.95591, 0.95553, 0.95457, 0.95420,
                        0.95498, 0.95613, 0.95678, 0.95858, 0.96054, 0.96201, 0.96291, 0.83128],
                       [0.96709, 0.96642, 0.96783, 0.96676, 0.96670, 0.96721, 0.96653,
                        0.96691, 0.96714, 0.96558, 0.96447, 0.96174, 0.96103, 0.96068,
                        0.95953, 0.95848, 0.95711, 0.95523, 0.95428, 0.95392, 0.95399,
                        0.95404, 0.95491, 0.95583, 0.95729, 0.95971, 0.96106, 0.96317, 0.83133],
                       [0.96609, 0.96671, 0.96654, 0.96655, 0.96625, 0.96607, 0.96619,
                        0.96589, 0.96603, 0.96490, 0.96384, 0.96050, 0.96038, 0.95957,
                        0.95932, 0.95754, 0.95598, 0.95464, 0.95312, 0.95289, 0.95277,
                        0.95299, 0.95349, 0.95481, 0.95584, 0.95899, 0.96042, 0.96302, 0.83073],
                       [0.96562, 0.96661, 0.96602, 0.96633, 0.96619, 0.96548, 0.96577,
                        0.96582, 0.96600, 0.96535, 0.96325, 0.96004, 0.96013, 0.95929,
                        0.95912, 0.95675, 0.95536, 0.95407, 0.95300, 0.95245, 0.95202,
                        0.95297, 0.95301, 0.95456, 0.95625, 0.95889, 0.96041, 0.96227, 0.83016],
                       [0.96497, 0.96518, 0.96579, 0.96551, 0.96562, 0.96454, 0.96453,
                        0.96519, 0.96623, 0.96504, 0.96221, 0.95954, 0.95898, 0.95863,
                        0.95780, 0.95592, 0.95473, 0.95312, 0.95248, 0.95156, 0.95199,
                        0.95264, 0.95266, 0.95423, 0.95649, 0.95814, 0.96023, 0.96125, 0.82979],
                       [0.96401, 0.96388, 0.96471, 0.96484, 0.96445, 0.96331, 0.96335,
                        0.96394, 0.96506, 0.96324, 0.96099, 0.95847, 0.95750, 0.95747,
                        0.95631, 0.95507, 0.95372, 0.95261, 0.95150, 0.95068, 0.95155,
                        0.95148, 0.95206, 0.95313, 0.95491, 0.95700, 0.95938, 0.96069, 0.82926],
                       [0.96370, 0.96373, 0.96394, 0.96472, 0.96387, 0.96314, 0.96350,
                        0.96367, 0.96351, 0.96221, 0.96031, 0.95784, 0.95688, 0.95696,
                        0.95616, 0.95476, 0.95359, 0.95247, 0.95120, 0.95080, 0.95070,
                        0.95137, 0.95178, 0.95237, 0.95356, 0.95630, 0.95826, 0.96059, 0.82867],
                       [0.96350, 0.96347, 0.96387, 0.96433, 0.96379, 0.96315, 0.96371,
                        0.96353, 0.96322, 0.96242, 0.96001, 0.95767, 0.95656, 0.95680,
                        0.95649, 0.95497, 0.95365, 0.95203, 0.95140, 0.95108, 0.95031,
                        0.95189, 0.95197, 0.95289, 0.95341, 0.95604, 0.95755, 0.96012, 0.82837],
                       [0.96278, 0.96284, 0.96342, 0.96362, 0.96329, 0.96260, 0.96297,
                        0.96270, 0.96318, 0.96223, 0.95987, 0.95730, 0.95632, 0.95645,
                        0.95599, 0.95474, 0.95300, 0.95185, 0.95136, 0.95090, 0.95071,
                        0.95196, 0.95209, 0.95343, 0.95357, 0.95577, 0.95726, 0.95957, 0.82800],
                       [0.96169, 0.96222, 0.96278, 0.96295, 0.96256, 0.96159, 0.96192,
                        0.96201, 0.96220, 0.96119, 0.95946, 0.95670, 0.95605, 0.95605,
                        0.95478, 0.95385, 0.95250, 0.95155, 0.95080, 0.95069, 0.95118,
                        0.95171, 0.95196, 0.95265, 0.95380, 0.95495, 0.95695, 0.95883, 0.82729],
                       [0.96083, 0.96129, 0.96215, 0.96235, 0.96164, 0.96074, 0.96080,
                        0.96145, 0.96073, 0.95991, 0.95807, 0.95596, 0.95555, 0.95524,
                        0.95383, 0.95306, 0.95207, 0.95061, 0.95003, 0.95040, 0.95117,
                        0.95144, 0.95159, 0.95145, 0.95319, 0.95381, 0.95611, 0.95744, 0.82650],
                       [0.96064, 0.96059, 0.96173, 0.96173, 0.96095, 0.96042, 0.95983,
                        0.96061, 0.95993, 0.95917, 0.95685, 0.95530, 0.95519, 0.95399,
                        0.95381, 0.95251, 0.95149, 0.95031, 0.94987, 0.95004, 0.95115,
                        0.95138, 0.95143, 0.95126, 0.95171, 0.95292, 0.95501, 0.95650, 0.82584],
                       [0.96087, 0.96090, 0.96137, 0.96118, 0.96107, 0.96008, 0.95966,
                        0.95997, 0.96012, 0.95923, 0.95683, 0.95518, 0.95511, 0.95335,
                        0.95397, 0.95253, 0.95129, 0.95113, 0.95074, 0.95058, 0.95154,
                        0.95182, 0.95196, 0.95184, 0.95136, 0.95229, 0.95418, 0.95630, 0.82521],
                       [0.96069, 0.96102, 0.96097, 0.96078, 0.96075, 0.95978, 0.95981,
                        0.95968, 0.95969, 0.95894, 0.95700, 0.95507, 0.95472, 0.95337,
                        0.95343, 0.95268, 0.95140, 0.95183, 0.95145, 0.95164, 0.95211,
                        0.95225, 0.95200, 0.95204, 0.95199, 0.95174, 0.95370, 0.95586, 0.82420],
                       [0.96033, 0.96033, 0.96095, 0.96037, 0.96019, 0.95957, 0.95933,
                        0.95956, 0.95881, 0.95845, 0.95662, 0.95500, 0.95432, 0.95385,
                        0.95309, 0.95237, 0.95158, 0.95184, 0.95155, 0.95245, 0.95251,
                        0.95226, 0.95161, 0.95167, 0.95195, 0.95169, 0.95354, 0.95502, 0.82336],
                       [0.96019, 0.95966, 0.96037, 0.96002, 0.95992, 0.95892, 0.95820,
                        0.95896, 0.95843, 0.95773, 0.95589, 0.95494, 0.95398, 0.95410,
                        0.95264, 0.95178, 0.95158, 0.95124, 0.95184, 0.95251, 0.95247,
                        0.95197, 0.95181, 0.95144, 0.95100, 0.95137, 0.95262, 0.95351, 0.82250],
                       [0.96019, 0.96000, 0.95952, 0.96002, 0.95963, 0.95848, 0.95796,
                        0.95827, 0.95818, 0.95703, 0.95559, 0.95463, 0.95360, 0.95386,
                        0.95228, 0.95163, 0.95162, 0.95142, 0.95249, 0.95254, 0.95253,
                        0.95231, 0.95206, 0.95146, 0.95050, 0.95073, 0.95144, 0.95233, 0.82155],
                       [0.96051, 0.96089, 0.95984, 0.96055, 0.95992, 0.95896, 0.95915,
                        0.95842, 0.95811, 0.95748, 0.95588, 0.95499, 0.95403, 0.95374,
                        0.95278, 0.95244, 0.95212, 0.95276, 0.95361, 0.95363, 0.95391,
                        0.95369, 0.95259, 0.95182, 0.95093, 0.95083, 0.95132, 0.95209, 0.82135],
                       [0.96102, 0.96076, 0.96091, 0.96132, 0.96045, 0.95956, 0.95973,
                        0.95882, 0.95819, 0.95794, 0.95660, 0.95586, 0.95491, 0.95382,
                        0.95301, 0.95314, 0.95306, 0.95419, 0.95496, 0.95488, 0.95546,
                        0.95473, 0.95355, 0.95221, 0.95112, 0.95078, 0.95120, 0.95165, 0.82128],
                       [0.96045, 0.95970, 0.96096, 0.96081, 0.95988, 0.95950, 0.95873,
                        0.95821, 0.95766, 0.95712, 0.95644, 0.95564, 0.95460, 0.95381,
                        0.95285, 0.95275, 0.95313, 0.95471, 0.95513, 0.95503, 0.95519,
                        0.95451, 0.95327, 0.95115, 0.95008, 0.94966, 0.94996, 0.95029, 0.82031],
                       [0.95989, 0.96007, 0.96012, 0.95985, 0.95944, 0.95978, 0.95845,
                        0.95761, 0.95734, 0.95655, 0.95607, 0.95531, 0.95447, 0.95391,
                        0.95334, 0.95278, 0.95305, 0.95467, 0.95494, 0.95549, 0.95508,
                        0.95412, 0.95284, 0.95051, 0.94938, 0.94927, 0.94913, 0.94939, 0.81951],
                       [0.96086, 0.96129, 0.96036, 0.96042, 0.96028, 0.96028, 0.95935,
                        0.95838, 0.95757, 0.95698, 0.95663, 0.95581, 0.95509, 0.95415,
                        0.95386, 0.95363, 0.95408, 0.95527, 0.95605, 0.95694, 0.95602,
                        0.95485, 0.95360, 0.95146, 0.95003, 0.94948, 0.94906, 0.94977, 0.81920],
                       [0.96184, 0.96138, 0.96151, 0.96136, 0.96126, 0.96024, 0.95973,
                        0.95934, 0.95776, 0.95755, 0.95727, 0.95620, 0.95544, 0.95406,
                        0.95374, 0.95416, 0.95522, 0.95656, 0.95787, 0.95798, 0.95670,
                        0.95602, 0.95396, 0.95204, 0.95033, 0.94897, 0.94843, 0.94983, 0.81865],
                       [0.96174, 0.96098, 0.96128, 0.96133, 0.96113, 0.96025, 0.95932,
                        0.95926, 0.95780, 0.95774, 0.95725, 0.95600, 0.95570, 0.95373,
                        0.95348, 0.95451, 0.95562, 0.95744, 0.95883, 0.95800, 0.95707,
                        0.95601, 0.95338, 0.95195, 0.94980, 0.94856, 0.94806, 0.94906, 0.81797],
                       [0.96120, 0.96106, 0.96058, 0.96100, 0.96028, 0.96057, 0.95948,
                        0.95860, 0.95788, 0.95744, 0.95685, 0.95589, 0.95565, 0.95408,
                        0.95402, 0.95492, 0.95593, 0.95786, 0.95884, 0.95787, 0.95691,
                        0.95521, 0.95320, 0.95202, 0.94965, 0.94857, 0.94821, 0.94791, 0.81751],
                       [0.96121, 0.96189, 0.96146, 0.96107, 0.96042, 0.96090, 0.96042,
                        0.95869, 0.95802, 0.95730, 0.95731, 0.95655, 0.95562, 0.95513,
                        0.95512, 0.95538, 0.95720, 0.95866, 0.95950, 0.95874, 0.95689,
                        0.95530, 0.95388, 0.95214, 0.94987, 0.94871, 0.94816, 0.94753, 0.81753],
                       [0.96211, 0.96261, 0.96230, 0.96124, 0.96125, 0.96085, 0.96063,
                        0.95927, 0.95790, 0.95742, 0.95785, 0.95754, 0.95615, 0.95567,
                        0.95601, 0.95636, 0.95883, 0.95951, 0.96044, 0.96027, 0.95747,
                        0.95573, 0.95418, 0.95211, 0.94990, 0.94890, 0.94806, 0.94768, 0.81740],
                       [0.96275, 0.96229, 0.96195, 0.96143, 0.96139, 0.96051, 0.96007,
                        0.95946, 0.95808, 0.95785, 0.95724, 0.95726, 0.95672, 0.95585,
                        0.95650, 0.95757, 0.95962, 0.96029, 0.96085, 0.96064, 0.95791,
                        0.95563, 0.95399, 0.95229, 0.95000, 0.94867, 0.94794, 0.94722, 0.81703],
                       [0.96247, 0.96166, 0.96162, 0.96139, 0.96095, 0.96063, 0.96002,
                        0.95922, 0.95831, 0.95882, 0.95661, 0.95663, 0.95683, 0.95590,
                        0.95657, 0.95818, 0.95974, 0.96121, 0.96095, 0.96002, 0.95819,
                        0.95576, 0.95411, 0.95262, 0.95065, 0.94831, 0.94773, 0.94683, 0.81667],
                       [0.96204, 0.96189, 0.96180, 0.96129, 0.96110, 0.96153, 0.96043,
                        0.95917, 0.95839, 0.95915, 0.95727, 0.95756, 0.95700, 0.95637,
                        0.95677, 0.95863, 0.96013, 0.96195, 0.96134, 0.95993, 0.95858,
                        0.95644, 0.95473, 0.95311, 0.95159, 0.94903, 0.94769, 0.94698, 0.81668],
                       [0.96205, 0.96271, 0.96244, 0.96197, 0.96186, 0.96209, 0.96080,
                        0.95971, 0.95899, 0.95841, 0.95824, 0.95843, 0.95750, 0.95765,
                        0.95771, 0.95968, 0.96108, 0.96278, 0.96201, 0.96005, 0.95876,
                        0.95686, 0.95513, 0.95354, 0.95237, 0.95019, 0.94807, 0.94739, 0.81764],
                       [0.96247, 0.96303, 0.96283, 0.96256, 0.96218, 0.96198, 0.96117,
                        0.96048, 0.95937, 0.95827, 0.95841, 0.95880, 0.95842, 0.95885,
                        0.95927, 0.96091, 0.96246, 0.96341, 0.96237, 0.96007, 0.95854,
                        0.95692, 0.95523, 0.95372, 0.95302, 0.95102, 0.94877, 0.94810, 0.81860],
                       [0.96252, 0.96271, 0.96226, 0.96227, 0.96190, 0.96161, 0.96135,
                        0.96074, 0.95931, 0.95869, 0.95845, 0.95950, 0.95939, 0.95977,
                        0.96043, 0.96144, 0.96379, 0.96293, 0.96233, 0.96022, 0.95795,
                        0.95697, 0.95574, 0.95421, 0.95343, 0.95136, 0.94930, 0.94879, 0.81895],
                       [0.96249, 0.96259, 0.96215, 0.96237, 0.96179, 0.96156, 0.96128,
                        0.96040, 0.95956, 0.95900, 0.95908, 0.95979, 0.95986, 0.96036,
                        0.96094, 0.96181, 0.96418, 0.96297, 0.96217, 0.95998, 0.95794,
                        0.95744, 0.95644, 0.95495, 0.95376, 0.95154, 0.94983, 0.94917, 0.81937],
                       [0.96277, 0.96229, 0.96242, 0.96252, 0.96202, 0.96186, 0.96090,
                        0.96003, 0.96010, 0.95930, 0.95976, 0.96004, 0.96005, 0.96016,
                        0.96094, 0.96261, 0.96332, 0.96355, 0.96230, 0.95963, 0.95846,
                        0.95802, 0.95637, 0.95518, 0.95418, 0.95215, 0.95032, 0.94929, 0.81986],
                       [0.96263, 0.96178, 0.96245, 0.96208, 0.96199, 0.96181, 0.96069,
                        0.96022, 0.95989, 0.95916, 0.95968, 0.96086, 0.96034, 0.96036,
                        0.96142, 0.96337, 0.96332, 0.96367, 0.96187, 0.95983, 0.95847,
                        0.95836, 0.95636, 0.95540, 0.95494, 0.95331, 0.95064, 0.95002, 0.82031],
                       [0.96255, 0.96235, 0.96287, 0.96231, 0.96208, 0.96202, 0.96139,
                        0.96067, 0.95924, 0.95931, 0.96000, 0.96183, 0.96136, 0.96176,
                        0.96294, 0.96400, 0.96487, 0.96388, 0.96124, 0.96030, 0.95854,
                        0.95882, 0.95772, 0.95681, 0.95637, 0.95468, 0.95191, 0.95162, 0.82120],
                       [0.96310, 0.96321, 0.96299, 0.96309, 0.96293, 0.96256, 0.96195,
                        0.96117, 0.95962, 0.96000, 0.96099, 0.96196, 0.96289, 0.96326,
                        0.96402, 0.96448, 0.96562, 0.96357, 0.96096, 0.96026, 0.95905,
                        0.95899, 0.95906, 0.95864, 0.95752, 0.95552, 0.95335, 0.95257, 0.82255],
                       [0.96330, 0.96361, 0.96284, 0.96326, 0.96339, 0.96265, 0.96238,
                        0.96147, 0.96094, 0.96042, 0.96134, 0.96224, 0.96387, 0.96424,
                        0.96430, 0.96524, 0.96545, 0.96295, 0.96103, 0.95996, 0.95954,
                        0.95892, 0.95922, 0.95960, 0.95809, 0.95602, 0.95427, 0.95265, 0.82369],
                       [0.96297, 0.96390, 0.96348, 0.96323, 0.96313, 0.96256, 0.96286,
                        0.96166, 0.96166, 0.96084, 0.96189, 0.96331, 0.96435, 0.96451,
                        0.96491, 0.96640, 0.96537, 0.96305, 0.96150, 0.96001, 0.95980,
                        0.95933, 0.95935, 0.96012, 0.95930, 0.95685, 0.95561, 0.95345, 0.82402],
                       [0.96330, 0.96379, 0.96423, 0.96332, 0.96282, 0.96288, 0.96259,
                        0.96189, 0.96130, 0.96155, 0.96295, 0.96423, 0.96508, 0.96479,
                        0.96576, 0.96636, 0.96510, 0.96309, 0.96152, 0.96029, 0.95986,
                        0.96009, 0.96019, 0.96098, 0.96073, 0.95784, 0.95671, 0.95491, 0.82422],
                       [0.96398, 0.96339, 0.96375, 0.96316, 0.96260, 0.96318, 0.96221,
                        0.96175, 0.96121, 0.96151, 0.96353, 0.96466, 0.96586, 0.96552,
                        0.96542, 0.96535, 0.96416, 0.96237, 0.96065, 0.96012, 0.96004,
                        0.96048, 0.96092, 0.96130, 0.96140, 0.95882, 0.95685, 0.95606, 0.82493],
                       [0.96469, 0.96393, 0.96353, 0.96388, 0.96348, 0.96388, 0.96285,
                        0.96219, 0.96242, 0.96171, 0.96429, 0.96562, 0.96692, 0.96674,
                        0.96558, 0.96550, 0.96370, 0.96247, 0.96069, 0.96049, 0.96107,
                        0.96170, 0.96168, 0.96221, 0.96227, 0.96037, 0.95769, 0.95733, 0.82634],
                       [0.96488, 0.96486, 0.96418, 0.96512, 0.96460, 0.96439, 0.96363,
                        0.96293, 0.96297, 0.96281, 0.96490, 0.96665, 0.96769, 0.96718,
                        0.96655, 0.96560, 0.96409, 0.96295, 0.96154, 0.96116, 0.96171,
                        0.96334, 0.96251, 0.96375, 0.96288, 0.96163, 0.95949, 0.95848, 0.82778],
                       [0.96439, 0.96533, 0.96473, 0.96496, 0.96468, 0.96432, 0.96422,
                        0.96343, 0.96274, 0.96382, 0.96537, 0.96665, 0.96763, 0.96673,
                        0.96664, 0.96499, 0.96403, 0.96212, 0.96176, 0.96086, 0.96148,
                        0.96330, 0.96306, 0.96410, 0.96265, 0.96236, 0.96064, 0.95905, 0.82857],
                       [0.96447, 0.96531, 0.96488, 0.96425, 0.96465, 0.96461, 0.96497,
                        0.96421, 0.96364, 0.96461, 0.96605, 0.96715, 0.96767, 0.96669,
                        0.96611, 0.96498, 0.96368, 0.96113, 0.96134, 0.96075, 0.96148,
                        0.96263, 0.96329, 0.96371, 0.96292, 0.96321, 0.96115, 0.95982, 0.82926],
                       [0.96563, 0.96539, 0.96539, 0.96469, 0.96523, 0.96540, 0.96537,
                        0.96480, 0.96488, 0.96512, 0.96645, 0.96821, 0.96790, 0.96705,
                        0.96602, 0.96504, 0.96373, 0.96064, 0.96114, 0.96140, 0.96182,
                        0.96313, 0.96367, 0.96384, 0.96443, 0.96390, 0.96207, 0.96112, 0.83003],
                       [0.96657, 0.96563, 0.96620, 0.96527, 0.96579, 0.96602, 0.96495,
                        0.96531, 0.96506, 0.96521, 0.96633, 0.96815, 0.96799, 0.96716,
                        0.96648, 0.96445, 0.96306, 0.96056, 0.96140, 0.96167, 0.96210,
                        0.96393, 0.96464, 0.96464, 0.96558, 0.96409, 0.96320, 0.96193, 0.83034],
                       [0.96658, 0.96567, 0.96622, 0.96555, 0.96595, 0.96654, 0.96468,
                        0.96556, 0.96461, 0.96531, 0.96606, 0.96757, 0.96803, 0.96683,
                        0.96631, 0.96380, 0.96160, 0.96096, 0.96125, 0.96156, 0.96256,
                        0.96403, 0.96488, 0.96478, 0.96502, 0.96377, 0.96331, 0.96201, 0.83041],
                       [0.96683, 0.96625, 0.96634, 0.96647, 0.96631, 0.96712, 0.96593,
                        0.96541, 0.96474, 0.96601, 0.96682, 0.96814, 0.96786, 0.96668,
                        0.96541, 0.96386, 0.96098, 0.96146, 0.96087, 0.96194, 0.96342,
                        0.96385, 0.96452, 0.96476, 0.96475, 0.96434, 0.96296, 0.96257, 0.83124],
                       [0.96735, 0.96718, 0.96748, 0.96700, 0.96662, 0.96755, 0.96730,
                        0.96606, 0.96545, 0.96725, 0.96835, 0.96864, 0.96769, 0.96656,
                        0.96483, 0.96394, 0.96150, 0.96144, 0.96088, 0.96247, 0.96369,
                        0.96397, 0.96497, 0.96518, 0.96523, 0.96541, 0.96306, 0.96302, 0.83202],
                       [0.96747, 0.96781, 0.96825, 0.96681, 0.96692, 0.96787, 0.96758,
                        0.96698, 0.96592, 0.96780, 0.96890, 0.96813, 0.96744, 0.96571,
                        0.96418, 0.96281, 0.96158, 0.96050, 0.96102, 0.96260, 0.96313,
                        0.96430, 0.96521, 0.96488, 0.96483, 0.96534, 0.96343, 0.96260, 0.83179],
                       [0.96763, 0.96793, 0.96814, 0.96713, 0.96780, 0.96821, 0.96789,
                        0.96722, 0.96655, 0.96761, 0.96844, 0.96784, 0.96663, 0.96513,
                        0.96377, 0.96133, 0.96039, 0.95986, 0.96108, 0.96244, 0.96317,
                        0.96401, 0.96428, 0.96441, 0.96411, 0.96436, 0.96363, 0.96279, 0.83165],
                       [0.96840, 0.96821, 0.96844, 0.96800, 0.96855, 0.96882, 0.96843,
                        0.96768, 0.96801, 0.96787, 0.96811, 0.96785, 0.96604, 0.96540,
                        0.96413, 0.96103, 0.95988, 0.96017, 0.96136, 0.96251, 0.96366,
                        0.96362, 0.96366, 0.96439, 0.96416, 0.96373, 0.96375, 0.96384, 0.83218],
                       [0.96868, 0.96865, 0.96872, 0.96847, 0.96850, 0.96903, 0.96863,
                        0.96820, 0.96885, 0.96810, 0.96775, 0.96705, 0.96551, 0.96501,
                        0.96331, 0.96097, 0.96024, 0.96000, 0.96136, 0.96254, 0.96356,
                        0.96323, 0.96339, 0.96382, 0.96425, 0.96370, 0.96373, 0.96367, 0.83175],
                       [0.96855, 0.96901, 0.96890, 0.96872, 0.96859, 0.96893, 0.96889,
                        0.96835, 0.96800, 0.96824, 0.96768, 0.96593, 0.96499, 0.96409,
                        0.96168, 0.96021, 0.96036, 0.96039, 0.96162, 0.96228, 0.96315,
                        0.96273, 0.96340, 0.96328, 0.96368, 0.96382, 0.96379, 0.96284, 0.83097],
                       [0.96852, 0.96867, 0.96903, 0.96851, 0.96889, 0.96854, 0.96850,
                        0.96828, 0.96710, 0.96835, 0.96745, 0.96490, 0.96421, 0.96286,
                        0.96083, 0.95951, 0.95971, 0.96069, 0.96172, 0.96177, 0.96204,
                        0.96220, 0.96307, 0.96265, 0.96267, 0.96322, 0.96333, 0.96250, 0.83100],
                       [0.96892, 0.96857, 0.96890, 0.96824, 0.96912, 0.96809, 0.96811,
                        0.96849, 0.96755, 0.96841, 0.96693, 0.96437, 0.96291, 0.96172,
                        0.96111, 0.95975, 0.95939, 0.96015, 0.96119, 0.96174, 0.96108,
                        0.96194, 0.96177, 0.96188, 0.96199, 0.96254, 0.96282, 0.96276, 0.83132],
                       [0.96930, 0.96886, 0.96828, 0.96832, 0.96897, 0.96841, 0.96840,
                        0.96847, 0.96780, 0.96784, 0.96628, 0.96433, 0.96167, 0.96125,
                        0.96129, 0.95954, 0.95945, 0.95972, 0.96012, 0.96171, 0.96091,
                        0.96121, 0.96024, 0.96098, 0.96135, 0.96175, 0.96256, 0.96255, 0.83122],
                       [0.96905, 0.96853, 0.96827, 0.96866, 0.96817, 0.96852, 0.96813,
                        0.96809, 0.96786, 0.96694, 0.96537, 0.96371, 0.96118, 0.96105,
                        0.96009, 0.95843, 0.95929, 0.95966, 0.95940, 0.96088, 0.96076,
                        0.95993, 0.95959, 0.95997, 0.96078, 0.96080, 0.96202, 0.96189, 0.83070],
                       [0.96870, 0.96826, 0.96926, 0.96881, 0.96744, 0.96739, 0.96724,
                        0.96756, 0.96821, 0.96674, 0.96445, 0.96233, 0.96081, 0.96026,
                        0.95840, 0.95778, 0.95906, 0.95956, 0.95966, 0.95969, 0.96016,
                        0.95913, 0.95947, 0.95924, 0.96034, 0.96057, 0.96139, 0.96153, 0.83059],
                       [0.96811, 0.96774, 0.96899, 0.96843, 0.96747, 0.96669, 0.96698,
                        0.96704, 0.96785, 0.96658, 0.96386, 0.96103, 0.96012, 0.95888,
                        0.95767, 0.95812, 0.95867, 0.95937, 0.95968, 0.95940, 0.95905,
                        0.95901, 0.95844, 0.95833, 0.95939, 0.96031, 0.96094, 0.96114, 0.83109],
                       [0.96697, 0.96639, 0.96742, 0.96755, 0.96713, 0.96648, 0.96658,
                        0.96624, 0.96652, 0.96537, 0.96323, 0.95993, 0.95870, 0.95814,
                        0.95746, 0.95810, 0.95812, 0.95898, 0.95941, 0.95946, 0.95795,
                        0.95844, 0.95705, 0.95744, 0.95790, 0.95948, 0.96033, 0.96087, 0.83049],
                       [0.96665, 0.96610, 0.96696, 0.96704, 0.96642, 0.96594, 0.96585,
                        0.96563, 0.96577, 0.96463, 0.96246, 0.95955, 0.95771, 0.95830,
                        0.95778, 0.95785, 0.95812, 0.95861, 0.95929, 0.95904, 0.95759,
                        0.95691, 0.95700, 0.95740, 0.95718, 0.95930, 0.95984, 0.96123, 0.82953],
                       [0.96683, 0.96623, 0.96696, 0.96687, 0.96622, 0.96550, 0.96534,
                        0.96546, 0.96560, 0.96441, 0.96168, 0.95928, 0.95757, 0.95809,
                        0.95841, 0.95797, 0.95832, 0.95866, 0.95875, 0.95841, 0.95744,
                        0.95590, 0.95723, 0.95749, 0.95755, 0.95926, 0.95985, 0.96140, 0.82966],
                       [0.96610, 0.96525, 0.96573, 0.96614, 0.96561, 0.96531, 0.96460,
                        0.96451, 0.96457, 0.96355, 0.96075, 0.95784, 0.95653, 0.95711,
                        0.95770, 0.95768, 0.95826, 0.95844, 0.95767, 0.95756, 0.95652,
                        0.95585, 0.95629, 0.95647, 0.95719, 0.95799, 0.95959, 0.96088, 0.82954],
                       [0.96480, 0.96442, 0.96458, 0.96544, 0.96473, 0.96469, 0.96385,
                        0.96364, 0.96358, 0.96284, 0.95976, 0.95639, 0.95573, 0.95620,
                        0.95636, 0.95712, 0.95812, 0.95811, 0.95698, 0.95673, 0.95544,
                        0.95575, 0.95520, 0.95541, 0.95610, 0.95687, 0.95912, 0.96046, 0.82914],
                       [0.96375, 0.96405, 0.96424, 0.96452, 0.96399, 0.96299, 0.96292,
                        0.96339, 0.96293, 0.96175, 0.95849, 0.95568, 0.95550, 0.95582,
                        0.95547, 0.95662, 0.95754, 0.95772, 0.95670, 0.95570, 0.95474,
                        0.95514, 0.95431, 0.95466, 0.95525, 0.95663, 0.95806, 0.95936, 0.82914],
                       [0.96330, 0.96324, 0.96348, 0.96346, 0.96327, 0.96179, 0.96202,
                        0.96296, 0.96222, 0.96028, 0.95772, 0.95510, 0.95490, 0.95605,
                        0.95539, 0.95675, 0.95729, 0.95707, 0.95607, 0.95492, 0.95425,
                        0.95426, 0.95384, 0.95414, 0.95502, 0.95658, 0.95709, 0.95793, 0.82929],
                       [0.96287, 0.96234, 0.96224, 0.96295, 0.96243, 0.96130, 0.96116,
                        0.96212, 0.96134, 0.95930, 0.95769, 0.95451, 0.95481, 0.95620,
                        0.95601, 0.95694, 0.95757, 0.95656, 0.95553, 0.95487, 0.95377,
                        0.95334, 0.95386, 0.95426, 0.95518, 0.95648, 0.95734, 0.95810, 0.82924],
                       [0.96202, 0.96202, 0.96167, 0.96277, 0.96170, 0.96084, 0.96042,
                        0.96120, 0.96047, 0.95915, 0.95777, 0.95479, 0.95543, 0.95598,
                        0.95653, 0.95723, 0.95773, 0.95646, 0.95582, 0.95472, 0.95339,
                        0.95328, 0.95391, 0.95501, 0.95534, 0.95652, 0.95794, 0.95913, 0.82913],
                       [0.96081, 0.96137, 0.96136, 0.96211, 0.96124, 0.96018, 0.95977,
                        0.96015, 0.95965, 0.95911, 0.95682, 0.95479, 0.95536, 0.95576,
                        0.95648, 0.95745, 0.95753, 0.95667, 0.95562, 0.95433, 0.95332,
                        0.95368, 0.95355, 0.95486, 0.95514, 0.95633, 0.95779, 0.95919, 0.82893],
                       [0.95993, 0.96037, 0.96076, 0.96045, 0.96043, 0.95930, 0.95892,
                        0.95917, 0.95885, 0.95839, 0.95582, 0.95390, 0.95462, 0.95556,
                        0.95656, 0.95700, 0.95691, 0.95618, 0.95446, 0.95380, 0.95326,
                        0.95294, 0.95323, 0.95354, 0.95436, 0.95572, 0.95705, 0.95827, 0.82837],
                       [0.95945, 0.95999, 0.96039, 0.95938, 0.95985, 0.95886, 0.95827,
                        0.95844, 0.95827, 0.95773, 0.95614, 0.95402, 0.95466, 0.95629,
                        0.95699, 0.95695, 0.95667, 0.95536, 0.95407, 0.95353, 0.95319,
                        0.95226, 0.95321, 0.95294, 0.95383, 0.95528, 0.95654, 0.95727, 0.82801],
                       [0.95904, 0.95963, 0.95982, 0.95936, 0.95956, 0.95855, 0.95772,
                        0.95774, 0.95769, 0.95709, 0.95598, 0.95498, 0.95526, 0.95689,
                        0.95637, 0.95725, 0.95682, 0.95531, 0.95455, 0.95379, 0.95299,
                        0.95282, 0.95341, 0.95332, 0.95392, 0.95517, 0.95661, 0.95725, 0.82770],
                       [0.95876, 0.95933, 0.95885, 0.95926, 0.95919, 0.95816, 0.95725,
                        0.95752, 0.95681, 0.95621, 0.95537, 0.95523, 0.95588, 0.95606,
                        0.95548, 0.95714, 0.95661, 0.95518, 0.95442, 0.95401, 0.95329,
                        0.95340, 0.95389, 0.95383, 0.95407, 0.95521, 0.95640, 0.95779, 0.82725],
                       [0.95844, 0.95924, 0.95853, 0.95877, 0.95894, 0.95769, 0.95692,
                        0.95729, 0.95626, 0.95535, 0.95529, 0.95476, 0.95598, 0.95534,
                        0.95598, 0.95674, 0.95594, 0.95444, 0.95370, 0.95342, 0.95366,
                        0.95327, 0.95385, 0.95400, 0.95380, 0.95499, 0.95589, 0.95776, 0.82718],
                       [0.95876, 0.95936, 0.95913, 0.95885, 0.95921, 0.95764, 0.95725,
                        0.95735, 0.95677, 0.95568, 0.95560, 0.95493, 0.95581, 0.95613,
                        0.95771, 0.95677, 0.95581, 0.95465, 0.95392, 0.95291, 0.95348,
                        0.95336, 0.95363, 0.95416, 0.95414, 0.95494, 0.95569, 0.95761, 0.82762],
                       [0.95934, 0.95943, 0.95922, 0.95928, 0.95898, 0.95803, 0.95778,
                        0.95766, 0.95699, 0.95649, 0.95574, 0.95586, 0.95619, 0.95680,
                        0.95803, 0.95700, 0.95613, 0.95541, 0.95465, 0.95316, 0.95359,
                        0.95403, 0.95349, 0.95404, 0.95469, 0.95464, 0.95534, 0.95710, 0.82775],
                       [0.95953, 0.95940, 0.95891, 0.95923, 0.95826, 0.95816, 0.95767,
                        0.95738, 0.95630, 0.95637, 0.95604, 0.95669, 0.95709, 0.95678,
                        0.95686, 0.95705, 0.95624, 0.95550, 0.95506, 0.95422, 0.95430,
                        0.95474, 0.95386, 0.95396, 0.95453, 0.95419, 0.95506, 0.95678, 0.82752],
                       [0.95969, 0.95948, 0.95921, 0.95943, 0.95889, 0.95834, 0.95764,
                        0.95731, 0.95617, 0.95599, 0.95681, 0.95730, 0.95794, 0.95773,
                        0.95719, 0.95718, 0.95621, 0.95582, 0.95603, 0.95541, 0.95509,
                        0.95470, 0.95460, 0.95459, 0.95403, 0.95431, 0.95546, 0.95732, 0.82759],
                       [0.96002, 0.95973, 0.95988, 0.95964, 0.95953, 0.95871, 0.95848,
                        0.95785, 0.95660, 0.95624, 0.95748, 0.95787, 0.95796, 0.95915,
                        0.95817, 0.95723, 0.95598, 0.95659, 0.95678, 0.95561, 0.95576,
                        0.95424, 0.95498, 0.95473, 0.95360, 0.95425, 0.95575, 0.95718, 0.82732],
                       [0.96013, 0.96005, 0.96014, 0.95918, 0.95913, 0.95869, 0.95897,
                        0.95799, 0.95674, 0.95692, 0.95788, 0.95806, 0.95774, 0.95901,
                        0.95757, 0.95672, 0.95623, 0.95654, 0.95577, 0.95532, 0.95564,
                        0.95493, 0.95477, 0.95394, 0.95381, 0.95398, 0.95513, 0.95614, 0.82653],
                       [0.96012, 0.96045, 0.96005, 0.95906, 0.95940, 0.95875, 0.95813,
                        0.95787, 0.95698, 0.95718, 0.95795, 0.95823, 0.95818, 0.95790,
                        0.95655, 0.95653, 0.95686, 0.95602, 0.95485, 0.95561, 0.95530,
                        0.95601, 0.95453, 0.95393, 0.95451, 0.95398, 0.95421, 0.95549, 0.82595],
                       [0.96060, 0.96081, 0.96013, 0.95937, 0.95990, 0.95951, 0.95764,
                        0.95792, 0.95744, 0.95704, 0.95809, 0.95893, 0.95877, 0.95777,
                        0.95729, 0.95680, 0.95670, 0.95632, 0.95588, 0.95636, 0.95557,
                        0.95563, 0.95498, 0.95415, 0.95439, 0.95370, 0.95364, 0.95516, 0.82542],
                       [0.96153, 0.96131, 0.96068, 0.96002, 0.95983, 0.96025, 0.95879,
                        0.95840, 0.95749, 0.95748, 0.95851, 0.95946, 0.95895, 0.95867,
                        0.95832, 0.95684, 0.95658, 0.95713, 0.95784, 0.95668, 0.95637,
                        0.95515, 0.95546, 0.95404, 0.95384, 0.95301, 0.95371, 0.95427, 0.82518],
                       [0.96196, 0.96212, 0.96154, 0.96127, 0.96085, 0.96126, 0.96035,
                        0.95917, 0.95779, 0.95850, 0.95899, 0.95963, 0.95936, 0.95958,
                        0.95855, 0.95750, 0.95744, 0.95755, 0.95857, 0.95658, 0.95708,
                        0.95598, 0.95549, 0.95488, 0.95471, 0.95285, 0.95397, 0.95351, 0.82517],
                       [0.96243, 0.96289, 0.96256, 0.96190, 0.96216, 0.96242, 0.96134,
                        0.95978, 0.95911, 0.95960, 0.95977, 0.96041, 0.96021, 0.95989,
                        0.95893, 0.95843, 0.95833, 0.95809, 0.95788, 0.95729, 0.95722,
                        0.95678, 0.95555, 0.95622, 0.95576, 0.95334, 0.95388, 0.95383, 0.82527],
                       [0.96327, 0.96339, 0.96332, 0.96191, 0.96209, 0.96267, 0.96197,
                        0.96084, 0.96013, 0.96025, 0.96044, 0.96103, 0.96037, 0.96008,
                        0.95903, 0.95855, 0.95847, 0.95881, 0.95753, 0.95808, 0.95762,
                        0.95678, 0.95600, 0.95624, 0.95516, 0.95370, 0.95351, 0.95450, 0.82492],
                       [0.96413, 0.96373, 0.96369, 0.96264, 0.96224, 0.96284, 0.96251,
                        0.96179, 0.96002, 0.96084, 0.96110, 0.96108, 0.96030, 0.96053,
                        0.95899, 0.95829, 0.95842, 0.95880, 0.95793, 0.95849, 0.95847,
                        0.95731, 0.95665, 0.95590, 0.95464, 0.95408, 0.95363, 0.95481, 0.82406],
                       [0.96473, 0.96431, 0.96375, 0.96381, 0.96330, 0.96377, 0.96312,
                        0.96160, 0.95996, 0.96148, 0.96163, 0.96127, 0.96116, 0.96058,
                        0.95951, 0.95863, 0.95856, 0.95866, 0.95841, 0.95884, 0.95862,
                        0.95807, 0.95701, 0.95665, 0.95524, 0.95391, 0.95385, 0.95406, 0.82380],
                       [0.96451, 0.96470, 0.96373, 0.96423, 0.96401, 0.96448, 0.96356,
                        0.96141, 0.96058, 0.96148, 0.96193, 0.96161, 0.96197, 0.95998,
                        0.95948, 0.95923, 0.95876, 0.95891, 0.95875, 0.95885, 0.95793,
                        0.95767, 0.95703, 0.95695, 0.95536, 0.95323, 0.95355, 0.95261, 0.82409],
                       [0.96409, 0.96481, 0.96450, 0.96429, 0.96439, 0.96459, 0.96398,
                        0.96237, 0.96171, 0.96156, 0.96254, 0.96194, 0.96140, 0.95990,
                        0.95902, 0.95892, 0.95970, 0.95922, 0.95923, 0.95867, 0.95775,
                        0.95709, 0.95723, 0.95646, 0.95498, 0.95374, 0.95349, 0.95229, 0.82409],
                       [0.96434, 0.96483, 0.96559, 0.96467, 0.96456, 0.96490, 0.96469,
                        0.96364, 0.96276, 0.96249, 0.96316, 0.96239, 0.96090, 0.96083,
                        0.95965, 0.95870, 0.96030, 0.95983, 0.95988, 0.95845, 0.95813,
                        0.95785, 0.95730, 0.95645, 0.95559, 0.95522, 0.95395, 0.95308, 0.82367],
                       [0.96544, 0.96481, 0.96614, 0.96556, 0.96472, 0.96584, 0.96505,
                        0.96379, 0.96335, 0.96338, 0.96324, 0.96299, 0.96174, 0.96179,
                        0.96053, 0.95949, 0.95967, 0.96034, 0.96017, 0.95836, 0.95830,
                        0.95878, 0.95732, 0.95726, 0.95684, 0.95588, 0.95409, 0.95355, 0.82356],
                       [0.96629, 0.96512, 0.96564, 0.96576, 0.96511, 0.96622, 0.96443,
                        0.96305, 0.96337, 0.96311, 0.96272, 0.96307, 0.96227, 0.96172,
                        0.96038, 0.96036, 0.95929, 0.95969, 0.95904, 0.95847, 0.95801,
                        0.95791, 0.95736, 0.95766, 0.95700, 0.95550, 0.95399, 0.95346, 0.82405],
                       [0.96629, 0.96576, 0.96517, 0.96517, 0.96563, 0.96595, 0.96411,
                        0.96351, 0.96340, 0.96276, 0.96280, 0.96275, 0.96228, 0.96103,
                        0.96038, 0.96087, 0.96000, 0.95900, 0.95804, 0.95891, 0.95804,
                        0.95714, 0.95764, 0.95734, 0.95678, 0.95544, 0.95481, 0.95396, 0.82463],
                       [0.96569, 0.96570, 0.96514, 0.96475, 0.96566, 0.96550, 0.96423,
                        0.96482, 0.96348, 0.96318, 0.96333, 0.96273, 0.96223, 0.96041,
                        0.96057, 0.96038, 0.96033, 0.95874, 0.95821, 0.95917, 0.95783,
                        0.95754, 0.95805, 0.95727, 0.95669, 0.95529, 0.95471, 0.95420, 0.82435],
                       [0.96504, 0.96582, 0.96521, 0.96488, 0.96572, 0.96523, 0.96454,
                        0.96520, 0.96344, 0.96389, 0.96360, 0.96323, 0.96215, 0.96061,
                        0.96035, 0.95977, 0.95984, 0.95884, 0.95815, 0.95852, 0.95757,
                        0.95797, 0.95818, 0.95816, 0.95699, 0.95555, 0.95415, 0.95434, 0.82439],
                       [0.96492, 0.96583, 0.96502, 0.96526, 0.96561, 0.96497, 0.96472,
                        0.96449, 0.96361, 0.96372, 0.96357, 0.96300, 0.96149, 0.96109,
                        0.96012, 0.95963, 0.95915, 0.95888, 0.95773, 0.95741, 0.95746,
                        0.95782, 0.95814, 0.95898, 0.95788, 0.95675, 0.95508, 0.95493, 0.82529],
                       [0.96511, 0.96481, 0.96430, 0.96530, 0.96475, 0.96418, 0.96453,
                        0.96324, 0.96374, 0.96276, 0.96303, 0.96200, 0.96051, 0.96092,
                        0.96010, 0.95937, 0.95872, 0.95828, 0.95755, 0.95663, 0.95685,
                        0.95758, 0.95856, 0.95827, 0.95789, 0.95765, 0.95644, 0.95528, 0.82602],
                       [0.96454, 0.96410, 0.96440, 0.96491, 0.96432, 0.96392, 0.96470,
                        0.96298, 0.96392, 0.96294, 0.96275, 0.96141, 0.96050, 0.96057,
                        0.96056, 0.95925, 0.95877, 0.95776, 0.95777, 0.95651, 0.95672,
                        0.95788, 0.95882, 0.95754, 0.95768, 0.95755, 0.95702, 0.95581, 0.82651],
                       [0.96303, 0.96342, 0.96437, 0.96405, 0.96379, 0.96417, 0.96416,
                        0.96394, 0.96397, 0.96351, 0.96258, 0.96085, 0.96068, 0.96020,
                        0.96026, 0.95918, 0.95828, 0.95722, 0.95774, 0.95677, 0.95698,
                        0.95757, 0.95785, 0.95766, 0.95821, 0.95722, 0.95644, 0.95607, 0.82650],
                       [0.96204, 0.96227, 0.96307, 0.96346, 0.96291, 0.96372, 0.96307,
                        0.96414, 0.96337, 0.96345, 0.96182, 0.96069, 0.96048, 0.96006,
                        0.95894, 0.95901, 0.95755, 0.95657, 0.95717, 0.95680, 0.95696,
                        0.95649, 0.95689, 0.95797, 0.95873, 0.95751, 0.95609, 0.95606, 0.82672],
                       [0.96201, 0.96159, 0.96217, 0.96332, 0.96282, 0.96330, 0.96340,
                        0.96374, 0.96347, 0.96354, 0.96157, 0.96148, 0.96053, 0.96030,
                        0.95906, 0.95882, 0.95761, 0.95613, 0.95652, 0.95671, 0.95706,
                        0.95665, 0.95750, 0.95905, 0.95892, 0.95841, 0.95753, 0.95736, 0.82779],
                       [0.96168, 0.96099, 0.96167, 0.96296, 0.96297, 0.96241, 0.96344,
                        0.96367, 0.96406, 0.96325, 0.96189, 0.96153, 0.96031, 0.95992,
                        0.95946, 0.95805, 0.95757, 0.95572, 0.95538, 0.95629, 0.95673,
                        0.95771, 0.95880, 0.95987, 0.95885, 0.95897, 0.95920, 0.95856, 0.82857],
                       [0.96014, 0.96015, 0.96067, 0.96191, 0.96206, 0.96070, 0.96183,
                        0.96297, 0.96359, 0.96209, 0.96109, 0.96019, 0.95953, 0.95904,
                        0.95816, 0.95676, 0.95651, 0.95505, 0.95440, 0.95498, 0.95579,
                        0.95772, 0.95892, 0.95921, 0.95881, 0.95877, 0.95892, 0.95818, 0.82850],
                       [0.95768, 0.95887, 0.95895, 0.96003, 0.95999, 0.95915, 0.96010,
                        0.96127, 0.96238, 0.96089, 0.95970, 0.95841, 0.95832, 0.95824,
                        0.95674, 0.95577, 0.95495, 0.95395, 0.95401, 0.95382, 0.95476,
                        0.95662, 0.95770, 0.95768, 0.95834, 0.95817, 0.95798, 0.95777, 0.82828],
                       [0.95578, 0.95636, 0.95730, 0.95878, 0.95811, 0.95803, 0.95899,
                        0.96025, 0.96155, 0.96098, 0.95920, 0.95724, 0.95666, 0.95733,
                        0.95661, 0.95547, 0.95370, 0.95301, 0.95355, 0.95367, 0.95462,
                        0.95632, 0.95654, 0.95718, 0.95808, 0.95862, 0.95868, 0.95859, 0.82907],
                       [0.95438, 0.95364, 0.95636, 0.95789, 0.95750, 0.95702, 0.95817,
                        0.96005, 0.96111, 0.96116, 0.95900, 0.95683, 0.95530, 0.95649,
                        0.95670, 0.95474, 0.95285, 0.95195, 0.95266, 0.95346, 0.95427,
                        0.95654, 0.95625, 0.95804, 0.95896, 0.95965, 0.96000, 0.95956, 0.83035],
                       [0.95162, 0.95170, 0.95454, 0.95543, 0.95645, 0.95522, 0.95666,
                        0.95894, 0.96006, 0.96000, 0.95798, 0.95519, 0.95405, 0.95539,
                        0.95516, 0.95297, 0.95165, 0.94993, 0.95054, 0.95178, 0.95245,
                        0.95474, 0.95583, 0.95788, 0.95902, 0.95924, 0.95979, 0.95930, 0.83041],
                       [0.94753, 0.94902, 0.95098, 0.95248, 0.95340, 0.95247, 0.95414,
                        0.95662, 0.95823, 0.95823, 0.95633, 0.95248, 0.95265, 0.95387,
                        0.95288, 0.95158, 0.94945, 0.94732, 0.94711, 0.94877, 0.95046,
                        0.95193, 0.95489, 0.95604, 0.95762, 0.95875, 0.95858, 0.95883, 0.82944],
                       [0.94356, 0.94492, 0.94716, 0.94977, 0.95010, 0.94936, 0.95162,
                        0.95445, 0.95691, 0.95689, 0.95427, 0.95031, 0.95123, 0.95182,
                        0.95170, 0.95092, 0.94746, 0.94483, 0.94409, 0.94626, 0.94862,
                        0.95056, 0.95365, 0.95471, 0.95668, 0.95886, 0.95848, 0.95923, 0.82921],
                       [0.93950, 0.94031, 0.94358, 0.94666, 0.94762, 0.94650, 0.94917,
                        0.95338, 0.95653, 0.95621, 0.95195, 0.94843, 0.94918, 0.94985,
                        0.95051, 0.94908, 0.94552, 0.94235, 0.94173, 0.94410, 0.94657,
                        0.94968, 0.95194, 0.95424, 0.95669, 0.95838, 0.95936, 0.95985, 0.83007],
                       [0.93405, 0.93492, 0.93870, 0.94268, 0.94376, 0.94334, 0.94596,
                        0.95132, 0.95492, 0.95488, 0.94976, 0.94595, 0.94558, 0.94765,
                        0.94789, 0.94523, 0.94186, 0.93917, 0.93834, 0.94012, 0.94326,
                        0.94671, 0.94993, 0.95314, 0.95628, 0.95759, 0.95890, 0.96013, 0.83036],
                       [0.92685, 0.92800, 0.93261, 0.93755, 0.93808, 0.93852, 0.94207,
                        0.94810, 0.95217, 0.95202, 0.94701, 0.94246, 0.94145, 0.94466,
                        0.94488, 0.94099, 0.93689, 0.93410, 0.93312, 0.93466, 0.93825,
                        0.94243, 0.94734, 0.95109, 0.95492, 0.95700, 0.95756, 0.95990, 0.82973],
                       [0.91886, 0.92049, 0.92609, 0.93200, 0.93199, 0.93245, 0.93745,
                        0.94511, 0.94984, 0.94869, 0.94335, 0.93801, 0.93795, 0.94097,
                        0.94214, 0.93753, 0.93211, 0.92740, 0.92634, 0.92907, 0.93288,
                        0.93860, 0.94416, 0.94887, 0.95322, 0.95623, 0.95756, 0.95919, 0.82902],
                       [0.90960, 0.91196, 0.91818, 0.92511, 0.92539, 0.92515, 0.93115,
                        0.94106, 0.94674, 0.94559, 0.93924, 0.93288, 0.93338, 0.93646,
                        0.93775, 0.93342, 0.92657, 0.91996, 0.91789, 0.92212, 0.92686,
                        0.93350, 0.94034, 0.94626, 0.95127, 0.95532, 0.95775, 0.95870, 0.82930],
                       [0.89829, 0.90133, 0.90876, 0.91627, 0.91771, 0.91651, 0.92370,
                        0.93577, 0.94251, 0.94258, 0.93445, 0.92745, 0.92762, 0.93105,
                        0.93160, 0.92742, 0.91925, 0.91187, 0.90847, 0.91321, 0.91929,
                        0.92653, 0.93526, 0.94282, 0.94941, 0.95452, 0.95721, 0.95892, 0.83058],
                       [0.88535, 0.88821, 0.89767, 0.90626, 0.90828, 0.90654, 0.91562,
                        0.93015, 0.93803, 0.93867, 0.92840, 0.92016, 0.92081, 0.92491,
                        0.92568, 0.92040, 0.91056, 0.90181, 0.89869, 0.90270, 0.91019,
                        0.91874, 0.92900, 0.93907, 0.94740, 0.95291, 0.95683, 0.95896, 0.83079],
                       [0.87060, 0.87312, 0.88447, 0.89533, 0.89703, 0.89513, 0.90599,
                        0.92333, 0.93284, 0.93337, 0.92118, 0.91083, 0.91198, 0.91785,
                        0.91907, 0.91244, 0.90043, 0.88882, 0.88633, 0.89051, 0.89915,
                        0.90940, 0.92148, 0.93442, 0.94447, 0.95096, 0.95622, 0.95816, 0.82994],
                       [0.85347, 0.85684, 0.86957, 0.88296, 0.88427, 0.88248, 0.89466,
                        0.91490, 0.92650, 0.92743, 0.91320, 0.90105, 0.90175, 0.90945,
                        0.91021, 0.90244, 0.88838, 0.87396, 0.87066, 0.87660, 0.88569,
                        0.89822, 0.91254, 0.92792, 0.94034, 0.94906, 0.95493, 0.95769, 0.82921],
                       [0.83411, 0.83870, 0.85279, 0.86818, 0.86948, 0.86762, 0.88201,
                        0.90543, 0.91938, 0.92058, 0.90378, 0.88993, 0.89066, 0.89916,
                        0.90001, 0.89027, 0.87417, 0.85774, 0.85335, 0.86020, 0.87046,
                        0.88507, 0.90214, 0.91959, 0.93512, 0.94609, 0.95371, 0.95772, 0.82854],
                       [0.81289, 0.81736, 0.83360, 0.85098, 0.85244, 0.85015, 0.86740,
                        0.89444, 0.91101, 0.91179, 0.89219, 0.87565, 0.87759, 0.88662,
                        0.88900, 0.87690, 0.85789, 0.83916, 0.83434, 0.84100, 0.85351,
                        0.86970, 0.89011, 0.91091, 0.92948, 0.94257, 0.95274, 0.95690, 0.82752],
                       [0.78913, 0.79325, 0.81180, 0.83182, 0.83292, 0.83045, 0.85030,
                        0.88168, 0.90073, 0.90134, 0.87920, 0.85850, 0.86186, 0.87270,
                        0.87576, 0.86186, 0.83902, 0.81792, 0.81256, 0.82019, 0.83392,
                        0.85237, 0.87650, 0.90138, 0.92263, 0.93853, 0.95078, 0.95591, 0.82646],
                       [0.76291, 0.76743, 0.78785, 0.81025, 0.81107, 0.80800, 0.83110,
                        0.86761, 0.88884, 0.88955, 0.86408, 0.84061, 0.84416, 0.85732,
                        0.85995, 0.84371, 0.81754, 0.79407, 0.78778, 0.79708, 0.81197,
                        0.83286, 0.86054, 0.88861, 0.91366, 0.93334, 0.94776, 0.95497, 0.82581],
                       [0.73400, 0.73954, 0.76167, 0.78631, 0.78746, 0.78348, 0.80963,
                        0.85155, 0.87534, 0.87592, 0.84627, 0.82130, 0.82450, 0.83977,
                        0.84179, 0.82314, 0.79412, 0.76818, 0.76068, 0.77082, 0.78793,
                        0.81099, 0.84161, 0.87328, 0.90324, 0.92772, 0.94457, 0.95292, 0.82471],
                       [0.70227, 0.70911, 0.73320, 0.76052, 0.76206, 0.75736, 0.78574,
                        0.83258, 0.85933, 0.86009, 0.82703, 0.79862, 0.80241, 0.81963,
                        0.82116, 0.80073, 0.76820, 0.74034, 0.73171, 0.74277, 0.76140,
                        0.78697, 0.82039, 0.85678, 0.89126, 0.92105, 0.94079, 0.95009, 0.82260],
                       [0.66942, 0.67655, 0.70303, 0.73281, 0.73458, 0.72837, 0.76004,
                        0.81125, 0.84127, 0.84225, 0.80599, 0.77297, 0.77781, 0.79692,
                        0.79876, 0.77627, 0.74011, 0.70949, 0.70063, 0.71290, 0.73233,
                        0.76074, 0.79724, 0.83850, 0.87693, 0.91220, 0.93600, 0.94750, 0.82042],
                       [0.63539, 0.64267, 0.67039, 0.70271, 0.70407, 0.69625, 0.73158,
                        0.78772, 0.82159, 0.82201, 0.78177, 0.74470, 0.75021, 0.77140,
                        0.77387, 0.74916, 0.70954, 0.67576, 0.66712, 0.68022, 0.70112,
                        0.73138, 0.77156, 0.81729, 0.86002, 0.90076, 0.92935, 0.94403, 0.81764],
                       [0.59947, 0.60766, 0.63551, 0.67049, 0.67165, 0.66279, 0.70065,
                        0.76153, 0.79945, 0.79957, 0.75500, 0.71448, 0.72026, 0.74378,
                        0.74623, 0.71944, 0.67704, 0.64098, 0.63230, 0.64565, 0.66851,
                        0.69970, 0.74380, 0.79283, 0.84178, 0.88807, 0.92171, 0.93848, 0.81371],
                       [0.56240, 0.57086, 0.60012, 0.63702, 0.63794, 0.62922, 0.66883,
                        0.73394, 0.77469, 0.77545, 0.72677, 0.68285, 0.68917, 0.71505,
                        0.71717, 0.68793, 0.64384, 0.60603, 0.59695, 0.61056, 0.63442,
                        0.66726, 0.71425, 0.76618, 0.82204, 0.87438, 0.91425, 0.93281, 0.80911],
                       [0.52507, 0.53366, 0.56427, 0.60258, 0.60254, 0.59422, 0.63577,
                        0.70557, 0.74842, 0.74943, 0.69726, 0.64931, 0.65752, 0.68474,
                        0.68615, 0.65467, 0.60922, 0.57004, 0.56061, 0.57518, 0.59888,
                        0.63344, 0.68280, 0.73897, 0.79935, 0.85876, 0.90521, 0.92785, 0.80405],
                       [0.48796, 0.49684, 0.52762, 0.56698, 0.56641, 0.55713, 0.60103,
                        0.67515, 0.72055, 0.72109, 0.66586, 0.61393, 0.62405, 0.65263,
                        0.65305, 0.61999, 0.57295, 0.53288, 0.52392, 0.53917, 0.56269,
                        0.59804, 0.64964, 0.70976, 0.77385, 0.84107, 0.89334, 0.92081, 0.79837],
                       [0.45131, 0.45956, 0.49015, 0.53027, 0.52992, 0.51909, 0.56486,
                        0.64182, 0.69034, 0.68954, 0.63238, 0.57725, 0.58775, 0.61843,
                        0.61897, 0.58468, 0.53593, 0.49556, 0.48706, 0.50212, 0.52625,
                        0.56186, 0.61441, 0.67743, 0.74615, 0.82093, 0.87916, 0.91060, 0.79099],
                       [0.41518, 0.42279, 0.45271, 0.49355, 0.49351, 0.48147, 0.52788,
                        0.60697, 0.65818, 0.65613, 0.59749, 0.53994, 0.55022, 0.58264,
                        0.58357, 0.54851, 0.49883, 0.45870, 0.45036, 0.46470, 0.48946,
                        0.52498, 0.57811, 0.64365, 0.71673, 0.79805, 0.86347, 0.89875, 0.78114],
                       [0.37999, 0.38778, 0.41650, 0.45731, 0.45715, 0.44470, 0.49088,
                        0.57137, 0.62396, 0.62220, 0.56147, 0.50250, 0.51278, 0.54679,
                        0.54679, 0.51097, 0.46191, 0.42252, 0.41456, 0.42843, 0.45263,
                        0.48791, 0.54183, 0.60833, 0.68512, 0.77229, 0.84603, 0.88556, 0.76988],
                       [0.34640, 0.35427, 0.38171, 0.42158, 0.42107, 0.40902, 0.45407,
                        0.53509, 0.58889, 0.58739, 0.52519, 0.46544, 0.47640, 0.51128,
                        0.51015, 0.47417, 0.42614, 0.38775, 0.38005, 0.39398, 0.41685,
                        0.45162, 0.50536, 0.57174, 0.65153, 0.74501, 0.82679, 0.87050, 0.75805],
                       [0.31456, 0.32200, 0.34835, 0.38675, 0.38602, 0.37448, 0.41809,
                        0.49886, 0.55366, 0.55160, 0.48947, 0.42915, 0.44089, 0.47503,
                        0.47401, 0.43857, 0.39165, 0.35469, 0.34695, 0.36096, 0.38289,
                        0.41633, 0.46894, 0.53513, 0.61696, 0.71650, 0.80515, 0.85359, 0.74488],
                       [0.28447, 0.29130, 0.31626, 0.35324, 0.35230, 0.34096, 0.38383,
                        0.46298, 0.51767, 0.51496, 0.45375, 0.39384, 0.40501, 0.43858,
                        0.43749, 0.40279, 0.35785, 0.32276, 0.31546, 0.32901, 0.35029,
                        0.38191, 0.43301, 0.49861, 0.58115, 0.68557, 0.78034, 0.83435, 0.72857],
                       [0.25682, 0.26295, 0.28612, 0.32151, 0.32037, 0.30933, 0.35091,
                        0.42713, 0.48145, 0.47866, 0.41797, 0.35957, 0.37006, 0.40370,
                        0.40164, 0.36843, 0.32568, 0.29244, 0.28663, 0.29885, 0.31902,
                        0.34893, 0.39828, 0.46235, 0.54461, 0.65272, 0.75376, 0.81284, 0.70967],
                       [0.23172, 0.23727, 0.25881, 0.29167, 0.29064, 0.28026, 0.31906,
                        0.39181, 0.44574, 0.44299, 0.38352, 0.32694, 0.33759, 0.37009,
                        0.36795, 0.33675, 0.29604, 0.26471, 0.26011, 0.27103, 0.28994,
                        0.31803, 0.36511, 0.42692, 0.50817, 0.61872, 0.72572, 0.78925, 0.68951],
                       [0.20826, 0.21366, 0.23355, 0.26384, 0.26299, 0.25349, 0.28881,
                        0.35815, 0.41052, 0.40735, 0.35098, 0.29691, 0.30699, 0.33735,
                        0.33580, 0.30675, 0.26853, 0.23952, 0.23483, 0.24542, 0.26304,
                        0.28907, 0.33331, 0.39281, 0.47164, 0.58360, 0.69549, 0.76294, 0.66739],
                       [0.18687, 0.19197, 0.20984, 0.23823, 0.23718, 0.22853, 0.26096,
                        0.32685, 0.37616, 0.37305, 0.32009, 0.26885, 0.27807, 0.30649,
                        0.30493, 0.27819, 0.24257, 0.21644, 0.21125, 0.22165, 0.23775,
                        0.26198, 0.30312, 0.35991, 0.43591, 0.54754, 0.66336, 0.73424, 0.64325],
                       [0.16796, 0.17243, 0.18862, 0.21451, 0.21347, 0.20531, 0.23583,
                        0.29718, 0.34354, 0.34079, 0.29059, 0.24235, 0.25130, 0.27790,
                        0.27649, 0.25135, 0.21866, 0.19515, 0.19033, 0.19969, 0.21425,
                        0.23660, 0.27525, 0.32837, 0.40161, 0.51118, 0.63045, 0.70425, 0.61785],
                       [0.15106, 0.15496, 0.16985, 0.19268, 0.19242, 0.18427, 0.21291,
                        0.26897, 0.31279, 0.31001, 0.26297, 0.21820, 0.22672, 0.25198,
                        0.25086, 0.22657, 0.19761, 0.17584, 0.17192, 0.18011, 0.19335,
                        0.21337, 0.24982, 0.29882, 0.36834, 0.47578, 0.59677, 0.67284, 0.59121],
                       [0.13556, 0.13939, 0.15252, 0.17332, 0.17347, 0.16568, 0.19160,
                        0.24287, 0.28359, 0.28089, 0.23759, 0.19660, 0.20394, 0.22825,
                        0.22668, 0.20432, 0.17840, 0.15845, 0.15485, 0.16258, 0.17451,
                        0.19289, 0.22566, 0.27126, 0.33626, 0.44104, 0.56088, 0.63910, 0.56249],
                       [0.12177, 0.12522, 0.13697, 0.15609, 0.15581, 0.14908, 0.17198,
                        0.21910, 0.25650, 0.25409, 0.21454, 0.17732, 0.18357, 0.20570,
                        0.20407, 0.18456, 0.16041, 0.14256, 0.13953, 0.14656, 0.15754,
                        0.17419, 0.20334, 0.24561, 0.30637, 0.40642, 0.52442, 0.60415, 0.53202],
                       [0.10992, 0.11266, 0.12361, 0.14047, 0.13968, 0.13420, 0.15434,
                        0.19761, 0.23194, 0.22933, 0.19364, 0.15989, 0.16546, 0.18495,
                        0.18418, 0.16642, 0.14414, 0.12818, 0.12620, 0.13216, 0.14227,
                        0.15671, 0.18374, 0.22225, 0.27868, 0.37287, 0.48908, 0.56925, 0.50170],
                       [0.09942, 0.10164, 0.11158, 0.12648, 0.12567, 0.12104, 0.13867,
                        0.17809, 0.20941, 0.20673, 0.17452, 0.14372, 0.14903, 0.16654,
                        0.16608, 0.14966, 0.13001, 0.11583, 0.11396, 0.11919, 0.12829,
                        0.14139, 0.16598, 0.20109, 0.25271, 0.34128, 0.45410, 0.53400, 0.47131],
                       [0.08932, 0.09157, 0.10013, 0.11352, 0.11324, 0.10891, 0.12475,
                        0.15992, 0.18854, 0.18627, 0.15674, 0.12877, 0.13414, 0.14989,
                        0.14901, 0.13461, 0.11750, 0.10495, 0.10248, 0.10754, 0.11539,
                        0.12780, 0.14955, 0.18140, 0.22844, 0.31151, 0.41916, 0.49782, 0.43971],
                       [0.08005, 0.08249, 0.08971, 0.10166, 0.10192, 0.09748, 0.11226,
                        0.14317, 0.16928, 0.16743, 0.14050, 0.11552, 0.12039, 0.13483,
                        0.13380, 0.12105, 0.10566, 0.09429, 0.09195, 0.09680, 0.10362,
                        0.11526, 0.13461, 0.16326, 0.20594, 0.28305, 0.38538, 0.46146, 0.40779],
                       [0.07220, 0.07421, 0.08076, 0.09133, 0.09160, 0.08744, 0.10080,
                        0.12814, 0.15152, 0.15020, 0.12602, 0.10398, 0.10786, 0.12122,
                        0.12030, 0.10884, 0.09481, 0.08432, 0.08259, 0.08673, 0.09327,
                        0.10357, 0.12133, 0.14688, 0.18537, 0.25617, 0.35279, 0.42634, 0.37653],
                       [0.06525, 0.06681, 0.07303, 0.08236, 0.08215, 0.07892, 0.09060,
                        0.11514, 0.13594, 0.13459, 0.11309, 0.09350, 0.09701, 0.10868,
                        0.10824, 0.09798, 0.08553, 0.07631, 0.07467, 0.07822, 0.08448,
                        0.09303, 0.10919, 0.13189, 0.16695, 0.23176, 0.32143, 0.39258, 0.34653],
                       [0.05879, 0.06061, 0.06605, 0.07436, 0.07383, 0.07115, 0.08168,
                        0.10372, 0.12233, 0.12074, 0.10195, 0.08399, 0.08757, 0.09766,
                        0.09746, 0.08855, 0.07735, 0.06970, 0.06802, 0.07138, 0.07654,
                        0.08388, 0.09793, 0.11890, 0.15070, 0.20948, 0.29214, 0.35954, 0.31784],
                       [0.05323, 0.05524, 0.05981, 0.06705, 0.06690, 0.06449, 0.07383,
                        0.09339, 0.11033, 0.10899, 0.09226, 0.07597, 0.07933, 0.08842,
                        0.08800, 0.08015, 0.07011, 0.06327, 0.06218, 0.06504, 0.06923,
                        0.07624, 0.08856, 0.10775, 0.13626, 0.18896, 0.26569, 0.32816, 0.29076],
                       [0.04870, 0.05026, 0.05439, 0.06073, 0.06101, 0.05885, 0.06693,
                        0.08426, 0.09969, 0.09855, 0.08338, 0.06900, 0.07199, 0.08006,
                        0.07977, 0.07218, 0.06383, 0.05734, 0.05663, 0.05913, 0.06300,
                        0.06945, 0.08082, 0.09739, 0.12309, 0.17052, 0.24137, 0.29960, 0.26510],
                       [0.04450, 0.04563, 0.04956, 0.05556, 0.05552, 0.05335, 0.06082,
                        0.07617, 0.08981, 0.08881, 0.07526, 0.06261, 0.06505, 0.07245,
                        0.07228, 0.06536, 0.05808, 0.05219, 0.05144, 0.05399, 0.05763,
                        0.06303, 0.07330, 0.08800, 0.11069, 0.15405, 0.21871, 0.27292, 0.24107],
                       [0.04064, 0.04173, 0.04532, 0.05061, 0.05043, 0.04843, 0.05532,
                        0.06914, 0.08108, 0.08040, 0.06819, 0.05713, 0.05888, 0.06571,
                        0.06559, 0.05992, 0.05286, 0.04757, 0.04686, 0.04947, 0.05268,
                        0.05742, 0.06627, 0.07994, 0.09983, 0.13923, 0.19775, 0.24739, 0.21929],
                       [0.03735, 0.03834, 0.04166, 0.04577, 0.04600, 0.04451, 0.05042,
                        0.06306, 0.07348, 0.07308, 0.06224, 0.05224, 0.05389, 0.05976,
                        0.05986, 0.05479, 0.04820, 0.04352, 0.04286, 0.04529, 0.04793,
                        0.05256, 0.06055, 0.07280, 0.09101, 0.12607, 0.17842, 0.22402, 0.19910],
                       [0.03438, 0.03525, 0.03833, 0.04205, 0.04229, 0.04101, 0.04618,
                        0.05753, 0.06666, 0.06629, 0.05658, 0.04780, 0.04942, 0.05460,
                        0.05469, 0.04988, 0.04414, 0.03997, 0.03946, 0.04130, 0.04377,
                        0.04811, 0.05549, 0.06638, 0.08303, 0.11423, 0.16134, 0.20277, 0.18017],
                       [0.03180, 0.03256, 0.03521, 0.03906, 0.03903, 0.03752, 0.04240,
                        0.05243, 0.06087, 0.06021, 0.05141, 0.04386, 0.04513, 0.05003,
                        0.04998, 0.04572, 0.04051, 0.03693, 0.03634, 0.03780, 0.04033,
                        0.04412, 0.05083, 0.06067, 0.07541, 0.10335, 0.14619, 0.18309, 0.16284],
                       [0.02942, 0.02988, 0.03244, 0.03587, 0.03585, 0.03439, 0.03886,
                        0.04784, 0.05582, 0.05485, 0.04722, 0.04005, 0.04140, 0.04588,
                        0.04582, 0.04205, 0.03719, 0.03412, 0.03339, 0.03517, 0.03727,
                        0.04059, 0.04676, 0.05549, 0.06870, 0.09354, 0.13219, 0.16552, 0.14691],
                       [0.02700, 0.02743, 0.02987, 0.03299, 0.03283, 0.03168, 0.03577,
                        0.04387, 0.05092, 0.05012, 0.04340, 0.03648, 0.03817, 0.04197,
                        0.04197, 0.03842, 0.03456, 0.03155, 0.03091, 0.03274, 0.03444,
                        0.03748, 0.04304, 0.05064, 0.06273, 0.08477, 0.11955, 0.15017, 0.13258],
                       [0.02484, 0.02568, 0.02750, 0.03056, 0.03020, 0.02927, 0.03303,
                        0.04044, 0.04638, 0.04594, 0.03974, 0.03372, 0.03508, 0.03863,
                        0.03850, 0.03523, 0.03215, 0.02942, 0.02874, 0.03004, 0.03181,
                        0.03476, 0.03961, 0.04606, 0.05707, 0.07711, 0.10834, 0.13611, 0.12013],
                       [0.02315, 0.02402, 0.02539, 0.02828, 0.02784, 0.02728, 0.03034,
                        0.03711, 0.04222, 0.04213, 0.03647, 0.03157, 0.03224, 0.03547,
                        0.03558, 0.03268, 0.02961, 0.02716, 0.02660, 0.02770, 0.02938,
                        0.03218, 0.03663, 0.04218, 0.05191, 0.07027, 0.09821, 0.12285, 0.10905],
                       [0.02170, 0.02207, 0.02351, 0.02606, 0.02570, 0.02555, 0.02806,
                        0.03390, 0.03877, 0.03870, 0.03370, 0.02930, 0.02988, 0.03247,
                        0.03279, 0.03032, 0.02734, 0.02492, 0.02478, 0.02591, 0.02718,
                        0.02973, 0.03399, 0.03924, 0.04779, 0.06397, 0.08900, 0.11091, 0.09858],
                       [0.02029, 0.02017, 0.02176, 0.02399, 0.02386, 0.02371, 0.02598,
                        0.03106, 0.03589, 0.03551, 0.03093, 0.02671, 0.02742, 0.02989,
                        0.03013, 0.02801, 0.02528, 0.02323, 0.02324, 0.02394, 0.02534,
                        0.02751, 0.03133, 0.03645, 0.04408, 0.05840, 0.08073, 0.10052, 0.08882],
                       [0.01881, 0.01865, 0.02019, 0.02211, 0.02220, 0.02164, 0.02389,
                        0.02864, 0.03283, 0.03241, 0.02831, 0.02448, 0.02500, 0.02750,
                        0.02775, 0.02572, 0.02333, 0.02167, 0.02145, 0.02205, 0.02366,
                        0.02527, 0.02855, 0.03349, 0.04009, 0.05346, 0.07312, 0.09078, 0.08016],
                       [0.01732, 0.01763, 0.01881, 0.02050, 0.02046, 0.01967, 0.02203,
                        0.02647, 0.02976, 0.02964, 0.02616, 0.02263, 0.02317, 0.02525,
                        0.02552, 0.02343, 0.02138, 0.01997, 0.01970, 0.02068, 0.02183,
                        0.02328, 0.02609, 0.03078, 0.03635, 0.04884, 0.06615, 0.08177, 0.07273],
                       [0.01604, 0.01660, 0.01720, 0.01909, 0.01881, 0.01812, 0.02032,
                        0.02427, 0.02732, 0.02733, 0.02417, 0.02073, 0.02169, 0.02326,
                        0.02340, 0.02149, 0.01968, 0.01854, 0.01841, 0.01932, 0.02021,
                        0.02177, 0.02422, 0.02825, 0.03350, 0.04441, 0.06004, 0.07396, 0.06605],
                       [0.01504, 0.01542, 0.01577, 0.01778, 0.01749, 0.01709, 0.01875,
                        0.02226, 0.02532, 0.02539, 0.02224, 0.01926, 0.02035, 0.02164,
                        0.02167, 0.02007, 0.01859, 0.01744, 0.01718, 0.01786, 0.01887,
                        0.02024, 0.02275, 0.02578, 0.03129, 0.04040, 0.05477, 0.06729, 0.05979],
                       [0.01418, 0.01423, 0.01491, 0.01657, 0.01629, 0.01606, 0.01741,
                        0.02065, 0.02340, 0.02344, 0.02043, 0.01812, 0.01890, 0.02017,
                        0.02026, 0.01887, 0.01741, 0.01638, 0.01591, 0.01667, 0.01744,
                        0.01873, 0.02132, 0.02383, 0.02881, 0.03709, 0.05022, 0.06143, 0.05428],
                       [0.01330, 0.01319, 0.01422, 0.01547, 0.01529, 0.01483, 0.01619,
                        0.01936, 0.02167, 0.02162, 0.01895, 0.01707, 0.01760, 0.01869,
                        0.01892, 0.01772, 0.01607, 0.01545, 0.01509, 0.01571, 0.01635,
                        0.01761, 0.01982, 0.02222, 0.02632, 0.03439, 0.04621, 0.05598, 0.04958],
                       [0.01250, 0.01252, 0.01352, 0.01441, 0.01447, 0.01395, 0.01527,
                        0.01814, 0.02024, 0.02022, 0.01796, 0.01623, 0.01654, 0.01752,
                        0.01782, 0.01658, 0.01525, 0.01467, 0.01457, 0.01500, 0.01580,
                        0.01661, 0.01862, 0.02084, 0.02452, 0.03178, 0.04247, 0.05105, 0.04541],
                       [0.01198, 0.01223, 0.01274, 0.01351, 0.01360, 0.01340, 0.01458,
                        0.01676, 0.01901, 0.01894, 0.01709, 0.01511, 0.01559, 0.01649,
                        0.01678, 0.01546, 0.01475, 0.01391, 0.01395, 0.01441, 0.01514,
                        0.01575, 0.01778, 0.01971, 0.02304, 0.02914, 0.03920, 0.04702, 0.04186],
                       [0.01150, 0.01185, 0.01204, 0.01307, 0.01286, 0.01277, 0.01389,
                        0.01564, 0.01799, 0.01780, 0.01589, 0.01392, 0.01471, 0.01548,
                        0.01585, 0.01471, 0.01412, 0.01312, 0.01325, 0.01362, 0.01420,
                        0.01501, 0.01677, 0.01863, 0.02144, 0.02698, 0.03616, 0.04350, 0.03856],
                       [0.01092, 0.01107, 0.01155, 0.01249, 0.01218, 0.01196, 0.01304,
                        0.01494, 0.01697, 0.01680, 0.01491, 0.01321, 0.01386, 0.01484,
                        0.01507, 0.01426, 0.01333, 0.01256, 0.01271, 0.01282, 0.01340,
                        0.01446, 0.01565, 0.01753, 0.02004, 0.02553, 0.03343, 0.03999, 0.03545],
                       [0.01041, 0.01032, 0.01106, 0.01148, 0.01163, 0.01125, 0.01216,
                        0.01434, 0.01592, 0.01590, 0.01442, 0.01285, 0.01323, 0.01433,
                        0.01421, 0.01381, 0.01252, 0.01228, 0.01223, 0.01230, 0.01274,
                        0.01390, 0.01479, 0.01655, 0.01919, 0.02418, 0.03110, 0.03698, 0.03289],
                       [0.00996, 0.00994, 0.01043, 0.01066, 0.01125, 0.01073, 0.01156,
                        0.01351, 0.01500, 0.01484, 0.01386, 0.01257, 0.01248, 0.01358,
                        0.01340, 0.01321, 0.01189, 0.01171, 0.01171, 0.01177, 0.01229,
                        0.01306, 0.01405, 0.01580, 0.01833, 0.02275, 0.02884, 0.03442, 0.03051],
                       [0.00970, 0.00980, 0.01012, 0.01046, 0.01072, 0.01043, 0.01123,
                        0.01293, 0.01415, 0.01398, 0.01309, 0.01205, 0.01186, 0.01296,
                        0.01296, 0.01250, 0.01160, 0.01119, 0.01119, 0.01125, 0.01205,
                        0.01256, 0.01340, 0.01518, 0.01729, 0.02128, 0.02687, 0.03193, 0.02814],
                       [0.00925, 0.00943, 0.00993, 0.01023, 0.01034, 0.01011, 0.01075,
                        0.01249, 0.01340, 0.01326, 0.01244, 0.01124, 0.01149, 0.01247,
                        0.01238, 0.01165, 0.01133, 0.01097, 0.01065, 0.01083, 0.01153,
                        0.01223, 0.01292, 0.01432, 0.01622, 0.01969, 0.02515, 0.02957, 0.02586],
                       [0.00874, 0.00886, 0.00957, 0.00983, 0.01009, 0.00980, 0.01033,
                        0.01196, 0.01284, 0.01259, 0.01190, 0.01074, 0.01098, 0.01188,
                        0.01171, 0.01118, 0.01090, 0.01059, 0.01033, 0.01061, 0.01083,
                        0.01167, 0.01264, 0.01367, 0.01510, 0.01831, 0.02347, 0.02748, 0.02398],
                       [0.00851, 0.00852, 0.00910, 0.00928, 0.00957, 0.00942, 0.01007,
                        0.01136, 0.01211, 0.01214, 0.01099, 0.01043, 0.01056, 0.01122,
                        0.01121, 0.01090, 0.01030, 0.01002, 0.01010, 0.01029, 0.01045,
                        0.01111, 0.01225, 0.01321, 0.01415, 0.01726, 0.02168, 0.02542, 0.02239],
                       [0.00857, 0.00848, 0.00861, 0.00891, 0.00913, 0.00907, 0.00972,
                        0.01078, 0.01135, 0.01154, 0.01024, 0.01010, 0.01037, 0.01067,
                        0.01078, 0.01046, 0.00988, 0.00969, 0.00975, 0.00983, 0.01042,
                        0.01064, 0.01158, 0.01253, 0.01355, 0.01643, 0.02024, 0.02349, 0.02090],
                       [0.00843, 0.00837, 0.00833, 0.00861, 0.00876, 0.00871, 0.00913,
                        0.01015, 0.01080, 0.01067, 0.01023, 0.00951, 0.00993, 0.01028,
                        0.01031, 0.00994, 0.00953, 0.00927, 0.00937, 0.00952, 0.01027,
                        0.01019, 0.01091, 0.01194, 0.01311, 0.01544, 0.01932, 0.02198, 0.01951],
                       [0.00799, 0.00795, 0.00822, 0.00837, 0.00840, 0.00829, 0.00889,
                        0.00962, 0.01049, 0.01028, 0.01022, 0.00904, 0.00941, 0.00989,
                        0.01008, 0.00965, 0.00911, 0.00882, 0.00926, 0.00949, 0.00969,
                        0.01007, 0.01051, 0.01151, 0.01279, 0.01453, 0.01832, 0.02081, 0.01832],
                       [0.00763, 0.00754, 0.00787, 0.00816, 0.00822, 0.00790, 0.00893,
                        0.00942, 0.01023, 0.01015, 0.00950, 0.00882, 0.00904, 0.00939,
                        0.00982, 0.00951, 0.00902, 0.00868, 0.00905, 0.00929, 0.00903,
                        0.00987, 0.01016, 0.01103, 0.01215, 0.01401, 0.01727, 0.01972, 0.01709],
                       [0.00754, 0.00726, 0.00769, 0.00777, 0.00817, 0.00791, 0.00866,
                        0.00931, 0.00984, 0.00979, 0.00890, 0.00863, 0.00864, 0.00906,
                        0.00936, 0.00943, 0.00915, 0.00870, 0.00869, 0.00900, 0.00901,
                        0.00934, 0.01010, 0.01064, 0.01162, 0.01359, 0.01648, 0.01869, 0.01617],
                       [0.00742, 0.00714, 0.00764, 0.00757, 0.00819, 0.00790, 0.00818,
                        0.00892, 0.00949, 0.00946, 0.00889, 0.00836, 0.00833, 0.00894,
                        0.00905, 0.00911, 0.00891, 0.00855, 0.00856, 0.00882, 0.00923,
                        0.00890, 0.01006, 0.01045, 0.01129, 0.01308, 0.01566, 0.01766, 0.01543],
                       [0.00730, 0.00721, 0.00760, 0.00771, 0.00805, 0.00749, 0.00785,
                        0.00863, 0.00932, 0.00907, 0.00884, 0.00826, 0.00837, 0.00908,
                        0.00894, 0.00880, 0.00845, 0.00829, 0.00864, 0.00859, 0.00895,
                        0.00882, 0.00969, 0.01036, 0.01083, 0.01257, 0.01473, 0.01647, 0.01442],
                       [0.00732, 0.00725, 0.00746, 0.00785, 0.00767, 0.00721, 0.00782,
                        0.00845, 0.00908, 0.00884, 0.00872, 0.00832, 0.00842, 0.00910,
                        0.00873, 0.00866, 0.00826, 0.00837, 0.00854, 0.00839, 0.00844,
                        0.00891, 0.00904, 0.01015, 0.01048, 0.01212, 0.01415, 0.01533, 0.01378],
                       [0.00737, 0.00722, 0.00736, 0.00783, 0.00729, 0.00718, 0.00783,
                        0.00810, 0.00873, 0.00891, 0.00843, 0.00819, 0.00814, 0.00874,
                        0.00844, 0.00859, 0.00834, 0.00857, 0.00827, 0.00845, 0.00835,
                        0.00894, 0.00875, 0.00968, 0.01046, 0.01164, 0.01371, 0.01478, 0.01329],
                       [0.00734, 0.00716, 0.00740, 0.00754, 0.00729, 0.00742, 0.00770,
                        0.00771, 0.00837, 0.00866, 0.00800, 0.00795, 0.00789, 0.00822,
                        0.00835, 0.00851, 0.00830, 0.00827, 0.00820, 0.00833, 0.00848,
                        0.00871, 0.00892, 0.00915, 0.01048, 0.01135, 0.01320, 0.01452, 0.01255],
                       [0.00715, 0.00695, 0.00719, 0.00739, 0.00751, 0.00760, 0.00752,
                        0.00775, 0.00808, 0.00824, 0.00798, 0.00785, 0.00790, 0.00808,
                        0.00828, 0.00816, 0.00822, 0.00779, 0.00830, 0.00811, 0.00853,
                        0.00848, 0.00891, 0.00918, 0.01019, 0.01132, 0.01275, 0.01412, 0.01195],
                       [0.00696, 0.00670, 0.00692, 0.00746, 0.00769, 0.00740, 0.00748,
                        0.00802, 0.00815, 0.00841, 0.00798, 0.00811, 0.00798, 0.00814,
                        0.00819, 0.00801, 0.00812, 0.00784, 0.00833, 0.00816, 0.00838,
                        0.00844, 0.00873, 0.00926, 0.00960, 0.01112, 0.01217, 0.01357, 0.01165],
                       [0.00696, 0.00680, 0.00691, 0.00742, 0.00757, 0.00698, 0.00738,
                        0.00789, 0.00853, 0.00843, 0.00783, 0.00820, 0.00784, 0.00802,
                        0.00819, 0.00825, 0.00796, 0.00823, 0.00842, 0.00817, 0.00810,
                        0.00833, 0.00865, 0.00917, 0.00935, 0.01057, 0.01155, 0.01290, 0.01126],
                       [0.00696, 0.00712, 0.00688, 0.00718, 0.00729, 0.00686, 0.00715,
                        0.00765, 0.00851, 0.00801, 0.00788, 0.00797, 0.00783, 0.00798,
                        0.00817, 0.00838, 0.00804, 0.00825, 0.00843, 0.00796, 0.00814,
                        0.00825, 0.00874, 0.00901, 0.00936, 0.01017, 0.01130, 0.01239, 0.01105],
                       [0.00691, 0.00710, 0.00672, 0.00699, 0.00708, 0.00713, 0.00717,
                        0.00761, 0.00807, 0.00784, 0.00775, 0.00759, 0.00797, 0.00794,
                        0.00801, 0.00828, 0.00803, 0.00801, 0.00814, 0.00782, 0.00836,
                        0.00840, 0.00865, 0.00863, 0.00923, 0.01013, 0.01120, 0.01205, 0.01095],
                       [0.00709, 0.00692, 0.00682, 0.00716, 0.00718, 0.00733, 0.00740,
                        0.00759, 0.00777, 0.00788, 0.00765, 0.00741, 0.00780, 0.00778,
                        0.00780, 0.00813, 0.00786, 0.00795, 0.00789, 0.00792, 0.00822,
                        0.00850, 0.00843, 0.00865, 0.00925, 0.00991, 0.01100, 0.01178, 0.01034],
                       [0.00723, 0.00694, 0.00699, 0.00738, 0.00734, 0.00728, 0.00748,
                        0.00744, 0.00745, 0.00776, 0.00767, 0.00757, 0.00754, 0.00747,
                        0.00787, 0.00786, 0.00787, 0.00779, 0.00778, 0.00783, 0.00793,
                        0.00846, 0.00831, 0.00877, 0.00899, 0.00950, 0.01077, 0.01143, 0.00952],
                       [0.00686, 0.00699, 0.00726, 0.00754, 0.00745, 0.00721, 0.00732,
                        0.00732, 0.00725, 0.00781, 0.00761, 0.00770, 0.00757, 0.00751,
                        0.00794, 0.00779, 0.00815, 0.00763, 0.00796, 0.00778, 0.00799,
                        0.00823, 0.00838, 0.00847, 0.00871, 0.00957, 0.01056, 0.01120, 0.00946],
                       [0.00669, 0.00685, 0.00731, 0.00733, 0.00739, 0.00700, 0.00692,
                        0.00726, 0.00742, 0.00781, 0.00743, 0.00756, 0.00770, 0.00766,
                        0.00761, 0.00779, 0.00807, 0.00770, 0.00815, 0.00775, 0.00799,
                        0.00800, 0.00833, 0.00826, 0.00876, 0.00956, 0.01034, 0.01093, 0.00975],
                       [0.00697, 0.00689, 0.00691, 0.00692, 0.00727, 0.00687, 0.00686,
                        0.00724, 0.00769, 0.00763, 0.00755, 0.00753, 0.00781, 0.00774,
                        0.00753, 0.00780, 0.00776, 0.00781, 0.00787, 0.00761, 0.00777,
                        0.00827, 0.00815, 0.00852, 0.00894, 0.00915, 0.01026, 0.01060, 0.00960],
                       [0.00706, 0.00710, 0.00670, 0.00680, 0.00706, 0.00706, 0.00722,
                        0.00710, 0.00761, 0.00767, 0.00763, 0.00750, 0.00773, 0.00779,
                        0.00783, 0.00784, 0.00763, 0.00772, 0.00769, 0.00749, 0.00777,
                        0.00831, 0.00813, 0.00842, 0.00872, 0.00896, 0.01001, 0.01036, 0.00914],
                       [0.00706, 0.00722, 0.00711, 0.00710, 0.00720, 0.00738, 0.00747,
                        0.00712, 0.00736, 0.00783, 0.00755, 0.00754, 0.00753, 0.00780,
                        0.00795, 0.00784, 0.00773, 0.00779, 0.00799, 0.00757, 0.00811,
                        0.00792, 0.00834, 0.00809, 0.00836, 0.00923, 0.00949, 0.01024, 0.00884],
                       [0.00690, 0.00703, 0.00733, 0.00726, 0.00745, 0.00741, 0.00740,
                        0.00723, 0.00735, 0.00761, 0.00733, 0.00760, 0.00737, 0.00760,
                        0.00770, 0.00789, 0.00771, 0.00780, 0.00811, 0.00770, 0.00804,
                        0.00761, 0.00820, 0.00810, 0.00824, 0.00911, 0.00921, 0.01010, 0.00856],
                       [0.00685, 0.00702, 0.00732, 0.00724, 0.00731, 0.00735, 0.00724,
                        0.00734, 0.00743, 0.00753, 0.00722, 0.00760, 0.00747, 0.00742,
                        0.00766, 0.00806, 0.00776, 0.00781, 0.00796, 0.00773, 0.00772,
                        0.00778, 0.00805, 0.00831, 0.00837, 0.00862, 0.00932, 0.00990, 0.00839],
                       [0.00678, 0.00722, 0.00720, 0.00713, 0.00694, 0.00728, 0.00726,
                        0.00735, 0.00733, 0.00778, 0.00718, 0.00757, 0.00751, 0.00739,
                        0.00766, 0.00805, 0.00774, 0.00797, 0.00763, 0.00757, 0.00758,
                        0.00814, 0.00822, 0.00819, 0.00846, 0.00848, 0.00929, 0.00969, 0.00819],
                       [0.00696, 0.00720, 0.00719, 0.00720, 0.00698, 0.00728, 0.00747,
                        0.00736, 0.00736, 0.00786, 0.00735, 0.00766, 0.00751, 0.00738,
                        0.00747, 0.00795, 0.00768, 0.00810, 0.00746, 0.00762, 0.00765,
                        0.00821, 0.00842, 0.00804, 0.00851, 0.00889, 0.00936, 0.00962, 0.00803],
                       [0.00734, 0.00711, 0.00729, 0.00736, 0.00729, 0.00726, 0.00732,
                        0.00727, 0.00757, 0.00770, 0.00747, 0.00759, 0.00748, 0.00741,
                        0.00752, 0.00777, 0.00777, 0.00793, 0.00763, 0.00791, 0.00780,
                        0.00794, 0.00823, 0.00806, 0.00849, 0.00894, 0.00936, 0.00941, 0.00807],
                       [0.00751, 0.00752, 0.00729, 0.00732, 0.00715, 0.00733, 0.00709,
                        0.00708, 0.00780, 0.00753, 0.00751, 0.00754, 0.00741, 0.00766,
                        0.00809, 0.00765, 0.00793, 0.00753, 0.00789, 0.00774, 0.00790,
                        0.00780, 0.00802, 0.00831, 0.00842, 0.00851, 0.00926, 0.00939, 0.00824],
                       [0.00735, 0.00764, 0.00708, 0.00730, 0.00699, 0.00730, 0.00717,
                        0.00710, 0.00774, 0.00746, 0.00755, 0.00758, 0.00747, 0.00791,
                        0.00813, 0.00779, 0.00794, 0.00744, 0.00790, 0.00728, 0.00764,
                        0.00786, 0.00807, 0.00846, 0.00827, 0.00838, 0.00912, 0.00934, 0.00807],
                       [0.00717, 0.00738, 0.00710, 0.00735, 0.00750, 0.00751, 0.00744,
                        0.00751, 0.00745, 0.00776, 0.00774, 0.00755, 0.00758, 0.00778,
                        0.00772, 0.00827, 0.00792, 0.00780, 0.00795, 0.00756, 0.00752,
                        0.00795, 0.00822, 0.00845, 0.00835, 0.00866, 0.00902, 0.00932, 0.00778],
                       [0.00722, 0.00713, 0.00729, 0.00737, 0.00771, 0.00779, 0.00753,
                        0.00770, 0.00728, 0.00782, 0.00783, 0.00761, 0.00753, 0.00756,
                        0.00767, 0.00832, 0.00781, 0.00787, 0.00779, 0.00806, 0.00773,
                        0.00797, 0.00817, 0.00838, 0.00836, 0.00875, 0.00889, 0.00940, 0.00779],
                       ])),
    i2=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                             100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                             180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                             260.0, 270.0, 280.0]),
            lam=np.array([625.18, 625.61, 626.04, 626.47, 626.90, 627.33, 627.76, 628.19,
                          628.62, 629.05, 629.48, 629.91, 630.34, 630.77, 631.20, 631.63,
                          632.06, 632.50, 632.93, 633.36, 633.79, 634.22, 634.65, 635.08,
                          635.51, 635.94, 636.37, 636.81, 637.24, 637.67, 638.10, 638.53,
                          638.96, 639.39, 639.82, 640.26, 640.69, 641.12, 641.55, 641.98,
                          642.41, 642.85, 643.28, 643.71, 644.14, 644.57, 645.00, 645.44,
                          645.87, 646.30, 646.73, 647.16, 647.60, 648.03, 648.46, 648.89,
                          649.33, 649.76, 650.19, 650.62, 651.05, 651.49, 651.92, 652.35,
                          652.78, 653.22, 653.65, 654.08, 654.52, 654.95, 655.38, 655.81,
                          656.25, 656.68, 657.11, 657.55, 657.98, 658.41, 658.84, 659.28,
                          659.71, 660.14, 660.58, 661.01, 661.44, 661.88, 662.31, 662.74,
                          663.18, 663.61, 664.04, 664.48, 664.91, 665.35, 665.78, 666.21,
                          666.65, 667.08, 667.51, 667.95, 668.38, 668.82, 669.25, 669.68,
                          670.12, 670.55, 670.99, 671.42, 671.85, 672.29, 672.72, 673.16,
                          673.59, 674.03, 674.46, 674.89, 675.33, 675.76, 676.20, 676.63,
                          677.07, 677.50, 677.94, 678.37, 678.81, 679.24, 679.68, 680.11,
                          680.55, 680.98, 681.42, 681.85, 682.29, 682.72, 683.16, 683.59,
                          684.03, 684.46, 684.90, 685.33, 685.77, 686.20, 686.64, 687.07,
                          687.51, 687.95, 688.38, 688.82, 689.25, 689.69, 690.12, 690.56,
                          691.00, 691.43, 691.87, 692.30, 692.74, 693.18, 693.61, 694.05,
                          694.48, 694.92, 695.36, 695.79, 696.23, 696.66, 697.10, 697.54,
                          697.97, 698.41, 698.85, 699.28, 699.72, 700.16, 700.59, 701.03,
                          701.47, 701.90, 702.34, 702.78, 703.21, 703.65, 704.09, 704.52,
                          704.96, 705.40, 705.83, 706.27, 706.71, 707.15, 707.58, 708.02,
                          708.46, 708.89, 709.33, 709.77, 710.21, 710.64, 711.08, 711.52,
                          711.96, 712.39, 712.83, 713.27, 713.71, 714.14, 714.58, 715.02,
                          715.46, 715.90, 716.33, 716.77, 717.21, 717.65, 718.09, 718.52,
                          718.96, 719.40, 719.84, 720.28, 720.71, 721.15, 721.59, 722.03,
                          722.47, 722.91, 723.34, 723.78, 724.22, 724.66, 725.10, 725.54,
                          725.97, 726.41, 726.85, 727.29, 727.73, 728.17, 728.61, 729.05,
                          729.49, 729.92, 730.36, 730.80, 731.24, 731.68, 732.12, 732.56,
                          733.00, 733.44, 733.88, 734.31, 734.75, 735.19, 735.63, 736.07,
                          736.51, 736.95, 737.39, 737.83, 738.27, 738.71, 739.15, 739.59,
                          740.03, 740.47, 740.91, 741.35, 741.79, 742.23, 742.67, 743.11,
                          743.55, 743.99, 744.43, 744.87, 745.31, 745.75, 746.19, 746.63,
                          747.07, 747.51, 747.95, 748.39, 748.83, 749.27, 749.71, 750.15,
                          750.59, 751.03, 751.47, 751.91, 752.35, 752.79, 753.23, 753.68,
                          754.12, 754.56, 755.00, 755.44, 755.88, 756.32, 756.76, 757.20,
                          757.64, 758.08, 758.53, 758.97, 759.41, 759.85, 760.29, 760.73,
                          761.17, 761.61, 762.06, 762.50, 762.94, 763.38, 763.82, 764.26,
                          764.70, 765.15, 765.59, 766.03, 766.47, 766.91, 767.35, 767.80,
                          768.24, 768.68, 769.12, 769.56, 770.00, 770.45, 770.89, 771.33,
                          771.77, 772.21, 772.66, 773.10, 773.54, 773.98, 774.43, 774.87,
                          775.31, 775.75, 776.19, 776.64, 777.08, 777.52, 777.96, 778.41,
                          778.85, 779.29, 779.73, 780.18, 780.62, 781.06, 781.50, 781.95,
                          782.39, 782.83, 783.28, 783.72, 784.16, 784.60, 785.05, 785.49,
                          785.93, 786.38, 786.82, 787.26, 787.71, 788.15, 788.59, 789.04,
                          789.48, 789.92, 790.37, 790.81, 791.25, 791.70, 792.14, 792.58,
                          793.03, 793.47, 793.91, 794.36, 794.80, 795.24, 795.69, 796.13,
                          796.57, 797.02, 797.46, 797.91, 798.35, 798.79, 799.24, 799.68,
                          800.13, 800.57, 801.01, 801.46, 801.90, 802.35, 802.79, 803.23,
                          803.68, 804.12, 804.57, 805.01, 805.46, 805.90, 806.34, 806.79,
                          807.23, 807.68, 808.12, 808.57, 809.01, 809.46, 809.90, 810.35,
                          810.79, 811.23, 811.68, 812.12, 812.57, 813.01, 813.46, 813.90,
                          814.35, 814.79, 815.24, 815.68, 816.13, 816.57, 817.02, 817.46,
                          817.91, 818.35, 818.80, 819.24, 819.69, 820.14, 820.58, 821.03,
                          821.47, 821.92, 822.36, 822.81, 823.25, 823.70, 824.14, 824.59,
                          825.03, 825.48, 825.93, 826.37, 826.82, 827.26, 827.71, 828.15,
                          828.60, 829.05, 829.49, 829.94, 830.38, 830.83, 831.28, 831.72,
                          832.17, 832.61, 833.06, 833.51, 833.95, 834.40, 834.84, 835.29,
                          835.74, 836.18, 836.63, 837.08, 837.52, 837.97, 838.42, 838.86,
                          839.31, 839.75, 840.20, 840.65, 841.09, 841.54, 841.99, 842.43,
                          842.88, 843.33, 843.77, 844.22, 844.67, 845.11, 845.56, 846.01,
                          846.46, 846.90, 847.35, 847.80, 848.24, 848.69, 849.14, 849.58,
                          850.03, 850.48, 850.93, 851.37, 851.82, 852.27, 852.71, 853.16,
                          853.61, 854.06, 854.50, 854.95, 855.40, 855.85, 856.29, 856.74,
                          857.19, 857.64, 858.08, 858.53, 858.98, 859.43, 859.87, 860.32,
                          860.77, 861.22, 861.67, 862.11, 862.56, 863.01, 863.46, 863.90,
                          864.35, 864.80, 865.25, 865.70, 866.14, 866.59, 867.04, 867.49,
                          867.94, 868.38, 868.83, 869.28, 869.73, 870.18, 870.63, 871.07,
                          871.52, 871.97, 872.42, 872.87, 873.32, 873.76, 874.21, 874.66,
                          875.11, 875.56, 876.01, 876.46, 876.90, 877.35, 877.80, 878.25,
                          878.70, 879.15, 879.60]),
            T=np.array([[0.00206, 0.00217, 0.00219, 0.00227, 0.00229, 0.00208, 0.00197,
                         0.00225, 0.00205, 0.00218, 0.00225, 0.00209, 0.00217, 0.00230,
                         0.00205, 0.00231, 0.00220, 0.00221, 0.00220, 0.00220, 0.00196,
                         0.00235, 0.00208, 0.00212, 0.00207, 0.00214, 0.00225, 0.00226, 0.00199],
                        [0.00215, 0.00212, 0.00227, 0.00204, 0.00219, 0.00210, 0.00199,
                         0.00220, 0.00188, 0.00213, 0.00223, 0.00214, 0.00222, 0.00220,
                         0.00219, 0.00211, 0.00225, 0.00217, 0.00209, 0.00218, 0.00211,
                         0.00209, 0.00221, 0.00216, 0.00214, 0.00222, 0.00227, 0.00230, 0.00213],
                        [0.00223, 0.00207, 0.00228, 0.00194, 0.00210, 0.00228, 0.00216,
                         0.00223, 0.00195, 0.00211, 0.00216, 0.00219, 0.00234, 0.00211,
                         0.00228, 0.00206, 0.00224, 0.00215, 0.00217, 0.00215, 0.00225,
                         0.00206, 0.00236, 0.00225, 0.00232, 0.00228, 0.00227, 0.00235, 0.00226],
                        [0.00217, 0.00211, 0.00213, 0.00214, 0.00221, 0.00230, 0.00234,
                         0.00221, 0.00227, 0.00213, 0.00217, 0.00222, 0.00229, 0.00214,
                         0.00220, 0.00225, 0.00217, 0.00223, 0.00218, 0.00223, 0.00225,
                         0.00214, 0.00229, 0.00216, 0.00229, 0.00215, 0.00225, 0.00244, 0.00215],
                        [0.00216, 0.00215, 0.00197, 0.00234, 0.00237, 0.00219, 0.00237,
                         0.00218, 0.00248, 0.00212, 0.00229, 0.00217, 0.00220, 0.00229,
                         0.00214, 0.00233, 0.00214, 0.00223, 0.00209, 0.00229, 0.00228,
                         0.00216, 0.00220, 0.00209, 0.00208, 0.00216, 0.00232, 0.00242, 0.00203],
                        [0.00230, 0.00217, 0.00202, 0.00227, 0.00232, 0.00218, 0.00219,
                         0.00224, 0.00234, 0.00211, 0.00238, 0.00224, 0.00230, 0.00223,
                         0.00221, 0.00228, 0.00218, 0.00216, 0.00209, 0.00228, 0.00218,
                         0.00219, 0.00221, 0.00225, 0.00208, 0.00222, 0.00238, 0.00231, 0.00210],
                        [0.00233, 0.00221, 0.00225, 0.00211, 0.00215, 0.00230, 0.00210,
                         0.00225, 0.00219, 0.00229, 0.00224, 0.00233, 0.00229, 0.00219,
                         0.00230, 0.00227, 0.00233, 0.00220, 0.00218, 0.00225, 0.00211,
                         0.00226, 0.00221, 0.00241, 0.00232, 0.00217, 0.00230, 0.00234, 0.00230],
                        [0.00218, 0.00222, 0.00235, 0.00203, 0.00209, 0.00230, 0.00220,
                         0.00211, 0.00215, 0.00242, 0.00215, 0.00223, 0.00225, 0.00221,
                         0.00233, 0.00232, 0.00233, 0.00234, 0.00223, 0.00223, 0.00217,
                         0.00222, 0.00222, 0.00233, 0.00246, 0.00218, 0.00227, 0.00243, 0.00239],
                        [0.00221, 0.00228, 0.00240, 0.00215, 0.00223, 0.00222, 0.00227,
                         0.00217, 0.00213, 0.00236, 0.00232, 0.00223, 0.00228, 0.00223,
                         0.00242, 0.00243, 0.00219, 0.00238, 0.00233, 0.00218, 0.00216,
                         0.00210, 0.00227, 0.00227, 0.00243, 0.00237, 0.00236, 0.00253, 0.00231],
                        [0.00231, 0.00232, 0.00246, 0.00234, 0.00217, 0.00230, 0.00231,
                         0.00236, 0.00215, 0.00223, 0.00248, 0.00228, 0.00230, 0.00230,
                         0.00240, 0.00238, 0.00223, 0.00224, 0.00244, 0.00226, 0.00222,
                         0.00206, 0.00227, 0.00233, 0.00233, 0.00247, 0.00241, 0.00256, 0.00222],
                        [0.00233, 0.00224, 0.00243, 0.00243, 0.00201, 0.00246, 0.00249,
                         0.00237, 0.00229, 0.00218, 0.00237, 0.00225, 0.00234, 0.00236,
                         0.00224, 0.00221, 0.00245, 0.00218, 0.00241, 0.00240, 0.00241,
                         0.00221, 0.00238, 0.00240, 0.00232, 0.00238, 0.00253, 0.00253, 0.00215],
                        [0.00234, 0.00225, 0.00241, 0.00244, 0.00223, 0.00251, 0.00246,
                         0.00223, 0.00246, 0.00221, 0.00222, 0.00236, 0.00232, 0.00232,
                         0.00217, 0.00219, 0.00248, 0.00227, 0.00226, 0.00235, 0.00240,
                         0.00229, 0.00253, 0.00241, 0.00240, 0.00231, 0.00252, 0.00246, 0.00221],
                        [0.00229, 0.00236, 0.00249, 0.00244, 0.00248, 0.00238, 0.00227,
                         0.00221, 0.00243, 0.00232, 0.00224, 0.00242, 0.00234, 0.00226,
                         0.00220, 0.00240, 0.00232, 0.00240, 0.00226, 0.00237, 0.00225,
                         0.00233, 0.00247, 0.00232, 0.00245, 0.00241, 0.00239, 0.00250, 0.00244],
                        [0.00224, 0.00243, 0.00250, 0.00241, 0.00241, 0.00232, 0.00226,
                         0.00231, 0.00225, 0.00238, 0.00237, 0.00232, 0.00243, 0.00235,
                         0.00220, 0.00256, 0.00228, 0.00239, 0.00245, 0.00254, 0.00223,
                         0.00235, 0.00224, 0.00237, 0.00235, 0.00247, 0.00231, 0.00259, 0.00253],
                        [0.00240, 0.00243, 0.00247, 0.00235, 0.00238, 0.00249, 0.00233,
                         0.00239, 0.00227, 0.00246, 0.00259, 0.00246, 0.00245, 0.00239,
                         0.00224, 0.00248, 0.00246, 0.00238, 0.00266, 0.00263, 0.00247,
                         0.00229, 0.00227, 0.00256, 0.00228, 0.00253, 0.00233, 0.00259, 0.00252],
                        [0.00255, 0.00233, 0.00249, 0.00235, 0.00247, 0.00246, 0.00244,
                         0.00243, 0.00237, 0.00255, 0.00256, 0.00262, 0.00239, 0.00228,
                         0.00241, 0.00236, 0.00256, 0.00242, 0.00253, 0.00245, 0.00263,
                         0.00227, 0.00256, 0.00250, 0.00239, 0.00253, 0.00244, 0.00256, 0.00252],
                        [0.00253, 0.00240, 0.00254, 0.00250, 0.00247, 0.00241, 0.00259,
                         0.00243, 0.00248, 0.00257, 0.00239, 0.00257, 0.00240, 0.00233,
                         0.00261, 0.00248, 0.00257, 0.00249, 0.00234, 0.00230, 0.00259,
                         0.00233, 0.00261, 0.00248, 0.00261, 0.00249, 0.00253, 0.00267, 0.00254],
                        [0.00248, 0.00258, 0.00258, 0.00267, 0.00245, 0.00255, 0.00266,
                         0.00244, 0.00257, 0.00249, 0.00247, 0.00250, 0.00251, 0.00256,
                         0.00252, 0.00259, 0.00251, 0.00254, 0.00243, 0.00248, 0.00252,
                         0.00249, 0.00242, 0.00263, 0.00267, 0.00266, 0.00256, 0.00273, 0.00257],
                        [0.00256, 0.00266, 0.00270, 0.00263, 0.00263, 0.00265, 0.00262,
                         0.00251, 0.00254, 0.00248, 0.00260, 0.00240, 0.00252, 0.00272,
                         0.00236, 0.00247, 0.00238, 0.00243, 0.00261, 0.00277, 0.00239,
                         0.00257, 0.00244, 0.00263, 0.00259, 0.00275, 0.00264, 0.00269, 0.00259],
                        [0.00258, 0.00269, 0.00276, 0.00248, 0.00277, 0.00263, 0.00252,
                         0.00255, 0.00253, 0.00253, 0.00259, 0.00241, 0.00244, 0.00275,
                         0.00251, 0.00249, 0.00241, 0.00238, 0.00269, 0.00272, 0.00241,
                         0.00254, 0.00261, 0.00259, 0.00260, 0.00259, 0.00268, 0.00270, 0.00268],
                        [0.00251, 0.00262, 0.00265, 0.00247, 0.00263, 0.00263, 0.00253,
                         0.00262, 0.00258, 0.00244, 0.00253, 0.00268, 0.00250, 0.00265,
                         0.00261, 0.00262, 0.00258, 0.00258, 0.00256, 0.00249, 0.00261,
                         0.00259, 0.00266, 0.00264, 0.00263, 0.00257, 0.00272, 0.00274, 0.00275],
                        [0.00260, 0.00254, 0.00256, 0.00261, 0.00264, 0.00277, 0.00262,
                         0.00263, 0.00255, 0.00243, 0.00249, 0.00277, 0.00270, 0.00259,
                         0.00242, 0.00259, 0.00268, 0.00275, 0.00251, 0.00258, 0.00262,
                         0.00270, 0.00260, 0.00274, 0.00273, 0.00264, 0.00272, 0.00276, 0.00270],
                        [0.00278, 0.00257, 0.00261, 0.00269, 0.00283, 0.00285, 0.00273,
                         0.00255, 0.00258, 0.00257, 0.00264, 0.00267, 0.00280, 0.00256,
                         0.00246, 0.00260, 0.00270, 0.00269, 0.00276, 0.00278, 0.00259,
                         0.00272, 0.00274, 0.00280, 0.00284, 0.00257, 0.00270, 0.00279, 0.00256],
                        [0.00275, 0.00269, 0.00270, 0.00266, 0.00283, 0.00275, 0.00282,
                         0.00267, 0.00272, 0.00260, 0.00279, 0.00270, 0.00268, 0.00253,
                         0.00273, 0.00266, 0.00272, 0.00265, 0.00296, 0.00286, 0.00261,
                         0.00271, 0.00286, 0.00275, 0.00276, 0.00257, 0.00276, 0.00283, 0.00250],
                        [0.00267, 0.00282, 0.00282, 0.00267, 0.00270, 0.00274, 0.00280,
                         0.00285, 0.00277, 0.00266, 0.00273, 0.00273, 0.00259, 0.00258,
                         0.00281, 0.00266, 0.00267, 0.00280, 0.00281, 0.00274, 0.00259,
                         0.00277, 0.00274, 0.00268, 0.00265, 0.00274, 0.00279, 0.00285, 0.00257],
                        [0.00261, 0.00284, 0.00280, 0.00274, 0.00274, 0.00284, 0.00282,
                         0.00280, 0.00284, 0.00282, 0.00266, 0.00274, 0.00255, 0.00271,
                         0.00280, 0.00272, 0.00265, 0.00291, 0.00258, 0.00260, 0.00261,
                         0.00283, 0.00268, 0.00265, 0.00263, 0.00292, 0.00282, 0.00289, 0.00258],
                        [0.00258, 0.00279, 0.00261, 0.00283, 0.00276, 0.00280, 0.00271,
                         0.00278, 0.00289, 0.00278, 0.00277, 0.00274, 0.00273, 0.00283,
                         0.00273, 0.00277, 0.00270, 0.00280, 0.00273, 0.00265, 0.00267,
                         0.00283, 0.00278, 0.00271, 0.00271, 0.00286, 0.00287, 0.00288, 0.00264],
                        [0.00270, 0.00270, 0.00256, 0.00281, 0.00276, 0.00270, 0.00243,
                         0.00284, 0.00272, 0.00269, 0.00280, 0.00269, 0.00293, 0.00278,
                         0.00263, 0.00279, 0.00269, 0.00264, 0.00291, 0.00275, 0.00277,
                         0.00277, 0.00285, 0.00283, 0.00289, 0.00271, 0.00277, 0.00281, 0.00284],
                        [0.00286, 0.00264, 0.00267, 0.00274, 0.00284, 0.00265, 0.00246,
                         0.00281, 0.00253, 0.00268, 0.00274, 0.00266, 0.00285, 0.00268,
                         0.00273, 0.00286, 0.00265, 0.00265, 0.00281, 0.00279, 0.00282,
                         0.00272, 0.00281, 0.00289, 0.00293, 0.00274, 0.00266, 0.00271, 0.00288],
                        [0.00282, 0.00277, 0.00281, 0.00282, 0.00278, 0.00273, 0.00274,
                         0.00271, 0.00262, 0.00268, 0.00281, 0.00272, 0.00276, 0.00276,
                         0.00280, 0.00297, 0.00270, 0.00278, 0.00269, 0.00280, 0.00280,
                         0.00266, 0.00278, 0.00276, 0.00276, 0.00282, 0.00274, 0.00262, 0.00281],
                        [0.00275, 0.00292, 0.00281, 0.00278, 0.00273, 0.00291, 0.00292,
                         0.00270, 0.00286, 0.00279, 0.00288, 0.00276, 0.00289, 0.00281,
                         0.00278, 0.00297, 0.00283, 0.00290, 0.00277, 0.00284, 0.00285,
                         0.00270, 0.00282, 0.00262, 0.00276, 0.00281, 0.00287, 0.00272, 0.00285],
                        [0.00282, 0.00291, 0.00282, 0.00274, 0.00273, 0.00290, 0.00292,
                         0.00289, 0.00297, 0.00295, 0.00286, 0.00280, 0.00307, 0.00274,
                         0.00280, 0.00280, 0.00292, 0.00292, 0.00293, 0.00290, 0.00290,
                         0.00287, 0.00287, 0.00273, 0.00290, 0.00287, 0.00294, 0.00294, 0.00290],
                        [0.00291, 0.00284, 0.00286, 0.00293, 0.00279, 0.00270, 0.00281,
                         0.00302, 0.00291, 0.00297, 0.00284, 0.00282, 0.00299, 0.00275,
                         0.00293, 0.00270, 0.00293, 0.00280, 0.00303, 0.00293, 0.00292,
                         0.00289, 0.00294, 0.00288, 0.00292, 0.00298, 0.00299, 0.00300, 0.00291],
                        [0.00275, 0.00290, 0.00284, 0.00299, 0.00290, 0.00264, 0.00271,
                         0.00296, 0.00286, 0.00288, 0.00289, 0.00282, 0.00275, 0.00292,
                         0.00308, 0.00281, 0.00286, 0.00279, 0.00294, 0.00291, 0.00283,
                         0.00287, 0.00307, 0.00288, 0.00292, 0.00291, 0.00301, 0.00292, 0.00298],
                        [0.00259, 0.00304, 0.00285, 0.00290, 0.00299, 0.00284, 0.00277,
                         0.00287, 0.00285, 0.00277, 0.00294, 0.00291, 0.00270, 0.00302,
                         0.00301, 0.00297, 0.00287, 0.00288, 0.00282, 0.00287, 0.00274,
                         0.00302, 0.00307, 0.00294, 0.00300, 0.00287, 0.00298, 0.00288, 0.00307],
                        [0.00269, 0.00301, 0.00285, 0.00290, 0.00291, 0.00299, 0.00296,
                         0.00280, 0.00287, 0.00277, 0.00287, 0.00293, 0.00284, 0.00301,
                         0.00285, 0.00306, 0.00287, 0.00287, 0.00289, 0.00290, 0.00292,
                         0.00310, 0.00285, 0.00307, 0.00303, 0.00302, 0.00293, 0.00296, 0.00314],
                        [0.00293, 0.00291, 0.00285, 0.00291, 0.00286, 0.00296, 0.00307,
                         0.00280, 0.00292, 0.00292, 0.00278, 0.00278, 0.00301, 0.00297,
                         0.00288, 0.00295, 0.00283, 0.00298, 0.00306, 0.00299, 0.00316,
                         0.00299, 0.00280, 0.00312, 0.00302, 0.00309, 0.00298, 0.00308, 0.00321],
                        [0.00292, 0.00290, 0.00289, 0.00284, 0.00297, 0.00298, 0.00297,
                         0.00288, 0.00291, 0.00304, 0.00288, 0.00275, 0.00305, 0.00298,
                         0.00303, 0.00286, 0.00289, 0.00308, 0.00307, 0.00303, 0.00309,
                         0.00302, 0.00299, 0.00300, 0.00299, 0.00305, 0.00303, 0.00304, 0.00322],
                        [0.00270, 0.00293, 0.00290, 0.00277, 0.00305, 0.00299, 0.00286,
                         0.00292, 0.00275, 0.00300, 0.00297, 0.00290, 0.00287, 0.00304,
                         0.00314, 0.00295, 0.00299, 0.00297, 0.00294, 0.00297, 0.00293,
                         0.00318, 0.00307, 0.00295, 0.00297, 0.00315, 0.00309, 0.00300, 0.00312],
                        [0.00283, 0.00294, 0.00293, 0.00276, 0.00309, 0.00286, 0.00291,
                         0.00293, 0.00269, 0.00286, 0.00296, 0.00297, 0.00282, 0.00306,
                         0.00308, 0.00305, 0.00304, 0.00291, 0.00287, 0.00287, 0.00285,
                         0.00326, 0.00298, 0.00305, 0.00300, 0.00323, 0.00313, 0.00313, 0.00305],
                        [0.00307, 0.00294, 0.00298, 0.00280, 0.00309, 0.00276, 0.00295,
                         0.00301, 0.00285, 0.00274, 0.00291, 0.00299, 0.00301, 0.00309,
                         0.00290, 0.00305, 0.00302, 0.00289, 0.00295, 0.00292, 0.00287,
                         0.00306, 0.00296, 0.00312, 0.00297, 0.00316, 0.00300, 0.00318, 0.00311],
                        [0.00298, 0.00291, 0.00298, 0.00293, 0.00301, 0.00290, 0.00289,
                         0.00301, 0.00302, 0.00281, 0.00297, 0.00299, 0.00309, 0.00309,
                         0.00285, 0.00298, 0.00300, 0.00286, 0.00289, 0.00297, 0.00303,
                         0.00282, 0.00300, 0.00307, 0.00297, 0.00304, 0.00296, 0.00298, 0.00322],
                        [0.00288, 0.00299, 0.00295, 0.00307, 0.00295, 0.00307, 0.00295,
                         0.00299, 0.00310, 0.00294, 0.00309, 0.00297, 0.00300, 0.00288,
                         0.00298, 0.00305, 0.00299, 0.00308, 0.00280, 0.00289, 0.00309,
                         0.00289, 0.00300, 0.00308, 0.00311, 0.00296, 0.00307, 0.00292, 0.00333],
                        [0.00296, 0.00306, 0.00295, 0.00295, 0.00300, 0.00304, 0.00305,
                         0.00300, 0.00302, 0.00294, 0.00301, 0.00291, 0.00293, 0.00267,
                         0.00308, 0.00304, 0.00289, 0.00319, 0.00300, 0.00278, 0.00298,
                         0.00303, 0.00303, 0.00312, 0.00312, 0.00299, 0.00306, 0.00310, 0.00340],
                        [0.00298, 0.00299, 0.00304, 0.00277, 0.00301, 0.00296, 0.00299,
                         0.00295, 0.00294, 0.00299, 0.00288, 0.00290, 0.00299, 0.00280,
                         0.00308, 0.00288, 0.00282, 0.00301, 0.00315, 0.00286, 0.00295,
                         0.00310, 0.00312, 0.00307, 0.00303, 0.00301, 0.00294, 0.00315, 0.00339],
                        [0.00284, 0.00293, 0.00318, 0.00292, 0.00301, 0.00308, 0.00286,
                         0.00294, 0.00291, 0.00310, 0.00294, 0.00310, 0.00300, 0.00313,
                         0.00307, 0.00298, 0.00291, 0.00299, 0.00305, 0.00314, 0.00305,
                         0.00311, 0.00317, 0.00306, 0.00305, 0.00305, 0.00297, 0.00305, 0.00335],
                        [0.00276, 0.00293, 0.00315, 0.00308, 0.00312, 0.00309, 0.00287,
                         0.00303, 0.00282, 0.00311, 0.00307, 0.00318, 0.00279, 0.00313,
                         0.00305, 0.00317, 0.00300, 0.00302, 0.00294, 0.00317, 0.00306,
                         0.00301, 0.00315, 0.00303, 0.00304, 0.00314, 0.00300, 0.00297, 0.00332],
                        [0.00290, 0.00307, 0.00306, 0.00306, 0.00321, 0.00294, 0.00307,
                         0.00320, 0.00291, 0.00309, 0.00316, 0.00300, 0.00279, 0.00298,
                         0.00312, 0.00307, 0.00300, 0.00305, 0.00292, 0.00305, 0.00306,
                         0.00302, 0.00313, 0.00301, 0.00308, 0.00317, 0.00302, 0.00308, 0.00345],
                        [0.00301, 0.00312, 0.00308, 0.00308, 0.00310, 0.00285, 0.00318,
                         0.00324, 0.00311, 0.00305, 0.00309, 0.00291, 0.00299, 0.00295,
                         0.00306, 0.00297, 0.00298, 0.00315, 0.00288, 0.00308, 0.00303,
                         0.00310, 0.00313, 0.00299, 0.00309, 0.00294, 0.00298, 0.00317, 0.00364],
                        [0.00299, 0.00305, 0.00306, 0.00315, 0.00305, 0.00293, 0.00308,
                         0.00317, 0.00318, 0.00303, 0.00305, 0.00309, 0.00303, 0.00298,
                         0.00289, 0.00311, 0.00305, 0.00317, 0.00293, 0.00312, 0.00299,
                         0.00315, 0.00316, 0.00292, 0.00306, 0.00287, 0.00294, 0.00308, 0.00364],
                        [0.00292, 0.00297, 0.00296, 0.00301, 0.00311, 0.00305, 0.00300,
                         0.00302, 0.00309, 0.00307, 0.00306, 0.00319, 0.00288, 0.00298,
                         0.00297, 0.00308, 0.00308, 0.00321, 0.00306, 0.00300, 0.00302,
                         0.00312, 0.00311, 0.00288, 0.00313, 0.00315, 0.00300, 0.00307, 0.00350],
                        [0.00292, 0.00299, 0.00306, 0.00288, 0.00306, 0.00301, 0.00300,
                         0.00291, 0.00303, 0.00314, 0.00304, 0.00310, 0.00279, 0.00300,
                         0.00315, 0.00291, 0.00300, 0.00325, 0.00308, 0.00302, 0.00307,
                         0.00302, 0.00307, 0.00303, 0.00325, 0.00334, 0.00314, 0.00314, 0.00346],
                        [0.00285, 0.00302, 0.00323, 0.00294, 0.00296, 0.00302, 0.00296,
                         0.00294, 0.00297, 0.00308, 0.00306, 0.00296, 0.00294, 0.00309,
                         0.00308, 0.00280, 0.00292, 0.00314, 0.00297, 0.00310, 0.00305,
                         0.00305, 0.00307, 0.00318, 0.00322, 0.00311, 0.00322, 0.00309, 0.00358],
                        [0.00278, 0.00293, 0.00314, 0.00299, 0.00288, 0.00312, 0.00292,
                         0.00305, 0.00285, 0.00291, 0.00308, 0.00298, 0.00308, 0.00308,
                         0.00295, 0.00282, 0.00293, 0.00295, 0.00296, 0.00307, 0.00292,
                         0.00319, 0.00300, 0.00301, 0.00312, 0.00279, 0.00308, 0.00296, 0.00364],
                        [0.00296, 0.00284, 0.00299, 0.00297, 0.00282, 0.00304, 0.00296,
                         0.00307, 0.00283, 0.00285, 0.00297, 0.00314, 0.00294, 0.00296,
                         0.00293, 0.00287, 0.00299, 0.00286, 0.00299, 0.00306, 0.00284,
                         0.00312, 0.00298, 0.00284, 0.00307, 0.00279, 0.00301, 0.00294, 0.00360],
                        [0.00300, 0.00287, 0.00296, 0.00292, 0.00284, 0.00288, 0.00302,
                         0.00299, 0.00293, 0.00293, 0.00288, 0.00324, 0.00279, 0.00299,
                         0.00302, 0.00290, 0.00307, 0.00296, 0.00293, 0.00307, 0.00299,
                         0.00295, 0.00302, 0.00291, 0.00314, 0.00294, 0.00307, 0.00310, 0.00370],
                        [0.00284, 0.00293, 0.00295, 0.00290, 0.00287, 0.00283, 0.00298,
                         0.00289, 0.00288, 0.00296, 0.00296, 0.00311, 0.00284, 0.00297,
                         0.00306, 0.00291, 0.00312, 0.00304, 0.00290, 0.00297, 0.00306,
                         0.00292, 0.00297, 0.00293, 0.00329, 0.00304, 0.00302, 0.00316, 0.00372],
                        [0.00275, 0.00299, 0.00303, 0.00302, 0.00292, 0.00289, 0.00287,
                         0.00292, 0.00279, 0.00298, 0.00302, 0.00290, 0.00298, 0.00287,
                         0.00295, 0.00302, 0.00313, 0.00300, 0.00295, 0.00297, 0.00306,
                         0.00297, 0.00299, 0.00291, 0.00321, 0.00318, 0.00293, 0.00295, 0.00371],
                        [0.00275, 0.00303, 0.00311, 0.00304, 0.00298, 0.00302, 0.00294,
                         0.00302, 0.00290, 0.00302, 0.00295, 0.00297, 0.00295, 0.00288,
                         0.00289, 0.00310, 0.00296, 0.00296, 0.00300, 0.00308, 0.00304,
                         0.00295, 0.00309, 0.00295, 0.00297, 0.00320, 0.00293, 0.00286, 0.00392],
                        [0.00283, 0.00293, 0.00303, 0.00296, 0.00294, 0.00310, 0.00302,
                         0.00293, 0.00299, 0.00302, 0.00287, 0.00309, 0.00280, 0.00290,
                         0.00295, 0.00297, 0.00280, 0.00297, 0.00302, 0.00311, 0.00298,
                         0.00290, 0.00301, 0.00298, 0.00294, 0.00304, 0.00303, 0.00298, 0.00408],
                        [0.00293, 0.00280, 0.00287, 0.00302, 0.00284, 0.00306, 0.00301,
                         0.00289, 0.00295, 0.00306, 0.00291, 0.00301, 0.00284, 0.00289,
                         0.00299, 0.00292, 0.00287, 0.00299, 0.00298, 0.00303, 0.00303,
                         0.00287, 0.00296, 0.00300, 0.00312, 0.00296, 0.00302, 0.00310, 0.00399],
                        [0.00290, 0.00290, 0.00285, 0.00307, 0.00276, 0.00289, 0.00299,
                         0.00309, 0.00293, 0.00297, 0.00291, 0.00300, 0.00292, 0.00289,
                         0.00296, 0.00300, 0.00307, 0.00290, 0.00296, 0.00306, 0.00312,
                         0.00291, 0.00313, 0.00304, 0.00317, 0.00294, 0.00283, 0.00309, 0.00399],
                        [0.00280, 0.00307, 0.00287, 0.00308, 0.00280, 0.00278, 0.00308,
                         0.00317, 0.00300, 0.00286, 0.00287, 0.00311, 0.00290, 0.00293,
                         0.00297, 0.00304, 0.00315, 0.00290, 0.00303, 0.00322, 0.00315,
                         0.00304, 0.00321, 0.00302, 0.00309, 0.00293, 0.00284, 0.00307, 0.00416],
                        [0.00279, 0.00308, 0.00295, 0.00312, 0.00290, 0.00291, 0.00313,
                         0.00305, 0.00305, 0.00298, 0.00291, 0.00308, 0.00302, 0.00298,
                         0.00304, 0.00295, 0.00302, 0.00303, 0.00314, 0.00320, 0.00310,
                         0.00310, 0.00310, 0.00293, 0.00306, 0.00298, 0.00301, 0.00304, 0.00419],
                        [0.00287, 0.00300, 0.00307, 0.00307, 0.00301, 0.00305, 0.00306,
                         0.00300, 0.00311, 0.00310, 0.00296, 0.00298, 0.00312, 0.00305,
                         0.00324, 0.00290, 0.00292, 0.00309, 0.00318, 0.00306, 0.00303,
                         0.00300, 0.00301, 0.00296, 0.00317, 0.00304, 0.00318, 0.00300, 0.00411],
                        [0.00307, 0.00299, 0.00304, 0.00304, 0.00305, 0.00307, 0.00296,
                         0.00300, 0.00309, 0.00308, 0.00296, 0.00297, 0.00301, 0.00303,
                         0.00316, 0.00303, 0.00299, 0.00291, 0.00308, 0.00297, 0.00295,
                         0.00291, 0.00299, 0.00298, 0.00320, 0.00300, 0.00325, 0.00312, 0.00407],
                        [0.00311, 0.00299, 0.00301, 0.00306, 0.00295, 0.00307, 0.00289,
                         0.00298, 0.00289, 0.00307, 0.00300, 0.00299, 0.00287, 0.00281,
                         0.00298, 0.00316, 0.00311, 0.00282, 0.00294, 0.00291, 0.00298,
                         0.00302, 0.00295, 0.00293, 0.00303, 0.00293, 0.00320, 0.00316, 0.00420],
                        [0.00294, 0.00300, 0.00304, 0.00301, 0.00291, 0.00306, 0.00292,
                         0.00291, 0.00276, 0.00305, 0.00310, 0.00298, 0.00287, 0.00275,
                         0.00304, 0.00324, 0.00320, 0.00300, 0.00291, 0.00290, 0.00310,
                         0.00314, 0.00297, 0.00296, 0.00292, 0.00287, 0.00297, 0.00309, 0.00442],
                        [0.00285, 0.00312, 0.00302, 0.00292, 0.00300, 0.00298, 0.00298,
                         0.00281, 0.00282, 0.00300, 0.00313, 0.00299, 0.00301, 0.00300,
                         0.00303, 0.00326, 0.00315, 0.00313, 0.00296, 0.00291, 0.00306,
                         0.00303, 0.00303, 0.00303, 0.00307, 0.00273, 0.00278, 0.00301, 0.00457],
                        [0.00285, 0.00306, 0.00292, 0.00290, 0.00304, 0.00296, 0.00303,
                         0.00289, 0.00293, 0.00289, 0.00297, 0.00309, 0.00315, 0.00315,
                         0.00294, 0.00307, 0.00287, 0.00307, 0.00303, 0.00293, 0.00299,
                         0.00284, 0.00303, 0.00311, 0.00315, 0.00272, 0.00291, 0.00300, 0.00456],
                        [0.00284, 0.00281, 0.00280, 0.00290, 0.00293, 0.00296, 0.00305,
                         0.00304, 0.00288, 0.00279, 0.00285, 0.00325, 0.00307, 0.00296,
                         0.00302, 0.00289, 0.00275, 0.00296, 0.00297, 0.00287, 0.00298,
                         0.00273, 0.00298, 0.00304, 0.00304, 0.00289, 0.00300, 0.00299, 0.00443],
                        [0.00296, 0.00287, 0.00290, 0.00305, 0.00295, 0.00292, 0.00296,
                         0.00300, 0.00287, 0.00297, 0.00302, 0.00322, 0.00295, 0.00287,
                         0.00314, 0.00290, 0.00298, 0.00295, 0.00301, 0.00299, 0.00305,
                         0.00287, 0.00302, 0.00300, 0.00300, 0.00309, 0.00301, 0.00294, 0.00453],
                        [0.00301, 0.00311, 0.00303, 0.00309, 0.00307, 0.00295, 0.00286,
                         0.00285, 0.00293, 0.00313, 0.00308, 0.00292, 0.00295, 0.00302,
                         0.00301, 0.00288, 0.00308, 0.00298, 0.00306, 0.00317, 0.00306,
                         0.00312, 0.00303, 0.00300, 0.00290, 0.00305, 0.00302, 0.00291, 0.00474],
                        [0.00297, 0.00314, 0.00295, 0.00300, 0.00312, 0.00302, 0.00294,
                         0.00294, 0.00289, 0.00312, 0.00296, 0.00281, 0.00296, 0.00308,
                         0.00282, 0.00292, 0.00303, 0.00298, 0.00298, 0.00316, 0.00302,
                         0.00315, 0.00293, 0.00296, 0.00280, 0.00299, 0.00306, 0.00300, 0.00487],
                        [0.00300, 0.00296, 0.00292, 0.00294, 0.00300, 0.00296, 0.00298,
                         0.00300, 0.00290, 0.00298, 0.00289, 0.00295, 0.00294, 0.00289,
                         0.00288, 0.00304, 0.00303, 0.00299, 0.00290, 0.00301, 0.00302,
                         0.00293, 0.00283, 0.00291, 0.00287, 0.00300, 0.00305, 0.00302, 0.00487],
                        [0.00299, 0.00293, 0.00301, 0.00295, 0.00294, 0.00279, 0.00288,
                         0.00295, 0.00302, 0.00294, 0.00288, 0.00301, 0.00290, 0.00290,
                         0.00307, 0.00308, 0.00298, 0.00302, 0.00293, 0.00296, 0.00299,
                         0.00277, 0.00291, 0.00296, 0.00298, 0.00298, 0.00301, 0.00300, 0.00493],
                        [0.00295, 0.00297, 0.00299, 0.00298, 0.00297, 0.00273, 0.00281,
                         0.00289, 0.00299, 0.00299, 0.00282, 0.00287, 0.00293, 0.00297,
                         0.00309, 0.00304, 0.00285, 0.00299, 0.00300, 0.00302, 0.00298,
                         0.00280, 0.00299, 0.00302, 0.00295, 0.00286, 0.00293, 0.00298, 0.00505],
                        [0.00302, 0.00303, 0.00287, 0.00307, 0.00294, 0.00284, 0.00297,
                         0.00290, 0.00293, 0.00298, 0.00282, 0.00287, 0.00301, 0.00290,
                         0.00295, 0.00303, 0.00284, 0.00297, 0.00307, 0.00309, 0.00306,
                         0.00293, 0.00295, 0.00294, 0.00300, 0.00290, 0.00295, 0.00297, 0.00524],
                        [0.00298, 0.00300, 0.00287, 0.00298, 0.00285, 0.00306, 0.00310,
                         0.00299, 0.00293, 0.00299, 0.00286, 0.00291, 0.00302, 0.00288,
                         0.00288, 0.00299, 0.00292, 0.00304, 0.00313, 0.00300, 0.00302,
                         0.00301, 0.00286, 0.00296, 0.00309, 0.00312, 0.00309, 0.00295, 0.00540],
                        [0.00292, 0.00294, 0.00305, 0.00293, 0.00291, 0.00319, 0.00296,
                         0.00309, 0.00293, 0.00297, 0.00286, 0.00295, 0.00299, 0.00302,
                         0.00295, 0.00301, 0.00301, 0.00312, 0.00304, 0.00290, 0.00295,
                         0.00293, 0.00290, 0.00305, 0.00302, 0.00322, 0.00309, 0.00296, 0.00559],
                        [0.00292, 0.00293, 0.00308, 0.00310, 0.00299, 0.00303, 0.00290,
                         0.00304, 0.00296, 0.00295, 0.00289, 0.00305, 0.00297, 0.00302,
                         0.00295, 0.00301, 0.00303, 0.00312, 0.00280, 0.00305, 0.00296,
                         0.00289, 0.00299, 0.00291, 0.00292, 0.00305, 0.00305, 0.00305, 0.00573],
                        [0.00296, 0.00292, 0.00294, 0.00320, 0.00303, 0.00291, 0.00300,
                         0.00297, 0.00306, 0.00299, 0.00293, 0.00297, 0.00300, 0.00291,
                         0.00293, 0.00290, 0.00292, 0.00306, 0.00280, 0.00317, 0.00308,
                         0.00304, 0.00301, 0.00282, 0.00297, 0.00293, 0.00313, 0.00310, 0.00581],
                        [0.00297, 0.00302, 0.00287, 0.00310, 0.00312, 0.00305, 0.00301,
                         0.00301, 0.00319, 0.00303, 0.00297, 0.00293, 0.00299, 0.00293,
                         0.00299, 0.00290, 0.00284, 0.00307, 0.00306, 0.00304, 0.00311,
                         0.00315, 0.00301, 0.00295, 0.00310, 0.00296, 0.00311, 0.00304, 0.00594],
                        [0.00300, 0.00317, 0.00298, 0.00294, 0.00315, 0.00307, 0.00302,
                         0.00298, 0.00316, 0.00308, 0.00300, 0.00305, 0.00289, 0.00305,
                         0.00305, 0.00307, 0.00293, 0.00299, 0.00329, 0.00296, 0.00296,
                         0.00315, 0.00298, 0.00311, 0.00314, 0.00302, 0.00301, 0.00296, 0.00604],
                        [0.00305, 0.00318, 0.00313, 0.00291, 0.00311, 0.00296, 0.00312,
                         0.00294, 0.00300, 0.00307, 0.00306, 0.00309, 0.00280, 0.00310,
                         0.00308, 0.00313, 0.00307, 0.00283, 0.00325, 0.00302, 0.00298,
                         0.00309, 0.00299, 0.00316, 0.00299, 0.00309, 0.00307, 0.00299, 0.00611],
                        [0.00304, 0.00310, 0.00315, 0.00304, 0.00307, 0.00305, 0.00307,
                         0.00306, 0.00301, 0.00296, 0.00314, 0.00315, 0.00288, 0.00310,
                         0.00309, 0.00304, 0.00321, 0.00293, 0.00299, 0.00312, 0.00317,
                         0.00312, 0.00306, 0.00315, 0.00294, 0.00312, 0.00315, 0.00316, 0.00622],
                        [0.00300, 0.00306, 0.00312, 0.00318, 0.00305, 0.00328, 0.00300,
                         0.00320, 0.00307, 0.00303, 0.00321, 0.00317, 0.00318, 0.00312,
                         0.00309, 0.00301, 0.00328, 0.00319, 0.00297, 0.00318, 0.00326,
                         0.00317, 0.00315, 0.00311, 0.00310, 0.00306, 0.00315, 0.00325, 0.00647],
                        [0.00296, 0.00299, 0.00308, 0.00318, 0.00313, 0.00331, 0.00302,
                         0.00318, 0.00302, 0.00326, 0.00317, 0.00311, 0.00334, 0.00310,
                         0.00305, 0.00310, 0.00313, 0.00322, 0.00316, 0.00304, 0.00314,
                         0.00309, 0.00313, 0.00308, 0.00322, 0.00309, 0.00306, 0.00323, 0.00674],
                        [0.00298, 0.00296, 0.00313, 0.00318, 0.00325, 0.00321, 0.00297,
                         0.00318, 0.00316, 0.00331, 0.00312, 0.00316, 0.00331, 0.00314,
                         0.00308, 0.00316, 0.00313, 0.00309, 0.00320, 0.00307, 0.00306,
                         0.00317, 0.00313, 0.00317, 0.00323, 0.00330, 0.00314, 0.00340, 0.00693],
                        [0.00310, 0.00306, 0.00325, 0.00318, 0.00322, 0.00312, 0.00299,
                         0.00327, 0.00334, 0.00317, 0.00305, 0.00316, 0.00323, 0.00315,
                         0.00320, 0.00308, 0.00316, 0.00309, 0.00306, 0.00329, 0.00312,
                         0.00328, 0.00314, 0.00318, 0.00311, 0.00336, 0.00339, 0.00338, 0.00695],
                        [0.00327, 0.00325, 0.00328, 0.00307, 0.00324, 0.00315, 0.00324,
                         0.00334, 0.00334, 0.00311, 0.00316, 0.00314, 0.00323, 0.00316,
                         0.00338, 0.00317, 0.00312, 0.00320, 0.00313, 0.00331, 0.00318,
                         0.00320, 0.00312, 0.00317, 0.00308, 0.00335, 0.00350, 0.00323, 0.00713],
                        [0.00323, 0.00335, 0.00330, 0.00300, 0.00332, 0.00326, 0.00328,
                         0.00325, 0.00326, 0.00311, 0.00339, 0.00325, 0.00325, 0.00323,
                         0.00345, 0.00329, 0.00317, 0.00331, 0.00325, 0.00322, 0.00317,
                         0.00306, 0.00313, 0.00322, 0.00324, 0.00340, 0.00349, 0.00341, 0.00747],
                        [0.00315, 0.00339, 0.00333, 0.00318, 0.00323, 0.00331, 0.00314,
                         0.00321, 0.00322, 0.00321, 0.00344, 0.00335, 0.00324, 0.00323,
                         0.00332, 0.00323, 0.00332, 0.00334, 0.00320, 0.00330, 0.00319,
                         0.00304, 0.00310, 0.00329, 0.00335, 0.00337, 0.00351, 0.00362, 0.00770],
                        [0.00324, 0.00333, 0.00341, 0.00345, 0.00317, 0.00323, 0.00328,
                         0.00335, 0.00322, 0.00335, 0.00334, 0.00333, 0.00326, 0.00331,
                         0.00323, 0.00315, 0.00326, 0.00327, 0.00318, 0.00334, 0.00327,
                         0.00325, 0.00308, 0.00343, 0.00329, 0.00339, 0.00345, 0.00348, 0.00791],
                        [0.00337, 0.00330, 0.00350, 0.00357, 0.00327, 0.00325, 0.00348,
                         0.00345, 0.00332, 0.00324, 0.00340, 0.00332, 0.00331, 0.00338,
                         0.00322, 0.00314, 0.00314, 0.00328, 0.00333, 0.00329, 0.00332,
                         0.00352, 0.00326, 0.00348, 0.00327, 0.00350, 0.00336, 0.00337, 0.00817],
                        [0.00342, 0.00345, 0.00343, 0.00354, 0.00343, 0.00336, 0.00342,
                         0.00338, 0.00338, 0.00319, 0.00357, 0.00345, 0.00335, 0.00334,
                         0.00323, 0.00328, 0.00335, 0.00328, 0.00339, 0.00327, 0.00339,
                         0.00355, 0.00343, 0.00342, 0.00334, 0.00349, 0.00338, 0.00345, 0.00836],
                        [0.00338, 0.00352, 0.00346, 0.00348, 0.00354, 0.00347, 0.00332,
                         0.00332, 0.00334, 0.00346, 0.00352, 0.00356, 0.00337, 0.00331,
                         0.00327, 0.00340, 0.00358, 0.00323, 0.00332, 0.00335, 0.00344,
                         0.00349, 0.00340, 0.00347, 0.00342, 0.00345, 0.00344, 0.00345, 0.00844],
                        [0.00328, 0.00336, 0.00359, 0.00346, 0.00344, 0.00341, 0.00337,
                         0.00339, 0.00339, 0.00356, 0.00333, 0.00347, 0.00332, 0.00338,
                         0.00330, 0.00343, 0.00349, 0.00333, 0.00335, 0.00354, 0.00338,
                         0.00340, 0.00334, 0.00355, 0.00344, 0.00353, 0.00352, 0.00344, 0.00850],
                        [0.00334, 0.00335, 0.00355, 0.00359, 0.00346, 0.00332, 0.00356,
                         0.00355, 0.00358, 0.00344, 0.00336, 0.00335, 0.00340, 0.00342,
                         0.00333, 0.00340, 0.00335, 0.00350, 0.00348, 0.00358, 0.00332,
                         0.00335, 0.00333, 0.00354, 0.00345, 0.00360, 0.00358, 0.00350, 0.00877],
                        [0.00342, 0.00346, 0.00334, 0.00354, 0.00354, 0.00343, 0.00360,
                         0.00359, 0.00364, 0.00332, 0.00350, 0.00332, 0.00348, 0.00336,
                         0.00336, 0.00332, 0.00335, 0.00357, 0.00350, 0.00349, 0.00335,
                         0.00337, 0.00328, 0.00348, 0.00348, 0.00347, 0.00347, 0.00344, 0.00916],
                        [0.00349, 0.00352, 0.00331, 0.00346, 0.00355, 0.00362, 0.00363,
                         0.00349, 0.00359, 0.00339, 0.00359, 0.00342, 0.00358, 0.00345,
                         0.00351, 0.00346, 0.00342, 0.00367, 0.00344, 0.00349, 0.00356,
                         0.00358, 0.00339, 0.00356, 0.00352, 0.00335, 0.00344, 0.00351, 0.00952],
                        [0.00355, 0.00355, 0.00351, 0.00348, 0.00357, 0.00370, 0.00365,
                         0.00338, 0.00350, 0.00352, 0.00362, 0.00343, 0.00358, 0.00360,
                         0.00360, 0.00364, 0.00340, 0.00363, 0.00338, 0.00344, 0.00371,
                         0.00371, 0.00347, 0.00363, 0.00353, 0.00344, 0.00352, 0.00366, 0.00974],
                        [0.00353, 0.00361, 0.00371, 0.00353, 0.00356, 0.00369, 0.00357,
                         0.00344, 0.00344, 0.00354, 0.00354, 0.00336, 0.00340, 0.00353,
                         0.00350, 0.00360, 0.00343, 0.00351, 0.00343, 0.00337, 0.00368,
                         0.00347, 0.00346, 0.00360, 0.00367, 0.00361, 0.00355, 0.00368, 0.00999],
                        [0.00350, 0.00351, 0.00374, 0.00356, 0.00347, 0.00356, 0.00355,
                         0.00361, 0.00344, 0.00349, 0.00340, 0.00344, 0.00345, 0.00341,
                         0.00348, 0.00353, 0.00356, 0.00347, 0.00351, 0.00330, 0.00350,
                         0.00328, 0.00347, 0.00355, 0.00375, 0.00359, 0.00361, 0.00367, 0.01036],
                        [0.00350, 0.00344, 0.00365, 0.00363, 0.00357, 0.00347, 0.00364,
                         0.00362, 0.00358, 0.00357, 0.00348, 0.00355, 0.00378, 0.00356,
                         0.00357, 0.00365, 0.00363, 0.00352, 0.00363, 0.00342, 0.00341,
                         0.00344, 0.00349, 0.00344, 0.00356, 0.00354, 0.00364, 0.00375, 0.01067],
                        [0.00348, 0.00357, 0.00355, 0.00353, 0.00366, 0.00361, 0.00367,
                         0.00355, 0.00365, 0.00367, 0.00361, 0.00349, 0.00384, 0.00373,
                         0.00358, 0.00373, 0.00360, 0.00355, 0.00362, 0.00366, 0.00356,
                         0.00358, 0.00360, 0.00345, 0.00337, 0.00360, 0.00363, 0.00373, 0.01104],
                        [0.00354, 0.00373, 0.00362, 0.00348, 0.00355, 0.00374, 0.00358,
                         0.00367, 0.00363, 0.00375, 0.00358, 0.00350, 0.00356, 0.00371,
                         0.00353, 0.00364, 0.00360, 0.00344, 0.00349, 0.00366, 0.00373,
                         0.00363, 0.00370, 0.00369, 0.00348, 0.00359, 0.00368, 0.00365, 0.01154],
                        [0.00358, 0.00364, 0.00365, 0.00360, 0.00345, 0.00368, 0.00347,
                         0.00372, 0.00357, 0.00369, 0.00349, 0.00364, 0.00345, 0.00365,
                         0.00346, 0.00353, 0.00349, 0.00337, 0.00351, 0.00354, 0.00364,
                         0.00366, 0.00364, 0.00377, 0.00366, 0.00360, 0.00364, 0.00365, 0.01190],
                        [0.00360, 0.00347, 0.00355, 0.00364, 0.00353, 0.00361, 0.00346,
                         0.00356, 0.00351, 0.00349, 0.00350, 0.00363, 0.00349, 0.00364,
                         0.00352, 0.00357, 0.00339, 0.00350, 0.00367, 0.00351, 0.00353,
                         0.00359, 0.00355, 0.00372, 0.00358, 0.00365, 0.00359, 0.00372, 0.01228],
                        [0.00370, 0.00354, 0.00359, 0.00362, 0.00371, 0.00366, 0.00358,
                         0.00350, 0.00361, 0.00339, 0.00366, 0.00349, 0.00355, 0.00362,
                         0.00363, 0.00371, 0.00349, 0.00361, 0.00368, 0.00353, 0.00361,
                         0.00350, 0.00357, 0.00370, 0.00349, 0.00367, 0.00363, 0.00371, 0.01276],
                        [0.00377, 0.00372, 0.00368, 0.00367, 0.00371, 0.00374, 0.00373,
                         0.00363, 0.00383, 0.00350, 0.00381, 0.00349, 0.00365, 0.00360,
                         0.00366, 0.00366, 0.00368, 0.00364, 0.00358, 0.00355, 0.00368,
                         0.00358, 0.00362, 0.00367, 0.00362, 0.00371, 0.00365, 0.00368, 0.01324],
                        [0.00369, 0.00381, 0.00361, 0.00376, 0.00357, 0.00367, 0.00378,
                         0.00365, 0.00384, 0.00371, 0.00376, 0.00359, 0.00357, 0.00356,
                         0.00360, 0.00358, 0.00383, 0.00362, 0.00364, 0.00362, 0.00370,
                         0.00370, 0.00371, 0.00362, 0.00376, 0.00372, 0.00374, 0.00368, 0.01365],
                        [0.00363, 0.00370, 0.00357, 0.00379, 0.00353, 0.00358, 0.00373,
                         0.00361, 0.00371, 0.00386, 0.00364, 0.00367, 0.00351, 0.00353,
                         0.00353, 0.00360, 0.00384, 0.00354, 0.00377, 0.00372, 0.00378,
                         0.00377, 0.00372, 0.00365, 0.00375, 0.00372, 0.00380, 0.00368, 0.01401],
                        [0.00364, 0.00357, 0.00359, 0.00374, 0.00360, 0.00365, 0.00366,
                         0.00374, 0.00371, 0.00384, 0.00356, 0.00376, 0.00367, 0.00355,
                         0.00358, 0.00364, 0.00380, 0.00357, 0.00379, 0.00369, 0.00379,
                         0.00383, 0.00359, 0.00369, 0.00370, 0.00374, 0.00371, 0.00377, 0.01442],
                        [0.00358, 0.00365, 0.00363, 0.00373, 0.00377, 0.00367, 0.00368,
                         0.00384, 0.00376, 0.00379, 0.00361, 0.00373, 0.00376, 0.00367,
                         0.00376, 0.00367, 0.00375, 0.00388, 0.00381, 0.00355, 0.00357,
                         0.00374, 0.00355, 0.00360, 0.00380, 0.00370, 0.00365, 0.00383, 0.01504],
                        [0.00355, 0.00379, 0.00375, 0.00372, 0.00383, 0.00379, 0.00372,
                         0.00381, 0.00371, 0.00380, 0.00371, 0.00366, 0.00371, 0.00381,
                         0.00377, 0.00368, 0.00367, 0.00399, 0.00377, 0.00354, 0.00346,
                         0.00355, 0.00369, 0.00362, 0.00395, 0.00375, 0.00375, 0.00381, 0.01578],
                        [0.00364, 0.00385, 0.00383, 0.00374, 0.00370, 0.00392, 0.00375,
                         0.00379, 0.00369, 0.00390, 0.00374, 0.00368, 0.00372, 0.00382,
                         0.00366, 0.00364, 0.00369, 0.00378, 0.00366, 0.00369, 0.00363,
                         0.00347, 0.00377, 0.00385, 0.00393, 0.00385, 0.00394, 0.00388, 0.01644],
                        [0.00371, 0.00374, 0.00376, 0.00391, 0.00369, 0.00386, 0.00386,
                         0.00386, 0.00377, 0.00395, 0.00375, 0.00385, 0.00380, 0.00384,
                         0.00376, 0.00365, 0.00378, 0.00367, 0.00371, 0.00386, 0.00378,
                         0.00360, 0.00381, 0.00390, 0.00381, 0.00389, 0.00404, 0.00401, 0.01699],
                        [0.00367, 0.00364, 0.00373, 0.00399, 0.00378, 0.00376, 0.00383,
                         0.00389, 0.00381, 0.00369, 0.00382, 0.00395, 0.00380, 0.00388,
                         0.00388, 0.00373, 0.00371, 0.00371, 0.00380, 0.00387, 0.00384,
                         0.00375, 0.00388, 0.00371, 0.00372, 0.00386, 0.00399, 0.00404, 0.01754],
                        [0.00371, 0.00374, 0.00384, 0.00385, 0.00387, 0.00376, 0.00374,
                         0.00378, 0.00387, 0.00359, 0.00386, 0.00390, 0.00373, 0.00384,
                         0.00381, 0.00379, 0.00375, 0.00375, 0.00382, 0.00382, 0.00397,
                         0.00385, 0.00381, 0.00372, 0.00383, 0.00389, 0.00393, 0.00404, 0.01825],
                        [0.00382, 0.00382, 0.00380, 0.00373, 0.00383, 0.00385, 0.00386,
                         0.00367, 0.00387, 0.00377, 0.00376, 0.00381, 0.00371, 0.00381,
                         0.00371, 0.00376, 0.00383, 0.00377, 0.00375, 0.00375, 0.00396,
                         0.00386, 0.00371, 0.00385, 0.00392, 0.00405, 0.00387, 0.00399, 0.01907],
                        [0.00378, 0.00378, 0.00371, 0.00379, 0.00365, 0.00386, 0.00401,
                         0.00369, 0.00381, 0.00383, 0.00372, 0.00378, 0.00382, 0.00386,
                         0.00374, 0.00373, 0.00379, 0.00386, 0.00388, 0.00384, 0.00389,
                         0.00390, 0.00377, 0.00389, 0.00397, 0.00405, 0.00388, 0.00388, 0.01999],
                        [0.00365, 0.00368, 0.00375, 0.00388, 0.00359, 0.00373, 0.00398,
                         0.00374, 0.00387, 0.00378, 0.00382, 0.00384, 0.00394, 0.00380,
                         0.00384, 0.00378, 0.00383, 0.00396, 0.00398, 0.00392, 0.00386,
                         0.00404, 0.00389, 0.00386, 0.00400, 0.00384, 0.00393, 0.00391, 0.02087],
                        [0.00364, 0.00364, 0.00373, 0.00388, 0.00375, 0.00378, 0.00390,
                         0.00379, 0.00404, 0.00375, 0.00388, 0.00384, 0.00399, 0.00380,
                         0.00391, 0.00385, 0.00385, 0.00389, 0.00386, 0.00383, 0.00384,
                         0.00403, 0.00399, 0.00397, 0.00392, 0.00383, 0.00397, 0.00410, 0.02172],
                        [0.00372, 0.00376, 0.00362, 0.00392, 0.00396, 0.00410, 0.00383,
                         0.00382, 0.00397, 0.00382, 0.00382, 0.00383, 0.00402, 0.00389,
                         0.00389, 0.00386, 0.00378, 0.00381, 0.00389, 0.00381, 0.00377,
                         0.00386, 0.00409, 0.00410, 0.00388, 0.00402, 0.00406, 0.00411, 0.02268],
                        [0.00385, 0.00389, 0.00366, 0.00399, 0.00398, 0.00413, 0.00374,
                         0.00383, 0.00380, 0.00393, 0.00380, 0.00388, 0.00393, 0.00389,
                         0.00383, 0.00383, 0.00381, 0.00389, 0.00402, 0.00387, 0.00377,
                         0.00379, 0.00417, 0.00399, 0.00389, 0.00403, 0.00404, 0.00397, 0.02358],
                        [0.00387, 0.00393, 0.00390, 0.00397, 0.00382, 0.00388, 0.00383,
                         0.00385, 0.00380, 0.00391, 0.00392, 0.00397, 0.00392, 0.00396,
                         0.00385, 0.00395, 0.00387, 0.00410, 0.00404, 0.00388, 0.00397,
                         0.00391, 0.00410, 0.00383, 0.00390, 0.00399, 0.00394, 0.00392, 0.02465],
                        [0.00367, 0.00389, 0.00390, 0.00384, 0.00366, 0.00376, 0.00407,
                         0.00382, 0.00385, 0.00379, 0.00403, 0.00396, 0.00398, 0.00400,
                         0.00389, 0.00407, 0.00393, 0.00416, 0.00402, 0.00393, 0.00403,
                         0.00402, 0.00394, 0.00386, 0.00387, 0.00404, 0.00399, 0.00398, 0.02604],
                        [0.00364, 0.00389, 0.00374, 0.00377, 0.00367, 0.00388, 0.00413,
                         0.00379, 0.00398, 0.00375, 0.00398, 0.00392, 0.00395, 0.00390,
                         0.00391, 0.00397, 0.00397, 0.00405, 0.00395, 0.00401, 0.00395,
                         0.00406, 0.00390, 0.00391, 0.00390, 0.00409, 0.00407, 0.00408, 0.02733],
                        [0.00388, 0.00385, 0.00380, 0.00379, 0.00383, 0.00404, 0.00390,
                         0.00380, 0.00410, 0.00387, 0.00380, 0.00393, 0.00392, 0.00382,
                         0.00402, 0.00380, 0.00389, 0.00394, 0.00383, 0.00403, 0.00394,
                         0.00414, 0.00398, 0.00396, 0.00403, 0.00405, 0.00396, 0.00416, 0.02853],
                        [0.00388, 0.00387, 0.00400, 0.00381, 0.00397, 0.00396, 0.00369,
                         0.00385, 0.00402, 0.00393, 0.00374, 0.00388, 0.00393, 0.00384,
                         0.00412, 0.00384, 0.00385, 0.00390, 0.00386, 0.00393, 0.00398,
                         0.00420, 0.00407, 0.00404, 0.00404, 0.00393, 0.00394, 0.00416, 0.02985],
                        [0.00377, 0.00399, 0.00411, 0.00392, 0.00397, 0.00384, 0.00373,
                         0.00391, 0.00391, 0.00389, 0.00388, 0.00398, 0.00402, 0.00391,
                         0.00406, 0.00399, 0.00398, 0.00399, 0.00401, 0.00392, 0.00401,
                         0.00419, 0.00416, 0.00400, 0.00397, 0.00397, 0.00411, 0.00409, 0.03134],
                        [0.00387, 0.00402, 0.00395, 0.00401, 0.00386, 0.00386, 0.00388,
                         0.00384, 0.00398, 0.00391, 0.00401, 0.00414, 0.00407, 0.00393,
                         0.00388, 0.00415, 0.00409, 0.00410, 0.00402, 0.00405, 0.00411,
                         0.00414, 0.00419, 0.00393, 0.00402, 0.00407, 0.00407, 0.00410, 0.03309],
                        [0.00397, 0.00402, 0.00379, 0.00400, 0.00379, 0.00390, 0.00396,
                         0.00380, 0.00405, 0.00389, 0.00409, 0.00406, 0.00393, 0.00391,
                         0.00386, 0.00410, 0.00404, 0.00402, 0.00392, 0.00402, 0.00419,
                         0.00411, 0.00404, 0.00399, 0.00413, 0.00410, 0.00390, 0.00428, 0.03506],
                        [0.00403, 0.00402, 0.00385, 0.00395, 0.00387, 0.00402, 0.00405,
                         0.00385, 0.00396, 0.00381, 0.00409, 0.00393, 0.00379, 0.00396,
                         0.00405, 0.00385, 0.00400, 0.00400, 0.00398, 0.00398, 0.00412,
                         0.00410, 0.00394, 0.00403, 0.00416, 0.00405, 0.00394, 0.00432, 0.03703],
                        [0.00405, 0.00388, 0.00395, 0.00400, 0.00390, 0.00406, 0.00405,
                         0.00397, 0.00391, 0.00387, 0.00394, 0.00388, 0.00386, 0.00402,
                         0.00420, 0.00380, 0.00393, 0.00411, 0.00409, 0.00402, 0.00398,
                         0.00404, 0.00401, 0.00404, 0.00401, 0.00394, 0.00415, 0.00426, 0.03897],
                        [0.00398, 0.00385, 0.00405, 0.00418, 0.00388, 0.00399, 0.00393,
                         0.00402, 0.00398, 0.00412, 0.00384, 0.00395, 0.00397, 0.00395,
                         0.00415, 0.00399, 0.00391, 0.00405, 0.00408, 0.00404, 0.00392,
                         0.00394, 0.00407, 0.00412, 0.00394, 0.00399, 0.00430, 0.00436, 0.04118],
                        [0.00389, 0.00406, 0.00413, 0.00417, 0.00393, 0.00390, 0.00391,
                         0.00398, 0.00396, 0.00417, 0.00392, 0.00408, 0.00393, 0.00380,
                         0.00399, 0.00412, 0.00399, 0.00390, 0.00391, 0.00408, 0.00393,
                         0.00398, 0.00409, 0.00414, 0.00409, 0.00415, 0.00421, 0.00460, 0.04366],
                        [0.00391, 0.00419, 0.00418, 0.00404, 0.00413, 0.00390, 0.00409,
                         0.00398, 0.00394, 0.00399, 0.00410, 0.00414, 0.00394, 0.00384,
                         0.00390, 0.00405, 0.00411, 0.00401, 0.00394, 0.00418, 0.00410,
                         0.00421, 0.00410, 0.00409, 0.00425, 0.00419, 0.00410, 0.00489, 0.04627],
                        [0.00404, 0.00411, 0.00402, 0.00406, 0.00429, 0.00406, 0.00406,
                         0.00399, 0.00406, 0.00396, 0.00422, 0.00409, 0.00410, 0.00402,
                         0.00400, 0.00395, 0.00420, 0.00409, 0.00410, 0.00421, 0.00432,
                         0.00430, 0.00408, 0.00404, 0.00428, 0.00409, 0.00422, 0.00504, 0.04902],
                        [0.00416, 0.00398, 0.00389, 0.00420, 0.00418, 0.00414, 0.00397,
                         0.00402, 0.00417, 0.00413, 0.00418, 0.00410, 0.00428, 0.00414,
                         0.00415, 0.00400, 0.00415, 0.00404, 0.00417, 0.00410, 0.00434,
                         0.00420, 0.00414, 0.00414, 0.00433, 0.00417, 0.00453, 0.00532, 0.05214],
                        [0.00417, 0.00414, 0.00418, 0.00426, 0.00407, 0.00414, 0.00423,
                         0.00415, 0.00416, 0.00424, 0.00415, 0.00418, 0.00426, 0.00411,
                         0.00420, 0.00416, 0.00408, 0.00411, 0.00415, 0.00411, 0.00420,
                         0.00425, 0.00440, 0.00438, 0.00438, 0.00446, 0.00471, 0.00587, 0.05549],
                        [0.00420, 0.00446, 0.00452, 0.00430, 0.00419, 0.00426, 0.00448,
                         0.00431, 0.00414, 0.00431, 0.00428, 0.00428, 0.00411, 0.00423,
                         0.00424, 0.00431, 0.00423, 0.00427, 0.00421, 0.00421, 0.00417,
                         0.00441, 0.00464, 0.00464, 0.00447, 0.00465, 0.00474, 0.00649, 0.05886],
                        [0.00441, 0.00460, 0.00459, 0.00449, 0.00440, 0.00443, 0.00440,
                         0.00448, 0.00426, 0.00448, 0.00443, 0.00440, 0.00414, 0.00454,
                         0.00440, 0.00451, 0.00445, 0.00443, 0.00445, 0.00428, 0.00437,
                         0.00454, 0.00467, 0.00483, 0.00475, 0.00491, 0.00496, 0.00726, 0.06283],
                        [0.00455, 0.00468, 0.00452, 0.00460, 0.00465, 0.00454, 0.00442,
                         0.00461, 0.00447, 0.00456, 0.00448, 0.00452, 0.00438, 0.00474,
                         0.00462, 0.00462, 0.00454, 0.00460, 0.00463, 0.00452, 0.00466,
                         0.00469, 0.00469, 0.00500, 0.00510, 0.00530, 0.00555, 0.00841, 0.06742],
                        [0.00481, 0.00483, 0.00477, 0.00468, 0.00492, 0.00478, 0.00481,
                         0.00478, 0.00469, 0.00466, 0.00471, 0.00472, 0.00480, 0.00486,
                         0.00476, 0.00472, 0.00470, 0.00470, 0.00478, 0.00483, 0.00498,
                         0.00500, 0.00494, 0.00534, 0.00539, 0.00571, 0.00637, 0.01001, 0.07228],
                        [0.00537, 0.00518, 0.00541, 0.00519, 0.00524, 0.00511, 0.00540,
                         0.00514, 0.00509, 0.00496, 0.00511, 0.00511, 0.00517, 0.00502,
                         0.00496, 0.00504, 0.00508, 0.00494, 0.00510, 0.00510, 0.00534,
                         0.00548, 0.00548, 0.00583, 0.00585, 0.00633, 0.00706, 0.01211, 0.07753],
                        [0.00602, 0.00583, 0.00599, 0.00586, 0.00581, 0.00565, 0.00592,
                         0.00563, 0.00569, 0.00547, 0.00547, 0.00566, 0.00552, 0.00540,
                         0.00534, 0.00551, 0.00555, 0.00537, 0.00552, 0.00554, 0.00573,
                         0.00600, 0.00610, 0.00634, 0.00664, 0.00718, 0.00796, 0.01466, 0.08341],
                        [0.00666, 0.00653, 0.00659, 0.00649, 0.00667, 0.00651, 0.00644,
                         0.00627, 0.00640, 0.00612, 0.00594, 0.00630, 0.00607, 0.00613,
                         0.00600, 0.00600, 0.00602, 0.00593, 0.00601, 0.00627, 0.00630,
                         0.00657, 0.00678, 0.00715, 0.00768, 0.00827, 0.00957, 0.01793, 0.09034],
                        [0.00754, 0.00745, 0.00749, 0.00738, 0.00768, 0.00759, 0.00730,
                         0.00727, 0.00728, 0.00697, 0.00686, 0.00698, 0.00681, 0.00694,
                         0.00685, 0.00665, 0.00670, 0.00667, 0.00674, 0.00722, 0.00723,
                         0.00745, 0.00774, 0.00834, 0.00912, 0.01001, 0.01188, 0.02233, 0.09859],
                        [0.00898, 0.00897, 0.00878, 0.00874, 0.00881, 0.00880, 0.00858,
                         0.00858, 0.00837, 0.00817, 0.00818, 0.00790, 0.00774, 0.00782,
                         0.00783, 0.00778, 0.00784, 0.00780, 0.00783, 0.00838, 0.00848,
                         0.00877, 0.00918, 0.00976, 0.01097, 0.01243, 0.01492, 0.02794, 0.10787],
                        [0.01100, 0.01112, 0.01078, 0.01078, 0.01061, 0.01046, 0.01046,
                         0.01033, 0.01001, 0.00985, 0.00980, 0.00947, 0.00932, 0.00928,
                         0.00931, 0.00949, 0.00939, 0.00948, 0.00955, 0.00996, 0.01015,
                         0.01057, 0.01133, 0.01196, 0.01341, 0.01559, 0.01911, 0.03524, 0.11865],
                        [0.01368, 0.01383, 0.01355, 0.01360, 0.01330, 0.01300, 0.01306,
                         0.01263, 0.01237, 0.01219, 0.01194, 0.01181, 0.01165, 0.01144,
                         0.01143, 0.01152, 0.01136, 0.01150, 0.01176, 0.01202, 0.01239,
                         0.01301, 0.01419, 0.01534, 0.01697, 0.01983, 0.02470, 0.04470, 0.13149],
                        [0.01762, 0.01763, 0.01752, 0.01749, 0.01707, 0.01676, 0.01657,
                         0.01604, 0.01573, 0.01559, 0.01516, 0.01505, 0.01468, 0.01444,
                         0.01431, 0.01425, 0.01422, 0.01438, 0.01460, 0.01500, 0.01569,
                         0.01668, 0.01808, 0.01998, 0.02218, 0.02596, 0.03233, 0.05659, 0.14657],
                        [0.02321, 0.02310, 0.02307, 0.02277, 0.02233, 0.02188, 0.02148,
                         0.02096, 0.02061, 0.02027, 0.01963, 0.01925, 0.01877, 0.01852,
                         0.01821, 0.01819, 0.01824, 0.01852, 0.01866, 0.01936, 0.02034,
                         0.02170, 0.02337, 0.02588, 0.02923, 0.03438, 0.04262, 0.07115, 0.16408],
                        [0.03091, 0.03084, 0.03046, 0.03015, 0.02974, 0.02898, 0.02846,
                         0.02779, 0.02719, 0.02661, 0.02568, 0.02509, 0.02461, 0.02424,
                         0.02381, 0.02370, 0.02385, 0.02412, 0.02459, 0.02560, 0.02674,
                         0.02842, 0.03067, 0.03385, 0.03868, 0.04529, 0.05603, 0.08911, 0.18432],
                        [0.04111, 0.04112, 0.04044, 0.04029, 0.03967, 0.03868, 0.03803,
                         0.03698, 0.03596, 0.03511, 0.03401, 0.03332, 0.03256, 0.03211,
                         0.03163, 0.03139, 0.03154, 0.03181, 0.03263, 0.03382, 0.03529,
                         0.03757, 0.04067, 0.04478, 0.05105, 0.05933, 0.07292, 0.11102, 0.20760],
                        [0.05450, 0.05447, 0.05397, 0.05348, 0.05261, 0.05151, 0.05058,
                         0.04921, 0.04801, 0.04656, 0.04551, 0.04435, 0.04326, 0.04266,
                         0.04213, 0.04185, 0.04187, 0.04220, 0.04325, 0.04466, 0.04668,
                         0.04973, 0.05395, 0.05917, 0.06677, 0.07726, 0.09363, 0.13692, 0.23422],
                        [0.07168, 0.07153, 0.07106, 0.07004, 0.06908, 0.06791, 0.06639,
                         0.06489, 0.06352, 0.06163, 0.06028, 0.05847, 0.05723, 0.05636,
                         0.05565, 0.05526, 0.05534, 0.05584, 0.05712, 0.05893, 0.06157,
                         0.06524, 0.07048, 0.07710, 0.08630, 0.09922, 0.11847, 0.16679, 0.26401],
                        [0.09267, 0.09254, 0.09175, 0.09070, 0.08944, 0.08793, 0.08605,
                         0.08418, 0.08238, 0.08049, 0.07841, 0.07627, 0.07486, 0.07351,
                         0.07275, 0.07218, 0.07231, 0.07319, 0.07460, 0.07677, 0.08008,
                         0.08440, 0.09035, 0.09894, 0.10994, 0.12526, 0.14802, 0.20105, 0.29718],
                        [0.11769, 0.11764, 0.11678, 0.11575, 0.11405, 0.11203, 0.10998,
                         0.10763, 0.10516, 0.10312, 0.10050, 0.09828, 0.09630, 0.09451,
                         0.09379, 0.09311, 0.09314, 0.09428, 0.09593, 0.09859, 0.10239,
                         0.10755, 0.11469, 0.12496, 0.13808, 0.15595, 0.18275, 0.24021, 0.33381],
                        [0.14763, 0.14748, 0.14681, 0.14532, 0.14340, 0.14113, 0.13870,
                         0.13589, 0.13284, 0.13013, 0.12725, 0.12458, 0.12214, 0.12011,
                         0.11899, 0.11837, 0.11854, 0.11958, 0.12170, 0.12494, 0.12930,
                         0.13554, 0.14427, 0.15581, 0.17134, 0.19219, 0.22294, 0.28446, 0.37359],
                        [0.18302, 0.18251, 0.18172, 0.17999, 0.17771, 0.17517, 0.17234,
                         0.16890, 0.16552, 0.16211, 0.15887, 0.15546, 0.15288, 0.15063,
                         0.14893, 0.14836, 0.14878, 0.14961, 0.15209, 0.15582, 0.16115,
                         0.16864, 0.17875, 0.19210, 0.20996, 0.23424, 0.26842, 0.33342, 0.41592],
                        [0.22341, 0.22291, 0.22175, 0.21992, 0.21735, 0.21432, 0.21089,
                         0.20710, 0.20332, 0.19931, 0.19556, 0.19164, 0.18853, 0.18604,
                         0.18411, 0.18330, 0.18386, 0.18481, 0.18752, 0.19181, 0.19825,
                         0.20681, 0.21838, 0.23378, 0.25403, 0.28135, 0.31890, 0.38664, 0.45992],
                        [0.26891, 0.26872, 0.26736, 0.26495, 0.26260, 0.25916, 0.25492,
                         0.25090, 0.24648, 0.24200, 0.23746, 0.23326, 0.22924, 0.22640,
                         0.22458, 0.22347, 0.22408, 0.22545, 0.22861, 0.23334, 0.24070,
                         0.25032, 0.26331, 0.28084, 0.30330, 0.33299, 0.37371, 0.44348, 0.50409],
                        [0.31981, 0.31943, 0.31824, 0.31556, 0.31296, 0.30902, 0.30441,
                         0.29980, 0.29488, 0.29003, 0.28470, 0.28012, 0.27569, 0.27224,
                         0.27035, 0.26925, 0.26979, 0.27137, 0.27522, 0.28039, 0.28855,
                         0.29900, 0.31355, 0.33298, 0.35731, 0.38924, 0.43196, 0.50253, 0.54693],
                        [0.37540, 0.37457, 0.37336, 0.37110, 0.36747, 0.36321, 0.35854,
                         0.35338, 0.34821, 0.34280, 0.33703, 0.33193, 0.32760, 0.32367,
                         0.32129, 0.32048, 0.32073, 0.32241, 0.32665, 0.33287, 0.34142,
                         0.35276, 0.36870, 0.38917, 0.41517, 0.44899, 0.49259, 0.56173, 0.58748],
                        [0.43413, 0.43354, 0.43161, 0.42947, 0.42563, 0.42126, 0.41626,
                         0.41094, 0.40559, 0.39936, 0.39334, 0.38771, 0.38322, 0.37943,
                         0.37651, 0.37605, 0.37588, 0.37794, 0.38200, 0.38923, 0.39810,
                         0.41075, 0.42720, 0.44841, 0.47549, 0.51005, 0.55352, 0.61963, 0.62378],
                        [0.49436, 0.49463, 0.49226, 0.48959, 0.48641, 0.48183, 0.47670,
                         0.47137, 0.46573, 0.45878, 0.45281, 0.44662, 0.44182, 0.43798,
                         0.43509, 0.43436, 0.43431, 0.43682, 0.44098, 0.44823, 0.45775,
                         0.47070, 0.48770, 0.50954, 0.53694, 0.57082, 0.61304, 0.67444, 0.65460],
                        [0.55530, 0.55552, 0.55371, 0.55068, 0.54764, 0.54331, 0.53806,
                         0.53287, 0.52680, 0.51974, 0.51417, 0.50768, 0.50262, 0.49848,
                         0.49611, 0.49456, 0.49537, 0.49770, 0.50253, 0.50935, 0.51942,
                         0.53164, 0.54873, 0.57042, 0.59755, 0.62938, 0.66928, 0.72318, 0.67990],
                        [0.61475, 0.61406, 0.61287, 0.61017, 0.60689, 0.60336, 0.59794,
                         0.59290, 0.58678, 0.58039, 0.57487, 0.56877, 0.56313, 0.55946,
                         0.55730, 0.55570, 0.55674, 0.55874, 0.56382, 0.57030, 0.58058,
                         0.59252, 0.60823, 0.62881, 0.65443, 0.68304, 0.71871, 0.76351, 0.69965],
                        [0.66888, 0.66786, 0.66700, 0.66492, 0.66182, 0.65847, 0.65398,
                         0.64909, 0.64377, 0.63796, 0.63246, 0.62701, 0.62136, 0.61797,
                         0.61604, 0.61483, 0.61529, 0.61748, 0.62190, 0.62836, 0.63787,
                         0.64977, 0.66388, 0.68257, 0.70480, 0.72976, 0.75904, 0.79532, 0.71476],
                        [0.71577, 0.71515, 0.71450, 0.71295, 0.71046, 0.70704, 0.70389,
                         0.69952, 0.69544, 0.68971, 0.68503, 0.67993, 0.67573, 0.67192,
                         0.67035, 0.66937, 0.66957, 0.67172, 0.67539, 0.68164, 0.68965,
                         0.70045, 0.71346, 0.72948, 0.74760, 0.76856, 0.79132, 0.82052, 0.72649],
                        [0.75460, 0.75454, 0.75354, 0.75251, 0.75068, 0.74819, 0.74545,
                         0.74209, 0.73893, 0.73412, 0.73012, 0.72545, 0.72251, 0.71907,
                         0.71770, 0.71730, 0.71758, 0.71927, 0.72269, 0.72789, 0.73488,
                         0.74351, 0.75479, 0.76791, 0.78256, 0.79910, 0.81678, 0.84043, 0.73589],
                        [0.78504, 0.78514, 0.78393, 0.78310, 0.78191, 0.78054, 0.77802,
                         0.77609, 0.77324, 0.77035, 0.76660, 0.76286, 0.76003, 0.75766,
                         0.75654, 0.75661, 0.75717, 0.75856, 0.76178, 0.76573, 0.77164,
                         0.77836, 0.78714, 0.79787, 0.80961, 0.82239, 0.83635, 0.85524, 0.74357],
                        [0.80794, 0.80789, 0.80717, 0.80650, 0.80572, 0.80479, 0.80308,
                         0.80250, 0.79972, 0.79809, 0.79499, 0.79236, 0.78954, 0.78791,
                         0.78709, 0.78720, 0.78797, 0.78939, 0.79197, 0.79515, 0.79976,
                         0.80517, 0.81204, 0.82071, 0.82967, 0.84011, 0.85143, 0.86630, 0.74966],
                        [0.82519, 0.82500, 0.82529, 0.82457, 0.82420, 0.82342, 0.82265,
                         0.82239, 0.82026, 0.81896, 0.81671, 0.81473, 0.81222, 0.81118,
                         0.81076, 0.81097, 0.81155, 0.81316, 0.81479, 0.81791, 0.82156,
                         0.82578, 0.83132, 0.83825, 0.84512, 0.85395, 0.86346, 0.87582, 0.75523],
                        [0.83871, 0.83874, 0.83960, 0.83855, 0.83843, 0.83798, 0.83769,
                         0.83706, 0.83628, 0.83519, 0.83365, 0.83190, 0.82989, 0.82904,
                         0.82932, 0.82945, 0.83015, 0.83136, 0.83292, 0.83591, 0.83858,
                         0.84220, 0.84670, 0.85194, 0.85811, 0.86538, 0.87360, 0.88481, 0.76091],
                        [0.84955, 0.84981, 0.85013, 0.84975, 0.84944, 0.84898, 0.84875,
                         0.84864, 0.84879, 0.84786, 0.84709, 0.84569, 0.84419, 0.84304,
                         0.84360, 0.84374, 0.84462, 0.84560, 0.84730, 0.84967, 0.85168,
                         0.85508, 0.85893, 0.86275, 0.86906, 0.87491, 0.88223, 0.89267, 0.76567],
                        [0.85858, 0.85862, 0.85832, 0.85881, 0.85851, 0.85771, 0.85797,
                         0.85846, 0.85889, 0.85796, 0.85756, 0.85697, 0.85572, 0.85475,
                         0.85444, 0.85480, 0.85568, 0.85695, 0.85822, 0.86028, 0.86206,
                         0.86533, 0.86835, 0.87214, 0.87770, 0.88273, 0.88986, 0.89904, 0.76933],
                        [0.86672, 0.86664, 0.86631, 0.86662, 0.86636, 0.86579, 0.86641,
                         0.86705, 0.86721, 0.86666, 0.86639, 0.86613, 0.86501, 0.86472,
                         0.86359, 0.86379, 0.86491, 0.86611, 0.86745, 0.86951, 0.87100,
                         0.87418, 0.87635, 0.88086, 0.88499, 0.88990, 0.89674, 0.90466, 0.77263],
                        [0.87393, 0.87395, 0.87366, 0.87378, 0.87330, 0.87331, 0.87377,
                         0.87452, 0.87433, 0.87443, 0.87433, 0.87381, 0.87277, 0.87292,
                         0.87208, 0.87194, 0.87274, 0.87394, 0.87530, 0.87736, 0.87915,
                         0.88145, 0.88390, 0.88825, 0.89190, 0.89646, 0.90217, 0.90993, 0.77524],
                        [0.88091, 0.88053, 0.88033, 0.88085, 0.88024, 0.88029, 0.88082,
                         0.88107, 0.88112, 0.88176, 0.88142, 0.88130, 0.88044, 0.88029,
                         0.88008, 0.88000, 0.87995, 0.88152, 0.88216, 0.88419, 0.88631,
                         0.88808, 0.89108, 0.89442, 0.89854, 0.90207, 0.90710, 0.91464, 0.77742],
                        [0.88757, 0.88669, 0.88707, 0.88758, 0.88674, 0.88678, 0.88677,
                         0.88701, 0.88736, 0.88804, 0.88780, 0.88834, 0.88782, 0.88708,
                         0.88706, 0.88731, 0.88695, 0.88856, 0.88880, 0.89049, 0.89270,
                         0.89469, 0.89710, 0.89992, 0.90404, 0.90704, 0.91215, 0.91849, 0.77964],
                        [0.89297, 0.89251, 0.89314, 0.89297, 0.89206, 0.89217, 0.89182,
                         0.89222, 0.89263, 0.89314, 0.89382, 0.89429, 0.89391, 0.89298,
                         0.89324, 0.89298, 0.89355, 0.89430, 0.89524, 0.89610, 0.89836,
                         0.90031, 0.90210, 0.90499, 0.90806, 0.91196, 0.91642, 0.92156, 0.78114],
                        [0.89801, 0.89829, 0.89797, 0.89782, 0.89742, 0.89689, 0.89696,
                         0.89725, 0.89774, 0.89846, 0.89944, 0.89960, 0.89952, 0.89875,
                         0.89952, 0.89853, 0.89974, 0.89969, 0.90089, 0.90175, 0.90330,
                         0.90536, 0.90711, 0.90979, 0.91209, 0.91680, 0.91992, 0.92467, 0.78216],
                        [0.90309, 0.90365, 0.90241, 0.90288, 0.90260, 0.90207, 0.90193,
                         0.90255, 0.90270, 0.90357, 0.90414, 0.90462, 0.90500, 0.90467,
                         0.90533, 0.90458, 0.90516, 0.90491, 0.90544, 0.90705, 0.90784,
                         0.91017, 0.91200, 0.91411, 0.91689, 0.92070, 0.92334, 0.92776, 0.78334],
                        [0.90724, 0.90748, 0.90664, 0.90715, 0.90646, 0.90676, 0.90618,
                         0.90669, 0.90640, 0.90726, 0.90779, 0.90868, 0.90932, 0.90937,
                         0.90966, 0.90927, 0.90917, 0.90942, 0.90936, 0.91100, 0.91175,
                         0.91391, 0.91607, 0.91746, 0.92088, 0.92328, 0.92626, 0.92917, 0.78412],
                        [0.91059, 0.91001, 0.91008, 0.91024, 0.90961, 0.90992, 0.90920,
                         0.90903, 0.90891, 0.90982, 0.91084, 0.91201, 0.91236, 0.91279,
                         0.91283, 0.91259, 0.91250, 0.91329, 0.91319, 0.91439, 0.91514,
                         0.91683, 0.91874, 0.92001, 0.92316, 0.92538, 0.92828, 0.92974, 0.78410],
                        [0.91358, 0.91307, 0.91304, 0.91321, 0.91288, 0.91241, 0.91180,
                         0.91140, 0.91157, 0.91236, 0.91356, 0.91496, 0.91516, 0.91610,
                         0.91593, 0.91602, 0.91630, 0.91696, 0.91700, 0.91765, 0.91836,
                         0.91982, 0.92093, 0.92271, 0.92513, 0.92782, 0.93013, 0.93095, 0.78419],
                        [0.91581, 0.91602, 0.91571, 0.91596, 0.91539, 0.91477, 0.91461,
                         0.91432, 0.91464, 0.91487, 0.91552, 0.91672, 0.91789, 0.91875,
                         0.91904, 0.91925, 0.91971, 0.91980, 0.92004, 0.92017, 0.92117,
                         0.92242, 0.92336, 0.92547, 0.92700, 0.92958, 0.93150, 0.93210, 0.78474],
                        [0.91719, 0.91741, 0.91764, 0.91765, 0.91677, 0.91665, 0.91681,
                         0.91672, 0.91671, 0.91662, 0.91681, 0.91768, 0.91957, 0.92045,
                         0.92147, 0.92135, 0.92199, 0.92149, 0.92225, 0.92222, 0.92340,
                         0.92414, 0.92539, 0.92726, 0.92821, 0.93051, 0.93186, 0.93260, 0.78516],
                        [0.91863, 0.91824, 0.91881, 0.91875, 0.91801, 0.91802, 0.91820,
                         0.91829, 0.91764, 0.91792, 0.91817, 0.91902, 0.92068, 0.92196,
                         0.92298, 0.92306, 0.92374, 0.92357, 0.92410, 0.92443, 0.92522,
                         0.92583, 0.92713, 0.92857, 0.92974, 0.93179, 0.93204, 0.93297, 0.78572],
                        [0.91989, 0.91889, 0.91933, 0.91971, 0.91937, 0.91923, 0.91891,
                         0.91915, 0.91846, 0.91900, 0.91924, 0.92030, 0.92161, 0.92271,
                         0.92352, 0.92454, 0.92514, 0.92551, 0.92521, 0.92609, 0.92655,
                         0.92761, 0.92845, 0.92968, 0.93117, 0.93247, 0.93258, 0.93293, 0.78599],
                        [0.92014, 0.91924, 0.91940, 0.92011, 0.92050, 0.92019, 0.91931,
                         0.91978, 0.91949, 0.91953, 0.91996, 0.92072, 0.92188, 0.92258,
                         0.92383, 0.92509, 0.92602, 0.92629, 0.92566, 0.92682, 0.92775,
                         0.92861, 0.92943, 0.93051, 0.93175, 0.93216, 0.93296, 0.93232, 0.78551],
                        [0.91978, 0.91976, 0.91975, 0.91984, 0.92058, 0.92059, 0.91996,
                         0.92029, 0.91999, 0.91963, 0.92056, 0.92051, 0.92194, 0.92268,
                         0.92437, 0.92532, 0.92608, 0.92671, 0.92650, 0.92731, 0.92874,
                         0.92908, 0.93027, 0.93121, 0.93209, 0.93192, 0.93289, 0.93203, 0.78508],
                        [0.91941, 0.91978, 0.92024, 0.91965, 0.91989, 0.92068, 0.92074,
                         0.92050, 0.92009, 0.91993, 0.92067, 0.92063, 0.92185, 0.92309,
                         0.92482, 0.92554, 0.92605, 0.92701, 0.92771, 0.92799, 0.92909,
                         0.92967, 0.93064, 0.93162, 0.93228, 0.93228, 0.93270, 0.93224, 0.78515],
                        [0.91894, 0.91889, 0.92000, 0.91968, 0.91976, 0.92042, 0.92126,
                         0.92061, 0.92075, 0.92033, 0.92029, 0.92095, 0.92108, 0.92305,
                         0.92448, 0.92539, 0.92635, 0.92709, 0.92824, 0.92867, 0.92904,
                         0.93007, 0.93070, 0.93165, 0.93197, 0.93265, 0.93223, 0.93187, 0.78483],
                        [0.91768, 0.91781, 0.91885, 0.91924, 0.91959, 0.91950, 0.92075,
                         0.92050, 0.92135, 0.92040, 0.91971, 0.92041, 0.92017, 0.92227,
                         0.92341, 0.92474, 0.92636, 0.92675, 0.92804, 0.92866, 0.92916,
                         0.92977, 0.93068, 0.93137, 0.93136, 0.93203, 0.93124, 0.93067, 0.78403],
                        [0.91624, 0.91677, 0.91705, 0.91812, 0.91844, 0.91864, 0.91937,
                         0.92025, 0.92085, 0.92053, 0.91968, 0.91995, 0.92004, 0.92126,
                         0.92278, 0.92427, 0.92563, 0.92608, 0.92755, 0.92802, 0.92906,
                         0.92951, 0.93029, 0.93056, 0.93065, 0.93076, 0.93001, 0.92947, 0.78337],
                        [0.91572, 0.91564, 0.91551, 0.91677, 0.91713, 0.91821, 0.91845,
                         0.92006, 0.91973, 0.92026, 0.91993, 0.91982, 0.92006, 0.92050,
                         0.92247, 0.92387, 0.92479, 0.92561, 0.92699, 0.92769, 0.92839,
                         0.92957, 0.92936, 0.92956, 0.92974, 0.92972, 0.92911, 0.92846, 0.78261],
                        [0.91487, 0.91442, 0.91476, 0.91558, 0.91599, 0.91743, 0.91801,
                         0.91906, 0.91908, 0.91915, 0.91939, 0.91942, 0.91954, 0.91994,
                         0.92139, 0.92273, 0.92414, 0.92535, 0.92661, 0.92742, 0.92803,
                         0.92887, 0.92841, 0.92901, 0.92875, 0.92895, 0.92807, 0.92744, 0.78156],
                        [0.91277, 0.91299, 0.91376, 0.91403, 0.91448, 0.91554, 0.91665,
                         0.91713, 0.91844, 0.91814, 0.91845, 0.91855, 0.91857, 0.91916,
                         0.91980, 0.92102, 0.92277, 0.92437, 0.92579, 0.92620, 0.92745,
                         0.92735, 0.92797, 0.92823, 0.92755, 0.92740, 0.92627, 0.92631, 0.78033],
                        [0.91055, 0.91103, 0.91148, 0.91200, 0.91239, 0.91302, 0.91435,
                         0.91535, 0.91678, 0.91713, 0.91730, 0.91695, 0.91711, 0.91790,
                         0.91856, 0.91941, 0.92070, 0.92243, 0.92371, 0.92410, 0.92573,
                         0.92590, 0.92668, 0.92637, 0.92577, 0.92490, 0.92432, 0.92451, 0.77912],
                        [0.90883, 0.90885, 0.90894, 0.91007, 0.90992, 0.91084, 0.91235,
                         0.91358, 0.91442, 0.91553, 0.91559, 0.91541, 0.91569, 0.91623,
                         0.91707, 0.91810, 0.91860, 0.92052, 0.92115, 0.92194, 0.92346,
                         0.92418, 0.92374, 0.92382, 0.92339, 0.92239, 0.92222, 0.92215, 0.77824],
                        [0.90738, 0.90743, 0.90767, 0.90838, 0.90816, 0.90965, 0.91093,
                         0.91184, 0.91270, 0.91384, 0.91431, 0.91486, 0.91510, 0.91504,
                         0.91554, 0.91678, 0.91732, 0.91905, 0.91968, 0.92063, 0.92202,
                         0.92226, 0.92186, 0.92217, 0.92152, 0.92089, 0.92089, 0.92115, 0.77804],
                        [0.90600, 0.90633, 0.90663, 0.90664, 0.90726, 0.90833, 0.90914,
                         0.91020, 0.91183, 0.91263, 0.91360, 0.91446, 0.91423, 0.91431,
                         0.91433, 0.91498, 0.91633, 0.91729, 0.91862, 0.91957, 0.92061,
                         0.92054, 0.92117, 0.92092, 0.92006, 0.92011, 0.92062, 0.92118, 0.77786],
                        [0.90448, 0.90468, 0.90487, 0.90482, 0.90589, 0.90602, 0.90696,
                         0.90813, 0.91011, 0.91118, 0.91197, 0.91268, 0.91220, 0.91288,
                         0.91263, 0.91273, 0.91427, 0.91506, 0.91624, 0.91758, 0.91798,
                         0.91842, 0.91906, 0.91857, 0.91822, 0.91877, 0.91943, 0.92044, 0.77686],
                        [0.90312, 0.90300, 0.90354, 0.90355, 0.90392, 0.90408, 0.90515,
                         0.90641, 0.90747, 0.90896, 0.90974, 0.91050, 0.91072, 0.91099,
                         0.91108, 0.91105, 0.91191, 0.91333, 0.91372, 0.91501, 0.91574,
                         0.91627, 0.91627, 0.91623, 0.91646, 0.91703, 0.91755, 0.91919, 0.77599],
                        [0.90243, 0.90222, 0.90290, 0.90300, 0.90257, 0.90315, 0.90395,
                         0.90542, 0.90556, 0.90722, 0.90868, 0.90949, 0.91041, 0.90982,
                         0.91027, 0.91048, 0.91069, 0.91236, 0.91257, 0.91304, 0.91452,
                         0.91478, 0.91472, 0.91496, 0.91537, 0.91593, 0.91681, 0.91806, 0.77600],
                        [0.90244, 0.90228, 0.90240, 0.90274, 0.90239, 0.90283, 0.90321,
                         0.90443, 0.90485, 0.90648, 0.90835, 0.90902, 0.91014, 0.90956,
                         0.90976, 0.91026, 0.91023, 0.91146, 0.91203, 0.91194, 0.91328,
                         0.91368, 0.91418, 0.91415, 0.91491, 0.91565, 0.91720, 0.91764, 0.77625],
                        [0.90232, 0.90237, 0.90235, 0.90216, 0.90259, 0.90274, 0.90264,
                         0.90317, 0.90455, 0.90569, 0.90734, 0.90868, 0.90947, 0.90961,
                         0.90956, 0.90971, 0.90971, 0.91043, 0.91128, 0.91135, 0.91207,
                         0.91291, 0.91356, 0.91362, 0.91465, 0.91587, 0.91761, 0.91791, 0.77623],
                        [0.90188, 0.90206, 0.90223, 0.90169, 0.90222, 0.90226, 0.90195,
                         0.90206, 0.90329, 0.90463, 0.90593, 0.90776, 0.90829, 0.90928,
                         0.90932, 0.90883, 0.90900, 0.90984, 0.91027, 0.91085, 0.91120,
                         0.91231, 0.91266, 0.91322, 0.91418, 0.91560, 0.91748, 0.91814, 0.77602],
                        [0.90214, 0.90208, 0.90185, 0.90189, 0.90177, 0.90190, 0.90173,
                         0.90190, 0.90203, 0.90403, 0.90500, 0.90645, 0.90735, 0.90842,
                         0.90870, 0.90844, 0.90860, 0.90952, 0.90931, 0.91040, 0.91079,
                         0.91188, 0.91215, 0.91286, 0.91367, 0.91511, 0.91737, 0.91812, 0.77588],
                        [0.90292, 0.90279, 0.90246, 0.90275, 0.90231, 0.90241, 0.90250,
                         0.90283, 0.90267, 0.90386, 0.90482, 0.90601, 0.90758, 0.90813,
                         0.90868, 0.90903, 0.90914, 0.90958, 0.90938, 0.91055, 0.91090,
                         0.91206, 0.91250, 0.91339, 0.91444, 0.91608, 0.91814, 0.91839, 0.77598],
                        [0.90346, 0.90353, 0.90367, 0.90383, 0.90321, 0.90332, 0.90318,
                         0.90354, 0.90374, 0.90395, 0.90513, 0.90625, 0.90810, 0.90897,
                         0.90950, 0.90971, 0.91001, 0.91032, 0.91044, 0.91106, 0.91163,
                         0.91269, 0.91357, 0.91482, 0.91633, 0.91771, 0.91921, 0.91897, 0.77628],
                        [0.90372, 0.90399, 0.90456, 0.90433, 0.90389, 0.90391, 0.90319,
                         0.90342, 0.90344, 0.90425, 0.90538, 0.90629, 0.90777, 0.90954,
                         0.91013, 0.91018, 0.91040, 0.91092, 0.91089, 0.91143, 0.91239,
                         0.91316, 0.91399, 0.91587, 0.91716, 0.91855, 0.91932, 0.91918, 0.77658],
                        [0.90412, 0.90439, 0.90512, 0.90468, 0.90467, 0.90426, 0.90358,
                         0.90374, 0.90321, 0.90441, 0.90494, 0.90624, 0.90731, 0.90947,
                         0.91021, 0.91066, 0.91056, 0.91135, 0.91117, 0.91186, 0.91295,
                         0.91354, 0.91417, 0.91626, 0.91726, 0.91914, 0.91928, 0.91926, 0.77697],
                        [0.90489, 0.90497, 0.90526, 0.90560, 0.90515, 0.90489, 0.90490,
                         0.90475, 0.90400, 0.90457, 0.90468, 0.90648, 0.90735, 0.90967,
                         0.91031, 0.91097, 0.91153, 0.91226, 0.91252, 0.91261, 0.91372,
                         0.91424, 0.91540, 0.91639, 0.91799, 0.91968, 0.91999, 0.91972, 0.77745],
                        [0.90584, 0.90545, 0.90574, 0.90618, 0.90545, 0.90601, 0.90612,
                         0.90543, 0.90516, 0.90507, 0.90566, 0.90690, 0.90758, 0.90976,
                         0.91056, 0.91142, 0.91291, 0.91287, 0.91367, 0.91357, 0.91423,
                         0.91512, 0.91652, 0.91701, 0.91914, 0.91993, 0.92057, 0.92001, 0.77765],
                        [0.90668, 0.90573, 0.90621, 0.90612, 0.90610, 0.90703, 0.90645,
                         0.90602, 0.90600, 0.90566, 0.90664, 0.90673, 0.90773, 0.90934,
                         0.91076, 0.91206, 0.91322, 0.91282, 0.91370, 0.91444, 0.91466,
                         0.91584, 0.91699, 0.91808, 0.91984, 0.92009, 0.92042, 0.91964, 0.77810],
                        [0.90665, 0.90591, 0.90614, 0.90648, 0.90680, 0.90706, 0.90667,
                         0.90699, 0.90643, 0.90628, 0.90642, 0.90629, 0.90776, 0.90913,
                         0.91080, 0.91246, 0.91285, 0.91344, 0.91379, 0.91509, 0.91583,
                         0.91630, 0.91774, 0.91890, 0.92015, 0.92020, 0.91985, 0.91958, 0.77896],
                        [0.90625, 0.90656, 0.90680, 0.90750, 0.90743, 0.90725, 0.90780,
                         0.90806, 0.90745, 0.90718, 0.90658, 0.90681, 0.90791, 0.90951,
                         0.91075, 0.91256, 0.91303, 0.91478, 0.91459, 0.91571, 0.91674,
                         0.91659, 0.91898, 0.91955, 0.92081, 0.92037, 0.91973, 0.92021, 0.78025],
                        [0.90665, 0.90757, 0.90797, 0.90832, 0.90844, 0.90842, 0.90907,
                         0.90904, 0.90892, 0.90827, 0.90805, 0.90785, 0.90838, 0.90977,
                         0.91059, 0.91245, 0.91371, 0.91515, 0.91572, 0.91658, 0.91709,
                         0.91758, 0.91974, 0.92006, 0.92132, 0.92069, 0.92043, 0.92119, 0.78199],
                        [0.90747, 0.90795, 0.90859, 0.90843, 0.90939, 0.90947, 0.90969,
                         0.90992, 0.90996, 0.90939, 0.90937, 0.90903, 0.90881, 0.90966,
                         0.91086, 0.91246, 0.91411, 0.91493, 0.91645, 0.91752, 0.91793,
                         0.91930, 0.91958, 0.92025, 0.92132, 0.92131, 0.92115, 0.92241, 0.78349],
                        [0.90866, 0.90838, 0.90936, 0.90882, 0.91013, 0.91044, 0.91089,
                         0.91110, 0.91121, 0.91063, 0.91064, 0.91066, 0.90995, 0.91041,
                         0.91176, 0.91316, 0.91432, 0.91580, 0.91705, 0.91840, 0.91932,
                         0.92054, 0.91972, 0.92097, 0.92166, 0.92249, 0.92197, 0.92386, 0.78493],
                        [0.91014, 0.90985, 0.91039, 0.91029, 0.91103, 0.91198, 0.91281,
                         0.91265, 0.91304, 0.91236, 0.91224, 0.91203, 0.91183, 0.91183,
                         0.91287, 0.91434, 0.91511, 0.91731, 0.91822, 0.91894, 0.92051,
                         0.92113, 0.92120, 0.92267, 0.92279, 0.92362, 0.92316, 0.92572, 0.78700],
                        [0.91127, 0.91145, 0.91112, 0.91179, 0.91197, 0.91302, 0.91409,
                         0.91431, 0.91458, 0.91464, 0.91362, 0.91317, 0.91287, 0.91288,
                         0.91381, 0.91537, 0.91615, 0.91781, 0.91911, 0.91939, 0.92117,
                         0.92154, 0.92283, 0.92404, 0.92408, 0.92407, 0.92422, 0.92729, 0.78899],
                        [0.91234, 0.91274, 0.91249, 0.91314, 0.91335, 0.91366, 0.91532,
                         0.91630, 0.91590, 0.91677, 0.91552, 0.91497, 0.91413, 0.91427,
                         0.91480, 0.91631, 0.91730, 0.91809, 0.92024, 0.92069, 0.92197,
                         0.92292, 0.92372, 0.92485, 0.92516, 0.92485, 0.92562, 0.92891, 0.79065],
                        [0.91423, 0.91451, 0.91479, 0.91509, 0.91555, 0.91574, 0.91730,
                         0.91832, 0.91800, 0.91867, 0.91848, 0.91776, 0.91702, 0.91654,
                         0.91689, 0.91789, 0.91928, 0.91989, 0.92219, 0.92281, 0.92376,
                         0.92537, 0.92521, 0.92625, 0.92661, 0.92675, 0.92772, 0.93180, 0.79287],
                        [0.91632, 0.91631, 0.91667, 0.91681, 0.91756, 0.91807, 0.91900,
                         0.91988, 0.92044, 0.92073, 0.92099, 0.92052, 0.91968, 0.91877,
                         0.91939, 0.91965, 0.92121, 0.92204, 0.92365, 0.92430, 0.92562,
                         0.92694, 0.92711, 0.92783, 0.92818, 0.92848, 0.92964, 0.93476, 0.79502],
                        [0.91766, 0.91747, 0.91801, 0.91814, 0.91871, 0.91914, 0.92018,
                         0.92093, 0.92185, 0.92261, 0.92247, 0.92230, 0.92133, 0.92082,
                         0.92085, 0.92106, 0.92231, 0.92310, 0.92456, 0.92511, 0.92659,
                         0.92747, 0.92835, 0.92893, 0.92930, 0.92938, 0.93145, 0.93667, 0.79638],
                        [0.91882, 0.91866, 0.91932, 0.91959, 0.91981, 0.92021, 0.92145,
                         0.92214, 0.92277, 0.92388, 0.92418, 0.92385, 0.92337, 0.92287,
                         0.92206, 0.92231, 0.92333, 0.92421, 0.92558, 0.92644, 0.92752,
                         0.92856, 0.92932, 0.92965, 0.93038, 0.93033, 0.93341, 0.93831, 0.79713],
                        [0.92050, 0.92038, 0.92052, 0.92079, 0.92133, 0.92173, 0.92259,
                         0.92359, 0.92425, 0.92514, 0.92602, 0.92589, 0.92573, 0.92474,
                         0.92410, 0.92372, 0.92474, 0.92591, 0.92673, 0.92801, 0.92897,
                         0.93018, 0.93033, 0.93072, 0.93178, 0.93201, 0.93521, 0.94011, 0.79788],
                        [0.92240, 0.92219, 0.92205, 0.92236, 0.92266, 0.92295, 0.92345,
                         0.92490, 0.92590, 0.92697, 0.92755, 0.92765, 0.92793, 0.92657,
                         0.92661, 0.92606, 0.92622, 0.92730, 0.92779, 0.92880, 0.93055,
                         0.93145, 0.93157, 0.93250, 0.93316, 0.93427, 0.93734, 0.94210, 0.79872],
                        [0.92407, 0.92380, 0.92384, 0.92451, 0.92381, 0.92428, 0.92517,
                         0.92608, 0.92744, 0.92869, 0.92923, 0.92964, 0.92993, 0.92894,
                         0.92910, 0.92855, 0.92816, 0.92873, 0.92936, 0.93001, 0.93196,
                         0.93275, 0.93336, 0.93410, 0.93466, 0.93660, 0.93988, 0.94403, 0.79959],
                        [0.92505, 0.92527, 0.92513, 0.92591, 0.92508, 0.92554, 0.92701,
                         0.92695, 0.92823, 0.92952, 0.93044, 0.93150, 0.93149, 0.93132,
                         0.93100, 0.93015, 0.93040, 0.93036, 0.93127, 0.93209, 0.93295,
                         0.93397, 0.93472, 0.93480, 0.93608, 0.93796, 0.94137, 0.94541, 0.80036],
                        [0.92571, 0.92632, 0.92621, 0.92640, 0.92615, 0.92622, 0.92732,
                         0.92774, 0.92836, 0.92962, 0.93111, 0.93205, 0.93270, 0.93260,
                         0.93196, 0.93131, 0.93152, 0.93148, 0.93247, 0.93338, 0.93383,
                         0.93472, 0.93492, 0.93545, 0.93685, 0.93859, 0.94195, 0.94612, 0.80051],
                        [0.92632, 0.92661, 0.92694, 0.92658, 0.92693, 0.92679, 0.92693,
                         0.92825, 0.92885, 0.92947, 0.93141, 0.93206, 0.93362, 0.93311,
                         0.93282, 0.93255, 0.93209, 0.93244, 0.93296, 0.93355, 0.93468,
                         0.93525, 0.93496, 0.93659, 0.93757, 0.93965, 0.94279, 0.94624, 0.80003],
                        [0.92709, 0.92695, 0.92727, 0.92714, 0.92750, 0.92756, 0.92743,
                         0.92860, 0.92960, 0.92979, 0.93147, 0.93268, 0.93430, 0.93397,
                         0.93416, 0.93399, 0.93359, 0.93369, 0.93389, 0.93398, 0.93522,
                         0.93589, 0.93574, 0.93760, 0.93880, 0.94091, 0.94397, 0.94674, 0.79969],
                        [0.92809, 0.92766, 0.92812, 0.92830, 0.92821, 0.92826, 0.92848,
                         0.92916, 0.92995, 0.93062, 0.93195, 0.93362, 0.93477, 0.93538,
                         0.93532, 0.93536, 0.93503, 0.93488, 0.93541, 0.93504, 0.93594,
                         0.93663, 0.93669, 0.93810, 0.93988, 0.94195, 0.94481, 0.94741, 0.79970],
                        [0.92866, 0.92841, 0.92881, 0.92887, 0.92867, 0.92860, 0.92902,
                         0.92943, 0.92966, 0.93091, 0.93188, 0.93371, 0.93484, 0.93631,
                         0.93627, 0.93618, 0.93537, 0.93567, 0.93617, 0.93587, 0.93657,
                         0.93690, 0.93742, 0.93848, 0.94024, 0.94261, 0.94522, 0.94722, 0.79956],
                        [0.92892, 0.92929, 0.92844, 0.92881, 0.92889, 0.92885, 0.92897,
                         0.92933, 0.92960, 0.93053, 0.93142, 0.93307, 0.93477, 0.93598,
                         0.93690, 0.93665, 0.93581, 0.93631, 0.93610, 0.93658, 0.93694,
                         0.93715, 0.93818, 0.93923, 0.94073, 0.94319, 0.94575, 0.94684, 0.79945],
                        [0.92897, 0.92944, 0.92808, 0.92881, 0.92904, 0.92895, 0.92854,
                         0.92905, 0.92980, 0.93035, 0.93148, 0.93260, 0.93430, 0.93533,
                         0.93680, 0.93691, 0.93671, 0.93676, 0.93609, 0.93703, 0.93714,
                         0.93789, 0.93863, 0.93976, 0.94167, 0.94396, 0.94583, 0.94660, 0.79928],
                        [0.92886, 0.92887, 0.92859, 0.92916, 0.92937, 0.92906, 0.92879,
                         0.92897, 0.92980, 0.93068, 0.93132, 0.93246, 0.93367, 0.93546,
                         0.93661, 0.93684, 0.93741, 0.93708, 0.93652, 0.93684, 0.93734,
                         0.93863, 0.93902, 0.94003, 0.94223, 0.94420, 0.94557, 0.94646, 0.79880],
                        [0.92890, 0.92853, 0.92912, 0.92932, 0.92975, 0.92974, 0.92982,
                         0.92927, 0.92961, 0.93044, 0.93055, 0.93209, 0.93353, 0.93547,
                         0.93648, 0.93701, 0.93769, 0.93758, 0.93714, 0.93707, 0.93795,
                         0.93845, 0.93953, 0.94059, 0.94242, 0.94399, 0.94583, 0.94611, 0.79843],
                        [0.92895, 0.92871, 0.92928, 0.92930, 0.92957, 0.93015, 0.93027,
                         0.92969, 0.92955, 0.92978, 0.93020, 0.93152, 0.93346, 0.93470,
                         0.93618, 0.93743, 0.93767, 0.93793, 0.93792, 0.93829, 0.93878,
                         0.93825, 0.93985, 0.94118, 0.94270, 0.94413, 0.94614, 0.94528, 0.79867],
                        [0.92881, 0.92872, 0.92907, 0.92911, 0.92893, 0.92976, 0.92974,
                         0.93009, 0.92976, 0.92971, 0.93029, 0.93108, 0.93288, 0.93383,
                         0.93559, 0.93707, 0.93747, 0.93769, 0.93843, 0.93896, 0.93893,
                         0.93910, 0.94016, 0.94130, 0.94289, 0.94458, 0.94567, 0.94460, 0.79882],
                        [0.92862, 0.92840, 0.92891, 0.92878, 0.92879, 0.92965, 0.92932,
                         0.93049, 0.93006, 0.93013, 0.93009, 0.93053, 0.93243, 0.93349,
                         0.93489, 0.93677, 0.93774, 0.93786, 0.93872, 0.93896, 0.93878,
                         0.94009, 0.94077, 0.94183, 0.94324, 0.94478, 0.94517, 0.94481, 0.79863],
                        [0.92825, 0.92827, 0.92880, 0.92839, 0.92908, 0.92964, 0.92969,
                         0.93001, 0.93035, 0.92994, 0.92984, 0.93023, 0.93181, 0.93325,
                         0.93430, 0.93660, 0.93782, 0.93835, 0.93880, 0.93906, 0.93908,
                         0.94033, 0.94112, 0.94260, 0.94342, 0.94443, 0.94492, 0.94522, 0.79837],
                        [0.92807, 0.92820, 0.92830, 0.92803, 0.92894, 0.92921, 0.93007,
                         0.92939, 0.93032, 0.92917, 0.92994, 0.93071, 0.93104, 0.93300,
                         0.93382, 0.93580, 0.93701, 0.93807, 0.93875, 0.93916, 0.93934,
                         0.94028, 0.94111, 0.94261, 0.94320, 0.94392, 0.94430, 0.94521, 0.79811],
                        [0.92767, 0.92734, 0.92778, 0.92778, 0.92805, 0.92882, 0.92957,
                         0.92937, 0.93006, 0.92920, 0.92999, 0.93042, 0.93065, 0.93241,
                         0.93346, 0.93483, 0.93623, 0.93716, 0.93855, 0.93881, 0.93958,
                         0.94011, 0.94106, 0.94208, 0.94247, 0.94344, 0.94360, 0.94447, 0.79797],
                        [0.92684, 0.92652, 0.92749, 0.92766, 0.92764, 0.92904, 0.92910,
                         0.92953, 0.93000, 0.93023, 0.93009, 0.92957, 0.93070, 0.93153,
                         0.93365, 0.93437, 0.93603, 0.93684, 0.93837, 0.93869, 0.93991,
                         0.94014, 0.94126, 0.94197, 0.94211, 0.94286, 0.94324, 0.94369, 0.79800],
                        [0.92643, 0.92636, 0.92718, 0.92733, 0.92796, 0.92894, 0.92906,
                         0.92991, 0.92987, 0.93067, 0.93021, 0.92982, 0.93088, 0.93073,
                         0.93351, 0.93425, 0.93583, 0.93667, 0.93800, 0.93898, 0.93968,
                         0.94070, 0.94134, 0.94231, 0.94229, 0.94229, 0.94255, 0.94349, 0.79822],
                        [0.92640, 0.92662, 0.92696, 0.92718, 0.92816, 0.92800, 0.92900,
                         0.93015, 0.92985, 0.93045, 0.93052, 0.93065, 0.93099, 0.93083,
                         0.93252, 0.93364, 0.93534, 0.93639, 0.93756, 0.93882, 0.93950,
                         0.94106, 0.94102, 0.94241, 0.94240, 0.94232, 0.94216, 0.94382, 0.79847],
                        [0.92610, 0.92651, 0.92681, 0.92725, 0.92778, 0.92741, 0.92857,
                         0.92953, 0.92983, 0.93034, 0.93049, 0.93052, 0.93058, 0.93161,
                         0.93159, 0.93293, 0.93480, 0.93621, 0.93732, 0.93827, 0.93940,
                         0.94036, 0.94023, 0.94172, 0.94219, 0.94217, 0.94238, 0.94418, 0.79844],
                        [0.92568, 0.92580, 0.92629, 0.92674, 0.92689, 0.92733, 0.92806,
                         0.92891, 0.92965, 0.93033, 0.92987, 0.92993, 0.92987, 0.93149,
                         0.93136, 0.93252, 0.93417, 0.93585, 0.93694, 0.93777, 0.93884,
                         0.93937, 0.93952, 0.94064, 0.94151, 0.94116, 0.94214, 0.94388, 0.79838],
                        [0.92563, 0.92533, 0.92547, 0.92607, 0.92647, 0.92711, 0.92755,
                         0.92886, 0.92942, 0.93010, 0.92972, 0.92994, 0.92992, 0.93062,
                         0.93098, 0.93201, 0.93330, 0.93541, 0.93624, 0.93742, 0.93794,
                         0.93888, 0.93937, 0.93935, 0.94070, 0.94049, 0.94173, 0.94323, 0.79848],
                        [0.92572, 0.92565, 0.92577, 0.92601, 0.92680, 0.92736, 0.92748,
                         0.92878, 0.92931, 0.93020, 0.93041, 0.93073, 0.93084, 0.93040,
                         0.93062, 0.93192, 0.93291, 0.93496, 0.93583, 0.93703, 0.93770,
                         0.93868, 0.93958, 0.93899, 0.94029, 0.94037, 0.94181, 0.94348, 0.79883],
                        [0.92558, 0.92626, 0.92667, 0.92607, 0.92689, 0.92765, 0.92796,
                         0.92827, 0.92941, 0.93015, 0.93102, 0.93125, 0.93140, 0.93082,
                         0.93084, 0.93219, 0.93302, 0.93431, 0.93554, 0.93648, 0.93794,
                         0.93839, 0.93941, 0.93985, 0.94014, 0.94037, 0.94208, 0.94422, 0.79915],
                        [0.92582, 0.92648, 0.92677, 0.92612, 0.92656, 0.92727, 0.92796,
                         0.92788, 0.92937, 0.92960, 0.93104, 0.93091, 0.93138, 0.93116,
                         0.93112, 0.93198, 0.93291, 0.93388, 0.93493, 0.93614, 0.93769,
                         0.93819, 0.93881, 0.93998, 0.93989, 0.94057, 0.94224, 0.94449, 0.79923],
                        [0.92659, 0.92650, 0.92648, 0.92650, 0.92650, 0.92698, 0.92746,
                         0.92825, 0.92928, 0.92974, 0.93101, 0.93085, 0.93176, 0.93153,
                         0.93159, 0.93176, 0.93286, 0.93367, 0.93477, 0.93608, 0.93721,
                         0.93834, 0.93860, 0.93921, 0.93966, 0.94072, 0.94223, 0.94485, 0.79926],
                        [0.92719, 0.92660, 0.92685, 0.92726, 0.92679, 0.92719, 0.92741,
                         0.92869, 0.92943, 0.93039, 0.93111, 0.93147, 0.93234, 0.93238,
                         0.93211, 0.93237, 0.93298, 0.93374, 0.93506, 0.93593, 0.93689,
                         0.93808, 0.93874, 0.93893, 0.93969, 0.94107, 0.94278, 0.94539, 0.79925],
                        [0.92737, 0.92694, 0.92759, 0.92799, 0.92731, 0.92775, 0.92808,
                         0.92907, 0.92975, 0.93088, 0.93178, 0.93238, 0.93277, 0.93320,
                         0.93257, 0.93314, 0.93341, 0.93406, 0.93526, 0.93599, 0.93685,
                         0.93762, 0.93894, 0.93937, 0.94038, 0.94188, 0.94402, 0.94572, 0.79941],
                        [0.92728, 0.92685, 0.92744, 0.92774, 0.92757, 0.92768, 0.92849,
                         0.92883, 0.92959, 0.93064, 0.93183, 0.93243, 0.93269, 0.93295,
                         0.93276, 0.93303, 0.93365, 0.93364, 0.93493, 0.93581, 0.93673,
                         0.93755, 0.93848, 0.93927, 0.94101, 0.94179, 0.94435, 0.94536, 0.79923],
                        [0.92737, 0.92683, 0.92710, 0.92760, 0.92765, 0.92744, 0.92873,
                         0.92806, 0.92905, 0.93009, 0.93076, 0.93184, 0.93256, 0.93259,
                         0.93295, 0.93310, 0.93362, 0.93355, 0.93449, 0.93571, 0.93661,
                         0.93786, 0.93815, 0.93913, 0.94099, 0.94143, 0.94392, 0.94519, 0.79860],
                        [0.92762, 0.92748, 0.92756, 0.92830, 0.92819, 0.92789, 0.92871,
                         0.92822, 0.92911, 0.93007, 0.93040, 0.93227, 0.93275, 0.93297,
                         0.93358, 0.93380, 0.93413, 0.93471, 0.93488, 0.93646, 0.93646,
                         0.93810, 0.93839, 0.93978, 0.94088, 0.94212, 0.94378, 0.94554, 0.79823],
                        [0.92814, 0.92797, 0.92809, 0.92842, 0.92853, 0.92848, 0.92823,
                         0.92911, 0.93000, 0.93036, 0.93106, 0.93299, 0.93296, 0.93375,
                         0.93414, 0.93421, 0.93472, 0.93554, 0.93548, 0.93693, 0.93661,
                         0.93823, 0.93891, 0.94024, 0.94128, 0.94311, 0.94427, 0.94566, 0.79839],
                        [0.92865, 0.92808, 0.92853, 0.92811, 0.92835, 0.92880, 0.92836,
                         0.92958, 0.93062, 0.93066, 0.93135, 0.93261, 0.93330, 0.93433,
                         0.93430, 0.93449, 0.93520, 0.93567, 0.93579, 0.93689, 0.93744,
                         0.93846, 0.94000, 0.94025, 0.94203, 0.94390, 0.94502, 0.94537, 0.79846],
                        [0.92831, 0.92832, 0.92862, 0.92838, 0.92828, 0.92888, 0.92890,
                         0.92941, 0.92992, 0.93052, 0.93108, 0.93172, 0.93330, 0.93431,
                         0.93485, 0.93510, 0.93569, 0.93595, 0.93629, 0.93721, 0.93808,
                         0.93857, 0.94034, 0.94033, 0.94237, 0.94417, 0.94520, 0.94492, 0.79794],
                        [0.92750, 0.92827, 0.92779, 0.92853, 0.92812, 0.92889, 0.92882,
                         0.92889, 0.92881, 0.92977, 0.93090, 0.93115, 0.93253, 0.93358,
                         0.93554, 0.93569, 0.93564, 0.93615, 0.93663, 0.93709, 0.93804,
                         0.93844, 0.93918, 0.94042, 0.94211, 0.94335, 0.94468, 0.94412, 0.79704],
                        [0.92732, 0.92743, 0.92726, 0.92809, 0.92818, 0.92882, 0.92841,
                         0.92870, 0.92877, 0.92931, 0.93076, 0.93101, 0.93218, 0.93284,
                         0.93520, 0.93552, 0.93549, 0.93609, 0.93660, 0.93683, 0.93804,
                         0.93853, 0.93877, 0.94047, 0.94197, 0.94265, 0.94413, 0.94316, 0.79648],
                        [0.92767, 0.92676, 0.92738, 0.92758, 0.92831, 0.92839, 0.92831,
                         0.92904, 0.92919, 0.92914, 0.93019, 0.93089, 0.93221, 0.93267,
                         0.93424, 0.93497, 0.93554, 0.93592, 0.93651, 0.93686, 0.93802,
                         0.93884, 0.93993, 0.94076, 0.94187, 0.94253, 0.94341, 0.94238, 0.79633],
                        [0.92701, 0.92638, 0.92673, 0.92684, 0.92755, 0.92748, 0.92810,
                         0.92885, 0.92877, 0.92850, 0.92908, 0.93002, 0.93118, 0.93226,
                         0.93299, 0.93454, 0.93520, 0.93526, 0.93622, 0.93636, 0.93732,
                         0.93883, 0.94014, 0.94062, 0.94104, 0.94180, 0.94211, 0.94149, 0.79578],
                        [0.92552, 0.92564, 0.92566, 0.92603, 0.92638, 0.92686, 0.92729,
                         0.92781, 0.92787, 0.92775, 0.92794, 0.92877, 0.92985, 0.93153,
                         0.93199, 0.93368, 0.93442, 0.93471, 0.93575, 0.93594, 0.93646,
                         0.93824, 0.93902, 0.93962, 0.94012, 0.94103, 0.94115, 0.94062, 0.79503],
                        [0.92465, 0.92493, 0.92508, 0.92566, 0.92564, 0.92669, 0.92697,
                         0.92716, 0.92757, 0.92768, 0.92754, 0.92838, 0.92935, 0.93105,
                         0.93201, 0.93302, 0.93386, 0.93481, 0.93571, 0.93588, 0.93644,
                         0.93764, 0.93838, 0.93913, 0.93979, 0.94076, 0.94054, 0.94005, 0.79493],
                        [0.92469, 0.92452, 0.92474, 0.92558, 0.92526, 0.92629, 0.92693,
                         0.92734, 0.92750, 0.92786, 0.92787, 0.92866, 0.92937, 0.93052,
                         0.93160, 0.93284, 0.93364, 0.93480, 0.93535, 0.93607, 0.93691,
                         0.93756, 0.93807, 0.93932, 0.93953, 0.94006, 0.93964, 0.93972, 0.79543],
                        [0.92453, 0.92403, 0.92417, 0.92493, 0.92493, 0.92553, 0.92638,
                         0.92708, 0.92701, 0.92746, 0.92773, 0.92826, 0.92889, 0.92966,
                         0.93048, 0.93211, 0.93297, 0.93382, 0.93429, 0.93608, 0.93669,
                         0.93724, 0.93742, 0.93880, 0.93911, 0.93872, 0.93896, 0.93918, 0.79562],
                        [0.92374, 0.92365, 0.92365, 0.92407, 0.92456, 0.92476, 0.92607,
                         0.92601, 0.92651, 0.92693, 0.92717, 0.92727, 0.92784, 0.92892,
                         0.92997, 0.93108, 0.93230, 0.93297, 0.93380, 0.93548, 0.93612,
                         0.93667, 0.93706, 0.93802, 0.93866, 0.93780, 0.93852, 0.93877, 0.79538],
                        [0.92290, 0.92336, 0.92339, 0.92375, 0.92424, 0.92459, 0.92565,
                         0.92528, 0.92610, 0.92675, 0.92691, 0.92679, 0.92727, 0.92847,
                         0.92972, 0.93031, 0.93177, 0.93300, 0.93403, 0.93472, 0.93554,
                         0.93637, 0.93716, 0.93750, 0.93816, 0.93770, 0.93809, 0.93894, 0.79564],
                        [0.92242, 0.92306, 0.92336, 0.92380, 0.92402, 0.92520, 0.92512,
                         0.92566, 0.92620, 0.92680, 0.92715, 0.92727, 0.92765, 0.92823,
                         0.92921, 0.92996, 0.93124, 0.93287, 0.93425, 0.93437, 0.93489,
                         0.93618, 0.93710, 0.93718, 0.93785, 0.93773, 0.93778, 0.93926, 0.79664],
                        [0.92227, 0.92268, 0.92332, 0.92374, 0.92362, 0.92521, 0.92507,
                         0.92597, 0.92648, 0.92691, 0.92741, 0.92768, 0.92803, 0.92803,
                         0.92889, 0.92960, 0.93118, 0.93204, 0.93351, 0.93437, 0.93465,
                         0.93603, 0.93678, 0.93682, 0.93783, 0.93757, 0.93763, 0.93930, 0.79737],
                        [0.92242, 0.92269, 0.92322, 0.92378, 0.92356, 0.92479, 0.92522,
                         0.92603, 0.92640, 0.92691, 0.92751, 0.92784, 0.92821, 0.92813,
                         0.92903, 0.92953, 0.93104, 0.93191, 0.93240, 0.93424, 0.93491,
                         0.93601, 0.93657, 0.93661, 0.93794, 0.93754, 0.93768, 0.93991, 0.79783],
                        [0.92292, 0.92306, 0.92340, 0.92407, 0.92384, 0.92487, 0.92543,
                         0.92606, 0.92654, 0.92731, 0.92780, 0.92800, 0.92832, 0.92843,
                         0.92933, 0.92992, 0.93050, 0.93235, 0.93225, 0.93391, 0.93503,
                         0.93592, 0.93625, 0.93672, 0.93767, 0.93741, 0.93780, 0.94118, 0.79859],
                        [0.92345, 0.92302, 0.92350, 0.92395, 0.92396, 0.92470, 0.92536,
                         0.92550, 0.92656, 0.92759, 0.92808, 0.92814, 0.92802, 0.92882,
                         0.92955, 0.92997, 0.93038, 0.93221, 0.93279, 0.93391, 0.93494,
                         0.93568, 0.93581, 0.93709, 0.93686, 0.93734, 0.93831, 0.94171, 0.79928],
                        [0.92317, 0.92280, 0.92317, 0.92350, 0.92397, 0.92448, 0.92484,
                         0.92530, 0.92636, 0.92734, 0.92830, 0.92868, 0.92801, 0.92891,
                         0.92961, 0.92975, 0.93072, 0.93172, 0.93294, 0.93416, 0.93489,
                         0.93549, 0.93579, 0.93728, 0.93642, 0.93768, 0.93899, 0.94178, 0.79988],
                        [0.92271, 0.92319, 0.92320, 0.92352, 0.92421, 0.92466, 0.92480,
                         0.92590, 0.92645, 0.92755, 0.92828, 0.92929, 0.92863, 0.92890,
                         0.92931, 0.92977, 0.93098, 0.93147, 0.93267, 0.93412, 0.93492,
                         0.93571, 0.93614, 0.93711, 0.93723, 0.93822, 0.93966, 0.94253, 0.80043],
                        [0.92321, 0.92396, 0.92361, 0.92399, 0.92448, 0.92464, 0.92546,
                         0.92620, 0.92652, 0.92790, 0.92804, 0.92923, 0.92919, 0.92912,
                         0.92929, 0.93009, 0.93101, 0.93177, 0.93267, 0.93352, 0.93488,
                         0.93630, 0.93645, 0.93687, 0.93801, 0.93860, 0.94042, 0.94345, 0.80071],
                        [0.92408, 0.92413, 0.92397, 0.92467, 0.92444, 0.92486, 0.92599,
                         0.92600, 0.92692, 0.92838, 0.92836, 0.92940, 0.92971, 0.92980,
                         0.93018, 0.93079, 0.93103, 0.93260, 0.93324, 0.93328, 0.93500,
                         0.93658, 0.93675, 0.93698, 0.93795, 0.93891, 0.94079, 0.94397, 0.80098],
                        [0.92474, 0.92423, 0.92449, 0.92562, 0.92461, 0.92553, 0.92594,
                         0.92640, 0.92782, 0.92887, 0.92927, 0.93013, 0.93053, 0.93107,
                         0.93135, 0.93156, 0.93162, 0.93307, 0.93379, 0.93427, 0.93565,
                         0.93658, 0.93702, 0.93771, 0.93802, 0.93954, 0.94137, 0.94449, 0.80127],
                        [0.92488, 0.92454, 0.92468, 0.92543, 0.92495, 0.92585, 0.92565,
                         0.92667, 0.92811, 0.92809, 0.92979, 0.93026, 0.93094, 0.93167,
                         0.93163, 0.93184, 0.93219, 0.93289, 0.93368, 0.93485, 0.93602,
                         0.93622, 0.93729, 0.93790, 0.93862, 0.94021, 0.94243, 0.94509, 0.80130],
                        [0.92475, 0.92468, 0.92464, 0.92439, 0.92524, 0.92596, 0.92574,
                         0.92632, 0.92765, 0.92742, 0.92962, 0.92995, 0.93087, 0.93156,
                         0.93129, 0.93190, 0.93236, 0.93319, 0.93344, 0.93452, 0.93581,
                         0.93593, 0.93781, 0.93768, 0.93914, 0.94072, 0.94315, 0.94544, 0.80139],
                        [0.92491, 0.92469, 0.92505, 0.92464, 0.92575, 0.92637, 0.92636,
                         0.92636, 0.92748, 0.92804, 0.92913, 0.93024, 0.93093, 0.93163,
                         0.93186, 0.93226, 0.93297, 0.93401, 0.93411, 0.93483, 0.93587,
                         0.93648, 0.93814, 0.93831, 0.93941, 0.94158, 0.94364, 0.94583, 0.80153],
                        [0.92523, 0.92508, 0.92561, 0.92614, 0.92621, 0.92676, 0.92713,
                         0.92698, 0.92793, 0.92880, 0.92891, 0.93059, 0.93126, 0.93201,
                         0.93285, 0.93305, 0.93372, 0.93454, 0.93497, 0.93534, 0.93638,
                         0.93713, 0.93827, 0.93931, 0.93985, 0.94229, 0.94415, 0.94615, 0.80170],
                        [0.92568, 0.92583, 0.92609, 0.92723, 0.92655, 0.92700, 0.92765,
                         0.92750, 0.92817, 0.92909, 0.92917, 0.93066, 0.93167, 0.93238,
                         0.93299, 0.93371, 0.93413, 0.93486, 0.93539, 0.93566, 0.93677,
                         0.93755, 0.93856, 0.93968, 0.94064, 0.94246, 0.94432, 0.94620, 0.80225],
                        [0.92609, 0.92632, 0.92645, 0.92698, 0.92705, 0.92706, 0.92776,
                         0.92769, 0.92796, 0.92888, 0.92973, 0.93078, 0.93182, 0.93265,
                         0.93303, 0.93401, 0.93446, 0.93507, 0.93580, 0.93621, 0.93697,
                         0.93816, 0.93857, 0.93949, 0.94142, 0.94256, 0.94446, 0.94678, 0.80240],
                        [0.92617, 0.92665, 0.92639, 0.92647, 0.92721, 0.92682, 0.92785,
                         0.92810, 0.92798, 0.92876, 0.93020, 0.93056, 0.93162, 0.93297,
                         0.93348, 0.93399, 0.93450, 0.93499, 0.93569, 0.93630, 0.93721,
                         0.93820, 0.93838, 0.93959, 0.94155, 0.94298, 0.94517, 0.94718, 0.80182],
                        [0.92650, 0.92700, 0.92665, 0.92718, 0.92712, 0.92708, 0.92829,
                         0.92870, 0.92874, 0.92926, 0.93026, 0.93066, 0.93168, 0.93310,
                         0.93387, 0.93438, 0.93480, 0.93548, 0.93565, 0.93658, 0.93778,
                         0.93809, 0.93904, 0.94034, 0.94161, 0.94322, 0.94592, 0.94708, 0.80150],
                        [0.92681, 0.92684, 0.92714, 0.92799, 0.92747, 0.92795, 0.92874,
                         0.92883, 0.92937, 0.92951, 0.92991, 0.93114, 0.93210, 0.93292,
                         0.93413, 0.93474, 0.93533, 0.93624, 0.93652, 0.93715, 0.93831,
                         0.93844, 0.93961, 0.94099, 0.94189, 0.94310, 0.94566, 0.94698, 0.80184],
                        [0.92670, 0.92665, 0.92704, 0.92765, 0.92818, 0.92854, 0.92944,
                         0.92922, 0.92999, 0.92956, 0.93021, 0.93130, 0.93256, 0.93323,
                         0.93431, 0.93474, 0.93581, 0.93667, 0.93729, 0.93759, 0.93823,
                         0.93910, 0.93976, 0.94170, 0.94272, 0.94374, 0.94544, 0.94698, 0.80264],
                        [0.92710, 0.92732, 0.92746, 0.92774, 0.92860, 0.92905, 0.92999,
                         0.93041, 0.93099, 0.93054, 0.93144, 0.93152, 0.93306, 0.93395,
                         0.93470, 0.93546, 0.93656, 0.93711, 0.93761, 0.93832, 0.93848,
                         0.94027, 0.94068, 0.94252, 0.94364, 0.94488, 0.94602, 0.94739, 0.80335],
                        [0.92778, 0.92840, 0.92852, 0.92868, 0.92887, 0.92962, 0.92990,
                         0.93102, 0.93131, 0.93179, 0.93214, 0.93185, 0.93337, 0.93406,
                         0.93537, 0.93627, 0.93693, 0.93770, 0.93799, 0.93895, 0.93926,
                         0.94072, 0.94161, 0.94268, 0.94390, 0.94549, 0.94664, 0.94808, 0.80358],
                        [0.92809, 0.92873, 0.92887, 0.92914, 0.92921, 0.92987, 0.93011,
                         0.93089, 0.93110, 0.93217, 0.93216, 0.93247, 0.93322, 0.93378,
                         0.93569, 0.93632, 0.93683, 0.93805, 0.93840, 0.93915, 0.94001,
                         0.94029, 0.94186, 0.94273, 0.94405, 0.94556, 0.94700, 0.94836, 0.80360],
                        [0.92841, 0.92809, 0.92872, 0.92911, 0.92942, 0.93015, 0.93113,
                         0.93109, 0.93168, 0.93233, 0.93258, 0.93327, 0.93293, 0.93417,
                         0.93551, 0.93647, 0.93721, 0.93779, 0.93879, 0.93917, 0.94110,
                         0.94074, 0.94235, 0.94353, 0.94459, 0.94565, 0.94684, 0.94820, 0.80382],
                        [0.92902, 0.92793, 0.92907, 0.92933, 0.92986, 0.93091, 0.93206,
                         0.93202, 0.93315, 0.93292, 0.93359, 0.93390, 0.93361, 0.93525,
                         0.93580, 0.93732, 0.93835, 0.93818, 0.93951, 0.94014, 0.94200,
                         0.94191, 0.94340, 0.94465, 0.94520, 0.94626, 0.94713, 0.94859, 0.80448],
                        [0.92948, 0.92870, 0.92977, 0.92969, 0.93048, 0.93125, 0.93203,
                         0.93279, 0.93380, 0.93356, 0.93429, 0.93489, 0.93451, 0.93597,
                         0.93641, 0.93785, 0.93914, 0.93921, 0.94003, 0.94146, 0.94193,
                         0.94285, 0.94395, 0.94498, 0.94557, 0.94681, 0.94793, 0.94954, 0.80513],
                        [0.92922, 0.92900, 0.92984, 0.92948, 0.93041, 0.93068, 0.93154,
                         0.93289, 0.93320, 0.93400, 0.93465, 0.93549, 0.93499, 0.93598,
                         0.93646, 0.93729, 0.93883, 0.93954, 0.94014, 0.94164, 0.94205,
                         0.94327, 0.94381, 0.94472, 0.94559, 0.94652, 0.94821, 0.95003, 0.80517],
                        [0.92902, 0.92908, 0.92929, 0.92972, 0.92999, 0.93041, 0.93173,
                         0.93294, 0.93305, 0.93473, 0.93516, 0.93534, 0.93596, 0.93610,
                         0.93664, 0.93714, 0.93860, 0.93968, 0.94074, 0.94183, 0.94290,
                         0.94343, 0.94404, 0.94527, 0.94596, 0.94679, 0.94828, 0.95019, 0.80509],
                        [0.92938, 0.92952, 0.92920, 0.93043, 0.92993, 0.93069, 0.93210,
                         0.93276, 0.93384, 0.93546, 0.93562, 0.93579, 0.93664, 0.93672,
                         0.93737, 0.93814, 0.93924, 0.94009, 0.94121, 0.94245, 0.94365,
                         0.94379, 0.94470, 0.94590, 0.94676, 0.94784, 0.94856, 0.95037, 0.80513],
                        [0.92953, 0.92978, 0.92966, 0.93061, 0.93037, 0.93111, 0.93214,
                         0.93287, 0.93435, 0.93537, 0.93570, 0.93681, 0.93675, 0.93756,
                         0.93811, 0.93910, 0.93966, 0.94059, 0.94145, 0.94258, 0.94393,
                         0.94450, 0.94508, 0.94579, 0.94716, 0.94829, 0.94895, 0.95043, 0.80505],
                        [0.92953, 0.92984, 0.92993, 0.93039, 0.93092, 0.93145, 0.93208,
                         0.93332, 0.93393, 0.93472, 0.93536, 0.93709, 0.93666, 0.93800,
                         0.93822, 0.93911, 0.93950, 0.94083, 0.94178, 0.94253, 0.94370,
                         0.94477, 0.94505, 0.94587, 0.94722, 0.94815, 0.94909, 0.95038, 0.80489],
                        [0.93018, 0.92997, 0.93018, 0.93025, 0.93121, 0.93154, 0.93211,
                         0.93339, 0.93378, 0.93464, 0.93579, 0.93681, 0.93696, 0.93785,
                         0.93798, 0.93903, 0.93974, 0.94108, 0.94189, 0.94313, 0.94375,
                         0.94458, 0.94510, 0.94638, 0.94712, 0.94799, 0.94917, 0.95046, 0.80490],
                        [0.93053, 0.93011, 0.93023, 0.93019, 0.93110, 0.93142, 0.93213,
                         0.93305, 0.93392, 0.93514, 0.93620, 0.93691, 0.93788, 0.93777,
                         0.93822, 0.93944, 0.94019, 0.94124, 0.94191, 0.94363, 0.94413,
                         0.94479, 0.94563, 0.94632, 0.94676, 0.94797, 0.94922, 0.95077, 0.80471],
                        [0.92983, 0.93035, 0.93004, 0.93021, 0.93075, 0.93117, 0.93194,
                         0.93247, 0.93346, 0.93538, 0.93583, 0.93688, 0.93803, 0.93828,
                         0.93902, 0.93924, 0.94024, 0.94100, 0.94182, 0.94316, 0.94413,
                         0.94526, 0.94614, 0.94608, 0.94685, 0.94825, 0.94912, 0.95078, 0.80421],
                        [0.92971, 0.93057, 0.93019, 0.93077, 0.93081, 0.93093, 0.93188,
                         0.93241, 0.93345, 0.93502, 0.93564, 0.93657, 0.93761, 0.93865,
                         0.93944, 0.93869, 0.94007, 0.94084, 0.94216, 0.94268, 0.94403,
                         0.94528, 0.94613, 0.94675, 0.94718, 0.94829, 0.94971, 0.95037, 0.80412],
                        [0.93055, 0.93055, 0.93042, 0.93135, 0.93112, 0.93095, 0.93152,
                         0.93253, 0.93386, 0.93429, 0.93547, 0.93635, 0.93773, 0.93830,
                         0.93907, 0.93913, 0.93997, 0.94115, 0.94265, 0.94241, 0.94378,
                         0.94473, 0.94568, 0.94669, 0.94700, 0.94800, 0.95018, 0.95004, 0.80424],
                        [0.93119, 0.93067, 0.93053, 0.93137, 0.93115, 0.93110, 0.93118,
                         0.93235, 0.93337, 0.93396, 0.93541, 0.93631, 0.93781, 0.93849,
                         0.93873, 0.93994, 0.93999, 0.94155, 0.94218, 0.94235, 0.94356,
                         0.94452, 0.94547, 0.94599, 0.94658, 0.94840, 0.94946, 0.95034, 0.80416],
                        [0.93132, 0.93082, 0.93102, 0.93141, 0.93125, 0.93136, 0.93189,
                         0.93236, 0.93284, 0.93407, 0.93554, 0.93652, 0.93763, 0.93932,
                         0.93878, 0.94045, 0.94059, 0.94112, 0.94185, 0.94271, 0.94404,
                         0.94490, 0.94540, 0.94634, 0.94668, 0.94912, 0.94914, 0.95091, 0.80411],
                        [0.93102, 0.93032, 0.93114, 0.93114, 0.93120, 0.93149, 0.93227,
                         0.93213, 0.93273, 0.93387, 0.93514, 0.93650, 0.93744, 0.93891,
                         0.93907, 0.94043, 0.94107, 0.94029, 0.94186, 0.94262, 0.94405,
                         0.94451, 0.94517, 0.94626, 0.94674, 0.94866, 0.94958, 0.95060, 0.80362],
                        [0.93059, 0.93016, 0.93066, 0.93065, 0.93104, 0.93138, 0.93170,
                         0.93186, 0.93256, 0.93332, 0.93433, 0.93615, 0.93704, 0.93795,
                         0.93977, 0.93988, 0.94075, 0.94023, 0.94158, 0.94217, 0.94329,
                         0.94389, 0.94515, 0.94545, 0.94646, 0.94782, 0.94955, 0.94974, 0.80315],
                        [0.93055, 0.93103, 0.93098, 0.93118, 0.93091, 0.93147, 0.93147,
                         0.93201, 0.93255, 0.93287, 0.93398, 0.93595, 0.93678, 0.93810,
                         0.94005, 0.93970, 0.94038, 0.94073, 0.94153, 0.94223, 0.94299,
                         0.94439, 0.94510, 0.94581, 0.94689, 0.94800, 0.94937, 0.94933, 0.80333],
                        [0.93109, 0.93167, 0.93173, 0.93220, 0.93135, 0.93191, 0.93186,
                         0.93238, 0.93280, 0.93285, 0.93401, 0.93532, 0.93689, 0.93823,
                         0.93935, 0.94007, 0.94056, 0.94132, 0.94173, 0.94260, 0.94318,
                         0.94503, 0.94520, 0.94718, 0.94782, 0.94860, 0.94965, 0.94927, 0.80353],
                        [0.93114, 0.93121, 0.93169, 0.93232, 0.93221, 0.93221, 0.93198,
                         0.93231, 0.93248, 0.93269, 0.93406, 0.93463, 0.93646, 0.93774,
                         0.93848, 0.94008, 0.94100, 0.94179, 0.94196, 0.94263, 0.94334,
                         0.94441, 0.94559, 0.94720, 0.94781, 0.94871, 0.94952, 0.94922, 0.80315],
                        [0.93040, 0.93045, 0.93115, 0.93171, 0.93214, 0.93182, 0.93184,
                         0.93188, 0.93206, 0.93239, 0.93409, 0.93460, 0.93555, 0.93745,
                         0.93830, 0.93973, 0.94090, 0.94177, 0.94226, 0.94267, 0.94368,
                         0.94374, 0.94585, 0.94602, 0.94708, 0.94853, 0.94881, 0.94921, 0.80273],
                        [0.93012, 0.93019, 0.93050, 0.93069, 0.93147, 0.93170, 0.93196,
                         0.93209, 0.93240, 0.93230, 0.93380, 0.93417, 0.93521, 0.93710,
                         0.93839, 0.93927, 0.94027, 0.94116, 0.94242, 0.94291, 0.94417,
                         0.94422, 0.94536, 0.94584, 0.94699, 0.94806, 0.94847, 0.94884, 0.80291],
                        [0.93026, 0.92990, 0.93000, 0.93011, 0.93099, 0.93226, 0.93221,
                         0.93253, 0.93283, 0.93275, 0.93311, 0.93334, 0.93499, 0.93653,
                         0.93775, 0.93885, 0.94000, 0.94075, 0.94213, 0.94283, 0.94394,
                         0.94483, 0.94486, 0.94651, 0.94712, 0.94749, 0.94839, 0.94792, 0.80283],
                        [0.92958, 0.92937, 0.93013, 0.93017, 0.93086, 0.93185, 0.93195,
                         0.93221, 0.93277, 0.93310, 0.93249, 0.93317, 0.93420, 0.93600,
                         0.93695, 0.93838, 0.94019, 0.94093, 0.94180, 0.94228, 0.94314,
                         0.94465, 0.94508, 0.94648, 0.94680, 0.94747, 0.94776, 0.94725, 0.80241],
                        [0.92853, 0.92871, 0.92972, 0.92974, 0.93073, 0.93090, 0.93116,
                         0.93163, 0.93238, 0.93270, 0.93254, 0.93324, 0.93378, 0.93547,
                         0.93655, 0.93799, 0.93968, 0.94089, 0.94174, 0.94213, 0.94316,
                         0.94421, 0.94523, 0.94570, 0.94671, 0.94726, 0.94702, 0.94720, 0.80251],
                        [0.92789, 0.92787, 0.92840, 0.92887, 0.92998, 0.93044, 0.93068,
                         0.93147, 0.93217, 0.93241, 0.93283, 0.93279, 0.93386, 0.93480,
                         0.93603, 0.93771, 0.93868, 0.94003, 0.94126, 0.94250, 0.94351,
                         0.94384, 0.94498, 0.94535, 0.94652, 0.94645, 0.94657, 0.94702, 0.80242],
                        [0.92705, 0.92730, 0.92803, 0.92822, 0.92929, 0.93011, 0.93078,
                         0.93181, 0.93226, 0.93244, 0.93285, 0.93290, 0.93377, 0.93450,
                         0.93554, 0.93783, 0.93858, 0.93959, 0.94104, 0.94271, 0.94348,
                         0.94402, 0.94484, 0.94593, 0.94626, 0.94613, 0.94664, 0.94712, 0.80233],
                        [0.92602, 0.92682, 0.92780, 0.92777, 0.92897, 0.92973, 0.93086,
                         0.93200, 0.93218, 0.93262, 0.93279, 0.93357, 0.93352, 0.93475,
                         0.93515, 0.93756, 0.93872, 0.94004, 0.94130, 0.94230, 0.94333,
                         0.94424, 0.94470, 0.94611, 0.94607, 0.94601, 0.94670, 0.94730, 0.80272],
                        [0.92528, 0.92566, 0.92617, 0.92707, 0.92823, 0.92890, 0.93016,
                         0.93108, 0.93170, 0.93249, 0.93253, 0.93309, 0.93315, 0.93415,
                         0.93478, 0.93633, 0.93812, 0.93980, 0.94070, 0.94126, 0.94284,
                         0.94365, 0.94416, 0.94492, 0.94541, 0.94521, 0.94546, 0.94634, 0.80271],
                        [0.92453, 0.92437, 0.92473, 0.92606, 0.92710, 0.92815, 0.92952,
                         0.93023, 0.93135, 0.93203, 0.93250, 0.93228, 0.93266, 0.93314,
                         0.93469, 0.93531, 0.93741, 0.93905, 0.94001, 0.94048, 0.94185,
                         0.94287, 0.94350, 0.94389, 0.94468, 0.94439, 0.94444, 0.94558, 0.80237],
                        [0.92349, 0.92344, 0.92402, 0.92490, 0.92603, 0.92754, 0.92925,
                         0.92980, 0.93112, 0.93154, 0.93265, 0.93185, 0.93274, 0.93298,
                         0.93418, 0.93498, 0.93671, 0.93839, 0.93971, 0.94023, 0.94085,
                         0.94218, 0.94299, 0.94365, 0.94406, 0.94383, 0.94465, 0.94537, 0.80219],
                        [0.92262, 0.92228, 0.92345, 0.92374, 0.92512, 0.92670, 0.92801,
                         0.92936, 0.93068, 0.93106, 0.93226, 0.93179, 0.93297, 0.93284,
                         0.93331, 0.93475, 0.93583, 0.93748, 0.93867, 0.93983, 0.94034,
                         0.94158, 0.94251, 0.94322, 0.94345, 0.94329, 0.94451, 0.94527, 0.80220],
                        [0.92202, 0.92130, 0.92334, 0.92325, 0.92449, 0.92599, 0.92663,
                         0.92900, 0.93025, 0.93080, 0.93179, 0.93262, 0.93273, 0.93280,
                         0.93335, 0.93465, 0.93566, 0.93681, 0.93763, 0.93957, 0.94020,
                         0.94135, 0.94208, 0.94233, 0.94317, 0.94294, 0.94377, 0.94603, 0.80249],
                        [0.92142, 0.92168, 0.92281, 0.92346, 0.92429, 0.92520, 0.92629,
                         0.92828, 0.93014, 0.93138, 0.93200, 0.93352, 0.93295, 0.93317,
                         0.93401, 0.93457, 0.93586, 0.93674, 0.93791, 0.93940, 0.94049,
                         0.94126, 0.94182, 0.94216, 0.94290, 0.94276, 0.94337, 0.94655, 0.80309],
                        [0.92112, 0.92228, 0.92126, 0.92294, 0.92408, 0.92448, 0.92652,
                         0.92781, 0.93025, 0.93178, 0.93248, 0.93335, 0.93340, 0.93331,
                         0.93399, 0.93418, 0.93536, 0.93690, 0.93798, 0.93878, 0.94066,
                         0.94122, 0.94158, 0.94289, 0.94248, 0.94302, 0.94383, 0.94653, 0.80329],
                        [0.92087, 0.92120, 0.92007, 0.92143, 0.92291, 0.92386, 0.92621,
                         0.92791, 0.92949, 0.93065, 0.93231, 0.93241, 0.93306, 0.93304,
                         0.93340, 0.93384, 0.93462, 0.93655, 0.93686, 0.93784, 0.94019,
                         0.94087, 0.94088, 0.94271, 0.94198, 0.94312, 0.94416, 0.94646, 0.80300],
                        [0.92025, 0.91951, 0.92010, 0.92053, 0.92160, 0.92300, 0.92471,
                         0.92736, 0.92828, 0.92957, 0.93160, 0.93204, 0.93251, 0.93264,
                         0.93298, 0.93380, 0.93438, 0.93553, 0.93603, 0.93725, 0.93917,
                         0.94019, 0.94030, 0.94141, 0.94128, 0.94249, 0.94387, 0.94611, 0.80294],
                        [0.91991, 0.91952, 0.92049, 0.92079, 0.92160, 0.92243, 0.92381,
                         0.92636, 0.92791, 0.93000, 0.93144, 0.93236, 0.93322, 0.93291,
                         0.93360, 0.93412, 0.93488, 0.93496, 0.93616, 0.93755, 0.93855,
                         0.94017, 0.94055, 0.94040, 0.94093, 0.94247, 0.94431, 0.94658, 0.80330],
                        [0.92015, 0.92064, 0.92063, 0.92131, 0.92215, 0.92242, 0.92418,
                         0.92579, 0.92814, 0.93081, 0.93183, 0.93263, 0.93462, 0.93415,
                         0.93477, 0.93460, 0.93545, 0.93556, 0.93671, 0.93809, 0.93901,
                         0.94023, 0.94075, 0.94059, 0.94173, 0.94322, 0.94537, 0.94772, 0.80368],
                        [0.92047, 0.92107, 0.92082, 0.92141, 0.92196, 0.92230, 0.92438,
                         0.92560, 0.92795, 0.93023, 0.93145, 0.93258, 0.93440, 0.93502,
                         0.93502, 0.93476, 0.93544, 0.93655, 0.93710, 0.93801, 0.93949,
                         0.93991, 0.94063, 0.94148, 0.94273, 0.94367, 0.94597, 0.94832, 0.80370],
                        [0.92053, 0.92054, 0.92084, 0.92077, 0.92163, 0.92202, 0.92379,
                         0.92523, 0.92674, 0.92875, 0.93078, 0.93248, 0.93333, 0.93488,
                         0.93461, 0.93519, 0.93535, 0.93682, 0.93706, 0.93777, 0.93941,
                         0.94004, 0.94044, 0.94201, 0.94259, 0.94405, 0.94596, 0.94863, 0.80294],
                        [0.92039, 0.92004, 0.92092, 0.92021, 0.92184, 0.92217, 0.92301,
                         0.92491, 0.92590, 0.92795, 0.93074, 0.93278, 0.93353, 0.93471,
                         0.93480, 0.93611, 0.93597, 0.93651, 0.93724, 0.93828, 0.93952,
                         0.94036, 0.93993, 0.94196, 0.94260, 0.94455, 0.94602, 0.94893, 0.80210],
                        [0.92041, 0.92037, 0.92125, 0.92050, 0.92183, 0.92228, 0.92278,
                         0.92495, 0.92580, 0.92770, 0.93002, 0.93283, 0.93408, 0.93491,
                         0.93580, 0.93669, 0.93672, 0.93696, 0.93791, 0.93878, 0.93971,
                         0.94020, 0.94013, 0.94208, 0.94357, 0.94473, 0.94656, 0.94869, 0.80179],
                        [0.92070, 0.92117, 0.92131, 0.92128, 0.92142, 0.92209, 0.92291,
                         0.92458, 0.92546, 0.92743, 0.92901, 0.93233, 0.93392, 0.93491,
                         0.93674, 0.93671, 0.93695, 0.93770, 0.93820, 0.93872, 0.93954,
                         0.94027, 0.94150, 0.94267, 0.94421, 0.94489, 0.94740, 0.94784, 0.80221],
                        [0.92077, 0.92116, 0.92113, 0.92180, 0.92108, 0.92169, 0.92264,
                         0.92376, 0.92517, 0.92669, 0.92899, 0.93145, 0.93368, 0.93447,
                         0.93697, 0.93649, 0.93697, 0.93734, 0.93811, 0.93869, 0.93940,
                         0.94059, 0.94218, 0.94280, 0.94415, 0.94535, 0.94785, 0.94743, 0.80240],
                        [0.92065, 0.92068, 0.92142, 0.92202, 0.92112, 0.92151, 0.92212,
                         0.92316, 0.92472, 0.92583, 0.92898, 0.93029, 0.93353, 0.93415,
                         0.93683, 0.93688, 0.93720, 0.93711, 0.93816, 0.93899, 0.93966,
                         0.94067, 0.94168, 0.94275, 0.94414, 0.94589, 0.94777, 0.94744, 0.80121],
                        [0.92109, 0.92150, 0.92201, 0.92226, 0.92190, 0.92189, 0.92233,
                         0.92314, 0.92413, 0.92583, 0.92844, 0.92973, 0.93317, 0.93463,
                         0.93643, 0.93754, 0.93776, 0.93805, 0.93864, 0.93939, 0.94045,
                         0.94101, 0.94175, 0.94355, 0.94476, 0.94653, 0.94795, 0.94720, 0.80000],
                        [0.92172, 0.92240, 0.92190, 0.92196, 0.92245, 0.92221, 0.92270,
                         0.92305, 0.92375, 0.92556, 0.92739, 0.92958, 0.93235, 0.93475,
                         0.93560, 0.93704, 0.93801, 0.93912, 0.93900, 0.93951, 0.94072,
                         0.94126, 0.94227, 0.94370, 0.94521, 0.94673, 0.94769, 0.94641, 0.79948],
                        [0.92213, 0.92232, 0.92142, 0.92189, 0.92223, 0.92216, 0.92228,
                         0.92237, 0.92357, 0.92426, 0.92627, 0.92900, 0.93133, 0.93365,
                         0.93510, 0.93590, 0.93794, 0.93919, 0.93898, 0.93968, 0.94031,
                         0.94149, 0.94246, 0.94303, 0.94509, 0.94627, 0.94659, 0.94534, 0.79900],
                        [0.92265, 0.92228, 0.92159, 0.92267, 0.92203, 0.92195, 0.92161,
                         0.92158, 0.92340, 0.92343, 0.92536, 0.92786, 0.93046, 0.93253,
                         0.93533, 0.93590, 0.93774, 0.93822, 0.93862, 0.93962, 0.94024,
                         0.94223, 0.94257, 0.94307, 0.94474, 0.94578, 0.94553, 0.94455, 0.79830],
                        [0.92258, 0.92245, 0.92260, 0.92310, 0.92209, 0.92157, 0.92117,
                         0.92180, 0.92279, 0.92321, 0.92448, 0.92695, 0.92964, 0.93192,
                         0.93497, 0.93650, 0.93705, 0.93756, 0.93823, 0.93914, 0.94082,
                         0.94230, 0.94269, 0.94347, 0.94419, 0.94542, 0.94474, 0.94366, 0.79759],
                        [0.92206, 0.92278, 0.92331, 0.92249, 0.92279, 0.92148, 0.92125,
                         0.92276, 0.92223, 0.92284, 0.92370, 0.92608, 0.92866, 0.93119,
                         0.93340, 0.93603, 0.93600, 0.93753, 0.93834, 0.93928, 0.94100,
                         0.94132, 0.94235, 0.94344, 0.94402, 0.94499, 0.94418, 0.94255, 0.79723],
                        [0.92228, 0.92264, 0.92343, 0.92229, 0.92347, 0.92203, 0.92171,
                         0.92298, 0.92209, 0.92283, 0.92304, 0.92503, 0.92760, 0.93034,
                         0.93178, 0.93492, 0.93556, 0.93735, 0.93862, 0.93963, 0.94033,
                         0.94067, 0.94187, 0.94331, 0.94395, 0.94421, 0.94370, 0.94189, 0.79707],
                        [0.92345, 0.92264, 0.92354, 0.92357, 0.92349, 0.92328, 0.92235,
                         0.92250, 0.92238, 0.92288, 0.92310, 0.92465, 0.92694, 0.92960,
                         0.93103, 0.93423, 0.93588, 0.93729, 0.93885, 0.93950, 0.93981,
                         0.94074, 0.94210, 0.94340, 0.94370, 0.94314, 0.94290, 0.94151, 0.79681],
                        [0.92427, 0.92340, 0.92353, 0.92454, 0.92353, 0.92403, 0.92316,
                         0.92230, 0.92259, 0.92223, 0.92321, 0.92442, 0.92623, 0.92850,
                         0.93072, 0.93363, 0.93551, 0.93709, 0.93822, 0.93899, 0.93980,
                         0.94091, 0.94226, 0.94316, 0.94328, 0.94241, 0.94194, 0.94099, 0.79643],
                        [0.92428, 0.92423, 0.92365, 0.92464, 0.92410, 0.92381, 0.92405,
                         0.92329, 0.92270, 0.92216, 0.92317, 0.92390, 0.92529, 0.92767,
                         0.93031, 0.93279, 0.93460, 0.93675, 0.93735, 0.93847, 0.93995,
                         0.94094, 0.94200, 0.94289, 0.94299, 0.94248, 0.94141, 0.94056, 0.79687],
                        [0.92431, 0.92472, 0.92464, 0.92489, 0.92479, 0.92421, 0.92456,
                         0.92429, 0.92317, 0.92296, 0.92350, 0.92335, 0.92485, 0.92720,
                         0.92953, 0.93178, 0.93396, 0.93632, 0.93724, 0.93845, 0.94014,
                         0.94071, 0.94171, 0.94261, 0.94310, 0.94254, 0.94084, 0.94016, 0.79810],
                        [0.92447, 0.92469, 0.92562, 0.92523, 0.92498, 0.92546, 0.92478,
                         0.92445, 0.92381, 0.92327, 0.92358, 0.92304, 0.92482, 0.92662,
                         0.92877, 0.93106, 0.93331, 0.93571, 0.93708, 0.93842, 0.93982,
                         0.94017, 0.94116, 0.94237, 0.94244, 0.94163, 0.94008, 0.93966, 0.79839],
                        [0.92504, 0.92460, 0.92547, 0.92549, 0.92525, 0.92625, 0.92526,
                         0.92498, 0.92434, 0.92345, 0.92349, 0.92340, 0.92465, 0.92602,
                         0.92798, 0.93008, 0.93243, 0.93528, 0.93642, 0.93814, 0.93888,
                         0.93979, 0.94042, 0.94231, 0.94103, 0.94031, 0.93967, 0.93954, 0.79812],
                        [0.92561, 0.92525, 0.92542, 0.92623, 0.92614, 0.92621, 0.92565,
                         0.92596, 0.92488, 0.92451, 0.92403, 0.92431, 0.92444, 0.92567,
                         0.92757, 0.92913, 0.93218, 0.93465, 0.93598, 0.93797, 0.93850,
                         0.94000, 0.94029, 0.94164, 0.94048, 0.93964, 0.93929, 0.94005, 0.79901],
                        [0.92543, 0.92616, 0.92613, 0.92694, 0.92662, 0.92616, 0.92609,
                         0.92635, 0.92552, 0.92532, 0.92455, 0.92483, 0.92412, 0.92515,
                         0.92730, 0.92892, 0.93195, 0.93349, 0.93571, 0.93743, 0.93857,
                         0.94000, 0.94024, 0.94044, 0.94035, 0.93907, 0.93850, 0.94031, 0.80009],
                        [0.92548, 0.92618, 0.92658, 0.92690, 0.92665, 0.92629, 0.92683,
                         0.92648, 0.92624, 0.92547, 0.92475, 0.92438, 0.92413, 0.92468,
                         0.92640, 0.92868, 0.93104, 0.93266, 0.93511, 0.93623, 0.93809,
                         0.93944, 0.93993, 0.93979, 0.93991, 0.93845, 0.93799, 0.94008, 0.80038],
                        [0.92620, 0.92601, 0.92623, 0.92678, 0.92722, 0.92667, 0.92713,
                         0.92718, 0.92697, 0.92626, 0.92551, 0.92426, 0.92461, 0.92515,
                         0.92594, 0.92833, 0.93045, 0.93258, 0.93461, 0.93557, 0.93781,
                         0.93926, 0.93987, 0.93995, 0.93967, 0.93846, 0.93820, 0.94047, 0.80094],
                        [0.92672, 0.92656, 0.92599, 0.92703, 0.92809, 0.92727, 0.92749,
                         0.92776, 0.92784, 0.92724, 0.92664, 0.92537, 0.92508, 0.92611,
                         0.92676, 0.92823, 0.93004, 0.93292, 0.93434, 0.93581, 0.93794,
                         0.93922, 0.93975, 0.93977, 0.93948, 0.93884, 0.93890, 0.94118, 0.80197],
                        [0.92674, 0.92690, 0.92662, 0.92725, 0.92830, 0.92768, 0.92824,
                         0.92818, 0.92869, 0.92764, 0.92737, 0.92669, 0.92562, 0.92660,
                         0.92748, 0.92826, 0.92964, 0.93274, 0.93383, 0.93626, 0.93779,
                         0.93862, 0.93940, 0.93869, 0.93878, 0.93899, 0.93940, 0.94172, 0.80267],
                        [0.92661, 0.92676, 0.92728, 0.92711, 0.92776, 0.92828, 0.92880,
                         0.92871, 0.92905, 0.92808, 0.92792, 0.92731, 0.92623, 0.92651,
                         0.92707, 0.92807, 0.92957, 0.93182, 0.93322, 0.93634, 0.93725,
                         0.93790, 0.93867, 0.93803, 0.93795, 0.93835, 0.93929, 0.94340, 0.80325],
                        [0.92684, 0.92660, 0.92725, 0.92731, 0.92752, 0.92910, 0.92933,
                         0.92910, 0.92904, 0.92871, 0.92848, 0.92777, 0.92723, 0.92645,
                         0.92680, 0.92817, 0.92975, 0.93132, 0.93278, 0.93561, 0.93656,
                         0.93768, 0.93773, 0.93837, 0.93789, 0.93791, 0.93972, 0.94530, 0.80358],
                        [0.92717, 0.92692, 0.92717, 0.92810, 0.92753, 0.92879, 0.92965,
                         0.92965, 0.92912, 0.92934, 0.92906, 0.92851, 0.92811, 0.92660,
                         0.92714, 0.92836, 0.92974, 0.93130, 0.93250, 0.93448, 0.93604,
                         0.93763, 0.93711, 0.93850, 0.93796, 0.93843, 0.94073, 0.94532, 0.80374],
                        [0.92723, 0.92717, 0.92720, 0.92828, 0.92773, 0.92799, 0.92951,
                         0.93013, 0.92968, 0.92982, 0.92956, 0.92917, 0.92837, 0.92717,
                         0.92734, 0.92794, 0.92911, 0.93078, 0.93237, 0.93362, 0.93549,
                         0.93717, 0.93699, 0.93795, 0.93765, 0.93887, 0.94113, 0.94461, 0.80433],
                        [0.92705, 0.92663, 0.92700, 0.92739, 0.92802, 0.92807, 0.92879,
                         0.92952, 0.93036, 0.93009, 0.92953, 0.92947, 0.92853, 0.92790,
                         0.92751, 0.92800, 0.92867, 0.93006, 0.93224, 0.93318, 0.93489,
                         0.93622, 0.93670, 0.93722, 0.93741, 0.93873, 0.94087, 0.94485, 0.80456],
                        [0.92670, 0.92641, 0.92708, 0.92695, 0.92792, 0.92846, 0.92827,
                         0.92897, 0.93046, 0.93032, 0.92983, 0.92979, 0.92908, 0.92882,
                         0.92833, 0.92884, 0.92900, 0.93025, 0.93210, 0.93299, 0.93452,
                         0.93558, 0.93645, 0.93699, 0.93747, 0.93863, 0.94089, 0.94579, 0.80469],
                        [0.92614, 0.92656, 0.92708, 0.92730, 0.92769, 0.92856, 0.92880,
                         0.92956, 0.93018, 0.93040, 0.93078, 0.93047, 0.92992, 0.92965,
                         0.92896, 0.92878, 0.92944, 0.93044, 0.93182, 0.93280, 0.93414,
                         0.93536, 0.93667, 0.93705, 0.93789, 0.93869, 0.94153, 0.94679, 0.80580],
                        [0.92570, 0.92629, 0.92653, 0.92728, 0.92728, 0.92812, 0.92900,
                         0.92985, 0.93025, 0.93027, 0.93122, 0.93077, 0.93021, 0.92964,
                         0.92891, 0.92840, 0.92964, 0.92990, 0.93126, 0.93261, 0.93375,
                         0.93496, 0.93612, 0.93648, 0.93775, 0.93861, 0.94236, 0.94754, 0.80641],
                        [0.92623, 0.92609, 0.92626, 0.92710, 0.92714, 0.92772, 0.92875,
                         0.92959, 0.93028, 0.93062, 0.93098, 0.93094, 0.93019, 0.93005,
                         0.92947, 0.92933, 0.92992, 0.92950, 0.93100, 0.93297, 0.93366,
                         0.93489, 0.93529, 0.93604, 0.93723, 0.93921, 0.94358, 0.94790, 0.80585],
                        [0.92644, 0.92594, 0.92635, 0.92706, 0.92725, 0.92805, 0.92869,
                         0.92962, 0.92984, 0.93124, 0.93110, 0.93149, 0.93088, 0.93131,
                         0.93043, 0.93017, 0.93007, 0.92975, 0.93126, 0.93287, 0.93365,
                         0.93476, 0.93500, 0.93608, 0.93714, 0.94042, 0.94447, 0.94817, 0.80537],
                        [0.92577, 0.92566, 0.92664, 0.92708, 0.92736, 0.92843, 0.92869,
                         0.92996, 0.93008, 0.93110, 0.93172, 0.93219, 0.93201, 0.93160,
                         0.93065, 0.92984, 0.93044, 0.93042, 0.93142, 0.93204, 0.93344,
                         0.93429, 0.93513, 0.93609, 0.93787, 0.94096, 0.94439, 0.94873, 0.80575],
                        [0.92537, 0.92530, 0.92658, 0.92680, 0.92728, 0.92796, 0.92840,
                         0.92958, 0.93041, 0.93035, 0.93136, 0.93208, 0.93228, 0.93066,
                         0.93081, 0.92956, 0.93070, 0.93078, 0.93132, 0.93183, 0.93300,
                         0.93389, 0.93519, 0.93600, 0.93829, 0.94096, 0.94423, 0.94884, 0.80596],
                        [0.92487, 0.92506, 0.92587, 0.92645, 0.92652, 0.92722, 0.92802,
                         0.92896, 0.93004, 0.92997, 0.93069, 0.93129, 0.93176, 0.93068,
                         0.93137, 0.93041, 0.93044, 0.93056, 0.93138, 0.93183, 0.93247,
                         0.93371, 0.93502, 0.93621, 0.93795, 0.94102, 0.94481, 0.94835, 0.80521],
                        [0.92454, 0.92484, 0.92536, 0.92625, 0.92622, 0.92718, 0.92832,
                         0.92912, 0.92993, 0.93045, 0.93093, 0.93118, 0.93173, 0.93204,
                         0.93155, 0.93157, 0.93074, 0.93068, 0.93151, 0.93179, 0.93242,
                         0.93357, 0.93539, 0.93671, 0.93830, 0.94144, 0.94545, 0.94881, 0.80503],
                        [0.92521, 0.92501, 0.92552, 0.92623, 0.92687, 0.92774, 0.92885,
                         0.92945, 0.93033, 0.93142, 0.93197, 0.93185, 0.93273, 0.93309,
                         0.93203, 0.93240, 0.93183, 0.93171, 0.93201, 0.93259, 0.93352,
                         0.93416, 0.93634, 0.93736, 0.93938, 0.94256, 0.94579, 0.94962, 0.80596],
                        [0.92554, 0.92503, 0.92549, 0.92623, 0.92662, 0.92758, 0.92831,
                         0.92928, 0.93025, 0.93106, 0.93211, 0.93208, 0.93308, 0.93310,
                         0.93294, 0.93273, 0.93251, 0.93226, 0.93246, 0.93323, 0.93429,
                         0.93510, 0.93643, 0.93772, 0.94013, 0.94334, 0.94606, 0.94931, 0.80578],
                        [0.92495, 0.92493, 0.92530, 0.92617, 0.92609, 0.92709, 0.92760,
                         0.92907, 0.92973, 0.93032, 0.93115, 0.93222, 0.93282, 0.93321,
                         0.93350, 0.93296, 0.93281, 0.93216, 0.93283, 0.93363, 0.93427,
                         0.93553, 0.93629, 0.93797, 0.94069, 0.94343, 0.94650, 0.94946, 0.80503],
                        [0.92461, 0.92538, 0.92529, 0.92605, 0.92625, 0.92684, 0.92758,
                         0.92913, 0.92967, 0.93075, 0.93098, 0.93286, 0.93291, 0.93381,
                         0.93384, 0.93352, 0.93324, 0.93275, 0.93309, 0.93421, 0.93453,
                         0.93590, 0.93708, 0.93847, 0.94128, 0.94398, 0.94719, 0.95009, 0.80517],
                        [0.92495, 0.92538, 0.92508, 0.92608, 0.92645, 0.92679, 0.92781,
                         0.92908, 0.93019, 0.93112, 0.93163, 0.93287, 0.93317, 0.93395,
                         0.93414, 0.93446, 0.93412, 0.93386, 0.93328, 0.93452, 0.93513,
                         0.93634, 0.93752, 0.93929, 0.94199, 0.94523, 0.94801, 0.94964, 0.80536],
                        [0.92502, 0.92441, 0.92480, 0.92601, 0.92665, 0.92726, 0.92823,
                         0.92913, 0.93037, 0.93121, 0.93225, 0.93241, 0.93371, 0.93390,
                         0.93453, 0.93520, 0.93535, 0.93497, 0.93467, 0.93511, 0.93606,
                         0.93667, 0.93816, 0.94054, 0.94276, 0.94620, 0.94858, 0.94958, 0.80529],
                        [0.92453, 0.92385, 0.92509, 0.92583, 0.92671, 0.92746, 0.92841,
                         0.92916, 0.92985, 0.93138, 0.93231, 0.93250, 0.93389, 0.93403,
                         0.93515, 0.93536, 0.93571, 0.93609, 0.93658, 0.93622, 0.93667,
                         0.93753, 0.93971, 0.94134, 0.94374, 0.94600, 0.94889, 0.95035, 0.80569],
                        [0.92431, 0.92431, 0.92548, 0.92591, 0.92642, 0.92697, 0.92798,
                         0.92891, 0.92963, 0.93147, 0.93183, 0.93310, 0.93374, 0.93437,
                         0.93568, 0.93560, 0.93581, 0.93680, 0.93724, 0.93740, 0.93725,
                         0.93884, 0.94098, 0.94170, 0.94483, 0.94604, 0.94912, 0.95073, 0.80646],
                        [0.92398, 0.92462, 0.92502, 0.92533, 0.92557, 0.92653, 0.92746,
                         0.92815, 0.92986, 0.93121, 0.93118, 0.93310, 0.93353, 0.93438,
                         0.93528, 0.93579, 0.93619, 0.93680, 0.93704, 0.93777, 0.93811,
                         0.93925, 0.94125, 0.94224, 0.94532, 0.94700, 0.94894, 0.95051, 0.80622],
                        [0.92334, 0.92473, 0.92452, 0.92474, 0.92470, 0.92658, 0.92731,
                         0.92761, 0.93003, 0.93060, 0.93097, 0.93266, 0.93353, 0.93438,
                         0.93458, 0.93569, 0.93672, 0.93678, 0.93725, 0.93772, 0.93899,
                         0.93934, 0.94113, 0.94311, 0.94557, 0.94751, 0.94869, 0.95050, 0.80548],
                        [0.92307, 0.92417, 0.92444, 0.92506, 0.92495, 0.92653, 0.92706,
                         0.92797, 0.93013, 0.93042, 0.93146, 0.93261, 0.93405, 0.93497,
                         0.93500, 0.93618, 0.93759, 0.93734, 0.93759, 0.93836, 0.93983,
                         0.93978, 0.94141, 0.94411, 0.94595, 0.94751, 0.94899, 0.95081, 0.80536],
                        [0.92331, 0.92302, 0.92427, 0.92509, 0.92596, 0.92617, 0.92702,
                         0.92836, 0.92988, 0.93060, 0.93201, 0.93284, 0.93418, 0.93525,
                         0.93596, 0.93703, 0.93785, 0.93805, 0.93798, 0.93915, 0.94050,
                         0.94045, 0.94230, 0.94463, 0.94635, 0.94770, 0.94935, 0.95052, 0.80556],
                        [0.92335, 0.92277, 0.92373, 0.92459, 0.92584, 0.92562, 0.92719,
                         0.92816, 0.92929, 0.93045, 0.93156, 0.93274, 0.93374, 0.93480,
                         0.93607, 0.93715, 0.93770, 0.93858, 0.93875, 0.93947, 0.94097,
                         0.94138, 0.94328, 0.94439, 0.94673, 0.94793, 0.94906, 0.94986, 0.80545],
                        [0.92344, 0.92323, 0.92319, 0.92442, 0.92476, 0.92515, 0.92699,
                         0.92774, 0.92861, 0.92994, 0.93093, 0.93247, 0.93354, 0.93416,
                         0.93552, 0.93677, 0.93740, 0.93869, 0.93972, 0.93995, 0.94113,
                         0.94237, 0.94403, 0.94433, 0.94680, 0.94834, 0.94898, 0.94992, 0.80517],
                        [0.92336, 0.92368, 0.92353, 0.92432, 0.92420, 0.92503, 0.92635,
                         0.92703, 0.92802, 0.92933, 0.93091, 0.93238, 0.93327, 0.93390,
                         0.93536, 0.93642, 0.93680, 0.93853, 0.94036, 0.94019, 0.94099,
                         0.94260, 0.94429, 0.94472, 0.94669, 0.94844, 0.94904, 0.95016, 0.80519],
                        [0.92291, 0.92398, 0.92425, 0.92442, 0.92406, 0.92512, 0.92598,
                         0.92668, 0.92838, 0.92916, 0.93103, 0.93289, 0.93330, 0.93440,
                         0.93551, 0.93638, 0.93723, 0.93896, 0.94016, 0.94052, 0.94186,
                         0.94299, 0.94434, 0.94537, 0.94682, 0.94809, 0.94919, 0.95018, 0.80582],
                        [0.92286, 0.92357, 0.92404, 0.92440, 0.92388, 0.92505, 0.92580,
                         0.92701, 0.92866, 0.92924, 0.93058, 0.93293, 0.93343, 0.93496,
                         0.93545, 0.93661, 0.93820, 0.93941, 0.93954, 0.94099, 0.94297,
                         0.94370, 0.94434, 0.94588, 0.94649, 0.94770, 0.94944, 0.94999, 0.80570],
                        [0.92333, 0.92278, 0.92356, 0.92423, 0.92416, 0.92509, 0.92554,
                         0.92722, 0.92823, 0.92899, 0.92979, 0.93202, 0.93327, 0.93503,
                         0.93556, 0.93726, 0.93842, 0.93917, 0.93992, 0.94108, 0.94298,
                         0.94373, 0.94394, 0.94585, 0.94630, 0.94736, 0.94928, 0.94994, 0.80471],
                        [0.92372, 0.92289, 0.92362, 0.92438, 0.92468, 0.92528, 0.92587,
                         0.92714, 0.92834, 0.92923, 0.93018, 0.93150, 0.93339, 0.93476,
                         0.93571, 0.93810, 0.93809, 0.93945, 0.94129, 0.94175, 0.94299,
                         0.94394, 0.94430, 0.94645, 0.94726, 0.94762, 0.94903, 0.95018, 0.80528],
                        [0.92313, 0.92349, 0.92334, 0.92410, 0.92451, 0.92507, 0.92620,
                         0.92673, 0.92837, 0.92968, 0.93066, 0.93138, 0.93342, 0.93409,
                         0.93538, 0.93746, 0.93739, 0.93970, 0.94114, 0.94188, 0.94331,
                         0.94411, 0.94528, 0.94696, 0.94800, 0.94783, 0.94872, 0.95001, 0.80616],
                        [0.92235, 0.92338, 0.92279, 0.92357, 0.92386, 0.92457, 0.92549,
                         0.92629, 0.92747, 0.92895, 0.93001, 0.93146, 0.93272, 0.93341,
                         0.93491, 0.93611, 0.93727, 0.93864, 0.93986, 0.94135, 0.94274,
                         0.94421, 0.94530, 0.94595, 0.94750, 0.94739, 0.94835, 0.94981, 0.80519],
                        [0.92224, 0.92321, 0.92291, 0.92339, 0.92375, 0.92392, 0.92480,
                         0.92620, 0.92699, 0.92786, 0.92939, 0.93145, 0.93178, 0.93311,
                         0.93502, 0.93566, 0.93772, 0.93807, 0.93966, 0.94117, 0.94140,
                         0.94397, 0.94456, 0.94487, 0.94648, 0.94686, 0.94812, 0.94951, 0.80395],
                        [0.92253, 0.92333, 0.92340, 0.92351, 0.92427, 0.92396, 0.92491,
                         0.92642, 0.92693, 0.92756, 0.92899, 0.93114, 0.93172, 0.93298,
                         0.93543, 0.93604, 0.93765, 0.93868, 0.93975, 0.94049, 0.94151,
                         0.94352, 0.94404, 0.94470, 0.94598, 0.94650, 0.94805, 0.94874, 0.80388],
                        [0.92246, 0.92280, 0.92351, 0.92352, 0.92431, 0.92446, 0.92503,
                         0.92585, 0.92646, 0.92728, 0.92850, 0.93048, 0.93178, 0.93280,
                         0.93508, 0.93596, 0.93700, 0.93905, 0.93951, 0.94007, 0.94253,
                         0.94340, 0.94354, 0.94505, 0.94574, 0.94648, 0.94759, 0.94840, 0.80393],
                        [0.92206, 0.92220, 0.92309, 0.92325, 0.92383, 0.92455, 0.92493,
                         0.92499, 0.92637, 0.92712, 0.92824, 0.92949, 0.93133, 0.93287,
                         0.93430, 0.93529, 0.93659, 0.93862, 0.93984, 0.94098, 0.94275,
                         0.94335, 0.94358, 0.94550, 0.94590, 0.94681, 0.94728, 0.94881, 0.80376],
                        [0.92185, 0.92195, 0.92203, 0.92256, 0.92331, 0.92373, 0.92403,
                         0.92483, 0.92609, 0.92691, 0.92751, 0.92849, 0.93074, 0.93231,
                         0.93343, 0.93489, 0.93622, 0.93719, 0.93977, 0.94103, 0.94202,
                         0.94261, 0.94389, 0.94497, 0.94569, 0.94632, 0.94703, 0.94853, 0.80348],
                        [0.92162, 0.92190, 0.92153, 0.92235, 0.92312, 0.92289, 0.92358,
                         0.92473, 0.92534, 0.92622, 0.92678, 0.92824, 0.93014, 0.93185,
                         0.93310, 0.93484, 0.93603, 0.93625, 0.93930, 0.94010, 0.94106,
                         0.94209, 0.94328, 0.94384, 0.94480, 0.94542, 0.94649, 0.94764, 0.80309],
                        [0.92081, 0.92127, 0.92167, 0.92205, 0.92256, 0.92293, 0.92338,
                         0.92387, 0.92435, 0.92546, 0.92707, 0.92800, 0.92931, 0.93131,
                         0.93295, 0.93407, 0.93572, 0.93604, 0.93849, 0.93916, 0.94016,
                         0.94195, 0.94218, 0.94302, 0.94396, 0.94503, 0.94605, 0.94668, 0.80217],
                        [0.91979, 0.92002, 0.92122, 0.92126, 0.92171, 0.92266, 0.92240,
                         0.92298, 0.92341, 0.92474, 0.92699, 0.92689, 0.92863, 0.92987,
                         0.93155, 0.93301, 0.93457, 0.93548, 0.93742, 0.93828, 0.93978,
                         0.94126, 0.94160, 0.94239, 0.94326, 0.94458, 0.94561, 0.94579, 0.80124],
                        [0.91935, 0.91928, 0.92018, 0.92090, 0.92123, 0.92163, 0.92188,
                         0.92312, 0.92305, 0.92435, 0.92585, 0.92617, 0.92777, 0.92886,
                         0.93010, 0.93262, 0.93353, 0.93520, 0.93702, 0.93807, 0.93990,
                         0.94077, 0.94158, 0.94204, 0.94319, 0.94387, 0.94498, 0.94544, 0.80141],
                        [0.91902, 0.91908, 0.91950, 0.92049, 0.92096, 0.92082, 0.92192,
                         0.92304, 0.92303, 0.92434, 0.92469, 0.92653, 0.92688, 0.92868,
                         0.92990, 0.93227, 0.93334, 0.93526, 0.93690, 0.93796, 0.93965,
                         0.94093, 0.94153, 0.94202, 0.94322, 0.94344, 0.94442, 0.94543, 0.80143],
                        [0.91863, 0.91904, 0.91961, 0.92004, 0.92069, 0.92063, 0.92184,
                         0.92250, 0.92344, 0.92371, 0.92419, 0.92674, 0.92705, 0.92838,
                         0.93015, 0.93175, 0.93323, 0.93510, 0.93658, 0.93737, 0.93907,
                         0.94071, 0.94076, 0.94181, 0.94272, 0.94315, 0.94424, 0.94524, 0.80109],
                        [0.91808, 0.91862, 0.91945, 0.91938, 0.92017, 0.92065, 0.92124,
                         0.92266, 0.92353, 0.92289, 0.92391, 0.92551, 0.92705, 0.92773,
                         0.92930, 0.93091, 0.93255, 0.93436, 0.93618, 0.93681, 0.93812,
                         0.93973, 0.93996, 0.94121, 0.94173, 0.94303, 0.94363, 0.94464, 0.80089],
                        [0.91734, 0.91754, 0.91870, 0.91851, 0.91959, 0.92025, 0.92069,
                         0.92245, 0.92285, 0.92298, 0.92354, 0.92428, 0.92638, 0.92719,
                         0.92817, 0.93022, 0.93175, 0.93324, 0.93544, 0.93625, 0.93745,
                         0.93911, 0.93995, 0.94036, 0.94116, 0.94272, 0.94289, 0.94411, 0.80075],
                        [0.91668, 0.91656, 0.91767, 0.91784, 0.91881, 0.91949, 0.92035,
                         0.92143, 0.92227, 0.92290, 0.92333, 0.92377, 0.92557, 0.92627,
                         0.92774, 0.92971, 0.93121, 0.93252, 0.93392, 0.93566, 0.93725,
                         0.93853, 0.93945, 0.93943, 0.94098, 0.94130, 0.94248, 0.94369, 0.80029],
                        [0.91619, 0.91628, 0.91663, 0.91733, 0.91829, 0.91934, 0.91990,
                         0.92121, 0.92194, 0.92215, 0.92332, 0.92345, 0.92505, 0.92526,
                         0.92754, 0.92925, 0.93080, 0.93240, 0.93290, 0.93520, 0.93675,
                         0.93763, 0.93870, 0.93922, 0.94017, 0.94014, 0.94221, 0.94316, 0.79984],
                        [0.91563, 0.91546, 0.91571, 0.91665, 0.91794, 0.91903, 0.91933,
                         0.92127, 0.92126, 0.92134, 0.92285, 0.92345, 0.92451, 0.92503,
                         0.92692, 0.92822, 0.92994, 0.93178, 0.93271, 0.93485, 0.93573,
                         0.93708, 0.93848, 0.93896, 0.93949, 0.94004, 0.94128, 0.94282, 0.79981],
                        [0.91511, 0.91428, 0.91531, 0.91632, 0.91704, 0.91829, 0.91908,
                         0.92077, 0.92126, 0.92131, 0.92253, 0.92339, 0.92378, 0.92525,
                         0.92654, 0.92669, 0.92902, 0.93097, 0.93207, 0.93445, 0.93509,
                         0.93673, 0.93759, 0.93854, 0.93947, 0.93999, 0.94019, 0.94316, 0.80009],
                        [0.91432, 0.91406, 0.91549, 0.91603, 0.91602, 0.91752, 0.91894,
                         0.91999, 0.92176, 0.92170, 0.92259, 0.92273, 0.92313, 0.92489,
                         0.92611, 0.92615, 0.92816, 0.93025, 0.93104, 0.93338, 0.93512,
                         0.93598, 0.93573, 0.93838, 0.93896, 0.93952, 0.93997, 0.94325, 0.80021],
                        [0.91333, 0.91434, 0.91552, 0.91509, 0.91592, 0.91675, 0.91854,
                         0.91972, 0.92161, 0.92164, 0.92221, 0.92221, 0.92294, 0.92426,
                         0.92538, 0.92661, 0.92768, 0.92975, 0.93078, 0.93252, 0.93474,
                         0.93541, 0.93525, 0.93764, 0.93800, 0.93885, 0.94027, 0.94232, 0.79987],
                        [0.91333, 0.91427, 0.91507, 0.91491, 0.91648, 0.91644, 0.91869,
                         0.92009, 0.92107, 0.92153, 0.92207, 0.92278, 0.92338, 0.92410,
                         0.92541, 0.92682, 0.92849, 0.92967, 0.93151, 0.93269, 0.93394,
                         0.93556, 0.93641, 0.93712, 0.93753, 0.93893, 0.94061, 0.94201, 0.79994],
                        [0.91410, 0.91424, 0.91487, 0.91598, 0.91678, 0.91743, 0.91939,
                         0.92007, 0.92082, 0.92201, 0.92292, 0.92380, 0.92392, 0.92451,
                         0.92578, 0.92691, 0.92902, 0.92962, 0.93223, 0.93286, 0.93373,
                         0.93589, 0.93716, 0.93744, 0.93800, 0.93990, 0.94084, 0.94297, 0.80068],
                        [0.91439, 0.91467, 0.91483, 0.91639, 0.91647, 0.91860, 0.91949,
                         0.91991, 0.92115, 0.92255, 0.92310, 0.92398, 0.92424, 0.92468,
                         0.92573, 0.92697, 0.92810, 0.92946, 0.93163, 0.93226, 0.93387,
                         0.93569, 0.93690, 0.93715, 0.93848, 0.93978, 0.94076, 0.94355, 0.80123],
                        [0.91433, 0.91497, 0.91485, 0.91581, 0.91628, 0.91834, 0.91905,
                         0.92038, 0.92200, 0.92266, 0.92262, 0.92389, 0.92463, 0.92470,
                         0.92590, 0.92726, 0.92781, 0.92969, 0.93088, 0.93221, 0.93397,
                         0.93531, 0.93649, 0.93690, 0.93855, 0.93926, 0.94099, 0.94385, 0.80172],
                        [0.91443, 0.91425, 0.91494, 0.91510, 0.91633, 0.91722, 0.91831,
                         0.92038, 0.92213, 0.92212, 0.92318, 0.92421, 0.92506, 0.92503,
                         0.92620, 0.92743, 0.92833, 0.92990, 0.93081, 0.93222, 0.93419,
                         0.93489, 0.93656, 0.93691, 0.93819, 0.93958, 0.94138, 0.94410, 0.80150],
                        [0.91412, 0.91341, 0.91449, 0.91478, 0.91614, 0.91670, 0.91784,
                         0.91946, 0.92110, 0.92135, 0.92412, 0.92435, 0.92536, 0.92572,
                         0.92628, 0.92684, 0.92845, 0.92996, 0.93020, 0.93152, 0.93440,
                         0.93470, 0.93668, 0.93662, 0.93776, 0.93989, 0.94135, 0.94423, 0.80066],
                        [0.91361, 0.91334, 0.91385, 0.91489, 0.91590, 0.91660, 0.91800,
                         0.91911, 0.92022, 0.92127, 0.92415, 0.92409, 0.92552, 0.92661,
                         0.92640, 0.92667, 0.92825, 0.93016, 0.93030, 0.93177, 0.93401,
                         0.93506, 0.93602, 0.93725, 0.93808, 0.94016, 0.94150, 0.94486, 0.80095],
                        [0.91329, 0.91357, 0.91410, 0.91498, 0.91554, 0.91619, 0.91813,
                         0.91915, 0.92039, 0.92196, 0.92357, 0.92413, 0.92544, 0.92684,
                         0.92653, 0.92739, 0.92795, 0.92996, 0.93145, 0.93313, 0.93381,
                         0.93556, 0.93573, 0.93840, 0.93868, 0.94058, 0.94220, 0.94567, 0.80180],
                        [0.91332, 0.91386, 0.91474, 0.91469, 0.91524, 0.91555, 0.91752,
                         0.91870, 0.92087, 0.92255, 0.92328, 0.92462, 0.92548, 0.92635,
                         0.92675, 0.92793, 0.92847, 0.92989, 0.93155, 0.93346, 0.93437,
                         0.93589, 0.93636, 0.93849, 0.93931, 0.94070, 0.94289, 0.94594, 0.80176],
                        [0.91353, 0.91400, 0.91460, 0.91435, 0.91541, 0.91553, 0.91683,
                         0.91873, 0.92031, 0.92203, 0.92369, 0.92509, 0.92575, 0.92624,
                         0.92729, 0.92840, 0.92957, 0.93002, 0.93104, 0.93267, 0.93453,
                         0.93588, 0.93693, 0.93792, 0.93996, 0.94108, 0.94320, 0.94586, 0.80130],
                        [0.91364, 0.91392, 0.91420, 0.91449, 0.91571, 0.91592, 0.91722,
                         0.91911, 0.91952, 0.92109, 0.92373, 0.92498, 0.92587, 0.92711,
                         0.92757, 0.92858, 0.92976, 0.93002, 0.93134, 0.93255, 0.93445,
                         0.93559, 0.93668, 0.93779, 0.93984, 0.94157, 0.94331, 0.94578, 0.80085],
                        [0.91383, 0.91416, 0.91422, 0.91501, 0.91563, 0.91581, 0.91724,
                         0.91850, 0.91925, 0.92081, 0.92319, 0.92434, 0.92580, 0.92761,
                         0.92739, 0.92794, 0.92901, 0.93015, 0.93160, 0.93290, 0.93469,
                         0.93524, 0.93617, 0.93851, 0.93924, 0.94142, 0.94353, 0.94570, 0.80006],
                        [0.91386, 0.91479, 0.91425, 0.91531, 0.91541, 0.91579, 0.91623,
                         0.91786, 0.91907, 0.92115, 0.92289, 0.92424, 0.92589, 0.92734,
                         0.92737, 0.92787, 0.92892, 0.93054, 0.93176, 0.93321, 0.93480,
                         0.93544, 0.93648, 0.93930, 0.93929, 0.94181, 0.94378, 0.94589, 0.79979],
                        [0.91403, 0.91473, 0.91424, 0.91523, 0.91527, 0.91595, 0.91634,
                         0.91807, 0.91905, 0.92123, 0.92253, 0.92450, 0.92601, 0.92727,
                         0.92770, 0.92870, 0.92992, 0.93100, 0.93207, 0.93327, 0.93459,
                         0.93588, 0.93738, 0.93903, 0.93996, 0.94234, 0.94414, 0.94639, 0.80019],
                        [0.91452, 0.91419, 0.91442, 0.91535, 0.91544, 0.91582, 0.91737,
                         0.91823, 0.91897, 0.92069, 0.92184, 0.92437, 0.92551, 0.92705,
                         0.92828, 0.92947, 0.93029, 0.93116, 0.93195, 0.93313, 0.93474,
                         0.93609, 0.93760, 0.93855, 0.94040, 0.94195, 0.94462, 0.94671, 0.79983],
                        [0.91426, 0.91398, 0.91495, 0.91549, 0.91584, 0.91587, 0.91746,
                         0.91791, 0.91859, 0.92022, 0.92126, 0.92374, 0.92479, 0.92653,
                         0.92831, 0.92976, 0.92981, 0.93101, 0.93167, 0.93339, 0.93545,
                         0.93637, 0.93737, 0.93869, 0.94084, 0.94206, 0.94485, 0.94654, 0.79918],
                        [0.91360, 0.91432, 0.91524, 0.91562, 0.91592, 0.91625, 0.91664,
                         0.91765, 0.91835, 0.91997, 0.92081, 0.92298, 0.92441, 0.92615,
                         0.92773, 0.92902, 0.92974, 0.93104, 0.93205, 0.93387, 0.93590,
                         0.93668, 0.93766, 0.93891, 0.94164, 0.94265, 0.94451, 0.94604, 0.79899],
                        [0.91365, 0.91491, 0.91505, 0.91565, 0.91589, 0.91630, 0.91563,
                         0.91729, 0.91844, 0.91931, 0.92062, 0.92225, 0.92460, 0.92582,
                         0.92755, 0.92831, 0.92991, 0.93120, 0.93304, 0.93377, 0.93535,
                         0.93665, 0.93811, 0.93888, 0.94149, 0.94251, 0.94414, 0.94538, 0.79873],
                        [0.91439, 0.91491, 0.91498, 0.91549, 0.91582, 0.91595, 0.91531,
                         0.91707, 0.91799, 0.91874, 0.92067, 0.92157, 0.92445, 0.92546,
                         0.92763, 0.92895, 0.92963, 0.93127, 0.93346, 0.93366, 0.93446,
                         0.93642, 0.93838, 0.93901, 0.94070, 0.94220, 0.94432, 0.94492, 0.79829],
                        [0.91477, 0.91457, 0.91497, 0.91527, 0.91523, 0.91578, 0.91561,
                         0.91706, 0.91732, 0.91876, 0.91999, 0.92116, 0.92339, 0.92499,
                         0.92700, 0.92907, 0.92908, 0.93069, 0.93265, 0.93393, 0.93456,
                         0.93644, 0.93795, 0.93916, 0.94023, 0.94196, 0.94378, 0.94450, 0.79761],
                        [0.91469, 0.91449, 0.91456, 0.91511, 0.91499, 0.91588, 0.91626,
                         0.91705, 0.91745, 0.91877, 0.91903, 0.92095, 0.92281, 0.92463,
                         0.92614, 0.92803, 0.92932, 0.93010, 0.93190, 0.93391, 0.93499,
                         0.93648, 0.93758, 0.93922, 0.94002, 0.94171, 0.94302, 0.94439, 0.79693],
                        [0.91441, 0.91387, 0.91429, 0.91527, 0.91518, 0.91590, 0.91704,
                         0.91684, 0.91781, 0.91835, 0.91888, 0.92056, 0.92258, 0.92439,
                         0.92586, 0.92734, 0.92985, 0.93045, 0.93179, 0.93350, 0.93511,
                         0.93608, 0.93771, 0.93909, 0.94019, 0.94143, 0.94300, 0.94401, 0.79658],
                        [0.91376, 0.91337, 0.91465, 0.91565, 0.91557, 0.91622, 0.91728,
                         0.91668, 0.91774, 0.91791, 0.91933, 0.91996, 0.92203, 0.92399,
                         0.92611, 0.92714, 0.92971, 0.93101, 0.93189, 0.93343, 0.93549,
                         0.93586, 0.93784, 0.93896, 0.94046, 0.94161, 0.94279, 0.94300, 0.79688],
                        [0.91396, 0.91382, 0.91531, 0.91628, 0.91668, 0.91673, 0.91716,
                         0.91714, 0.91757, 0.91814, 0.91973, 0.91988, 0.92132, 0.92421,
                         0.92637, 0.92719, 0.92919, 0.93139, 0.93215, 0.93348, 0.93566,
                         0.93664, 0.93791, 0.93954, 0.94110, 0.94235, 0.94281, 0.94284, 0.79745],
                        [0.91471, 0.91400, 0.91560, 0.91658, 0.91677, 0.91689, 0.91715,
                         0.91775, 0.91803, 0.91892, 0.92013, 0.92030, 0.92096, 0.92447,
                         0.92579, 0.92731, 0.92891, 0.93170, 0.93237, 0.93367, 0.93558,
                         0.93764, 0.93755, 0.93992, 0.94122, 0.94213, 0.94310, 0.94383, 0.79706],
                        [0.91427, 0.91363, 0.91457, 0.91540, 0.91548, 0.91634, 0.91694,
                         0.91757, 0.91888, 0.91876, 0.91968, 0.92000, 0.92082, 0.92343,
                         0.92433, 0.92658, 0.92856, 0.93138, 0.93209, 0.93395, 0.93554,
                         0.93735, 0.93712, 0.93954, 0.94021, 0.94118, 0.94261, 0.94408, 0.79610],
                        [0.91283, 0.91311, 0.91327, 0.91378, 0.91433, 0.91533, 0.91647,
                         0.91703, 0.91861, 0.91753, 0.91803, 0.91904, 0.92020, 0.92218,
                         0.92348, 0.92567, 0.92769, 0.93007, 0.93153, 0.93350, 0.93506,
                         0.93660, 0.93769, 0.93890, 0.93965, 0.94073, 0.94143, 0.94284, 0.79566],
                        [0.91201, 0.91221, 0.91254, 0.91325, 0.91389, 0.91460, 0.91607,
                         0.91702, 0.91734, 0.91703, 0.91746, 0.91848, 0.91954, 0.92177,
                         0.92344, 0.92552, 0.92734, 0.92901, 0.93128, 0.93299, 0.93445,
                         0.93644, 0.93809, 0.93828, 0.94004, 0.94041, 0.94051, 0.94161, 0.79548],
                        [0.91176, 0.91196, 0.91217, 0.91388, 0.91421, 0.91481, 0.91550,
                         0.91758, 0.91706, 0.91774, 0.91858, 0.91882, 0.91998, 0.92137,
                         0.92315, 0.92546, 0.92789, 0.92924, 0.93143, 0.93308, 0.93475,
                         0.93635, 0.93747, 0.93790, 0.94049, 0.94003, 0.94053, 0.94156, 0.79557],
                        [0.91106, 0.91159, 0.91142, 0.91416, 0.91413, 0.91459, 0.91513,
                         0.91730, 0.91725, 0.91805, 0.91887, 0.91883, 0.92059, 0.92061,
                         0.92271, 0.92441, 0.92757, 0.92929, 0.93106, 0.93312, 0.93485,
                         0.93625, 0.93702, 0.93778, 0.93935, 0.93951, 0.94047, 0.94204, 0.79562],
                        [0.90983, 0.91033, 0.91054, 0.91247, 0.91257, 0.91337, 0.91518,
                         0.91564, 0.91680, 0.91715, 0.91739, 0.91804, 0.91990, 0.91982,
                         0.92230, 0.92324, 0.92578, 0.92842, 0.92999, 0.93228, 0.93355,
                         0.93554, 0.93673, 0.93754, 0.93743, 0.93881, 0.93957, 0.94175, 0.79512],
                        [0.90829, 0.90879, 0.91004, 0.90976, 0.91058, 0.91224, 0.91434,
                         0.91435, 0.91630, 0.91601, 0.91631, 0.91753, 0.91817, 0.91912,
                         0.92113, 0.92232, 0.92429, 0.92679, 0.92909, 0.93054, 0.93234,
                         0.93419, 0.93568, 0.93686, 0.93690, 0.93792, 0.93846, 0.94099, 0.79454],
                        [0.90723, 0.90726, 0.90898, 0.90829, 0.90952, 0.91181, 0.91314,
                         0.91438, 0.91600, 0.91584, 0.91663, 0.91743, 0.91709, 0.91884,
                         0.91992, 0.92172, 0.92387, 0.92578, 0.92841, 0.92956, 0.93232,
                         0.93365, 0.93507, 0.93649, 0.93712, 0.93712, 0.93803, 0.94089, 0.79443],
                        [0.90621, 0.90605, 0.90698, 0.90783, 0.90909, 0.91119, 0.91217,
                         0.91441, 0.91535, 0.91585, 0.91659, 0.91686, 0.91739, 0.91865,
                         0.91937, 0.92177, 0.92361, 0.92574, 0.92767, 0.92960, 0.93181,
                         0.93346, 0.93505, 0.93600, 0.93662, 0.93642, 0.93823, 0.94081, 0.79451],
                        [0.90528, 0.90556, 0.90549, 0.90743, 0.90854, 0.90984, 0.91081,
                         0.91325, 0.91411, 0.91539, 0.91562, 0.91582, 0.91753, 0.91769,
                         0.91887, 0.92125, 0.92264, 0.92515, 0.92646, 0.92907, 0.93064,
                         0.93218, 0.93448, 0.93454, 0.93527, 0.93557, 0.93779, 0.94048, 0.79412],
                        [0.90502, 0.90535, 0.90559, 0.90687, 0.90786, 0.90927, 0.91007,
                         0.91228, 0.91356, 0.91500, 0.91521, 0.91567, 0.91681, 0.91674,
                         0.91829, 0.92049, 0.92155, 0.92397, 0.92565, 0.92822, 0.93002,
                         0.93083, 0.93367, 0.93356, 0.93437, 0.93488, 0.93715, 0.94057, 0.79397],
                        [0.90457, 0.90451, 0.90583, 0.90633, 0.90755, 0.90919, 0.91026,
                         0.91196, 0.91377, 0.91483, 0.91539, 0.91612, 0.91620, 0.91655,
                         0.91774, 0.92034, 0.92118, 0.92301, 0.92541, 0.92768, 0.92937,
                         0.93076, 0.93265, 0.93340, 0.93387, 0.93460, 0.93712, 0.94072, 0.79422],
                        [0.90319, 0.90342, 0.90490, 0.90584, 0.90677, 0.90817, 0.90991,
                         0.91077, 0.91350, 0.91448, 0.91488, 0.91620, 0.91621, 0.91665,
                         0.91771, 0.91980, 0.92079, 0.92213, 0.92476, 0.92688, 0.92852,
                         0.93086, 0.93152, 0.93299, 0.93320, 0.93480, 0.93691, 0.94050, 0.79412],
                        [0.90246, 0.90319, 0.90424, 0.90535, 0.90593, 0.90750, 0.90947,
                         0.91024, 0.91297, 0.91408, 0.91447, 0.91642, 0.91661, 0.91685,
                         0.91801, 0.91900, 0.92049, 0.92186, 0.92443, 0.92615, 0.92804,
                         0.93041, 0.93096, 0.93272, 0.93345, 0.93552, 0.93698, 0.94071, 0.79420],
                        [0.90281, 0.90306, 0.90415, 0.90488, 0.90573, 0.90742, 0.90911,
                         0.91075, 0.91220, 0.91400, 0.91470, 0.91589, 0.91679, 0.91713,
                         0.91821, 0.91839, 0.92035, 0.92210, 0.92413, 0.92575, 0.92816,
                         0.92984, 0.93098, 0.93252, 0.93365, 0.93522, 0.93750, 0.94139, 0.79394],
                        [0.90257, 0.90259, 0.90362, 0.90438, 0.90562, 0.90704, 0.90866,
                         0.91031, 0.91154, 0.91363, 0.91492, 0.91521, 0.91668, 0.91759,
                         0.91800, 0.91814, 0.92039, 0.92223, 0.92383, 0.92543, 0.92790,
                         0.92948, 0.93073, 0.93207, 0.93324, 0.93417, 0.93756, 0.94164, 0.79335],
                        [0.90229, 0.90289, 0.90343, 0.90405, 0.90536, 0.90640, 0.90811,
                         0.90941, 0.91142, 0.91295, 0.91506, 0.91575, 0.91648, 0.91763,
                         0.91762, 0.91828, 0.92074, 0.92215, 0.92354, 0.92509, 0.92675,
                         0.92891, 0.93006, 0.93140, 0.93292, 0.93447, 0.93761, 0.94205, 0.79314],
                        [0.90276, 0.90325, 0.90364, 0.90411, 0.90501, 0.90602, 0.90756,
                         0.90998, 0.91141, 0.91307, 0.91494, 0.91665, 0.91634, 0.91749,
                         0.91832, 0.91860, 0.92048, 0.92164, 0.92283, 0.92521, 0.92643,
                         0.92839, 0.92971, 0.93126, 0.93268, 0.93539, 0.93805, 0.94317, 0.79350],
                        [0.90273, 0.90296, 0.90383, 0.90440, 0.90488, 0.90660, 0.90755,
                         0.91074, 0.91115, 0.91350, 0.91470, 0.91679, 0.91648, 0.91767,
                         0.91944, 0.91909, 0.91993, 0.92129, 0.92249, 0.92547, 0.92693,
                         0.92846, 0.92973, 0.93161, 0.93305, 0.93576, 0.93862, 0.94333, 0.79332],
                        [0.90227, 0.90268, 0.90392, 0.90485, 0.90559, 0.90703, 0.90776,
                         0.90994, 0.91144, 0.91346, 0.91479, 0.91648, 0.91722, 0.91802,
                         0.91948, 0.91961, 0.92027, 0.92163, 0.92300, 0.92489, 0.92717,
                         0.92872, 0.92973, 0.93170, 0.93374, 0.93576, 0.93925, 0.94301, 0.79228],
                        [0.90260, 0.90294, 0.90371, 0.90519, 0.90582, 0.90657, 0.90824,
                         0.90927, 0.91195, 0.91289, 0.91502, 0.91625, 0.91765, 0.91850,
                         0.91915, 0.92001, 0.92110, 0.92202, 0.92362, 0.92446, 0.92674,
                         0.92889, 0.92996, 0.93204, 0.93389, 0.93612, 0.94019, 0.94356, 0.79148],
                        [0.90361, 0.90408, 0.90426, 0.90523, 0.90570, 0.90657, 0.90837,
                         0.90964, 0.91170, 0.91259, 0.91485, 0.91644, 0.91763, 0.91913,
                         0.91969, 0.92046, 0.92191, 0.92245, 0.92421, 0.92536, 0.92645,
                         0.92933, 0.93048, 0.93248, 0.93411, 0.93719, 0.94112, 0.94433, 0.79106],
                        [0.90414, 0.90479, 0.90533, 0.90538, 0.90640, 0.90726, 0.90790,
                         0.90966, 0.91120, 0.91293, 0.91478, 0.91719, 0.91843, 0.92006,
                         0.92074, 0.92118, 0.92278, 0.92354, 0.92476, 0.92656, 0.92760,
                         0.93005, 0.93141, 0.93282, 0.93518, 0.93862, 0.94144, 0.94444, 0.79062],
                        [0.90382, 0.90408, 0.90513, 0.90533, 0.90627, 0.90730, 0.90792,
                         0.90927, 0.91075, 0.91304, 0.91498, 0.91695, 0.91871, 0.92032,
                         0.92142, 0.92168, 0.92326, 0.92434, 0.92505, 0.92691, 0.92876,
                         0.93038, 0.93223, 0.93356, 0.93611, 0.93948, 0.94157, 0.94444, 0.79025],
                        [0.90353, 0.90363, 0.90409, 0.90466, 0.90546, 0.90635, 0.90809,
                         0.90877, 0.91039, 0.91271, 0.91489, 0.91590, 0.91800, 0.92001,
                         0.92148, 0.92179, 0.92291, 0.92409, 0.92501, 0.92704, 0.92885,
                         0.93019, 0.93189, 0.93417, 0.93633, 0.93926, 0.94195, 0.94479, 0.78929],
                        [0.90363, 0.90401, 0.90390, 0.90447, 0.90543, 0.90569, 0.90781,
                         0.90819, 0.91070, 0.91174, 0.91417, 0.91587, 0.91774, 0.92003,
                         0.92123, 0.92172, 0.92279, 0.92432, 0.92528, 0.92769, 0.92913,
                         0.93006, 0.93186, 0.93396, 0.93668, 0.93918, 0.94204, 0.94497, 0.78754],
                        [0.90364, 0.90413, 0.90469, 0.90509, 0.90574, 0.90633, 0.90732,
                         0.90846, 0.91103, 0.91131, 0.91322, 0.91622, 0.91768, 0.91980,
                         0.92157, 0.92244, 0.92383, 0.92512, 0.92633, 0.92800, 0.93010,
                         0.93066, 0.93288, 0.93419, 0.93718, 0.94007, 0.94228, 0.94503, 0.78655],
                        [0.90377, 0.90433, 0.90504, 0.90550, 0.90607, 0.90726, 0.90726,
                         0.90888, 0.91027, 0.91180, 0.91298, 0.91619, 0.91779, 0.91964,
                         0.92256, 0.92405, 0.92461, 0.92539, 0.92724, 0.92809, 0.93043,
                         0.93174, 0.93370, 0.93583, 0.93767, 0.94072, 0.94275, 0.94514, 0.78681],
                        [0.90362, 0.90401, 0.90481, 0.90487, 0.90587, 0.90690, 0.90718,
                         0.90806, 0.90894, 0.91136, 0.91282, 0.91539, 0.91739, 0.91941,
                         0.92222, 0.92421, 0.92440, 0.92568, 0.92720, 0.92858, 0.93002,
                         0.93222, 0.93401, 0.93680, 0.93803, 0.94029, 0.94253, 0.94487, 0.78638],
                        [0.90257, 0.90252, 0.90423, 0.90363, 0.90459, 0.90554, 0.90648,
                         0.90727, 0.90837, 0.91021, 0.91183, 0.91398, 0.91608, 0.91864,
                         0.92071, 0.92223, 0.92366, 0.92568, 0.92644, 0.92859, 0.92973,
                         0.93164, 0.93370, 0.93576, 0.93760, 0.93962, 0.94191, 0.94348, 0.78401],
                        [0.90181, 0.90096, 0.90297, 0.90359, 0.90375, 0.90465, 0.90612,
                         0.90725, 0.90833, 0.90972, 0.91087, 0.91286, 0.91530, 0.91762,
                         0.91984, 0.92107, 0.92322, 0.92489, 0.92600, 0.92799, 0.92982,
                         0.93134, 0.93300, 0.93471, 0.93721, 0.93926, 0.94148, 0.94196, 0.78175],
                        [0.90167, 0.90073, 0.90201, 0.90394, 0.90385, 0.90452, 0.90561,
                         0.90707, 0.90799, 0.90971, 0.91073, 0.91209, 0.91518, 0.91679,
                         0.91935, 0.92167, 0.92363, 0.92441, 0.92609, 0.92785, 0.93019,
                         0.93215, 0.93326, 0.93516, 0.93731, 0.93924, 0.94150, 0.94166, 0.78100],
                        [0.90073, 0.90143, 0.90123, 0.90238, 0.90335, 0.90389, 0.90451,
                         0.90635, 0.90723, 0.90867, 0.91022, 0.91123, 0.91392, 0.91605,
                         0.91863, 0.92137, 0.92324, 0.92429, 0.92624, 0.92826, 0.93009,
                         0.93219, 0.93374, 0.93618, 0.93725, 0.93923, 0.94118, 0.94125, 0.78032],
                        [0.89955, 0.90082, 0.90034, 0.90077, 0.90206, 0.90315, 0.90386,
                         0.90533, 0.90651, 0.90704, 0.90880, 0.91058, 0.91248, 0.91521,
                         0.91793, 0.91987, 0.92172, 0.92403, 0.92648, 0.92827, 0.92967,
                         0.93134, 0.93340, 0.93665, 0.93709, 0.93911, 0.94028, 0.94063, 0.77864],
                        [0.89900, 0.89886, 0.89958, 0.90036, 0.90100, 0.90298, 0.90340,
                         0.90453, 0.90567, 0.90610, 0.90758, 0.90971, 0.91148, 0.91401,
                         0.91672, 0.91930, 0.92058, 0.92366, 0.92598, 0.92709, 0.92893,
                         0.93063, 0.93264, 0.93536, 0.93653, 0.93789, 0.93894, 0.94020, 0.77670],
                        [0.89789, 0.89724, 0.89870, 0.89960, 0.90046, 0.90221, 0.90259,
                         0.90394, 0.90484, 0.90599, 0.90703, 0.90849, 0.91025, 0.91261,
                         0.91496, 0.91896, 0.91985, 0.92306, 0.92436, 0.92601, 0.92793,
                         0.92983, 0.93175, 0.93350, 0.93537, 0.93585, 0.93749, 0.93937, 0.77541],
                        [0.89645, 0.89630, 0.89752, 0.89906, 0.90029, 0.90105, 0.90188,
                         0.90333, 0.90403, 0.90572, 0.90653, 0.90773, 0.90979, 0.91209,
                         0.91349, 0.91765, 0.91928, 0.92204, 0.92341, 0.92616, 0.92774,
                         0.92960, 0.93166, 0.93284, 0.93460, 0.93507, 0.93697, 0.93858, 0.77427],
                        [0.89565, 0.89588, 0.89648, 0.89836, 0.89943, 0.90037, 0.90103,
                         0.90259, 0.90317, 0.90453, 0.90604, 0.90703, 0.90913, 0.91120,
                         0.91272, 0.91638, 0.91868, 0.92091, 0.92344, 0.92589, 0.92801,
                         0.92988, 0.93210, 0.93264, 0.93433, 0.93573, 0.93663, 0.93768, 0.77308],
                        [0.89485, 0.89533, 0.89574, 0.89682, 0.89757, 0.89944, 0.89986,
                         0.90201, 0.90270, 0.90373, 0.90547, 0.90571, 0.90793, 0.91013,
                         0.91222, 0.91501, 0.91783, 0.92001, 0.92271, 0.92503, 0.92800,
                         0.92998, 0.93178, 0.93244, 0.93415, 0.93599, 0.93557, 0.93729, 0.77196],
                        [0.89353, 0.89365, 0.89454, 0.89530, 0.89599, 0.89771, 0.89908,
                         0.90143, 0.90212, 0.90336, 0.90435, 0.90460, 0.90709, 0.90979,
                         0.91138, 0.91365, 0.91661, 0.91906, 0.92156, 0.92449, 0.92674,
                         0.92915, 0.93096, 0.93200, 0.93373, 0.93448, 0.93457, 0.93743, 0.77041],
                        [0.89157, 0.89144, 0.89315, 0.89402, 0.89544, 0.89645, 0.89869,
                         0.90048, 0.90177, 0.90229, 0.90364, 0.90414, 0.90659, 0.90868,
                         0.91058, 0.91295, 0.91526, 0.91830, 0.92115, 0.92371, 0.92529,
                         0.92752, 0.93017, 0.93117, 0.93248, 0.93259, 0.93358, 0.93698, 0.76831],
                        [0.88954, 0.88982, 0.89171, 0.89260, 0.89446, 0.89552, 0.89733,
                         0.89931, 0.90149, 0.90112, 0.90303, 0.90368, 0.90539, 0.90651,
                         0.90946, 0.91177, 0.91407, 0.91754, 0.92041, 0.92237, 0.92515,
                         0.92645, 0.92933, 0.93052, 0.93091, 0.93213, 0.93277, 0.93581, 0.76607],
                        [0.88755, 0.88835, 0.88963, 0.89112, 0.89229, 0.89377, 0.89510,
                         0.89777, 0.89989, 0.90055, 0.90164, 0.90244, 0.90334, 0.90482,
                         0.90761, 0.90981, 0.91304, 0.91620, 0.91894, 0.92100, 0.92482,
                         0.92632, 0.92815, 0.92963, 0.93019, 0.93203, 0.93269, 0.93522, 0.76421],
                        [0.88529, 0.88636, 0.88723, 0.88920, 0.88985, 0.89159, 0.89324,
                         0.89550, 0.89772, 0.89992, 0.89995, 0.90092, 0.90215, 0.90389,
                         0.90605, 0.90858, 0.91196, 0.91450, 0.91748, 0.92012, 0.92333,
                         0.92598, 0.92647, 0.92812, 0.92926, 0.93083, 0.93245, 0.93481, 0.76238],
                        [0.88327, 0.88413, 0.88523, 0.88684, 0.88813, 0.88937, 0.89189,
                         0.89340, 0.89622, 0.89821, 0.89856, 0.90030, 0.90197, 0.90307,
                         0.90527, 0.90763, 0.91079, 0.91334, 0.91631, 0.91962, 0.92186,
                         0.92468, 0.92541, 0.92676, 0.92792, 0.92935, 0.93117, 0.93391, 0.75972],
                        [0.88139, 0.88179, 0.88347, 0.88458, 0.88642, 0.88773, 0.89037,
                         0.89238, 0.89448, 0.89614, 0.89768, 0.89962, 0.90113, 0.90231,
                         0.90411, 0.90617, 0.90979, 0.91232, 0.91515, 0.91893, 0.92081,
                         0.92317, 0.92493, 0.92600, 0.92705, 0.92823, 0.92985, 0.93355, 0.75669],
                        [0.87889, 0.87899, 0.88079, 0.88208, 0.88363, 0.88604, 0.88782,
                         0.89067, 0.89175, 0.89418, 0.89590, 0.89735, 0.89903, 0.90115,
                         0.90172, 0.90422, 0.90805, 0.91001, 0.91303, 0.91710, 0.91914,
                         0.92153, 0.92323, 0.92490, 0.92567, 0.92667, 0.92839, 0.93229, 0.75408],
                        [0.87571, 0.87600, 0.87759, 0.87930, 0.88034, 0.88276, 0.88477,
                         0.88720, 0.88932, 0.89131, 0.89348, 0.89483, 0.89667, 0.89892,
                         0.89984, 0.90206, 0.90519, 0.90773, 0.91036, 0.91419, 0.91657,
                         0.91907, 0.92046, 0.92293, 0.92387, 0.92486, 0.92675, 0.92958, 0.75127],
                        [0.87282, 0.87396, 0.87519, 0.87658, 0.87749, 0.87960, 0.88221,
                         0.88451, 0.88753, 0.88845, 0.89191, 0.89356, 0.89466, 0.89654,
                         0.89906, 0.90023, 0.90280, 0.90636, 0.90893, 0.91173, 0.91502,
                         0.91680, 0.91865, 0.92086, 0.92247, 0.92357, 0.92605, 0.92801, 0.74782],
                        [0.87046, 0.87154, 0.87230, 0.87356, 0.87553, 0.87751, 0.87965,
                         0.88270, 0.88529, 0.88714, 0.89003, 0.89229, 0.89246, 0.89436,
                         0.89764, 0.89869, 0.90158, 0.90455, 0.90814, 0.91000, 0.91396,
                         0.91539, 0.91750, 0.91938, 0.92046, 0.92215, 0.92560, 0.92688, 0.74420],
                        [0.86815, 0.86795, 0.86881, 0.87083, 0.87361, 0.87503, 0.87708,
                         0.88021, 0.88327, 0.88598, 0.88745, 0.89014, 0.89126, 0.89243,
                         0.89560, 0.89742, 0.90074, 0.90262, 0.90612, 0.90842, 0.91160,
                         0.91431, 0.91592, 0.91825, 0.91826, 0.92029, 0.92393, 0.92522, 0.74067],
                        [0.86510, 0.86478, 0.86612, 0.86861, 0.87033, 0.87173, 0.87449,
                         0.87706, 0.88114, 0.88356, 0.88529, 0.88804, 0.89049, 0.89105,
                         0.89330, 0.89559, 0.89948, 0.90104, 0.90363, 0.90677, 0.90941,
                         0.91271, 0.91430, 0.91700, 0.91713, 0.91895, 0.92204, 0.92396, 0.73706],
                        [0.86166, 0.86199, 0.86367, 0.86582, 0.86660, 0.86818, 0.87194,
                         0.87430, 0.87771, 0.88012, 0.88308, 0.88587, 0.88774, 0.88927,
                         0.89079, 0.89318, 0.89675, 0.89891, 0.90161, 0.90489, 0.90786,
                         0.91032, 0.91283, 0.91506, 0.91609, 0.91803, 0.92108, 0.92238, 0.73296],
                        [0.85864, 0.85866, 0.86000, 0.86183, 0.86308, 0.86496, 0.86872,
                         0.87152, 0.87381, 0.87653, 0.88015, 0.88246, 0.88410, 0.88669,
                         0.88880, 0.89099, 0.89305, 0.89604, 0.89964, 0.90274, 0.90589,
                         0.90733, 0.91108, 0.91205, 0.91415, 0.91636, 0.92005, 0.92010, 0.72891],
                        [0.85475, 0.85550, 0.85580, 0.85762, 0.86026, 0.86195, 0.86456,
                         0.86798, 0.87051, 0.87392, 0.87719, 0.87913, 0.88181, 0.88442,
                         0.88742, 0.88931, 0.89075, 0.89419, 0.89770, 0.90053, 0.90364,
                         0.90502, 0.90918, 0.90984, 0.91229, 0.91469, 0.91871, 0.91843, 0.72529],
                        [0.85003, 0.85204, 0.85220, 0.85374, 0.85719, 0.85834, 0.86051,
                         0.86414, 0.86778, 0.87125, 0.87407, 0.87661, 0.88008, 0.88254,
                         0.88558, 0.88728, 0.88973, 0.89294, 0.89557, 0.89849, 0.90163,
                         0.90423, 0.90702, 0.90889, 0.91136, 0.91349, 0.91729, 0.91694, 0.72077],
                        [0.84573, 0.84666, 0.84801, 0.84937, 0.85152, 0.85364, 0.85643,
                         0.85999, 0.86421, 0.86722, 0.87029, 0.87377, 0.87711, 0.88024,
                         0.88282, 0.88458, 0.88797, 0.89052, 0.89314, 0.89643, 0.89981,
                         0.90286, 0.90463, 0.90709, 0.91001, 0.91170, 0.91533, 0.91452, 0.71508],
                        [0.84070, 0.84059, 0.84228, 0.84425, 0.84508, 0.84827, 0.85170,
                         0.85534, 0.85901, 0.86241, 0.86610, 0.87032, 0.87349, 0.87728,
                         0.87947, 0.88236, 0.88515, 0.88807, 0.89099, 0.89393, 0.89765,
                         0.90015, 0.90259, 0.90476, 0.90753, 0.91001, 0.91335, 0.91139, 0.70943],
                        [0.83424, 0.83452, 0.83584, 0.83820, 0.84016, 0.84282, 0.84631,
                         0.85003, 0.85356, 0.85755, 0.86130, 0.86597, 0.87027, 0.87355,
                         0.87596, 0.87972, 0.88225, 0.88647, 0.88865, 0.89179, 0.89511,
                         0.89791, 0.90096, 0.90306, 0.90530, 0.90903, 0.91207, 0.90807, 0.70382],
                        [0.82624, 0.82657, 0.82835, 0.83033, 0.83389, 0.83594, 0.83944,
                         0.84361, 0.84751, 0.85197, 0.85572, 0.86002, 0.86537, 0.86846,
                         0.87220, 0.87565, 0.87917, 0.88357, 0.88536, 0.88970, 0.89232,
                         0.89548, 0.89883, 0.90112, 0.90339, 0.90721, 0.90947, 0.90436, 0.69718],
                        [0.81567, 0.81676, 0.81843, 0.82050, 0.82401, 0.82664, 0.83004,
                         0.83548, 0.83932, 0.84452, 0.84902, 0.85319, 0.85848, 0.86263,
                         0.86738, 0.87098, 0.87488, 0.87865, 0.88169, 0.88622, 0.88901,
                         0.89225, 0.89550, 0.89796, 0.90091, 0.90381, 0.90524, 0.89951, 0.68905],
                        [0.80316, 0.80487, 0.80592, 0.80904, 0.81183, 0.81562, 0.81913,
                         0.82518, 0.82967, 0.83527, 0.84063, 0.84577, 0.85120, 0.85626,
                         0.86106, 0.86548, 0.86976, 0.87338, 0.87800, 0.88147, 0.88514,
                         0.88895, 0.89124, 0.89431, 0.89739, 0.89935, 0.90131, 0.89384, 0.67978],
                        [0.78936, 0.79043, 0.79181, 0.79558, 0.79802, 0.80258, 0.80737,
                         0.81290, 0.81874, 0.82381, 0.83049, 0.83623, 0.84266, 0.84830,
                         0.85366, 0.85856, 0.86348, 0.86800, 0.87259, 0.87610, 0.88011,
                         0.88415, 0.88641, 0.89008, 0.89250, 0.89456, 0.89672, 0.88671, 0.66932],
                        [0.77328, 0.77387, 0.77634, 0.77987, 0.78238, 0.78720, 0.79296,
                         0.79910, 0.80552, 0.81093, 0.81884, 0.82472, 0.83168, 0.83850,
                         0.84509, 0.85032, 0.85577, 0.86113, 0.86500, 0.87026, 0.87408,
                         0.87816, 0.88112, 0.88458, 0.88728, 0.88959, 0.89060, 0.87797, 0.65798],
                        [0.75423, 0.75451, 0.75782, 0.76090, 0.76431, 0.76943, 0.77532,
                         0.78279, 0.78995, 0.79673, 0.80493, 0.81176, 0.81860, 0.82658,
                         0.83444, 0.84048, 0.84678, 0.85220, 0.85679, 0.86320, 0.86722,
                         0.87197, 0.87490, 0.87823, 0.88128, 0.88318, 0.88274, 0.86848, 0.64570],
                        [0.73199, 0.73229, 0.73551, 0.73888, 0.74329, 0.74906, 0.75569,
                         0.76343, 0.77173, 0.77953, 0.78769, 0.79662, 0.80416, 0.81265,
                         0.82148, 0.82863, 0.83586, 0.84230, 0.84819, 0.85432, 0.85855,
                         0.86381, 0.86740, 0.87095, 0.87308, 0.87444, 0.87297, 0.85685, 0.63142],
                        [0.70698, 0.70768, 0.71052, 0.71477, 0.71950, 0.72601, 0.73349,
                         0.74151, 0.75038, 0.75871, 0.76739, 0.77829, 0.78733, 0.79688,
                         0.80579, 0.81460, 0.82311, 0.83067, 0.83750, 0.84341, 0.84808,
                         0.85319, 0.85771, 0.86143, 0.86283, 0.86408, 0.86161, 0.84173, 0.61532],
                        [0.67873, 0.67946, 0.68255, 0.68783, 0.69223, 0.69933, 0.70737,
                         0.71615, 0.72556, 0.73455, 0.74444, 0.75588, 0.76681, 0.77758,
                         0.78693, 0.79753, 0.80703, 0.81502, 0.82290, 0.82938, 0.83529,
                         0.84053, 0.84478, 0.84811, 0.85028, 0.85138, 0.84762, 0.82345, 0.59715],
                        [0.64688, 0.64809, 0.65145, 0.65738, 0.66143, 0.66939, 0.67806,
                         0.68776, 0.69760, 0.70784, 0.71907, 0.73076, 0.74303, 0.75435,
                         0.76583, 0.77684, 0.78730, 0.79617, 0.80490, 0.81262, 0.81980,
                         0.82559, 0.83010, 0.83266, 0.83509, 0.83524, 0.83039, 0.80319, 0.57666],
                        [0.61284, 0.61493, 0.61793, 0.62309, 0.62808, 0.63695, 0.64566,
                         0.65659, 0.66700, 0.67825, 0.69058, 0.70332, 0.71581, 0.72841,
                         0.74177, 0.75292, 0.76497, 0.77502, 0.78426, 0.79326, 0.80067,
                         0.80728, 0.81300, 0.81607, 0.81649, 0.81570, 0.80987, 0.78086, 0.55422],
                        [0.57689, 0.57909, 0.58187, 0.58625, 0.59289, 0.60184, 0.61080,
                         0.62246, 0.63390, 0.64583, 0.65918, 0.67278, 0.68563, 0.70007,
                         0.71416, 0.72658, 0.74002, 0.75121, 0.76134, 0.77077, 0.77838,
                         0.78560, 0.79177, 0.79608, 0.79519, 0.79396, 0.78689, 0.75576, 0.53035],
                        [0.53881, 0.54033, 0.54364, 0.54829, 0.55602, 0.56424, 0.57399,
                         0.58622, 0.59882, 0.61145, 0.62552, 0.63924, 0.65332, 0.66896,
                         0.68344, 0.69746, 0.71199, 0.72400, 0.73564, 0.74507, 0.75382,
                         0.76130, 0.76720, 0.77168, 0.77122, 0.76965, 0.76166, 0.72772, 0.50504],
                        [0.49973, 0.50096, 0.50518, 0.50976, 0.51765, 0.52568, 0.53587,
                         0.54879, 0.56206, 0.57512, 0.58984, 0.60404, 0.61911, 0.63552,
                         0.65053, 0.66613, 0.68105, 0.69408, 0.70656, 0.71709, 0.72679,
                         0.73456, 0.74053, 0.74410, 0.74475, 0.74233, 0.73330, 0.69742, 0.47840],
                        [0.45955, 0.46119, 0.46558, 0.47028, 0.47760, 0.48650, 0.49705,
                         0.50958, 0.52301, 0.53669, 0.55176, 0.56725, 0.58277, 0.60012,
                         0.61593, 0.63260, 0.64737, 0.66194, 0.67454, 0.68679, 0.69690,
                         0.70489, 0.71141, 0.71446, 0.71570, 0.71220, 0.70161, 0.66449, 0.45014],
                        [0.41837, 0.41987, 0.42365, 0.42904, 0.43621, 0.44564, 0.45658,
                         0.46870, 0.48214, 0.49683, 0.51202, 0.52828, 0.54457, 0.56219,
                         0.57925, 0.59602, 0.61163, 0.62716, 0.64018, 0.65354, 0.66362,
                         0.67270, 0.67967, 0.68296, 0.68364, 0.67938, 0.66754, 0.62914, 0.41993],
                        [0.37680, 0.37729, 0.38144, 0.38687, 0.39430, 0.40372, 0.41459,
                         0.42724, 0.44070, 0.45616, 0.47180, 0.48796, 0.50474, 0.52206,
                         0.54066, 0.55713, 0.57478, 0.59031, 0.60390, 0.61758, 0.62796,
                         0.63842, 0.64506, 0.64881, 0.64894, 0.64453, 0.63137, 0.59227, 0.38823],
                        [0.33461, 0.33514, 0.33997, 0.34487, 0.35209, 0.36151, 0.37226,
                         0.38519, 0.39916, 0.41427, 0.43021, 0.44680, 0.46320, 0.48129,
                         0.50031, 0.51712, 0.53601, 0.55154, 0.56599, 0.57954, 0.59112,
                         0.60136, 0.60748, 0.61208, 0.61153, 0.60720, 0.59287, 0.55333, 0.35554],
                        [0.29282, 0.29401, 0.29824, 0.30306, 0.30996, 0.31907, 0.32967,
                         0.34240, 0.35669, 0.37118, 0.38714, 0.40421, 0.42051, 0.43975,
                         0.45802, 0.47622, 0.49473, 0.51063, 0.52610, 0.53980, 0.55156,
                         0.56147, 0.56805, 0.57251, 0.57146, 0.56668, 0.55206, 0.51221, 0.32225],
                        [0.25266, 0.25399, 0.25692, 0.26223, 0.26888, 0.27744, 0.28761,
                         0.29987, 0.31360, 0.32804, 0.34407, 0.36048, 0.37760, 0.39672,
                         0.41470, 0.43353, 0.45133, 0.46841, 0.48415, 0.49808, 0.50956,
                         0.51977, 0.52711, 0.53044, 0.52963, 0.52453, 0.50946, 0.46980, 0.28817],
                        [0.21487, 0.21586, 0.21826, 0.22352, 0.22965, 0.23761, 0.24760,
                         0.25907, 0.27177, 0.28589, 0.30149, 0.31718, 0.33463, 0.35271,
                         0.37152, 0.38962, 0.40708, 0.42498, 0.44090, 0.45460, 0.46667,
                         0.47694, 0.48408, 0.48747, 0.48730, 0.48173, 0.46573, 0.42590, 0.25382],
                        [0.18009, 0.18042, 0.18310, 0.18772, 0.19307, 0.20008, 0.20977,
                         0.22047, 0.23204, 0.24544, 0.25974, 0.27531, 0.29198, 0.30894,
                         0.32807, 0.34563, 0.36296, 0.38035, 0.39631, 0.41032, 0.42240,
                         0.43229, 0.43883, 0.44328, 0.44337, 0.43663, 0.42000, 0.38034, 0.22030],
                        [0.14897, 0.14913, 0.15189, 0.15556, 0.16036, 0.16648, 0.17492,
                         0.18458, 0.19508, 0.20759, 0.22038, 0.23528, 0.25072, 0.26695,
                         0.28483, 0.30202, 0.31939, 0.33568, 0.35099, 0.36550, 0.37723,
                         0.38650, 0.39340, 0.39778, 0.39706, 0.38988, 0.37340, 0.33479, 0.18845],
                        [0.12215, 0.12269, 0.12515, 0.12769, 0.13235, 0.13753, 0.14417,
                         0.15250, 0.16202, 0.17305, 0.18460, 0.19800, 0.21188, 0.22726,
                         0.24360, 0.25975, 0.27682, 0.29180, 0.30624, 0.32026, 0.33211,
                         0.34101, 0.34837, 0.35183, 0.35052, 0.34356, 0.32761, 0.29034, 0.15891],
                        [0.09973, 0.10041, 0.10247, 0.10467, 0.10873, 0.11261, 0.11800,
                         0.12508, 0.13328, 0.14268, 0.15292, 0.16430, 0.17684, 0.19030,
                         0.20508, 0.21997, 0.23575, 0.24958, 0.26325, 0.27612, 0.28754,
                         0.29628, 0.30303, 0.30595, 0.30510, 0.29837, 0.28273, 0.24728, 0.13246],
                        [0.08154, 0.08180, 0.08326, 0.08556, 0.08846, 0.09155, 0.09636,
                         0.10217, 0.10876, 0.11651, 0.12552, 0.13499, 0.14580, 0.15712,
                         0.16989, 0.18375, 0.19706, 0.21003, 0.22275, 0.23455, 0.24456,
                         0.25322, 0.25875, 0.26175, 0.26087, 0.25471, 0.23966, 0.20739, 0.10930],
                        [0.06666, 0.06650, 0.06772, 0.06969, 0.07162, 0.07418, 0.07851,
                         0.08320, 0.08813, 0.09425, 0.10210, 0.11002, 0.11872, 0.12861,
                         0.13913, 0.15140, 0.16237, 0.17404, 0.18522, 0.19595, 0.20458,
                         0.21265, 0.21735, 0.22025, 0.21939, 0.21335, 0.19989, 0.17161, 0.08910],
                        [0.05427, 0.05426, 0.05568, 0.05678, 0.05857, 0.06040, 0.06414,
                         0.06772, 0.07141, 0.07642, 0.08239, 0.08899, 0.09601, 0.10449,
                         0.11332, 0.12301, 0.13254, 0.14251, 0.15209, 0.16092, 0.16870,
                         0.17555, 0.17999, 0.18231, 0.18174, 0.17596, 0.16451, 0.13998, 0.07222],
                        [0.04449, 0.04508, 0.04604, 0.04655, 0.04838, 0.04975, 0.05261,
                         0.05525, 0.05844, 0.06248, 0.06664, 0.07182, 0.07745, 0.08432,
                         0.09188, 0.09928, 0.10728, 0.11551, 0.12377, 0.13080, 0.13743,
                         0.14314, 0.14727, 0.14920, 0.14840, 0.14360, 0.13408, 0.11330, 0.05867],
                        [0.03713, 0.03807, 0.03826, 0.03888, 0.04024, 0.04152, 0.04357,
                         0.04570, 0.04827, 0.05146, 0.05473, 0.05868, 0.06320, 0.06836,
                         0.07439, 0.08054, 0.08678, 0.09356, 0.09996, 0.10628, 0.11156,
                         0.11601, 0.11950, 0.12141, 0.12043, 0.11675, 0.10893, 0.09206, 0.04794],
                        [0.03171, 0.03201, 0.03236, 0.03303, 0.03391, 0.03503, 0.03669,
                         0.03841, 0.04025, 0.04282, 0.04559, 0.04883, 0.05247, 0.05648,
                         0.06097, 0.06587, 0.07075, 0.07628, 0.08131, 0.08640, 0.09083,
                         0.09390, 0.09698, 0.09823, 0.09762, 0.09484, 0.08848, 0.07532, 0.03978],
                        [0.02758, 0.02717, 0.02793, 0.02839, 0.02886, 0.03008, 0.03140,
                         0.03258, 0.03441, 0.03611, 0.03844, 0.04127, 0.04392, 0.04731,
                         0.05094, 0.05443, 0.05824, 0.06251, 0.06704, 0.07041, 0.07404,
                         0.07667, 0.07928, 0.07966, 0.07956, 0.07729, 0.07207, 0.06195, 0.03372],
                        [0.02417, 0.02402, 0.02450, 0.02492, 0.02499, 0.02648, 0.02745,
                         0.02822, 0.02988, 0.03123, 0.03300, 0.03528, 0.03730, 0.03981,
                         0.04272, 0.04577, 0.04869, 0.05180, 0.05553, 0.05842, 0.06074,
                         0.06365, 0.06521, 0.06560, 0.06559, 0.06368, 0.05935, 0.05140, 0.02889],
                        [0.02148, 0.02162, 0.02181, 0.02239, 0.02237, 0.02342, 0.02437,
                         0.02504, 0.02602, 0.02753, 0.02876, 0.02997, 0.03198, 0.03388,
                         0.03606, 0.03911, 0.04126, 0.04374, 0.04611, 0.04913, 0.05076,
                         0.05304, 0.05414, 0.05466, 0.05461, 0.05303, 0.04975, 0.04353, 0.02477],
                        [0.01948, 0.01919, 0.01954, 0.02026, 0.02031, 0.02069, 0.02174,
                         0.02237, 0.02286, 0.02411, 0.02545, 0.02581, 0.02745, 0.02949,
                         0.03118, 0.03373, 0.03537, 0.03764, 0.03896, 0.04125, 0.04316,
                         0.04439, 0.04573, 0.04583, 0.04610, 0.04461, 0.04224, 0.03752, 0.02159],
                        [0.01781, 0.01710, 0.01785, 0.01819, 0.01847, 0.01868, 0.01937,
                         0.02008, 0.02042, 0.02125, 0.02290, 0.02334, 0.02432, 0.02600,
                         0.02749, 0.02913, 0.03063, 0.03263, 0.03353, 0.03510, 0.03686,
                         0.03779, 0.03891, 0.03885, 0.03943, 0.03807, 0.03625, 0.03242, 0.01924],
                        [0.01636, 0.01588, 0.01675, 0.01647, 0.01697, 0.01744, 0.01763,
                         0.01829, 0.01857, 0.01943, 0.02057, 0.02127, 0.02227, 0.02319,
                         0.02457, 0.02549, 0.02677, 0.02835, 0.02931, 0.03078, 0.03196,
                         0.03261, 0.03332, 0.03369, 0.03393, 0.03321, 0.03158, 0.02822, 0.01736],
                        [0.01495, 0.01512, 0.01521, 0.01520, 0.01565, 0.01644, 0.01619,
                         0.01669, 0.01690, 0.01799, 0.01833, 0.01916, 0.02013, 0.02089,
                         0.02198, 0.02279, 0.02387, 0.02486, 0.02601, 0.02713, 0.02816,
                         0.02869, 0.02921, 0.02961, 0.02946, 0.02923, 0.02795, 0.02487, 0.01577],
                        [0.01396, 0.01421, 0.01368, 0.01426, 0.01451, 0.01499, 0.01483,
                         0.01519, 0.01555, 0.01641, 0.01691, 0.01767, 0.01803, 0.01895,
                         0.01983, 0.02052, 0.02173, 0.02227, 0.02346, 0.02387, 0.02506,
                         0.02573, 0.02616, 0.02632, 0.02627, 0.02569, 0.02502, 0.02250, 0.01448],
                        [0.01331, 0.01313, 0.01288, 0.01334, 0.01330, 0.01349, 0.01397,
                         0.01389, 0.01449, 0.01487, 0.01581, 0.01637, 0.01651, 0.01714,
                         0.01809, 0.01864, 0.01954, 0.02022, 0.02120, 0.02136, 0.02245,
                         0.02289, 0.02348, 0.02360, 0.02368, 0.02274, 0.02215, 0.02052, 0.01343],
                        [0.01241, 0.01234, 0.01217, 0.01247, 0.01216, 0.01260, 0.01326,
                         0.01312, 0.01366, 0.01388, 0.01456, 0.01502, 0.01556, 0.01557,
                         0.01657, 0.01723, 0.01785, 0.01849, 0.01920, 0.01937, 0.02021,
                         0.02038, 0.02123, 0.02108, 0.02113, 0.02056, 0.01972, 0.01861, 0.01245],
                        [0.01139, 0.01155, 0.01125, 0.01169, 0.01152, 0.01183, 0.01224,
                         0.01226, 0.01279, 0.01324, 0.01330, 0.01368, 0.01446, 0.01444,
                         0.01518, 0.01570, 0.01663, 0.01665, 0.01753, 0.01757, 0.01823,
                         0.01828, 0.01891, 0.01882, 0.01901, 0.01872, 0.01802, 0.01664, 0.01146],
                        [0.01061, 0.01074, 0.01078, 0.01115, 0.01128, 0.01104, 0.01119,
                         0.01132, 0.01172, 0.01219, 0.01228, 0.01249, 0.01308, 0.01363,
                         0.01396, 0.01412, 0.01513, 0.01506, 0.01612, 0.01634, 0.01671,
                         0.01666, 0.01696, 0.01729, 0.01786, 0.01721, 0.01681, 0.01526, 0.01072],
                        [0.01021, 0.01004, 0.01041, 0.01059, 0.01068, 0.01056, 0.01035,
                         0.01098, 0.01067, 0.01111, 0.01144, 0.01189, 0.01209, 0.01257,
                         0.01300, 0.01327, 0.01377, 0.01393, 0.01490, 0.01535, 0.01558,
                         0.01555, 0.01583, 0.01619, 0.01671, 0.01601, 0.01560, 0.01445, 0.01021],
                        [0.00985, 0.00958, 0.00963, 0.00985, 0.01001, 0.01007, 0.00989,
                         0.01066, 0.01026, 0.01084, 0.01077, 0.01154, 0.01154, 0.01162,
                         0.01228, 0.01272, 0.01294, 0.01296, 0.01361, 0.01419, 0.01450,
                         0.01462, 0.01488, 0.01504, 0.01497, 0.01468, 0.01434, 0.01355, 0.00967],
                        [0.00935, 0.00935, 0.00887, 0.00908, 0.00949, 0.00937, 0.00959,
                         0.00966, 0.01009, 0.01065, 0.01023, 0.01091, 0.01101, 0.01122,
                         0.01145, 0.01187, 0.01213, 0.01202, 0.01233, 0.01316, 0.01331,
                         0.01362, 0.01374, 0.01372, 0.01346, 0.01350, 0.01333, 0.01272, 0.00904],
                        [0.00899, 0.00907, 0.00858, 0.00879, 0.00888, 0.00899, 0.00937,
                         0.00891, 0.00976, 0.01010, 0.00974, 0.01019, 0.01045, 0.01079,
                         0.01066, 0.01112, 0.01130, 0.01155, 0.01168, 0.01233, 0.01231,
                         0.01265, 0.01264, 0.01272, 0.01279, 0.01272, 0.01257, 0.01213, 0.00858],
                        [0.00868, 0.00860, 0.00860, 0.00873, 0.00828, 0.00900, 0.00911,
                         0.00876, 0.00924, 0.00933, 0.00925, 0.00973, 0.00987, 0.01014,
                         0.01019, 0.01081, 0.01070, 0.01147, 0.01143, 0.01158, 0.01172,
                         0.01188, 0.01184, 0.01240, 0.01228, 0.01204, 0.01200, 0.01146, 0.00831],
                        [0.00841, 0.00821, 0.00869, 0.00839, 0.00814, 0.00884, 0.00865,
                         0.00886, 0.00870, 0.00879, 0.00898, 0.00955, 0.00961, 0.00960,
                         0.00990, 0.01048, 0.01023, 0.01105, 0.01102, 0.01088, 0.01145,
                         0.01127, 0.01153, 0.01191, 0.01160, 0.01131, 0.01168, 0.01077, 0.00824],
                        [0.00797, 0.00806, 0.00839, 0.00807, 0.00833, 0.00841, 0.00808,
                         0.00863, 0.00851, 0.00886, 0.00897, 0.00924, 0.00941, 0.00914,
                         0.00963, 0.00975, 0.00971, 0.01029, 0.01043, 0.01031, 0.01100,
                         0.01071, 0.01110, 0.01108, 0.01107, 0.01064, 0.01121, 0.01041, 0.00788],
                        [0.00743, 0.00794, 0.00773, 0.00809, 0.00824, 0.00804, 0.00778,
                         0.00825, 0.00858, 0.00895, 0.00868, 0.00871, 0.00882, 0.00904,
                         0.00931, 0.00905, 0.00934, 0.00972, 0.01009, 0.00989, 0.01029,
                         0.01032, 0.01026, 0.01054, 0.01064, 0.01013, 0.01043, 0.01012, 0.00744],
                        [0.00734, 0.00789, 0.00736, 0.00789, 0.00779, 0.00784, 0.00800,
                         0.00805, 0.00837, 0.00850, 0.00825, 0.00851, 0.00843, 0.00911,
                         0.00896, 0.00891, 0.00903, 0.00949, 0.00970, 0.00962, 0.00983,
                         0.01013, 0.00979, 0.01023, 0.01026, 0.00989, 0.01000, 0.00964, 0.00737],
                        [0.00761, 0.00800, 0.00746, 0.00768, 0.00761, 0.00766, 0.00810,
                         0.00787, 0.00816, 0.00797, 0.00802, 0.00853, 0.00855, 0.00854,
                         0.00868, 0.00889, 0.00879, 0.00934, 0.00907, 0.00941, 0.00960,
                         0.00990, 0.00962, 0.00985, 0.00989, 0.00961, 0.00993, 0.00925, 0.00762],
                        [0.00756, 0.00790, 0.00756, 0.00753, 0.00765, 0.00758, 0.00753,
                         0.00770, 0.00815, 0.00782, 0.00782, 0.00850, 0.00860, 0.00802,
                         0.00828, 0.00867, 0.00879, 0.00906, 0.00895, 0.00922, 0.00929,
                         0.00952, 0.00923, 0.00950, 0.00961, 0.00932, 0.00960, 0.00909, 0.00764],
                        [0.00724, 0.00767, 0.00727, 0.00738, 0.00753, 0.00747, 0.00698,
                         0.00768, 0.00785, 0.00791, 0.00777, 0.00805, 0.00818, 0.00802,
                         0.00791, 0.00843, 0.00866, 0.00893, 0.00903, 0.00915, 0.00888,
                         0.00918, 0.00903, 0.00928, 0.00943, 0.00910, 0.00911, 0.00913, 0.00709],
                        [0.00726, 0.00754, 0.00720, 0.00747, 0.00737, 0.00745, 0.00718,
                         0.00765, 0.00738, 0.00802, 0.00774, 0.00762, 0.00773, 0.00820,
                         0.00804, 0.00841, 0.00826, 0.00899, 0.00877, 0.00911, 0.00869,
                         0.00898, 0.00904, 0.00929, 0.00907, 0.00893, 0.00890, 0.00910, 0.00684],
                        [0.00741, 0.00745, 0.00740, 0.00748, 0.00733, 0.00740, 0.00758,
                         0.00765, 0.00725, 0.00793, 0.00747, 0.00759, 0.00768, 0.00815,
                         0.00840, 0.00832, 0.00782, 0.00876, 0.00861, 0.00886, 0.00872,
                         0.00872, 0.00870, 0.00918, 0.00893, 0.00885, 0.00883, 0.00871, 0.00713],
                        [0.00718, 0.00726, 0.00726, 0.00716, 0.00716, 0.00714, 0.00755,
                         0.00744, 0.00747, 0.00791, 0.00718, 0.00773, 0.00773, 0.00783,
                         0.00829, 0.00795, 0.00768, 0.00827, 0.00852, 0.00845, 0.00877,
                         0.00853, 0.00846, 0.00868, 0.00898, 0.00875, 0.00889, 0.00827, 0.00720],
                        [0.00684, 0.00710, 0.00689, 0.00697, 0.00703, 0.00694, 0.00714,
                         0.00697, 0.00746, 0.00788, 0.00729, 0.00767, 0.00776, 0.00754,
                         0.00772, 0.00754, 0.00806, 0.00799, 0.00815, 0.00797, 0.00844,
                         0.00857, 0.00841, 0.00839, 0.00873, 0.00863, 0.00881, 0.00800, 0.00677],
                        [0.00683, 0.00702, 0.00691, 0.00710, 0.00727, 0.00710, 0.00682,
                         0.00695, 0.00732, 0.00735, 0.00751, 0.00734, 0.00773, 0.00747,
                         0.00738, 0.00760, 0.00820, 0.00802, 0.00792, 0.00773, 0.00798,
                         0.00851, 0.00818, 0.00842, 0.00838, 0.00857, 0.00864, 0.00820, 0.00656],
                        [0.00687, 0.00684, 0.00732, 0.00703, 0.00730, 0.00722, 0.00687,
                         0.00742, 0.00736, 0.00690, 0.00736, 0.00732, 0.00757, 0.00753,
                         0.00736, 0.00805, 0.00781, 0.00797, 0.00804, 0.00779, 0.00773,
                         0.00835, 0.00775, 0.00831, 0.00826, 0.00825, 0.00837, 0.00868, 0.00680],
                        [0.00691, 0.00677, 0.00746, 0.00695, 0.00709, 0.00710, 0.00712,
                         0.00757, 0.00727, 0.00689, 0.00708, 0.00770, 0.00743, 0.00773,
                         0.00763, 0.00804, 0.00750, 0.00793, 0.00827, 0.00804, 0.00780,
                         0.00822, 0.00758, 0.00817, 0.00833, 0.00805, 0.00815, 0.00851, 0.00702],
                        [0.00693, 0.00689, 0.00693, 0.00708, 0.00703, 0.00701, 0.00713,
                         0.00721, 0.00697, 0.00713, 0.00701, 0.00739, 0.00720, 0.00780,
                         0.00779, 0.00740, 0.00733, 0.00782, 0.00809, 0.00812, 0.00792,
                         0.00808, 0.00784, 0.00816, 0.00818, 0.00815, 0.00806, 0.00786, 0.00686],
                        [0.00682, 0.00710, 0.00673, 0.00704, 0.00723, 0.00714, 0.00713,
                         0.00724, 0.00714, 0.00757, 0.00720, 0.00691, 0.00724, 0.00779,
                         0.00760, 0.00733, 0.00748, 0.00761, 0.00776, 0.00787, 0.00787,
                         0.00821, 0.00807, 0.00819, 0.00826, 0.00816, 0.00821, 0.00798, 0.00668],
                        [0.00681, 0.00722, 0.00693, 0.00670, 0.00745, 0.00720, 0.00718,
                         0.00750, 0.00733, 0.00764, 0.00738, 0.00699, 0.00752, 0.00743,
                         0.00724, 0.00770, 0.00776, 0.00761, 0.00755, 0.00756, 0.00769,
                         0.00822, 0.00788, 0.00816, 0.00836, 0.00790, 0.00824, 0.00839, 0.00655],
                        [0.00730, 0.00735, 0.00715, 0.00700, 0.00754, 0.00714, 0.00708,
                         0.00751, 0.00732, 0.00752, 0.00746, 0.00732, 0.00763, 0.00718,
                         0.00737, 0.00778, 0.00806, 0.00782, 0.00771, 0.00767, 0.00796,
                         0.00801, 0.00770, 0.00820, 0.00820, 0.00775, 0.00817, 0.00836, 0.00659],
                        [0.00740, 0.00711, 0.00724, 0.00758, 0.00751, 0.00690, 0.00692,
                         0.00734, 0.00728, 0.00726, 0.00740, 0.00739, 0.00730, 0.00724,
                         0.00774, 0.00767, 0.00787, 0.00781, 0.00788, 0.00785, 0.00799,
                         0.00793, 0.00762, 0.00804, 0.00786, 0.00774, 0.00812, 0.00818, 0.00677],
                        [0.00701, 0.00692, 0.00733, 0.00772, 0.00749, 0.00707, 0.00724,
                         0.00745, 0.00752, 0.00723, 0.00738, 0.00733, 0.00718, 0.00754,
                         0.00771, 0.00778, 0.00736, 0.00760, 0.00789, 0.00810, 0.00778,
                         0.00801, 0.00775, 0.00818, 0.00774, 0.00783, 0.00814, 0.00836, 0.00692],
                        [0.00682, 0.00721, 0.00738, 0.00728, 0.00730, 0.00741, 0.00766,
                         0.00745, 0.00774, 0.00746, 0.00747, 0.00721, 0.00737, 0.00793,
                         0.00746, 0.00771, 0.00731, 0.00739, 0.00785, 0.00831, 0.00793,
                         0.00788, 0.00790, 0.00845, 0.00803, 0.00809, 0.00805, 0.00838, 0.00674],
                        [0.00710, 0.00751, 0.00718, 0.00703, 0.00727, 0.00733, 0.00740,
                         0.00736, 0.00763, 0.00750, 0.00765, 0.00716, 0.00768, 0.00797,
                         0.00740, 0.00764, 0.00775, 0.00745, 0.00783, 0.00816, 0.00821,
                         0.00805, 0.00791, 0.00841, 0.00860, 0.00847, 0.00800, 0.00811, 0.00653],
                        [0.00718, 0.00749, 0.00736, 0.00715, 0.00733, 0.00700, 0.00710,
                         0.00757, 0.00748, 0.00722, 0.00754, 0.00752, 0.00791, 0.00749,
                         0.00737, 0.00770, 0.00792, 0.00780, 0.00773, 0.00783, 0.00828,
                         0.00828, 0.00792, 0.00818, 0.00864, 0.00837, 0.00793, 0.00777, 0.00643],
                        [0.00703, 0.00754, 0.00791, 0.00733, 0.00732, 0.00719, 0.00753,
                         0.00785, 0.00769, 0.00716, 0.00731, 0.00789, 0.00773, 0.00756,
                         0.00760, 0.00768, 0.00786, 0.00807, 0.00759, 0.00755, 0.00812,
                         0.00822, 0.00792, 0.00817, 0.00825, 0.00808, 0.00802, 0.00773, 0.00663],
                        [0.00711, 0.00747, 0.00796, 0.00744, 0.00741, 0.00765, 0.00792,
                         0.00766, 0.00772, 0.00744, 0.00721, 0.00755, 0.00734, 0.00793,
                         0.00785, 0.00758, 0.00755, 0.00787, 0.00767, 0.00751, 0.00777,
                         0.00783, 0.00789, 0.00819, 0.00831, 0.00800, 0.00827, 0.00805, 0.00687],
                        ])),
    z=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                            100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                            180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                            260.0, 270.0, 280.0]),
           lam=np.array([800.21, 800.65, 801.09, 801.54, 801.98, 802.43, 802.87, 803.31,
                         803.76, 804.20, 804.65, 805.09, 805.54, 805.98, 806.42, 806.87,
                         807.31, 807.76, 808.20, 808.65, 809.09, 809.54, 809.98, 810.43,
                         810.87, 811.31, 811.76, 812.20, 812.65, 813.09, 813.54, 813.98,
                         814.43, 814.87, 815.32, 815.76, 816.21, 816.65, 817.10, 817.54,
                         817.99, 818.43, 818.88, 819.32, 819.77, 820.22, 820.66, 821.11,
                         821.55, 822.00, 822.44, 822.89, 823.33, 823.78, 824.22, 824.67,
                         825.11, 825.56, 826.01, 826.45, 826.90, 827.34, 827.79, 828.23,
                         828.68, 829.13, 829.57, 830.02, 830.46, 830.91, 831.36, 831.80,
                         832.25, 832.69, 833.14, 833.59, 834.03, 834.48, 834.92, 835.37,
                         835.82, 836.26, 836.71, 837.16, 837.60, 838.05, 838.50, 838.94,
                         839.39, 839.83, 840.28, 840.73, 841.17, 841.62, 842.07, 842.51,
                         842.96, 843.41, 843.85, 844.30, 844.75, 845.19, 845.64, 846.09,
                         846.54, 846.98, 847.43, 847.88, 848.32, 848.77, 849.22, 849.66,
                         850.11, 850.56, 851.01, 851.45, 851.90, 852.35, 852.79, 853.24,
                         853.69, 854.14, 854.58, 855.03, 855.48, 855.93, 856.37, 856.82,
                         857.27, 857.72, 858.16, 858.61, 859.06, 859.51, 859.95, 860.40,
                         860.85, 861.30, 861.75, 862.19, 862.64, 863.09, 863.54, 863.98,
                         864.43, 864.88, 865.33, 865.78, 866.22, 866.67, 867.12, 867.57,
                         868.02, 868.46, 868.91, 869.36, 869.81, 870.26, 870.71, 871.15,
                         871.60, 872.05, 872.50, 872.95, 873.40, 873.84, 874.29, 874.74,
                         875.19, 875.64, 876.09, 876.54, 876.98, 877.43, 877.88, 878.33,
                         878.78, 879.23, 879.68, 880.13, 880.57, 881.02, 881.47, 881.92,
                         882.37, 882.82, 883.27, 883.72, 884.17, 884.61, 885.06, 885.51,
                         885.96, 886.41, 886.86, 887.31, 887.76, 888.21, 888.66, 889.11,
                         889.55, 890.00, 890.45, 890.90, 891.35, 891.80, 892.25, 892.70,
                         893.15, 893.60, 894.05, 894.50, 894.95, 895.40, 895.85, 896.30,
                         896.75, 897.20, 897.65, 898.10, 898.54, 898.99, 899.44, 899.89,
                         900.34, 900.79, 901.24, 901.69, 902.14, 902.59, 903.04, 903.49,
                         903.94, 904.39, 904.84, 905.29, 905.74, 906.19, 906.64, 907.09,
                         907.54, 907.99, 908.44, 908.89, 909.34, 909.80, 910.25, 910.70,
                         911.15, 911.60, 912.05, 912.50, 912.95, 913.40, 913.85, 914.30,
                         914.75, 915.20, 915.65, 916.10, 916.55, 917.00, 917.45, 917.90,
                         918.35, 918.81, 919.26, 919.71, 920.16, 920.61, 921.06, 921.51,
                         921.96, 922.41, 922.86, 923.31, 923.76, 924.22, 924.67, 925.12,
                         925.57, 926.02, 926.47, 926.92, 927.37, 927.82, 928.27, 928.73,
                         929.18, 929.63, 930.08, 930.53, 930.98, 931.43, 931.88, 932.34,
                         932.79, 933.24, 933.69, 934.14, 934.59, 935.04, 935.50, 935.95,
                         936.40, 936.85, 937.30, 937.75, 938.20, 938.66, 939.11, 939.56,
                         940.01, 940.46, 940.91, 941.37, 941.82, 942.27, 942.72, 943.17,
                         943.62, 944.08, 944.53, 944.98, 945.43, 945.88, 946.34, 946.79,
                         947.24, 947.69, 948.14, 948.59, 949.05, 949.50, 949.95, 950.40,
                         950.86, 951.31, 951.76, 952.21, 952.66, 953.12, 953.57, 954.02,
                         954.47, 954.92, 955.38, 955.83, 956.28, 956.73, 957.19, 957.64,
                         958.09, 958.54, 959.00, 959.45, 959.90]),
           T=np.array([[0.00396, 0.00415, 0.00400, 0.00416, 0.00391, 0.00392, 0.00425,
                        0.00391, 0.00401, 0.00411, 0.00425, 0.00371, 0.00393, 0.00388,
                        0.00407, 0.00446, 0.00402, 0.00395, 0.00390, 0.00409, 0.00392,
                        0.00428, 0.00401, 0.00390, 0.00418, 0.00404, 0.00402, 0.00406, 0.00384],
                       [0.00370, 0.00401, 0.00400, 0.00411, 0.00395, 0.00407, 0.00436,
                        0.00374, 0.00423, 0.00390, 0.00406, 0.00386, 0.00379, 0.00395,
                        0.00427, 0.00429, 0.00401, 0.00389, 0.00399, 0.00411, 0.00409,
                        0.00429, 0.00396, 0.00389, 0.00412, 0.00369, 0.00398, 0.00419, 0.00380],
                       [0.00386, 0.00384, 0.00393, 0.00400, 0.00419, 0.00419, 0.00420,
                        0.00399, 0.00431, 0.00384, 0.00396, 0.00399, 0.00372, 0.00410,
                        0.00426, 0.00398, 0.00396, 0.00402, 0.00412, 0.00408, 0.00413,
                        0.00424, 0.00390, 0.00406, 0.00407, 0.00366, 0.00404, 0.00407, 0.00378],
                       [0.00410, 0.00389, 0.00407, 0.00404, 0.00428, 0.00421, 0.00403,
                        0.00416, 0.00426, 0.00392, 0.00401, 0.00416, 0.00391, 0.00413,
                        0.00410, 0.00396, 0.00411, 0.00430, 0.00402, 0.00414, 0.00416,
                        0.00411, 0.00387, 0.00415, 0.00414, 0.00390, 0.00425, 0.00405, 0.00399],
                       [0.00420, 0.00402, 0.00417, 0.00420, 0.00410, 0.00413, 0.00410,
                        0.00411, 0.00419, 0.00407, 0.00404, 0.00431, 0.00407, 0.00410,
                        0.00406, 0.00420, 0.00420, 0.00446, 0.00387, 0.00420, 0.00416,
                        0.00410, 0.00395, 0.00417, 0.00417, 0.00409, 0.00423, 0.00425, 0.00406],
                       [0.00418, 0.00421, 0.00418, 0.00425, 0.00404, 0.00406, 0.00418,
                        0.00416, 0.00425, 0.00427, 0.00405, 0.00436, 0.00412, 0.00405,
                        0.00412, 0.00436, 0.00397, 0.00433, 0.00401, 0.00412, 0.00414,
                        0.00421, 0.00407, 0.00412, 0.00412, 0.00414, 0.00408, 0.00441, 0.00393],
                       [0.00405, 0.00425, 0.00412, 0.00405, 0.00420, 0.00409, 0.00412,
                        0.00420, 0.00434, 0.00432, 0.00415, 0.00423, 0.00417, 0.00410,
                        0.00417, 0.00426, 0.00380, 0.00405, 0.00414, 0.00407, 0.00397,
                        0.00415, 0.00401, 0.00413, 0.00403, 0.00414, 0.00403, 0.00423, 0.00385],
                       [0.00415, 0.00411, 0.00408, 0.00408, 0.00433, 0.00424, 0.00410,
                        0.00412, 0.00421, 0.00418, 0.00425, 0.00415, 0.00405, 0.00414,
                        0.00416, 0.00424, 0.00389, 0.00409, 0.00411, 0.00413, 0.00389,
                        0.00410, 0.00404, 0.00421, 0.00401, 0.00418, 0.00416, 0.00420, 0.00401],
                       [0.00422, 0.00405, 0.00406, 0.00430, 0.00437, 0.00418, 0.00418,
                        0.00404, 0.00403, 0.00410, 0.00421, 0.00428, 0.00396, 0.00395,
                        0.00418, 0.00415, 0.00406, 0.00416, 0.00408, 0.00419, 0.00390,
                        0.00424, 0.00431, 0.00415, 0.00410, 0.00421, 0.00423, 0.00425, 0.00397],
                       [0.00405, 0.00409, 0.00405, 0.00418, 0.00416, 0.00407, 0.00431,
                        0.00406, 0.00407, 0.00423, 0.00404, 0.00432, 0.00405, 0.00400,
                        0.00425, 0.00395, 0.00415, 0.00406, 0.00418, 0.00420, 0.00413,
                        0.00429, 0.00438, 0.00405, 0.00409, 0.00420, 0.00421, 0.00418, 0.00371],
                       [0.00403, 0.00421, 0.00408, 0.00399, 0.00401, 0.00415, 0.00429,
                        0.00409, 0.00432, 0.00432, 0.00401, 0.00412, 0.00417, 0.00413,
                        0.00421, 0.00408, 0.00407, 0.00405, 0.00423, 0.00413, 0.00424,
                        0.00407, 0.00416, 0.00410, 0.00411, 0.00423, 0.00425, 0.00420, 0.00379],
                       [0.00413, 0.00423, 0.00407, 0.00406, 0.00406, 0.00412, 0.00404,
                        0.00404, 0.00427, 0.00430, 0.00418, 0.00415, 0.00428, 0.00414,
                        0.00417, 0.00433, 0.00399, 0.00415, 0.00416, 0.00403, 0.00417,
                        0.00409, 0.00413, 0.00420, 0.00416, 0.00422, 0.00418, 0.00421, 0.00404],
                       [0.00403, 0.00403, 0.00395, 0.00421, 0.00425, 0.00407, 0.00393,
                        0.00400, 0.00407, 0.00427, 0.00435, 0.00443, 0.00430, 0.00413,
                        0.00431, 0.00418, 0.00389, 0.00418, 0.00405, 0.00397, 0.00422,
                        0.00428, 0.00424, 0.00410, 0.00412, 0.00422, 0.00416, 0.00410, 0.00389],
                       [0.00405, 0.00395, 0.00398, 0.00430, 0.00436, 0.00408, 0.00403,
                        0.00389, 0.00410, 0.00420, 0.00431, 0.00448, 0.00423, 0.00409,
                        0.00433, 0.00403, 0.00391, 0.00411, 0.00397, 0.00417, 0.00428,
                        0.00416, 0.00417, 0.00404, 0.00420, 0.00416, 0.00419, 0.00401, 0.00372],
                       [0.00420, 0.00406, 0.00423, 0.00421, 0.00414, 0.00416, 0.00419,
                        0.00390, 0.00413, 0.00412, 0.00399, 0.00436, 0.00409, 0.00398,
                        0.00417, 0.00396, 0.00413, 0.00401, 0.00400, 0.00422, 0.00418,
                        0.00405, 0.00413, 0.00404, 0.00425, 0.00397, 0.00415, 0.00400, 0.00380],
                       [0.00419, 0.00413, 0.00428, 0.00412, 0.00392, 0.00424, 0.00420,
                        0.00421, 0.00408, 0.00421, 0.00385, 0.00418, 0.00401, 0.00399,
                        0.00413, 0.00401, 0.00426, 0.00410, 0.00404, 0.00416, 0.00411,
                        0.00416, 0.00423, 0.00398, 0.00409, 0.00389, 0.00410, 0.00415, 0.00386],
                       [0.00410, 0.00419, 0.00407, 0.00412, 0.00394, 0.00407, 0.00393,
                        0.00434, 0.00414, 0.00410, 0.00389, 0.00404, 0.00401, 0.00406,
                        0.00413, 0.00411, 0.00427, 0.00424, 0.00396, 0.00416, 0.00418,
                        0.00415, 0.00420, 0.00410, 0.00402, 0.00404, 0.00415, 0.00419, 0.00399],
                       [0.00404, 0.00421, 0.00386, 0.00418, 0.00420, 0.00376, 0.00390,
                        0.00409, 0.00419, 0.00393, 0.00392, 0.00406, 0.00402, 0.00402,
                        0.00428, 0.00412, 0.00420, 0.00433, 0.00399, 0.00420, 0.00423,
                        0.00420, 0.00401, 0.00418, 0.00402, 0.00417, 0.00419, 0.00411, 0.00413],
                       [0.00394, 0.00418, 0.00394, 0.00415, 0.00442, 0.00390, 0.00409,
                        0.00388, 0.00420, 0.00400, 0.00396, 0.00409, 0.00407, 0.00389,
                        0.00415, 0.00401, 0.00397, 0.00423, 0.00413, 0.00436, 0.00419,
                        0.00429, 0.00395, 0.00408, 0.00397, 0.00413, 0.00413, 0.00404, 0.00405],
                       [0.00400, 0.00424, 0.00416, 0.00403, 0.00442, 0.00423, 0.00418,
                        0.00387, 0.00409, 0.00400, 0.00405, 0.00413, 0.00404, 0.00400,
                        0.00387, 0.00400, 0.00399, 0.00416, 0.00430, 0.00437, 0.00410,
                        0.00423, 0.00415, 0.00412, 0.00393, 0.00413, 0.00405, 0.00412, 0.00401],
                       [0.00419, 0.00429, 0.00416, 0.00398, 0.00426, 0.00420, 0.00409,
                        0.00416, 0.00391, 0.00405, 0.00426, 0.00425, 0.00404, 0.00407,
                        0.00405, 0.00406, 0.00432, 0.00409, 0.00426, 0.00430, 0.00419,
                        0.00413, 0.00433, 0.00425, 0.00412, 0.00428, 0.00420, 0.00426, 0.00401],
                       [0.00422, 0.00412, 0.00407, 0.00399, 0.00424, 0.00418, 0.00413,
                        0.00435, 0.00395, 0.00433, 0.00429, 0.00441, 0.00407, 0.00395,
                        0.00431, 0.00393, 0.00453, 0.00396, 0.00405, 0.00412, 0.00431,
                        0.00406, 0.00423, 0.00427, 0.00437, 0.00434, 0.00430, 0.00417, 0.00391],
                       [0.00420, 0.00400, 0.00405, 0.00392, 0.00428, 0.00419, 0.00418,
                        0.00432, 0.00413, 0.00455, 0.00409, 0.00451, 0.00403, 0.00397,
                        0.00426, 0.00400, 0.00434, 0.00411, 0.00403, 0.00414, 0.00425,
                        0.00395, 0.00418, 0.00429, 0.00442, 0.00418, 0.00415, 0.00396, 0.00390],
                       [0.00421, 0.00410, 0.00415, 0.00398, 0.00429, 0.00416, 0.00428,
                        0.00420, 0.00415, 0.00440, 0.00398, 0.00424, 0.00404, 0.00416,
                        0.00407, 0.00430, 0.00411, 0.00430, 0.00415, 0.00435, 0.00412,
                        0.00409, 0.00425, 0.00411, 0.00416, 0.00413, 0.00413, 0.00392, 0.00406],
                       [0.00414, 0.00428, 0.00417, 0.00427, 0.00426, 0.00425, 0.00428,
                        0.00417, 0.00407, 0.00414, 0.00405, 0.00399, 0.00414, 0.00428,
                        0.00405, 0.00431, 0.00406, 0.00412, 0.00416, 0.00436, 0.00405,
                        0.00433, 0.00443, 0.00386, 0.00408, 0.00415, 0.00414, 0.00409, 0.00418],
                       [0.00415, 0.00426, 0.00417, 0.00445, 0.00409, 0.00433, 0.00416,
                        0.00419, 0.00415, 0.00410, 0.00427, 0.00420, 0.00431, 0.00434,
                        0.00397, 0.00418, 0.00422, 0.00391, 0.00433, 0.00425, 0.00410,
                        0.00425, 0.00446, 0.00401, 0.00435, 0.00417, 0.00420, 0.00447, 0.00421],
                       [0.00418, 0.00421, 0.00403, 0.00411, 0.00409, 0.00432, 0.00409,
                        0.00411, 0.00427, 0.00412, 0.00425, 0.00431, 0.00420, 0.00436,
                        0.00395, 0.00419, 0.00440, 0.00406, 0.00441, 0.00411, 0.00415,
                        0.00411, 0.00419, 0.00433, 0.00430, 0.00419, 0.00420, 0.00446, 0.00409],
                       [0.00411, 0.00432, 0.00397, 0.00394, 0.00422, 0.00420, 0.00402,
                        0.00418, 0.00428, 0.00424, 0.00398, 0.00412, 0.00393, 0.00424,
                        0.00412, 0.00427, 0.00440, 0.00427, 0.00435, 0.00409, 0.00406,
                        0.00419, 0.00416, 0.00432, 0.00423, 0.00422, 0.00401, 0.00419, 0.00405],
                       [0.00401, 0.00433, 0.00411, 0.00423, 0.00420, 0.00423, 0.00394,
                        0.00428, 0.00415, 0.00432, 0.00402, 0.00400, 0.00397, 0.00418,
                        0.00406, 0.00424, 0.00427, 0.00430, 0.00445, 0.00404, 0.00410,
                        0.00410, 0.00435, 0.00414, 0.00417, 0.00416, 0.00407, 0.00420, 0.00415],
                       [0.00394, 0.00418, 0.00416, 0.00441, 0.00422, 0.00443, 0.00406,
                        0.00432, 0.00397, 0.00429, 0.00412, 0.00410, 0.00420, 0.00433,
                        0.00389, 0.00412, 0.00419, 0.00431, 0.00440, 0.00405, 0.00424,
                        0.00398, 0.00438, 0.00419, 0.00414, 0.00427, 0.00443, 0.00435, 0.00417],
                       [0.00411, 0.00408, 0.00430, 0.00429, 0.00435, 0.00448, 0.00430,
                        0.00437, 0.00392, 0.00419, 0.00406, 0.00430, 0.00438, 0.00432,
                        0.00402, 0.00425, 0.00422, 0.00420, 0.00436, 0.00415, 0.00411,
                        0.00403, 0.00438, 0.00435, 0.00430, 0.00441, 0.00450, 0.00434, 0.00407],
                       [0.00428, 0.00428, 0.00446, 0.00414, 0.00421, 0.00426, 0.00447,
                        0.00434, 0.00409, 0.00428, 0.00420, 0.00429, 0.00455, 0.00422,
                        0.00428, 0.00451, 0.00445, 0.00408, 0.00445, 0.00425, 0.00402,
                        0.00418, 0.00417, 0.00430, 0.00441, 0.00429, 0.00441, 0.00434, 0.00386],
                       [0.00425, 0.00448, 0.00433, 0.00421, 0.00409, 0.00406, 0.00423,
                        0.00425, 0.00423, 0.00435, 0.00442, 0.00419, 0.00441, 0.00426,
                        0.00425, 0.00442, 0.00452, 0.00421, 0.00429, 0.00427, 0.00417,
                        0.00422, 0.00398, 0.00426, 0.00435, 0.00429, 0.00445, 0.00446, 0.00385],
                       [0.00431, 0.00445, 0.00420, 0.00432, 0.00421, 0.00432, 0.00400,
                        0.00442, 0.00435, 0.00426, 0.00449, 0.00425, 0.00425, 0.00445,
                        0.00417, 0.00399, 0.00454, 0.00429, 0.00431, 0.00423, 0.00433,
                        0.00424, 0.00429, 0.00438, 0.00427, 0.00447, 0.00448, 0.00475, 0.00414],
                       [0.00445, 0.00437, 0.00416, 0.00431, 0.00442, 0.00463, 0.00411,
                        0.00448, 0.00442, 0.00434, 0.00447, 0.00437, 0.00439, 0.00461,
                        0.00427, 0.00386, 0.00437, 0.00424, 0.00445, 0.00427, 0.00429,
                        0.00435, 0.00465, 0.00435, 0.00428, 0.00461, 0.00449, 0.00467, 0.00417],
                       [0.00450, 0.00440, 0.00417, 0.00434, 0.00443, 0.00456, 0.00430,
                        0.00447, 0.00447, 0.00434, 0.00444, 0.00431, 0.00448, 0.00456,
                        0.00446, 0.00411, 0.00428, 0.00453, 0.00447, 0.00438, 0.00418,
                        0.00424, 0.00462, 0.00434, 0.00437, 0.00459, 0.00443, 0.00443, 0.00399],
                       [0.00440, 0.00450, 0.00437, 0.00451, 0.00440, 0.00437, 0.00433,
                        0.00448, 0.00453, 0.00437, 0.00453, 0.00424, 0.00437, 0.00455,
                        0.00441, 0.00436, 0.00463, 0.00462, 0.00450, 0.00450, 0.00417,
                        0.00415, 0.00443, 0.00447, 0.00451, 0.00461, 0.00439, 0.00440, 0.00400],
                       [0.00428, 0.00459, 0.00449, 0.00461, 0.00439, 0.00437, 0.00432,
                        0.00448, 0.00437, 0.00454, 0.00441, 0.00433, 0.00421, 0.00460,
                        0.00442, 0.00445, 0.00480, 0.00458, 0.00466, 0.00435, 0.00433,
                        0.00432, 0.00444, 0.00431, 0.00450, 0.00450, 0.00432, 0.00441, 0.00404],
                       [0.00445, 0.00459, 0.00430, 0.00451, 0.00450, 0.00445, 0.00440,
                        0.00441, 0.00428, 0.00437, 0.00431, 0.00445, 0.00439, 0.00442,
                        0.00462, 0.00441, 0.00468, 0.00457, 0.00475, 0.00429, 0.00436,
                        0.00445, 0.00451, 0.00418, 0.00435, 0.00442, 0.00452, 0.00455, 0.00409],
                       [0.00456, 0.00441, 0.00424, 0.00449, 0.00465, 0.00436, 0.00448,
                        0.00429, 0.00444, 0.00426, 0.00448, 0.00443, 0.00455, 0.00424,
                        0.00451, 0.00443, 0.00453, 0.00453, 0.00444, 0.00439, 0.00437,
                        0.00432, 0.00443, 0.00449, 0.00433, 0.00455, 0.00462, 0.00465, 0.00410],
                       [0.00435, 0.00432, 0.00432, 0.00458, 0.00452, 0.00420, 0.00458,
                        0.00436, 0.00468, 0.00453, 0.00456, 0.00446, 0.00449, 0.00435,
                        0.00441, 0.00438, 0.00443, 0.00459, 0.00424, 0.00441, 0.00449,
                        0.00421, 0.00450, 0.00468, 0.00440, 0.00458, 0.00438, 0.00469, 0.00420],
                       [0.00418, 0.00444, 0.00434, 0.00452, 0.00440, 0.00428, 0.00459,
                        0.00449, 0.00466, 0.00469, 0.00452, 0.00449, 0.00441, 0.00442,
                        0.00456, 0.00424, 0.00442, 0.00458, 0.00435, 0.00439, 0.00453,
                        0.00438, 0.00457, 0.00457, 0.00453, 0.00440, 0.00436, 0.00463, 0.00436],
                       [0.00439, 0.00452, 0.00441, 0.00451, 0.00450, 0.00449, 0.00431,
                        0.00446, 0.00462, 0.00447, 0.00463, 0.00449, 0.00431, 0.00442,
                        0.00453, 0.00420, 0.00458, 0.00437, 0.00451, 0.00453, 0.00448,
                        0.00454, 0.00454, 0.00462, 0.00464, 0.00436, 0.00456, 0.00453, 0.00444],
                       [0.00462, 0.00442, 0.00441, 0.00471, 0.00459, 0.00453, 0.00415,
                        0.00451, 0.00453, 0.00419, 0.00473, 0.00449, 0.00434, 0.00443,
                        0.00448, 0.00437, 0.00472, 0.00429, 0.00451, 0.00445, 0.00459,
                        0.00447, 0.00449, 0.00468, 0.00476, 0.00445, 0.00445, 0.00453, 0.00445],
                       [0.00464, 0.00435, 0.00447, 0.00473, 0.00446, 0.00447, 0.00431,
                        0.00466, 0.00437, 0.00442, 0.00470, 0.00454, 0.00453, 0.00438,
                        0.00457, 0.00447, 0.00453, 0.00444, 0.00442, 0.00426, 0.00469,
                        0.00445, 0.00436, 0.00456, 0.00467, 0.00449, 0.00446, 0.00446, 0.00431],
                       [0.00458, 0.00435, 0.00455, 0.00463, 0.00443, 0.00453, 0.00470,
                        0.00449, 0.00433, 0.00474, 0.00461, 0.00462, 0.00477, 0.00433,
                        0.00472, 0.00451, 0.00445, 0.00454, 0.00445, 0.00437, 0.00469,
                        0.00462, 0.00436, 0.00440, 0.00450, 0.00445, 0.00465, 0.00435, 0.00408],
                       [0.00468, 0.00440, 0.00448, 0.00468, 0.00441, 0.00486, 0.00495,
                        0.00435, 0.00443, 0.00464, 0.00475, 0.00454, 0.00497, 0.00430,
                        0.00472, 0.00469, 0.00470, 0.00462, 0.00453, 0.00456, 0.00472,
                        0.00466, 0.00434, 0.00433, 0.00431, 0.00434, 0.00472, 0.00463, 0.00403],
                       [0.00473, 0.00447, 0.00446, 0.00475, 0.00435, 0.00506, 0.00475,
                        0.00451, 0.00457, 0.00448, 0.00490, 0.00451, 0.00489, 0.00451,
                        0.00466, 0.00483, 0.00499, 0.00459, 0.00455, 0.00477, 0.00483,
                        0.00450, 0.00437, 0.00434, 0.00443, 0.00450, 0.00463, 0.00477, 0.00412],
                       [0.00461, 0.00478, 0.00456, 0.00489, 0.00456, 0.00492, 0.00461,
                        0.00467, 0.00474, 0.00454, 0.00473, 0.00466, 0.00475, 0.00493,
                        0.00469, 0.00461, 0.00495, 0.00449, 0.00456, 0.00500, 0.00483,
                        0.00440, 0.00464, 0.00457, 0.00471, 0.00490, 0.00459, 0.00467, 0.00434],
                       [0.00458, 0.00506, 0.00471, 0.00493, 0.00480, 0.00478, 0.00465,
                        0.00483, 0.00482, 0.00471, 0.00456, 0.00477, 0.00451, 0.00501,
                        0.00464, 0.00446, 0.00468, 0.00452, 0.00447, 0.00508, 0.00465,
                        0.00451, 0.00490, 0.00483, 0.00480, 0.00480, 0.00454, 0.00479, 0.00455],
                       [0.00477, 0.00493, 0.00480, 0.00493, 0.00487, 0.00489, 0.00471,
                        0.00495, 0.00488, 0.00480, 0.00464, 0.00494, 0.00454, 0.00480,
                        0.00475, 0.00471, 0.00459, 0.00484, 0.00455, 0.00502, 0.00470,
                        0.00475, 0.00481, 0.00495, 0.00475, 0.00464, 0.00465, 0.00485, 0.00464],
                       [0.00476, 0.00469, 0.00501, 0.00497, 0.00496, 0.00500, 0.00493,
                        0.00488, 0.00496, 0.00481, 0.00486, 0.00481, 0.00488, 0.00475,
                        0.00509, 0.00488, 0.00469, 0.00506, 0.00485, 0.00504, 0.00485,
                        0.00502, 0.00462, 0.00495, 0.00472, 0.00481, 0.00498, 0.00484, 0.00459],
                       [0.00458, 0.00479, 0.00505, 0.00513, 0.00528, 0.00510, 0.00506,
                        0.00507, 0.00491, 0.00494, 0.00506, 0.00478, 0.00520, 0.00485,
                        0.00513, 0.00483, 0.00488, 0.00497, 0.00514, 0.00518, 0.00495,
                        0.00525, 0.00470, 0.00490, 0.00485, 0.00489, 0.00521, 0.00494, 0.00460],
                       [0.00463, 0.00498, 0.00492, 0.00528, 0.00551, 0.00517, 0.00499,
                        0.00540, 0.00494, 0.00498, 0.00525, 0.00501, 0.00525, 0.00502,
                        0.00490, 0.00497, 0.00502, 0.00492, 0.00523, 0.00502, 0.00500,
                        0.00520, 0.00485, 0.00493, 0.00491, 0.00493, 0.00519, 0.00511, 0.00476],
                       [0.00490, 0.00522, 0.00501, 0.00529, 0.00524, 0.00533, 0.00512,
                        0.00545, 0.00511, 0.00509, 0.00525, 0.00499, 0.00512, 0.00528,
                        0.00487, 0.00514, 0.00519, 0.00509, 0.00504, 0.00482, 0.00518,
                        0.00513, 0.00506, 0.00518, 0.00501, 0.00506, 0.00521, 0.00522, 0.00497],
                       [0.00514, 0.00535, 0.00522, 0.00529, 0.00502, 0.00546, 0.00529,
                        0.00530, 0.00518, 0.00525, 0.00514, 0.00511, 0.00488, 0.00545,
                        0.00511, 0.00527, 0.00535, 0.00522, 0.00496, 0.00514, 0.00539,
                        0.00518, 0.00532, 0.00531, 0.00531, 0.00519, 0.00530, 0.00528, 0.00513],
                       [0.00516, 0.00535, 0.00545, 0.00538, 0.00516, 0.00547, 0.00529,
                        0.00526, 0.00512, 0.00532, 0.00510, 0.00538, 0.00506, 0.00538,
                        0.00538, 0.00548, 0.00567, 0.00524, 0.00523, 0.00539, 0.00554,
                        0.00521, 0.00555, 0.00532, 0.00543, 0.00537, 0.00535, 0.00545, 0.00535],
                       [0.00521, 0.00548, 0.00559, 0.00551, 0.00536, 0.00569, 0.00540,
                        0.00523, 0.00523, 0.00528, 0.00525, 0.00552, 0.00549, 0.00538,
                        0.00564, 0.00557, 0.00572, 0.00533, 0.00536, 0.00542, 0.00554,
                        0.00533, 0.00552, 0.00541, 0.00544, 0.00566, 0.00535, 0.00564, 0.00547],
                       [0.00534, 0.00568, 0.00567, 0.00544, 0.00550, 0.00572, 0.00572,
                        0.00538, 0.00569, 0.00541, 0.00558, 0.00561, 0.00552, 0.00555,
                        0.00574, 0.00549, 0.00547, 0.00546, 0.00546, 0.00547, 0.00553,
                        0.00552, 0.00557, 0.00566, 0.00544, 0.00588, 0.00541, 0.00567, 0.00540],
                       [0.00537, 0.00563, 0.00573, 0.00553, 0.00559, 0.00561, 0.00582,
                        0.00566, 0.00599, 0.00571, 0.00582, 0.00567, 0.00553, 0.00562,
                        0.00561, 0.00544, 0.00563, 0.00550, 0.00578, 0.00564, 0.00575,
                        0.00575, 0.00562, 0.00573, 0.00547, 0.00588, 0.00555, 0.00572, 0.00548],
                       [0.00544, 0.00573, 0.00565, 0.00585, 0.00566, 0.00539, 0.00568,
                        0.00578, 0.00591, 0.00586, 0.00581, 0.00564, 0.00577, 0.00571,
                        0.00548, 0.00562, 0.00590, 0.00563, 0.00593, 0.00574, 0.00597,
                        0.00581, 0.00572, 0.00561, 0.00573, 0.00588, 0.00575, 0.00594, 0.00567],
                       [0.00567, 0.00600, 0.00553, 0.00596, 0.00573, 0.00543, 0.00560,
                        0.00590, 0.00580, 0.00585, 0.00589, 0.00564, 0.00599, 0.00601,
                        0.00554, 0.00594, 0.00598, 0.00589, 0.00592, 0.00577, 0.00588,
                        0.00575, 0.00594, 0.00580, 0.00604, 0.00606, 0.00598, 0.00607, 0.00575],
                       [0.00572, 0.00598, 0.00583, 0.00603, 0.00595, 0.00597, 0.00594,
                        0.00627, 0.00587, 0.00601, 0.00612, 0.00580, 0.00608, 0.00614,
                        0.00596, 0.00607, 0.00598, 0.00614, 0.00607, 0.00597, 0.00587,
                        0.00583, 0.00609, 0.00632, 0.00621, 0.00629, 0.00642, 0.00620, 0.00597],
                       [0.00569, 0.00606, 0.00632, 0.00622, 0.00625, 0.00643, 0.00632,
                        0.00631, 0.00599, 0.00628, 0.00605, 0.00609, 0.00625, 0.00622,
                        0.00614, 0.00626, 0.00608, 0.00632, 0.00627, 0.00624, 0.00623,
                        0.00607, 0.00625, 0.00663, 0.00628, 0.00637, 0.00686, 0.00640, 0.00640],
                       [0.00615, 0.00631, 0.00650, 0.00625, 0.00661, 0.00654, 0.00651,
                        0.00610, 0.00633, 0.00649, 0.00608, 0.00645, 0.00641, 0.00643,
                        0.00615, 0.00645, 0.00636, 0.00647, 0.00653, 0.00648, 0.00666,
                        0.00639, 0.00659, 0.00678, 0.00649, 0.00663, 0.00699, 0.00673, 0.00669],
                       [0.00670, 0.00642, 0.00649, 0.00628, 0.00692, 0.00652, 0.00674,
                        0.00634, 0.00685, 0.00660, 0.00620, 0.00675, 0.00641, 0.00664,
                        0.00640, 0.00673, 0.00665, 0.00654, 0.00684, 0.00671, 0.00702,
                        0.00680, 0.00699, 0.00695, 0.00671, 0.00714, 0.00706, 0.00708, 0.00682],
                       [0.00689, 0.00666, 0.00655, 0.00662, 0.00696, 0.00683, 0.00703,
                        0.00688, 0.00703, 0.00654, 0.00642, 0.00703, 0.00657, 0.00677,
                        0.00673, 0.00700, 0.00679, 0.00669, 0.00695, 0.00708, 0.00718,
                        0.00721, 0.00730, 0.00716, 0.00705, 0.00737, 0.00724, 0.00735, 0.00698],
                       [0.00692, 0.00703, 0.00677, 0.00699, 0.00687, 0.00718, 0.00720,
                        0.00709, 0.00700, 0.00656, 0.00695, 0.00708, 0.00681, 0.00683,
                        0.00700, 0.00710, 0.00700, 0.00708, 0.00694, 0.00743, 0.00716,
                        0.00747, 0.00742, 0.00733, 0.00742, 0.00728, 0.00746, 0.00766, 0.00727],
                       [0.00702, 0.00718, 0.00709, 0.00726, 0.00705, 0.00727, 0.00730,
                        0.00706, 0.00717, 0.00700, 0.00732, 0.00698, 0.00712, 0.00708,
                        0.00705, 0.00715, 0.00733, 0.00745, 0.00728, 0.00749, 0.00742,
                        0.00752, 0.00738, 0.00754, 0.00783, 0.00762, 0.00778, 0.00798, 0.00753],
                       [0.00717, 0.00706, 0.00736, 0.00745, 0.00745, 0.00755, 0.00734,
                        0.00727, 0.00748, 0.00746, 0.00756, 0.00709, 0.00753, 0.00749,
                        0.00702, 0.00753, 0.00761, 0.00746, 0.00781, 0.00773, 0.00789,
                        0.00754, 0.00771, 0.00788, 0.00816, 0.00819, 0.00812, 0.00818, 0.00792],
                       [0.00729, 0.00707, 0.00770, 0.00759, 0.00770, 0.00789, 0.00747,
                        0.00770, 0.00782, 0.00758, 0.00777, 0.00758, 0.00794, 0.00787,
                        0.00744, 0.00798, 0.00796, 0.00768, 0.00808, 0.00835, 0.00820,
                        0.00778, 0.00822, 0.00819, 0.00834, 0.00849, 0.00839, 0.00846, 0.00826],
                       [0.00731, 0.00740, 0.00811, 0.00788, 0.00774, 0.00800, 0.00778,
                        0.00786, 0.00806, 0.00780, 0.00799, 0.00812, 0.00811, 0.00823,
                        0.00815, 0.00807, 0.00824, 0.00825, 0.00829, 0.00872, 0.00844,
                        0.00833, 0.00849, 0.00837, 0.00850, 0.00848, 0.00883, 0.00880, 0.00850],
                       [0.00775, 0.00783, 0.00829, 0.00831, 0.00788, 0.00807, 0.00817,
                        0.00804, 0.00825, 0.00831, 0.00815, 0.00837, 0.00816, 0.00858,
                        0.00846, 0.00822, 0.00835, 0.00859, 0.00854, 0.00876, 0.00862,
                        0.00885, 0.00865, 0.00882, 0.00876, 0.00864, 0.00923, 0.00908, 0.00883],
                       [0.00835, 0.00834, 0.00834, 0.00865, 0.00827, 0.00834, 0.00857,
                        0.00854, 0.00846, 0.00865, 0.00841, 0.00861, 0.00833, 0.00880,
                        0.00857, 0.00868, 0.00851, 0.00868, 0.00887, 0.00881, 0.00883,
                        0.00915, 0.00900, 0.00934, 0.00909, 0.00911, 0.00956, 0.00944, 0.00919],
                       [0.00854, 0.00864, 0.00858, 0.00888, 0.00883, 0.00882, 0.00892,
                        0.00912, 0.00877, 0.00874, 0.00880, 0.00901, 0.00865, 0.00902,
                        0.00889, 0.00897, 0.00890, 0.00899, 0.00912, 0.00911, 0.00932,
                        0.00935, 0.00937, 0.00966, 0.00961, 0.00970, 0.00978, 0.00985, 0.00963],
                       [0.00869, 0.00886, 0.00886, 0.00913, 0.00928, 0.00926, 0.00926,
                        0.00948, 0.00920, 0.00896, 0.00923, 0.00924, 0.00911, 0.00942,
                        0.00935, 0.00942, 0.00936, 0.00958, 0.00936, 0.00962, 0.00987,
                        0.00973, 0.00967, 0.01005, 0.01016, 0.01021, 0.01026, 0.01020, 0.01023],
                       [0.00918, 0.00934, 0.00935, 0.00953, 0.00952, 0.00954, 0.00960,
                        0.00950, 0.00972, 0.00935, 0.00958, 0.00948, 0.00969, 0.00981,
                        0.00970, 0.01004, 0.00960, 0.01008, 0.00972, 0.01001, 0.01004,
                        0.00996, 0.01002, 0.01050, 0.01049, 0.01049, 0.01087, 0.01063, 0.01062],
                       [0.00968, 0.00985, 0.01014, 0.01022, 0.00988, 0.00968, 0.01019,
                        0.00991, 0.01019, 0.00974, 0.00996, 0.01002, 0.01029, 0.01024,
                        0.01029, 0.01054, 0.00996, 0.01044, 0.01026, 0.01043, 0.01023,
                        0.01027, 0.01053, 0.01113, 0.01087, 0.01076, 0.01160, 0.01126, 0.01079],
                       [0.01006, 0.01029, 0.01067, 0.01082, 0.01072, 0.01016, 0.01085,
                        0.01082, 0.01067, 0.01041, 0.01056, 0.01061, 0.01077, 0.01078,
                        0.01089, 0.01096, 0.01075, 0.01091, 0.01096, 0.01095, 0.01086,
                        0.01090, 0.01133, 0.01158, 0.01145, 0.01148, 0.01230, 0.01195, 0.01136],
                       [0.01071, 0.01089, 0.01095, 0.01122, 0.01146, 0.01114, 0.01124,
                        0.01146, 0.01115, 0.01124, 0.01117, 0.01122, 0.01127, 0.01144,
                        0.01154, 0.01156, 0.01174, 0.01144, 0.01175, 0.01136, 0.01166,
                        0.01167, 0.01196, 0.01179, 0.01211, 0.01243, 0.01264, 0.01257, 0.01220],
                       [0.01169, 0.01156, 0.01133, 0.01186, 0.01177, 0.01220, 0.01181,
                        0.01196, 0.01194, 0.01188, 0.01189, 0.01197, 0.01206, 0.01216,
                        0.01229, 0.01224, 0.01239, 0.01217, 0.01244, 0.01217, 0.01236,
                        0.01238, 0.01252, 0.01256, 0.01283, 0.01316, 0.01319, 0.01333, 0.01299],
                       [0.01253, 0.01232, 0.01201, 0.01263, 0.01232, 0.01293, 0.01297,
                        0.01270, 0.01289, 0.01255, 0.01257, 0.01277, 0.01306, 0.01293,
                        0.01302, 0.01293, 0.01296, 0.01302, 0.01296, 0.01306, 0.01293,
                        0.01289, 0.01325, 0.01359, 0.01374, 0.01383, 0.01419, 0.01437, 0.01386],
                       [0.01321, 0.01337, 0.01330, 0.01330, 0.01336, 0.01378, 0.01404,
                        0.01376, 0.01369, 0.01345, 0.01326, 0.01352, 0.01393, 0.01390,
                        0.01406, 0.01371, 0.01374, 0.01399, 0.01363, 0.01380, 0.01364,
                        0.01360, 0.01436, 0.01453, 0.01483, 0.01475, 0.01524, 0.01544, 0.01450],
                       [0.01412, 0.01442, 0.01472, 0.01432, 0.01465, 0.01492, 0.01480,
                        0.01485, 0.01467, 0.01441, 0.01432, 0.01456, 0.01479, 0.01487,
                        0.01516, 0.01490, 0.01487, 0.01517, 0.01472, 0.01477, 0.01483,
                        0.01487, 0.01549, 0.01557, 0.01600, 0.01583, 0.01633, 0.01663, 0.01535],
                       [0.01523, 0.01553, 0.01554, 0.01591, 0.01590, 0.01595, 0.01586,
                        0.01584, 0.01571, 0.01550, 0.01567, 0.01566, 0.01585, 0.01596,
                        0.01606, 0.01623, 0.01609, 0.01619, 0.01602, 0.01598, 0.01611,
                        0.01616, 0.01641, 0.01672, 0.01682, 0.01713, 0.01752, 0.01793, 0.01673],
                       [0.01654, 0.01688, 0.01652, 0.01748, 0.01718, 0.01714, 0.01752,
                        0.01714, 0.01702, 0.01693, 0.01728, 0.01687, 0.01708, 0.01738,
                        0.01732, 0.01746, 0.01732, 0.01726, 0.01745, 0.01738, 0.01747,
                        0.01737, 0.01765, 0.01796, 0.01798, 0.01855, 0.01887, 0.01913, 0.01810],
                       [0.01795, 0.01827, 0.01822, 0.01859, 0.01866, 0.01884, 0.01947,
                        0.01877, 0.01864, 0.01848, 0.01872, 0.01857, 0.01846, 0.01885,
                        0.01891, 0.01889, 0.01892, 0.01887, 0.01893, 0.01889, 0.01886,
                        0.01871, 0.01907, 0.01929, 0.01988, 0.02014, 0.02047, 0.02062, 0.01956],
                       [0.01971, 0.01990, 0.02025, 0.01992, 0.02060, 0.02064, 0.02110,
                        0.02064, 0.02041, 0.02006, 0.02001, 0.02034, 0.02037, 0.02062,
                        0.02067, 0.02056, 0.02075, 0.02078, 0.02076, 0.02064, 0.02048,
                        0.02034, 0.02071, 0.02095, 0.02181, 0.02203, 0.02240, 0.02252, 0.02126],
                       [0.02175, 0.02184, 0.02240, 0.02221, 0.02285, 0.02265, 0.02274,
                        0.02267, 0.02245, 0.02216, 0.02191, 0.02222, 0.02248, 0.02270,
                        0.02274, 0.02270, 0.02251, 0.02289, 0.02268, 0.02261, 0.02246,
                        0.02232, 0.02283, 0.02315, 0.02376, 0.02417, 0.02454, 0.02484, 0.02333],
                       [0.02392, 0.02404, 0.02457, 0.02488, 0.02512, 0.02524, 0.02513,
                        0.02496, 0.02478, 0.02473, 0.02449, 0.02445, 0.02481, 0.02500,
                        0.02509, 0.02511, 0.02472, 0.02523, 0.02483, 0.02476, 0.02490,
                        0.02479, 0.02523, 0.02572, 0.02615, 0.02671, 0.02690, 0.02748, 0.02595],
                       [0.02633, 0.02656, 0.02686, 0.02741, 0.02766, 0.02834, 0.02789,
                        0.02766, 0.02729, 0.02738, 0.02718, 0.02708, 0.02741, 0.02749,
                        0.02774, 0.02767, 0.02772, 0.02772, 0.02736, 0.02753, 0.02749,
                        0.02745, 0.02797, 0.02857, 0.02915, 0.02972, 0.02970, 0.03041, 0.02878],
                       [0.02940, 0.02954, 0.02966, 0.03028, 0.03071, 0.03160, 0.03086,
                        0.03072, 0.03022, 0.03037, 0.03003, 0.03005, 0.03029, 0.03031,
                        0.03084, 0.03073, 0.03113, 0.03068, 0.03059, 0.03062, 0.03035,
                        0.03047, 0.03102, 0.03169, 0.03226, 0.03283, 0.03334, 0.03379, 0.03166],
                       [0.03309, 0.03300, 0.03316, 0.03371, 0.03426, 0.03485, 0.03438,
                        0.03418, 0.03374, 0.03387, 0.03346, 0.03348, 0.03409, 0.03382,
                        0.03463, 0.03445, 0.03463, 0.03435, 0.03453, 0.03399, 0.03386,
                        0.03398, 0.03441, 0.03504, 0.03583, 0.03645, 0.03748, 0.03760, 0.03535],
                       [0.03685, 0.03681, 0.03710, 0.03797, 0.03829, 0.03853, 0.03854,
                        0.03825, 0.03784, 0.03761, 0.03734, 0.03733, 0.03847, 0.03805,
                        0.03882, 0.03861, 0.03832, 0.03844, 0.03841, 0.03806, 0.03800,
                        0.03794, 0.03843, 0.03904, 0.04031, 0.04106, 0.04183, 0.04188, 0.03981],
                       [0.04112, 0.04116, 0.04166, 0.04275, 0.04304, 0.04309, 0.04324,
                        0.04293, 0.04273, 0.04184, 0.04157, 0.04191, 0.04296, 0.04270,
                        0.04339, 0.04322, 0.04296, 0.04293, 0.04282, 0.04276, 0.04272,
                        0.04249, 0.04330, 0.04404, 0.04538, 0.04628, 0.04686, 0.04709, 0.04474],
                       [0.04616, 0.04599, 0.04698, 0.04793, 0.04853, 0.04843, 0.04875,
                        0.04816, 0.04791, 0.04719, 0.04676, 0.04720, 0.04787, 0.04793,
                        0.04871, 0.04848, 0.04862, 0.04828, 0.04817, 0.04810, 0.04791,
                        0.04783, 0.04877, 0.04974, 0.05077, 0.05202, 0.05260, 0.05337, 0.05017],
                       [0.05187, 0.05164, 0.05288, 0.05369, 0.05437, 0.05458, 0.05503,
                        0.05421, 0.05366, 0.05330, 0.05283, 0.05318, 0.05365, 0.05419,
                        0.05485, 0.05458, 0.05478, 0.05459, 0.05439, 0.05430, 0.05386,
                        0.05419, 0.05480, 0.05614, 0.05710, 0.05881, 0.05948, 0.06045, 0.05639],
                       [0.05834, 0.05812, 0.05942, 0.05997, 0.06107, 0.06141, 0.06189,
                        0.06112, 0.06052, 0.05974, 0.05932, 0.05965, 0.06039, 0.06113,
                        0.06178, 0.06161, 0.06159, 0.06154, 0.06155, 0.06115, 0.06063,
                        0.06139, 0.06158, 0.06327, 0.06457, 0.06648, 0.06756, 0.06790, 0.06358],
                       [0.06544, 0.06536, 0.06656, 0.06723, 0.06873, 0.06900, 0.06934,
                        0.06858, 0.06819, 0.06720, 0.06680, 0.06699, 0.06777, 0.06868,
                        0.06953, 0.06934, 0.06922, 0.06913, 0.06910, 0.06854, 0.06834,
                        0.06905, 0.06927, 0.07134, 0.07288, 0.07474, 0.07642, 0.07636, 0.07192],
                       [0.07335, 0.07355, 0.07466, 0.07593, 0.07726, 0.07765, 0.07756,
                        0.07700, 0.07641, 0.07585, 0.07537, 0.07552, 0.07627, 0.07736,
                        0.07795, 0.07802, 0.07769, 0.07808, 0.07759, 0.07710, 0.07701,
                        0.07737, 0.07836, 0.08048, 0.08214, 0.08421, 0.08587, 0.08649, 0.08116],
                       [0.08233, 0.08286, 0.08379, 0.08553, 0.08661, 0.08733, 0.08693,
                        0.08661, 0.08575, 0.08520, 0.08481, 0.08510, 0.08602, 0.08706,
                        0.08762, 0.08787, 0.08744, 0.08817, 0.08778, 0.08702, 0.08695,
                        0.08719, 0.08891, 0.09074, 0.09283, 0.09509, 0.09667, 0.09796, 0.09147],
                       [0.09245, 0.09329, 0.09391, 0.09597, 0.09711, 0.09789, 0.09780,
                        0.09748, 0.09656, 0.09563, 0.09544, 0.09573, 0.09699, 0.09762,
                        0.09880, 0.09901, 0.09906, 0.09905, 0.09899, 0.09832, 0.09842,
                        0.09853, 0.10044, 0.10239, 0.10500, 0.10750, 0.10931, 0.11079, 0.10321],
                       [0.10356, 0.10456, 0.10529, 0.10752, 0.10910, 0.10971, 0.10979,
                        0.10942, 0.10825, 0.10721, 0.10694, 0.10731, 0.10887, 0.10966,
                        0.11092, 0.11127, 0.11176, 0.11113, 0.11108, 0.11083, 0.11078,
                        0.11114, 0.11301, 0.11554, 0.11840, 0.12136, 0.12314, 0.12475, 0.11655],
                       [0.11604, 0.11694, 0.11824, 0.12033, 0.12240, 0.12304, 0.12299,
                        0.12243, 0.12121, 0.11995, 0.11960, 0.12037, 0.12156, 0.12319,
                        0.12440, 0.12501, 0.12548, 0.12503, 0.12468, 0.12464, 0.12396,
                        0.12527, 0.12691, 0.13002, 0.13311, 0.13643, 0.13835, 0.13972, 0.13143],
                       [0.13005, 0.13072, 0.13229, 0.13447, 0.13659, 0.13782, 0.13771,
                        0.13692, 0.13579, 0.13413, 0.13419, 0.13469, 0.13587, 0.13809,
                        0.13940, 0.13994, 0.14037, 0.14027, 0.13972, 0.13966, 0.13915,
                        0.14021, 0.14222, 0.14565, 0.14911, 0.15277, 0.15549, 0.15645, 0.14753],
                       [0.14543, 0.14568, 0.14763, 0.15025, 0.15221, 0.15369, 0.15362,
                        0.15279, 0.15158, 0.15002, 0.14998, 0.15027, 0.15194, 0.15433,
                        0.15577, 0.15609, 0.15636, 0.15626, 0.15609, 0.15567, 0.15604,
                        0.15652, 0.15934, 0.16281, 0.16697, 0.17082, 0.17402, 0.17535, 0.16484],
                       [0.16202, 0.16206, 0.16463, 0.16736, 0.16937, 0.17079, 0.17128,
                        0.17003, 0.16879, 0.16751, 0.16680, 0.16757, 0.16959, 0.17165,
                        0.17351, 0.17392, 0.17419, 0.17410, 0.17426, 0.17334, 0.17420,
                        0.17508, 0.17801, 0.18142, 0.18650, 0.19063, 0.19367, 0.19589, 0.18365],
                       [0.17989, 0.18024, 0.18312, 0.18572, 0.18824, 0.18956, 0.19062,
                        0.18916, 0.18772, 0.18647, 0.18546, 0.18643, 0.18871, 0.19062,
                        0.19272, 0.19328, 0.19410, 0.19431, 0.19425, 0.19324, 0.19385,
                        0.19531, 0.19802, 0.20202, 0.20713, 0.21199, 0.21551, 0.21796, 0.20461],
                       [0.19969, 0.20009, 0.20318, 0.20590, 0.20899, 0.21043, 0.21100,
                        0.20988, 0.20823, 0.20681, 0.20571, 0.20730, 0.20971, 0.21165,
                        0.21374, 0.21457, 0.21539, 0.21581, 0.21558, 0.21512, 0.21507,
                        0.21677, 0.21967, 0.22464, 0.22965, 0.23482, 0.23936, 0.24162, 0.22753],
                       [0.22130, 0.22155, 0.22484, 0.22819, 0.23130, 0.23328, 0.23321,
                        0.23208, 0.23025, 0.22865, 0.22779, 0.22973, 0.23215, 0.23441,
                        0.23665, 0.23774, 0.23813, 0.23840, 0.23839, 0.23826, 0.23824,
                        0.23983, 0.24336, 0.24852, 0.25456, 0.25956, 0.26437, 0.26671, 0.25175],
                       [0.24446, 0.24501, 0.24796, 0.25214, 0.25498, 0.25745, 0.25762,
                        0.25623, 0.25401, 0.25230, 0.25166, 0.25306, 0.25579, 0.25881,
                        0.26102, 0.26219, 0.26295, 0.26291, 0.26291, 0.26244, 0.26314,
                        0.26461, 0.26878, 0.27406, 0.28092, 0.28624, 0.29072, 0.29341, 0.27745],
                       [0.26923, 0.27035, 0.27321, 0.27783, 0.28096, 0.28333, 0.28378,
                        0.28254, 0.28000, 0.27787, 0.27735, 0.27852, 0.28133, 0.28507,
                        0.28709, 0.28828, 0.28973, 0.28947, 0.28943, 0.28871, 0.28957,
                        0.29157, 0.29535, 0.30146, 0.30836, 0.31462, 0.31901, 0.32201, 0.30486],
                       [0.29592, 0.29706, 0.30041, 0.30495, 0.30890, 0.31068, 0.31142,
                        0.31017, 0.30766, 0.30522, 0.30501, 0.30630, 0.30860, 0.31317,
                        0.31511, 0.31619, 0.31753, 0.31744, 0.31769, 0.31721, 0.31725,
                        0.32021, 0.32348, 0.33013, 0.33731, 0.34405, 0.34889, 0.35223, 0.33326],
                       [0.32449, 0.32545, 0.32911, 0.33350, 0.33817, 0.33950, 0.34045,
                        0.33920, 0.33661, 0.33426, 0.33391, 0.33526, 0.33783, 0.34237,
                        0.34466, 0.34606, 0.34695, 0.34688, 0.34760, 0.34704, 0.34684,
                        0.34976, 0.35351, 0.36028, 0.36778, 0.37475, 0.38003, 0.38382, 0.36264],
                       [0.35477, 0.35564, 0.35985, 0.36431, 0.36883, 0.37074, 0.37141,
                        0.37009, 0.36743, 0.36479, 0.36420, 0.36560, 0.36886, 0.37294,
                        0.37575, 0.37747, 0.37801, 0.37814, 0.37853, 0.37807, 0.37796,
                        0.38038, 0.38528, 0.39215, 0.39954, 0.40716, 0.41264, 0.41636, 0.39379],
                       [0.38704, 0.38793, 0.39228, 0.39766, 0.40158, 0.40413, 0.40451,
                        0.40285, 0.39978, 0.39703, 0.39635, 0.39803, 0.40161, 0.40560,
                        0.40820, 0.41029, 0.41062, 0.41078, 0.41100, 0.41052, 0.41032,
                        0.41292, 0.41849, 0.42525, 0.43312, 0.44077, 0.44644, 0.44999, 0.42660],
                       [0.42089, 0.42222, 0.42641, 0.43240, 0.43611, 0.43915, 0.43941,
                        0.43720, 0.43383, 0.43151, 0.43031, 0.43188, 0.43570, 0.44019,
                        0.44224, 0.44440, 0.44490, 0.44489, 0.44520, 0.44439, 0.44469,
                        0.44774, 0.45230, 0.45959, 0.46829, 0.47541, 0.48146, 0.48500, 0.45978],
                       [0.45594, 0.45740, 0.46206, 0.46786, 0.47179, 0.47501, 0.47546,
                        0.47305, 0.47002, 0.46711, 0.46579, 0.46704, 0.47098, 0.47530,
                        0.47821, 0.47950, 0.48023, 0.48069, 0.48019, 0.47964, 0.48011,
                        0.48297, 0.48725, 0.49502, 0.50393, 0.51087, 0.51714, 0.52072, 0.49308],
                       [0.49258, 0.49371, 0.49861, 0.50473, 0.50897, 0.51172, 0.51217,
                        0.51037, 0.50702, 0.50381, 0.50220, 0.50356, 0.50743, 0.51106,
                        0.51485, 0.51574, 0.51634, 0.51702, 0.51603, 0.51600, 0.51604,
                        0.51828, 0.52357, 0.53093, 0.53978, 0.54701, 0.55271, 0.55648, 0.52714],
                       [0.52986, 0.53056, 0.53546, 0.54174, 0.54679, 0.54913, 0.54896,
                        0.54726, 0.54358, 0.54052, 0.53880, 0.54023, 0.54418, 0.54775,
                        0.55116, 0.55259, 0.55290, 0.55285, 0.55237, 0.55202, 0.55172,
                        0.55424, 0.55950, 0.56679, 0.57538, 0.58302, 0.58788, 0.59214, 0.56101],
                       [0.56714, 0.56779, 0.57292, 0.57927, 0.58400, 0.58663, 0.58631,
                        0.58404, 0.58061, 0.57663, 0.57569, 0.57721, 0.58120, 0.58486,
                        0.58812, 0.58937, 0.58980, 0.58898, 0.58872, 0.58798, 0.58740,
                        0.59024, 0.59477, 0.60236, 0.61103, 0.61851, 0.62321, 0.62730, 0.59468],
                       [0.60471, 0.60570, 0.61100, 0.61764, 0.62109, 0.62430, 0.62430,
                        0.62206, 0.61834, 0.61387, 0.61291, 0.61501, 0.61807, 0.62232,
                        0.62536, 0.62585, 0.62672, 0.62561, 0.62525, 0.62447, 0.62386,
                        0.62659, 0.63054, 0.63798, 0.64662, 0.65344, 0.65885, 0.66167, 0.62792],
                       [0.64242, 0.64309, 0.64829, 0.65450, 0.65812, 0.66130, 0.66158,
                        0.65981, 0.65566, 0.65132, 0.64996, 0.65224, 0.65420, 0.65873,
                        0.66116, 0.66239, 0.66289, 0.66162, 0.66131, 0.65975, 0.65947,
                        0.66226, 0.66600, 0.67328, 0.68086, 0.68772, 0.69300, 0.69589, 0.65976],
                       [0.67938, 0.67999, 0.68487, 0.69044, 0.69522, 0.69749, 0.69787,
                        0.69598, 0.69228, 0.68789, 0.68644, 0.68830, 0.69046, 0.69440,
                        0.69619, 0.69855, 0.69810, 0.69699, 0.69649, 0.69432, 0.69427,
                        0.69659, 0.70064, 0.70743, 0.71407, 0.72138, 0.72568, 0.72928, 0.69077],
                       [0.71527, 0.71659, 0.72088, 0.72662, 0.73197, 0.73331, 0.73319,
                        0.73083, 0.72773, 0.72339, 0.72180, 0.72347, 0.72630, 0.73009,
                        0.73120, 0.73297, 0.73242, 0.73175, 0.73095, 0.72883, 0.72878,
                        0.73004, 0.73443, 0.74061, 0.74692, 0.75349, 0.75766, 0.76058, 0.72086],
                       [0.75026, 0.75174, 0.75534, 0.76167, 0.76640, 0.76783, 0.76680,
                        0.76441, 0.76150, 0.75713, 0.75602, 0.75727, 0.76004, 0.76386,
                        0.76488, 0.76574, 0.76511, 0.76440, 0.76392, 0.76216, 0.76143,
                        0.76243, 0.76674, 0.77218, 0.77841, 0.78373, 0.78808, 0.78982, 0.74914],
                       [0.78434, 0.78547, 0.78890, 0.79492, 0.79842, 0.80031, 0.79965,
                        0.79707, 0.79411, 0.78990, 0.78951, 0.79009, 0.79218, 0.79502,
                        0.79716, 0.79764, 0.79697, 0.79593, 0.79549, 0.79396, 0.79242,
                        0.79418, 0.79730, 0.80237, 0.80861, 0.81331, 0.81719, 0.81893, 0.77662],
                       [0.81592, 0.81662, 0.82054, 0.82579, 0.82822, 0.83030, 0.83040,
                        0.82803, 0.82484, 0.82147, 0.82049, 0.82087, 0.82287, 0.82469,
                        0.82772, 0.82777, 0.82691, 0.82644, 0.82507, 0.82325, 0.82183,
                        0.82358, 0.82596, 0.83063, 0.83660, 0.84080, 0.84363, 0.84620, 0.80229],
                       [0.84407, 0.84504, 0.84948, 0.85421, 0.85634, 0.85800, 0.85770,
                        0.85643, 0.85335, 0.85061, 0.84823, 0.84897, 0.85158, 0.85351,
                        0.85536, 0.85505, 0.85395, 0.85389, 0.85210, 0.85054, 0.84903,
                        0.85024, 0.85303, 0.85678, 0.86229, 0.86555, 0.86803, 0.86941, 0.82446],
                       [0.87011, 0.87130, 0.87526, 0.87935, 0.88184, 0.88286, 0.88239,
                        0.88133, 0.87853, 0.87568, 0.87301, 0.87408, 0.87664, 0.87936,
                        0.87935, 0.87933, 0.87846, 0.87780, 0.87635, 0.87540, 0.87323,
                        0.87450, 0.87722, 0.88062, 0.88498, 0.88766, 0.89042, 0.88983, 0.84413],
                       [0.89431, 0.89470, 0.89735, 0.90093, 0.90372, 0.90517, 0.90414,
                        0.90297, 0.89992, 0.89745, 0.89568, 0.89632, 0.89831, 0.90084,
                        0.90084, 0.90097, 0.90039, 0.89942, 0.89852, 0.89735, 0.89515,
                        0.89597, 0.89847, 0.90094, 0.90458, 0.90741, 0.90976, 0.90924, 0.86263],
                       [0.91416, 0.91503, 0.91673, 0.91969, 0.92250, 0.92364, 0.92295,
                        0.92176, 0.91823, 0.91639, 0.91543, 0.91577, 0.91730, 0.91886,
                        0.91980, 0.91943, 0.91880, 0.91817, 0.91735, 0.91569, 0.91489,
                        0.91491, 0.91699, 0.91841, 0.92199, 0.92433, 0.92556, 0.92649, 0.87881],
                       [0.93111, 0.93270, 0.93391, 0.93655, 0.93897, 0.93900, 0.93938,
                        0.93834, 0.93479, 0.93319, 0.93280, 0.93320, 0.93384, 0.93517,
                        0.93625, 0.93553, 0.93505, 0.93468, 0.93380, 0.93203, 0.93268,
                        0.93174, 0.93312, 0.93495, 0.93774, 0.93940, 0.93997, 0.94129, 0.89293],
                       [0.94665, 0.94703, 0.94829, 0.95074, 0.95243, 0.95280, 0.95256,
                        0.95210, 0.94974, 0.94834, 0.94783, 0.94809, 0.94767, 0.94948,
                        0.95044, 0.94963, 0.94946, 0.94887, 0.94816, 0.94724, 0.94729,
                        0.94662, 0.94721, 0.94917, 0.95144, 0.95298, 0.95339, 0.95378, 0.90538],
                       [0.95977, 0.95888, 0.96039, 0.96292, 0.96365, 0.96411, 0.96368,
                        0.96341, 0.96288, 0.96108, 0.96029, 0.96057, 0.96017, 0.96169,
                        0.96228, 0.96160, 0.96110, 0.96090, 0.96004, 0.96003, 0.95914,
                        0.95969, 0.95962, 0.96072, 0.96268, 0.96415, 0.96456, 0.96394, 0.91567],
                       [0.96873, 0.96795, 0.96948, 0.97157, 0.97176, 0.97221, 0.97204,
                        0.97139, 0.97155, 0.96965, 0.96939, 0.96967, 0.97026, 0.97076,
                        0.97090, 0.97072, 0.96967, 0.97030, 0.96961, 0.96909, 0.96825,
                        0.96896, 0.96886, 0.96977, 0.97144, 0.97232, 0.97285, 0.97200, 0.92327],
                       [0.97444, 0.97414, 0.97577, 0.97655, 0.97677, 0.97801, 0.97708,
                        0.97629, 0.97616, 0.97543, 0.97525, 0.97539, 0.97660, 0.97693,
                        0.97670, 0.97720, 0.97568, 0.97667, 0.97597, 0.97569, 0.97488,
                        0.97468, 0.97532, 0.97597, 0.97752, 0.97825, 0.97844, 0.97791, 0.92848],
                       [0.97967, 0.97972, 0.98089, 0.98128, 0.98138, 0.98276, 0.98203,
                        0.98126, 0.98077, 0.98050, 0.98054, 0.98083, 0.98145, 0.98155,
                        0.98176, 0.98246, 0.98112, 0.98180, 0.98061, 0.98132, 0.98113,
                        0.98025, 0.98096, 0.98091, 0.98215, 0.98326, 0.98305, 0.98322, 0.93289],
                       [0.98414, 0.98427, 0.98496, 0.98553, 0.98572, 0.98621, 0.98655,
                        0.98567, 0.98523, 0.98433, 0.98571, 0.98543, 0.98575, 0.98527,
                        0.98590, 0.98658, 0.98556, 0.98610, 0.98574, 0.98563, 0.98605,
                        0.98556, 0.98624, 0.98554, 0.98668, 0.98715, 0.98733, 0.98757, 0.93710],
                       [0.98707, 0.98777, 0.98805, 0.98833, 0.98859, 0.98836, 0.98916,
                        0.98892, 0.98880, 0.98768, 0.98936, 0.98868, 0.98916, 0.98928,
                        0.98869, 0.98920, 0.98854, 0.98933, 0.98998, 0.98870, 0.98876,
                        0.98940, 0.99011, 0.98970, 0.99022, 0.99031, 0.99016, 0.99053, 0.94089],
                       [0.98788, 0.98936, 0.98906, 0.98904, 0.98922, 0.98947, 0.98995,
                        0.99029, 0.99029, 0.98960, 0.99074, 0.98958, 0.99032, 0.99143,
                        0.98984, 0.99008, 0.98984, 0.99098, 0.99078, 0.99001, 0.98985,
                        0.99103, 0.99101, 0.99185, 0.99096, 0.99183, 0.99125, 0.99193, 0.94230],
                       [0.98887, 0.98954, 0.98891, 0.98936, 0.98966, 0.99043, 0.99013,
                        0.99038, 0.99045, 0.99027, 0.99076, 0.98964, 0.99039, 0.99087,
                        0.99076, 0.99120, 0.99045, 0.99139, 0.99046, 0.99092, 0.99052,
                        0.99182, 0.99087, 0.99185, 0.99133, 0.99211, 0.99206, 0.99234, 0.94221],
                       [0.99065, 0.99002, 0.98954, 0.99096, 0.99084, 0.99095, 0.99066,
                        0.99068, 0.99095, 0.99077, 0.99127, 0.99086, 0.99102, 0.99039,
                        0.99215, 0.99272, 0.99151, 0.99162, 0.99144, 0.99179, 0.99182,
                        0.99277, 0.99145, 0.99208, 0.99311, 0.99243, 0.99265, 0.99329, 0.94245],
                       [0.99167, 0.99088, 0.99094, 0.99221, 0.99149, 0.99136, 0.99145,
                        0.99145, 0.99173, 0.99136, 0.99189, 0.99218, 0.99190, 0.99089,
                        0.99254, 0.99310, 0.99270, 0.99191, 0.99295, 0.99230, 0.99357,
                        0.99337, 0.99239, 0.99318, 0.99399, 0.99287, 0.99365, 0.99440, 0.94375],
                       [0.99138, 0.99101, 0.99112, 0.99152, 0.99181, 0.99137, 0.99153,
                        0.99134, 0.99153, 0.99128, 0.99161, 0.99195, 0.99258, 0.99174,
                        0.99217, 0.99244, 0.99282, 0.99170, 0.99298, 0.99253, 0.99305,
                        0.99276, 0.99261, 0.99353, 0.99297, 0.99316, 0.99411, 0.99357, 0.94389],
                       [0.99128, 0.99158, 0.99078, 0.99110, 0.99183, 0.99111, 0.99172,
                        0.99156, 0.99145, 0.99101, 0.99190, 0.99136, 0.99292, 0.99283,
                        0.99230, 0.99203, 0.99228, 0.99222, 0.99250, 0.99248, 0.99175,
                        0.99261, 0.99269, 0.99334, 0.99262, 0.99344, 0.99384, 0.99256, 0.94341],
                       [0.99155, 0.99236, 0.99095, 0.99120, 0.99091, 0.99131, 0.99121,
                        0.99220, 0.99142, 0.99096, 0.99167, 0.99169, 0.99193, 0.99257,
                        0.99206, 0.99154, 0.99144, 0.99259, 0.99227, 0.99183, 0.99112,
                        0.99296, 0.99240, 0.99259, 0.99231, 0.99273, 0.99274, 0.99245, 0.94316],
                       [0.99197, 0.99287, 0.99158, 0.99202, 0.99115, 0.99223, 0.99105,
                        0.99292, 0.99191, 0.99203, 0.99144, 0.99249, 0.99149, 0.99234,
                        0.99212, 0.99156, 0.99138, 0.99269, 0.99249, 0.99184, 0.99185,
                        0.99295, 0.99252, 0.99249, 0.99218, 0.99173, 0.99213, 0.99277, 0.94288],
                       [0.99295, 0.99243, 0.99216, 0.99307, 0.99189, 0.99311, 0.99235,
                        0.99315, 0.99260, 0.99306, 0.99239, 0.99259, 0.99242, 0.99302,
                        0.99257, 0.99197, 0.99188, 0.99252, 0.99281, 0.99278, 0.99245,
                        0.99237, 0.99288, 0.99303, 0.99212, 0.99204, 0.99300, 0.99313, 0.94305],
                       [0.99365, 0.99225, 0.99255, 0.99291, 0.99202, 0.99324, 0.99304,
                        0.99265, 0.99266, 0.99300, 0.99304, 0.99224, 0.99316, 0.99314,
                        0.99246, 0.99208, 0.99220, 0.99195, 0.99240, 0.99293, 0.99213,
                        0.99228, 0.99263, 0.99239, 0.99196, 0.99241, 0.99317, 0.99297, 0.94317],
                       [0.99339, 0.99309, 0.99289, 0.99239, 0.99221, 0.99308, 0.99202,
                        0.99278, 0.99239, 0.99282, 0.99278, 0.99210, 0.99257, 0.99239,
                        0.99197, 0.99192, 0.99246, 0.99187, 0.99196, 0.99238, 0.99218,
                        0.99298, 0.99246, 0.99181, 0.99246, 0.99178, 0.99273, 0.99243, 0.94274],
                       [0.99280, 0.99321, 0.99353, 0.99220, 0.99195, 0.99353, 0.99164,
                        0.99287, 0.99188, 0.99230, 0.99234, 0.99263, 0.99202, 0.99227,
                        0.99233, 0.99207, 0.99218, 0.99245, 0.99198, 0.99218, 0.99208,
                        0.99305, 0.99214, 0.99250, 0.99256, 0.99162, 0.99231, 0.99187, 0.94216],
                       [0.99286, 0.99341, 0.99437, 0.99254, 0.99227, 0.99365, 0.99247,
                        0.99309, 0.99283, 0.99209, 0.99236, 0.99361, 0.99270, 0.99314,
                        0.99304, 0.99272, 0.99258, 0.99306, 0.99275, 0.99277, 0.99224,
                        0.99305, 0.99201, 0.99357, 0.99293, 0.99281, 0.99224, 0.99215, 0.94224],
                       [0.99294, 0.99352, 0.99343, 0.99274, 0.99309, 0.99237, 0.99307,
                        0.99286, 0.99382, 0.99259, 0.99218, 0.99316, 0.99313, 0.99284,
                        0.99263, 0.99262, 0.99316, 0.99263, 0.99283, 0.99319, 0.99184,
                        0.99278, 0.99210, 0.99254, 0.99269, 0.99314, 0.99205, 0.99208, 0.94223],
                       [0.99345, 0.99393, 0.99212, 0.99326, 0.99368, 0.99178, 0.99350,
                        0.99269, 0.99343, 0.99311, 0.99280, 0.99241, 0.99339, 0.99280,
                        0.99264, 0.99277, 0.99293, 0.99207, 0.99243, 0.99260, 0.99158,
                        0.99235, 0.99217, 0.99115, 0.99224, 0.99296, 0.99179, 0.99188, 0.94226],
                       [0.99436, 0.99413, 0.99251, 0.99376, 0.99405, 0.99320, 0.99398,
                        0.99381, 0.99314, 0.99321, 0.99419, 0.99297, 0.99338, 0.99355,
                        0.99313, 0.99279, 0.99232, 0.99235, 0.99302, 0.99180, 0.99229,
                        0.99234, 0.99242, 0.99170, 0.99224, 0.99294, 0.99201, 0.99226, 0.94227],
                       [0.99436, 0.99360, 0.99380, 0.99405, 0.99443, 0.99493, 0.99407,
                        0.99489, 0.99372, 0.99332, 0.99437, 0.99371, 0.99297, 0.99370,
                        0.99311, 0.99266, 0.99244, 0.99296, 0.99344, 0.99231, 0.99332,
                        0.99309, 0.99270, 0.99321, 0.99190, 0.99224, 0.99254, 0.99216, 0.94247],
                       [0.99352, 0.99318, 0.99421, 0.99410, 0.99441, 0.99410, 0.99358,
                        0.99380, 0.99370, 0.99305, 0.99312, 0.99358, 0.99242, 0.99248,
                        0.99274, 0.99248, 0.99271, 0.99305, 0.99291, 0.99253, 0.99338,
                        0.99308, 0.99229, 0.99327, 0.99153, 0.99126, 0.99259, 0.99139, 0.94270],
                       [0.99375, 0.99383, 0.99404, 0.99407, 0.99409, 0.99302, 0.99340,
                        0.99267, 0.99365, 0.99305, 0.99255, 0.99357, 0.99267, 0.99207,
                        0.99295, 0.99296, 0.99271, 0.99292, 0.99284, 0.99242, 0.99276,
                        0.99272, 0.99238, 0.99225, 0.99235, 0.99131, 0.99245, 0.99183, 0.94270],
                       [0.99518, 0.99484, 0.99438, 0.99482, 0.99416, 0.99413, 0.99377,
                        0.99385, 0.99415, 0.99361, 0.99350, 0.99402, 0.99371, 0.99379,
                        0.99388, 0.99415, 0.99308, 0.99321, 0.99281, 0.99287, 0.99298,
                        0.99344, 0.99312, 0.99236, 0.99355, 0.99228, 0.99247, 0.99299, 0.94286],
                       [0.99558, 0.99490, 0.99477, 0.99491, 0.99434, 0.99506, 0.99383,
                        0.99507, 0.99454, 0.99395, 0.99418, 0.99392, 0.99428, 0.99457,
                        0.99439, 0.99424, 0.99339, 0.99318, 0.99250, 0.99322, 0.99318,
                        0.99356, 0.99320, 0.99289, 0.99306, 0.99263, 0.99272, 0.99323, 0.94254],
                       [0.99429, 0.99386, 0.99404, 0.99371, 0.99364, 0.99400, 0.99375,
                        0.99407, 0.99393, 0.99376, 0.99347, 0.99331, 0.99376, 0.99333,
                        0.99323, 0.99273, 0.99234, 0.99271, 0.99208, 0.99291, 0.99213,
                        0.99240, 0.99231, 0.99297, 0.99177, 0.99229, 0.99256, 0.99146, 0.94152],
                       [0.99343, 0.99366, 0.99308, 0.99358, 0.99316, 0.99271, 0.99331,
                        0.99239, 0.99293, 0.99347, 0.99325, 0.99306, 0.99306, 0.99266,
                        0.99182, 0.99217, 0.99114, 0.99211, 0.99148, 0.99220, 0.99104,
                        0.99187, 0.99146, 0.99234, 0.99139, 0.99160, 0.99198, 0.99007, 0.94093],
                       [0.99369, 0.99433, 0.99337, 0.99433, 0.99366, 0.99307, 0.99322,
                        0.99270, 0.99293, 0.99335, 0.99390, 0.99271, 0.99241, 0.99251,
                        0.99201, 0.99325, 0.99154, 0.99199, 0.99164, 0.99196, 0.99183,
                        0.99231, 0.99124, 0.99135, 0.99153, 0.99079, 0.99143, 0.99084, 0.94111],
                       [0.99411, 0.99419, 0.99419, 0.99460, 0.99388, 0.99427, 0.99374,
                        0.99382, 0.99420, 0.99356, 0.99435, 0.99278, 0.99286, 0.99283,
                        0.99283, 0.99385, 0.99293, 0.99264, 0.99290, 0.99246, 0.99333,
                        0.99248, 0.99174, 0.99175, 0.99216, 0.99167, 0.99145, 0.99224, 0.94150],
                       [0.99352, 0.99364, 0.99393, 0.99407, 0.99373, 0.99483, 0.99407,
                        0.99325, 0.99479, 0.99397, 0.99389, 0.99310, 0.99375, 0.99322,
                        0.99324, 0.99334, 0.99317, 0.99329, 0.99340, 0.99263, 0.99287,
                        0.99199, 0.99233, 0.99201, 0.99266, 0.99232, 0.99143, 0.99246, 0.94164],
                       [0.99362, 0.99402, 0.99353, 0.99304, 0.99373, 0.99386, 0.99418,
                        0.99255, 0.99362, 0.99411, 0.99332, 0.99318, 0.99331, 0.99312,
                        0.99294, 0.99247, 0.99254, 0.99341, 0.99216, 0.99223, 0.99135,
                        0.99228, 0.99302, 0.99198, 0.99272, 0.99233, 0.99193, 0.99140, 0.94175],
                       [0.99423, 0.99438, 0.99435, 0.99324, 0.99349, 0.99319, 0.99402,
                        0.99315, 0.99256, 0.99372, 0.99248, 0.99311, 0.99282, 0.99289,
                        0.99222, 0.99227, 0.99224, 0.99335, 0.99125, 0.99171, 0.99146,
                        0.99302, 0.99375, 0.99230, 0.99279, 0.99245, 0.99237, 0.99078, 0.94209],
                       [0.99381, 0.99396, 0.99403, 0.99356, 0.99354, 0.99382, 0.99363,
                        0.99361, 0.99244, 0.99331, 0.99231, 0.99317, 0.99284, 0.99256,
                        0.99217, 0.99243, 0.99235, 0.99265, 0.99176, 0.99166, 0.99219,
                        0.99301, 0.99307, 0.99283, 0.99204, 0.99162, 0.99216, 0.99049, 0.94181],
                       [0.99300, 0.99342, 0.99234, 0.99324, 0.99377, 0.99378, 0.99264,
                        0.99323, 0.99313, 0.99329, 0.99338, 0.99285, 0.99264, 0.99230,
                        0.99260, 0.99253, 0.99274, 0.99166, 0.99192, 0.99282, 0.99193,
                        0.99280, 0.99219, 0.99244, 0.99139, 0.99116, 0.99156, 0.99127, 0.94104],
                       [0.99249, 0.99352, 0.99187, 0.99272, 0.99321, 0.99268, 0.99166,
                        0.99280, 0.99333, 0.99324, 0.99360, 0.99206, 0.99213, 0.99213,
                        0.99271, 0.99238, 0.99226, 0.99106, 0.99159, 0.99319, 0.99149,
                        0.99253, 0.99216, 0.99106, 0.99163, 0.99121, 0.99120, 0.99190, 0.94108],
                       [0.99300, 0.99369, 0.99353, 0.99255, 0.99299, 0.99301, 0.99224,
                        0.99276, 0.99338, 0.99306, 0.99336, 0.99248, 0.99263, 0.99304,
                        0.99350, 0.99271, 0.99178, 0.99155, 0.99264, 0.99253, 0.99242,
                        0.99247, 0.99226, 0.99137, 0.99212, 0.99157, 0.99208, 0.99165, 0.94183],
                       [0.99323, 0.99318, 0.99456, 0.99250, 0.99340, 0.99304, 0.99369,
                        0.99300, 0.99343, 0.99283, 0.99283, 0.99326, 0.99303, 0.99303,
                        0.99348, 0.99297, 0.99203, 0.99234, 0.99314, 0.99252, 0.99327,
                        0.99263, 0.99219, 0.99214, 0.99211, 0.99242, 0.99261, 0.99191, 0.94256],
                       [0.99300, 0.99243, 0.99341, 0.99258, 0.99386, 0.99214, 0.99403,
                        0.99312, 0.99295, 0.99265, 0.99223, 0.99302, 0.99271, 0.99238,
                        0.99244, 0.99245, 0.99245, 0.99235, 0.99279, 0.99265, 0.99292,
                        0.99259, 0.99227, 0.99227, 0.99228, 0.99312, 0.99231, 0.99242, 0.94256],
                       [0.99232, 0.99210, 0.99197, 0.99254, 0.99365, 0.99164, 0.99250,
                        0.99239, 0.99204, 0.99209, 0.99179, 0.99200, 0.99260, 0.99268,
                        0.99260, 0.99161, 0.99200, 0.99175, 0.99232, 0.99153, 0.99210,
                        0.99196, 0.99185, 0.99193, 0.99252, 0.99252, 0.99228, 0.99244, 0.94193],
                       [0.99178, 0.99292, 0.99166, 0.99221, 0.99256, 0.99197, 0.99216,
                        0.99184, 0.99206, 0.99215, 0.99237, 0.99223, 0.99243, 0.99285,
                        0.99316, 0.99150, 0.99203, 0.99198, 0.99202, 0.99114, 0.99226,
                        0.99206, 0.99212, 0.99154, 0.99279, 0.99211, 0.99252, 0.99261, 0.94234],
                       [0.99274, 0.99417, 0.99277, 0.99315, 0.99261, 0.99305, 0.99350,
                        0.99269, 0.99277, 0.99330, 0.99308, 0.99346, 0.99262, 0.99296,
                        0.99292, 0.99291, 0.99296, 0.99343, 0.99260, 0.99261, 0.99341,
                        0.99324, 0.99355, 0.99227, 0.99354, 0.99237, 0.99289, 0.99325, 0.94404],
                       [0.99318, 0.99383, 0.99292, 0.99387, 0.99227, 0.99303, 0.99352,
                        0.99301, 0.99288, 0.99306, 0.99245, 0.99301, 0.99309, 0.99245,
                        0.99179, 0.99382, 0.99271, 0.99311, 0.99280, 0.99302, 0.99332,
                        0.99287, 0.99334, 0.99265, 0.99310, 0.99207, 0.99260, 0.99336, 0.94364],
                       [0.99252, 0.99267, 0.99214, 0.99318, 0.99171, 0.99206, 0.99276,
                        0.99314, 0.99295, 0.99194, 0.99221, 0.99275, 0.99341, 0.99251,
                        0.99159, 0.99360, 0.99223, 0.99238, 0.99277, 0.99238, 0.99271,
                        0.99200, 0.99228, 0.99245, 0.99228, 0.99237, 0.99230, 0.99315, 0.94272],
                       [0.99190, 0.99184, 0.99204, 0.99219, 0.99221, 0.99102, 0.99213,
                        0.99288, 0.99228, 0.99218, 0.99194, 0.99298, 0.99265, 0.99240,
                        0.99218, 0.99295, 0.99174, 0.99213, 0.99261, 0.99212, 0.99177,
                        0.99195, 0.99210, 0.99185, 0.99174, 0.99239, 0.99219, 0.99254, 0.94326],
                       [0.99211, 0.99200, 0.99256, 0.99195, 0.99282, 0.99082, 0.99193,
                        0.99211, 0.99187, 0.99309, 0.99187, 0.99255, 0.99215, 0.99138,
                        0.99250, 0.99228, 0.99146, 0.99187, 0.99232, 0.99229, 0.99107,
                        0.99222, 0.99239, 0.99182, 0.99180, 0.99217, 0.99242, 0.99162, 0.94352],
                       [0.99210, 0.99245, 0.99233, 0.99146, 0.99230, 0.99104, 0.99163,
                        0.99090, 0.99162, 0.99203, 0.99139, 0.99161, 0.99157, 0.99120,
                        0.99199, 0.99149, 0.99124, 0.99151, 0.99211, 0.99216, 0.99063,
                        0.99146, 0.99165, 0.99173, 0.99176, 0.99166, 0.99179, 0.99111, 0.94240],
                       [0.99187, 0.99275, 0.99210, 0.99161, 0.99148, 0.99154, 0.99195,
                        0.99117, 0.99159, 0.99105, 0.99113, 0.99109, 0.99127, 0.99242,
                        0.99136, 0.99139, 0.99174, 0.99131, 0.99203, 0.99232, 0.99128,
                        0.99121, 0.99139, 0.99203, 0.99206, 0.99162, 0.99153, 0.99147, 0.94159],
                       [0.99159, 0.99191, 0.99211, 0.99139, 0.99115, 0.99134, 0.99206,
                        0.99204, 0.99152, 0.99118, 0.99136, 0.99091, 0.99135, 0.99271,
                        0.99100, 0.99175, 0.99161, 0.99121, 0.99142, 0.99194, 0.99236,
                        0.99113, 0.99191, 0.99210, 0.99170, 0.99134, 0.99130, 0.99152, 0.94138],
                       [0.99192, 0.99129, 0.99223, 0.99194, 0.99129, 0.99126, 0.99229,
                        0.99233, 0.99169, 0.99236, 0.99170, 0.99188, 0.99174, 0.99260,
                        0.99167, 0.99186, 0.99172, 0.99186, 0.99171, 0.99190, 0.99269,
                        0.99153, 0.99250, 0.99173, 0.99109, 0.99167, 0.99100, 0.99156, 0.94223],
                       [0.99198, 0.99190, 0.99204, 0.99283, 0.99142, 0.99177, 0.99231,
                        0.99237, 0.99142, 0.99297, 0.99173, 0.99245, 0.99202, 0.99193,
                        0.99213, 0.99159, 0.99273, 0.99266, 0.99204, 0.99274, 0.99221,
                        0.99250, 0.99223, 0.99152, 0.99152, 0.99216, 0.99184, 0.99177, 0.94300],
                       [0.99215, 0.99236, 0.99238, 0.99247, 0.99170, 0.99239, 0.99212,
                        0.99219, 0.99136, 0.99243, 0.99200, 0.99263, 0.99233, 0.99163,
                        0.99186, 0.99146, 0.99313, 0.99244, 0.99156, 0.99313, 0.99198,
                        0.99243, 0.99163, 0.99203, 0.99248, 0.99201, 0.99261, 0.99200, 0.94245],
                       [0.99246, 0.99180, 0.99281, 0.99155, 0.99192, 0.99282, 0.99214,
                        0.99200, 0.99200, 0.99201, 0.99224, 0.99300, 0.99240, 0.99213,
                        0.99144, 0.99138, 0.99255, 0.99170, 0.99128, 0.99258, 0.99200,
                        0.99197, 0.99161, 0.99285, 0.99261, 0.99196, 0.99198, 0.99215, 0.94115],
                       [0.99200, 0.99108, 0.99172, 0.99055, 0.99164, 0.99182, 0.99141,
                        0.99095, 0.99149, 0.99135, 0.99139, 0.99201, 0.99128, 0.99139,
                        0.99117, 0.99149, 0.99104, 0.99122, 0.99153, 0.99097, 0.99064,
                        0.99148, 0.99147, 0.99220, 0.99071, 0.99128, 0.99096, 0.99116, 0.94053],
                       [0.99152, 0.99111, 0.99049, 0.99054, 0.99069, 0.99054, 0.99090,
                        0.99023, 0.99055, 0.99058, 0.99069, 0.99083, 0.99100, 0.99018,
                        0.99167, 0.99192, 0.98991, 0.99121, 0.99215, 0.99029, 0.99047,
                        0.99092, 0.99124, 0.99090, 0.98964, 0.99054, 0.99075, 0.99021, 0.94111],
                       [0.99176, 0.99130, 0.99059, 0.99116, 0.99068, 0.99021, 0.99111,
                        0.99133, 0.99047, 0.99068, 0.99093, 0.99102, 0.99161, 0.99045,
                        0.99172, 0.99209, 0.99077, 0.99149, 0.99182, 0.99139, 0.99218,
                        0.99135, 0.99161, 0.99112, 0.99073, 0.99068, 0.99121, 0.99061, 0.94151],
                       [0.99194, 0.99143, 0.99106, 0.99182, 0.99093, 0.99083, 0.99166,
                        0.99281, 0.99094, 0.99137, 0.99172, 0.99126, 0.99176, 0.99138,
                        0.99151, 0.99154, 0.99225, 0.99141, 0.99087, 0.99229, 0.99211,
                        0.99205, 0.99199, 0.99189, 0.99166, 0.99107, 0.99152, 0.99105, 0.94150],
                       [0.99115, 0.99162, 0.99108, 0.99165, 0.99025, 0.99085, 0.99147,
                        0.99280, 0.99108, 0.99153, 0.99153, 0.99055, 0.99110, 0.99140,
                        0.99174, 0.99023, 0.99224, 0.99105, 0.99046, 0.99197, 0.99091,
                        0.99134, 0.99179, 0.99155, 0.99164, 0.99154, 0.99109, 0.99061, 0.94114],
                       [0.99154, 0.99184, 0.99131, 0.99191, 0.99116, 0.99037, 0.99148,
                        0.99223, 0.99183, 0.99151, 0.99154, 0.99099, 0.99074, 0.99212,
                        0.99182, 0.99052, 0.99221, 0.99169, 0.99155, 0.99157, 0.99124,
                        0.99123, 0.99127, 0.99133, 0.99160, 0.99207, 0.99140, 0.99085, 0.94151],
                       [0.99217, 0.99146, 0.99086, 0.99195, 0.99206, 0.99093, 0.99177,
                        0.99153, 0.99194, 0.99175, 0.99160, 0.99149, 0.99080, 0.99216,
                        0.99114, 0.99156, 0.99193, 0.99233, 0.99217, 0.99106, 0.99202,
                        0.99156, 0.99097, 0.99141, 0.99116, 0.99167, 0.99152, 0.99089, 0.94171],
                       [0.99236, 0.99170, 0.99097, 0.99163, 0.99195, 0.99223, 0.99238,
                        0.99133, 0.99208, 0.99262, 0.99130, 0.99143, 0.99166, 0.99157,
                        0.99103, 0.99186, 0.99137, 0.99181, 0.99209, 0.99059, 0.99184,
                        0.99135, 0.99180, 0.99156, 0.99124, 0.99163, 0.99104, 0.99090, 0.94139],
                       [0.99270, 0.99277, 0.99216, 0.99193, 0.99157, 0.99280, 0.99272,
                        0.99215, 0.99306, 0.99277, 0.99186, 0.99170, 0.99263, 0.99177,
                        0.99163, 0.99207, 0.99149, 0.99151, 0.99224, 0.99089, 0.99123,
                        0.99145, 0.99276, 0.99202, 0.99181, 0.99173, 0.99125, 0.99166, 0.94154],
                       [0.99225, 0.99247, 0.99259, 0.99153, 0.99123, 0.99230, 0.99200,
                        0.99277, 0.99263, 0.99235, 0.99239, 0.99171, 0.99289, 0.99216,
                        0.99157, 0.99170, 0.99175, 0.99175, 0.99205, 0.99137, 0.99125,
                        0.99207, 0.99255, 0.99187, 0.99139, 0.99130, 0.99191, 0.99273, 0.94174],
                       [0.99170, 0.99156, 0.99267, 0.99122, 0.99150, 0.99253, 0.99179,
                        0.99229, 0.99153, 0.99209, 0.99245, 0.99189, 0.99289, 0.99226,
                        0.99150, 0.99138, 0.99187, 0.99195, 0.99182, 0.99158, 0.99177,
                        0.99221, 0.99158, 0.99132, 0.99097, 0.99111, 0.99167, 0.99264, 0.94154],
                       [0.99170, 0.99156, 0.99222, 0.99151, 0.99219, 0.99225, 0.99215,
                        0.99185, 0.99170, 0.99146, 0.99263, 0.99213, 0.99215, 0.99189,
                        0.99159, 0.99081, 0.99226, 0.99207, 0.99131, 0.99164, 0.99213,
                        0.99124, 0.99091, 0.99106, 0.99146, 0.99090, 0.99095, 0.99116, 0.94113],
                       [0.99197, 0.99159, 0.99158, 0.99183, 0.99219, 0.99093, 0.99203,
                        0.99196, 0.99221, 0.99135, 0.99215, 0.99162, 0.99138, 0.99106,
                        0.99200, 0.99048, 0.99192, 0.99171, 0.99089, 0.99138, 0.99155,
                        0.99058, 0.99092, 0.99072, 0.99187, 0.99092, 0.99045, 0.98998, 0.94113],
                       [0.99209, 0.99101, 0.99136, 0.99217, 0.99069, 0.99078, 0.99179,
                        0.99107, 0.99148, 0.99136, 0.99108, 0.99095, 0.99173, 0.99051,
                        0.99194, 0.99090, 0.99095, 0.99135, 0.99102, 0.99135, 0.99014,
                        0.99059, 0.99044, 0.99081, 0.99131, 0.99090, 0.99022, 0.99015, 0.94127],
                       [0.99180, 0.99089, 0.99129, 0.99209, 0.99047, 0.99153, 0.99177,
                        0.99055, 0.99114, 0.99136, 0.99049, 0.99082, 0.99228, 0.99115,
                        0.99086, 0.99149, 0.99094, 0.99076, 0.99043, 0.99135, 0.98959,
                        0.99098, 0.99000, 0.99152, 0.99020, 0.99108, 0.99073, 0.99127, 0.94111],
                       [0.99143, 0.99162, 0.99121, 0.99199, 0.99121, 0.99189, 0.99145,
                        0.99120, 0.99127, 0.99170, 0.99077, 0.99074, 0.99151, 0.99211,
                        0.99040, 0.99176, 0.99133, 0.99051, 0.98990, 0.99063, 0.99023,
                        0.99164, 0.99032, 0.99175, 0.99061, 0.99124, 0.99109, 0.99183, 0.94106],
                       [0.99153, 0.99178, 0.99101, 0.99182, 0.99085, 0.99158, 0.99131,
                        0.99163, 0.99114, 0.99098, 0.99156, 0.99137, 0.99072, 0.99187,
                        0.99139, 0.99091, 0.99152, 0.99050, 0.99096, 0.99037, 0.99127,
                        0.99161, 0.99095, 0.99146, 0.99253, 0.99104, 0.99124, 0.99124, 0.94130],
                       [0.99137, 0.99114, 0.99109, 0.99110, 0.99066, 0.99109, 0.99156,
                        0.99132, 0.99136, 0.98987, 0.99178, 0.99208, 0.99099, 0.99091,
                        0.99237, 0.99096, 0.99140, 0.99022, 0.99177, 0.99084, 0.99158,
                        0.99100, 0.99130, 0.99129, 0.99278, 0.99086, 0.99167, 0.99099, 0.94119],
                       [0.99055, 0.99133, 0.99128, 0.99022, 0.99104, 0.99126, 0.99143,
                        0.99090, 0.99122, 0.99039, 0.99134, 0.99154, 0.99120, 0.99098,
                        0.99166, 0.99198, 0.99129, 0.99035, 0.99131, 0.99077, 0.99122,
                        0.98989, 0.99144, 0.99167, 0.99137, 0.99081, 0.99119, 0.99155, 0.94129],
                       [0.99037, 0.99156, 0.99167, 0.99100, 0.99159, 0.99232, 0.99159,
                        0.99135, 0.99125, 0.99169, 0.99154, 0.99139, 0.99134, 0.99183,
                        0.99061, 0.99203, 0.99194, 0.99078, 0.99035, 0.99084, 0.99166,
                        0.99004, 0.99114, 0.99182, 0.99052, 0.99089, 0.99064, 0.99210, 0.94181],
                       [0.99096, 0.99127, 0.99193, 0.99195, 0.99140, 0.99242, 0.99144,
                        0.99166, 0.99174, 0.99167, 0.99124, 0.99104, 0.99086, 0.99127,
                        0.99031, 0.99092, 0.99166, 0.99067, 0.98962, 0.99136, 0.99138,
                        0.99062, 0.99091, 0.99070, 0.99100, 0.99045, 0.99070, 0.99119, 0.94157],
                       [0.99165, 0.99131, 0.99154, 0.99193, 0.99100, 0.99171, 0.99104,
                        0.99126, 0.99161, 0.99077, 0.99025, 0.99035, 0.99066, 0.99099,
                        0.99082, 0.99035, 0.99111, 0.99043, 0.99058, 0.99145, 0.99083,
                        0.99066, 0.99115, 0.99002, 0.99158, 0.99068, 0.99127, 0.99037, 0.94121],
                       [0.99129, 0.99092, 0.99125, 0.99160, 0.99079, 0.99121, 0.99076,
                        0.99066, 0.99086, 0.99046, 0.98962, 0.98986, 0.99073, 0.99136,
                        0.99144, 0.99025, 0.99063, 0.99020, 0.99123, 0.99080, 0.99086,
                        0.99022, 0.99085, 0.99009, 0.99080, 0.99128, 0.99127, 0.99028, 0.94156],
                       [0.99076, 0.99081, 0.99165, 0.99155, 0.99105, 0.99124, 0.99052,
                        0.99070, 0.99114, 0.99095, 0.98988, 0.99062, 0.99052, 0.99079,
                        0.99133, 0.99045, 0.99026, 0.99030, 0.99107, 0.99020, 0.99087,
                        0.99004, 0.99082, 0.99041, 0.99075, 0.99136, 0.99074, 0.99018, 0.94215],
                       [0.99041, 0.99109, 0.99130, 0.99114, 0.99099, 0.99137, 0.98991,
                        0.99074, 0.99144, 0.99091, 0.99038, 0.99128, 0.99039, 0.99016,
                        0.99063, 0.99079, 0.99067, 0.99045, 0.99061, 0.99004, 0.99069,
                        0.99075, 0.99116, 0.99085, 0.99154, 0.99084, 0.99040, 0.99054, 0.94181],
                       [0.99018, 0.99083, 0.99017, 0.99026, 0.99009, 0.99121, 0.99006,
                        0.99043, 0.99057, 0.99068, 0.99059, 0.99068, 0.99050, 0.99016,
                        0.99023, 0.99086, 0.99121, 0.99018, 0.98991, 0.98961, 0.99056,
                        0.99074, 0.99104, 0.99133, 0.99091, 0.98991, 0.99061, 0.99081, 0.94128],
                       [0.99053, 0.99062, 0.98979, 0.98984, 0.98987, 0.99065, 0.99084,
                        0.98990, 0.98962, 0.99055, 0.99121, 0.99051, 0.99062, 0.99012,
                        0.98995, 0.99012, 0.99087, 0.98964, 0.98989, 0.98939, 0.99039,
                        0.98981, 0.98947, 0.99063, 0.99006, 0.98960, 0.99043, 0.99073, 0.94138],
                       [0.99079, 0.99080, 0.98986, 0.99052, 0.99064, 0.99029, 0.99123,
                        0.99057, 0.98974, 0.99011, 0.99130, 0.99043, 0.98974, 0.99023,
                        0.98949, 0.98951, 0.99019, 0.98956, 0.98978, 0.98994, 0.99055,
                        0.98956, 0.98821, 0.98909, 0.98992, 0.99038, 0.98967, 0.99010, 0.94138],
                       [0.99021, 0.99050, 0.99004, 0.99077, 0.99046, 0.99032, 0.99043,
                        0.99136, 0.99050, 0.99000, 0.99019, 0.98983, 0.98921, 0.98993,
                        0.98956, 0.98950, 0.98875, 0.98983, 0.98911, 0.98998, 0.98978,
                        0.98960, 0.98908, 0.98920, 0.98979, 0.99026, 0.98917, 0.98954, 0.94053],
                       [0.99029, 0.99043, 0.99095, 0.99098, 0.99051, 0.99099, 0.99034,
                        0.99117, 0.99123, 0.99120, 0.99033, 0.99043, 0.99066, 0.99014,
                        0.99039, 0.98976, 0.98847, 0.99027, 0.98989, 0.99070, 0.99004,
                        0.98994, 0.99092, 0.99050, 0.99013, 0.99010, 0.99015, 0.99025, 0.94040],
                       [0.99060, 0.99129, 0.99151, 0.99100, 0.99086, 0.99118, 0.99104,
                        0.99056, 0.99140, 0.99160, 0.99035, 0.99159, 0.99118, 0.99020,
                        0.99072, 0.99053, 0.98980, 0.98987, 0.99045, 0.99128, 0.99175,
                        0.98995, 0.99114, 0.99070, 0.98988, 0.99044, 0.99068, 0.99074, 0.94044],
                       [0.99058, 0.99196, 0.99107, 0.99078, 0.99109, 0.99056, 0.99113,
                        0.99000, 0.99084, 0.99062, 0.99018, 0.99102, 0.99021, 0.98995,
                        0.99043, 0.99120, 0.99068, 0.98935, 0.98965, 0.99044, 0.99159,
                        0.99017, 0.99021, 0.99040, 0.98871, 0.99037, 0.99022, 0.99023, 0.94005],
                       [0.99029, 0.99161, 0.99013, 0.99108, 0.99093, 0.99030, 0.99128,
                        0.98975, 0.99111, 0.99052, 0.99049, 0.99018, 0.98992, 0.99028,
                        0.99016, 0.99124, 0.99041, 0.98967, 0.98948, 0.98987, 0.99030,
                        0.99090, 0.98983, 0.99049, 0.98858, 0.99019, 0.98996, 0.98999, 0.94039],
                       [0.99027, 0.99041, 0.98975, 0.99142, 0.98995, 0.99061, 0.99133,
                        0.99038, 0.99125, 0.99118, 0.99043, 0.99004, 0.99062, 0.99048,
                        0.98999, 0.99069, 0.99062, 0.98999, 0.98971, 0.99012, 0.98991,
                        0.99077, 0.98944, 0.99046, 0.98985, 0.99036, 0.99004, 0.99022, 0.94105],
                       [0.99051, 0.98996, 0.99027, 0.99155, 0.98993, 0.99103, 0.99088,
                        0.99147, 0.99069, 0.99156, 0.99036, 0.99053, 0.99083, 0.99030,
                        0.99056, 0.99043, 0.99064, 0.99026, 0.98960, 0.99025, 0.99070,
                        0.99050, 0.99024, 0.99046, 0.99048, 0.99043, 0.99048, 0.99017, 0.94118],
                       [0.99174, 0.99115, 0.99129, 0.99115, 0.99160, 0.99118, 0.99096,
                        0.99166, 0.99032, 0.99133, 0.99082, 0.99151, 0.99082, 0.99093,
                        0.99161, 0.99104, 0.99082, 0.99109, 0.99092, 0.99090, 0.99190,
                        0.99089, 0.99109, 0.99140, 0.99047, 0.99094, 0.99096, 0.99036, 0.94141],
                       [0.99302, 0.99167, 0.99185, 0.99068, 0.99202, 0.99075, 0.99125,
                        0.99118, 0.99001, 0.99036, 0.99075, 0.99148, 0.99061, 0.99165,
                        0.99125, 0.99077, 0.99071, 0.99133, 0.99197, 0.99139, 0.99196,
                        0.99091, 0.98997, 0.99153, 0.99047, 0.99071, 0.99118, 0.99096, 0.94143],
                       [0.99296, 0.99149, 0.99219, 0.99102, 0.99209, 0.99066, 0.99210,
                        0.99151, 0.99120, 0.99044, 0.99061, 0.99122, 0.99067, 0.99166,
                        0.99047, 0.99038, 0.99082, 0.99101, 0.99161, 0.99153, 0.99173,
                        0.99132, 0.99074, 0.99094, 0.99070, 0.99048, 0.99188, 0.99143, 0.94156],
                       [0.99207, 0.99134, 0.99204, 0.99152, 0.99206, 0.99056, 0.99268,
                        0.99181, 0.99272, 0.99096, 0.99130, 0.99108, 0.99145, 0.99181,
                        0.99097, 0.99118, 0.99122, 0.99129, 0.99127, 0.99215, 0.99215,
                        0.99177, 0.99223, 0.99120, 0.99077, 0.99114, 0.99228, 0.99182, 0.94241],
                       [0.99173, 0.99181, 0.99143, 0.99199, 0.99172, 0.99106, 0.99191,
                        0.99154, 0.99235, 0.99108, 0.99235, 0.99094, 0.99226, 0.99244,
                        0.99189, 0.99268, 0.99131, 0.99230, 0.99221, 0.99276, 0.99207,
                        0.99157, 0.99185, 0.99246, 0.99115, 0.99157, 0.99200, 0.99194, 0.94278],
                       [0.99274, 0.99319, 0.99216, 0.99252, 0.99294, 0.99271, 0.99229,
                        0.99200, 0.99205, 0.99226, 0.99351, 0.99197, 0.99317, 0.99295,
                        0.99344, 0.99386, 0.99218, 0.99322, 0.99278, 0.99273, 0.99225,
                        0.99194, 0.99238, 0.99368, 0.99237, 0.99224, 0.99252, 0.99182, 0.94348],
                       [0.99329, 0.99324, 0.99247, 0.99278, 0.99358, 0.99328, 0.99345,
                        0.99290, 0.99289, 0.99232, 0.99333, 0.99315, 0.99319, 0.99205,
                        0.99395, 0.99325, 0.99269, 0.99297, 0.99159, 0.99248, 0.99290,
                        0.99302, 0.99273, 0.99292, 0.99270, 0.99197, 0.99285, 0.99194, 0.94362],
                       [0.99328, 0.99258, 0.99205, 0.99253, 0.99277, 0.99306, 0.99292,
                        0.99299, 0.99380, 0.99199, 0.99246, 0.99378, 0.99277, 0.99140,
                        0.99281, 0.99242, 0.99233, 0.99220, 0.99151, 0.99276, 0.99315,
                        0.99290, 0.99189, 0.99183, 0.99234, 0.99153, 0.99258, 0.99262, 0.94296],
                       [0.99248, 0.99231, 0.99215, 0.99219, 0.99200, 0.99272, 0.99192,
                        0.99232, 0.99352, 0.99282, 0.99196, 0.99335, 0.99235, 0.99243,
                        0.99167, 0.99188, 0.99152, 0.99196, 0.99221, 0.99286, 0.99258,
                        0.99179, 0.99144, 0.99141, 0.99227, 0.99167, 0.99170, 0.99294, 0.94281],
                       [0.99222, 0.99280, 0.99279, 0.99286, 0.99267, 0.99305, 0.99256,
                        0.99277, 0.99295, 0.99338, 0.99213, 0.99289, 0.99223, 0.99343,
                        0.99173, 0.99209, 0.99163, 0.99284, 0.99270, 0.99258, 0.99272,
                        0.99234, 0.99206, 0.99190, 0.99290, 0.99230, 0.99149, 0.99263, 0.94348],
                       [0.99286, 0.99298, 0.99295, 0.99263, 0.99373, 0.99305, 0.99314,
                        0.99339, 0.99297, 0.99237, 0.99231, 0.99307, 0.99290, 0.99295,
                        0.99288, 0.99285, 0.99284, 0.99356, 0.99235, 0.99208, 0.99284,
                        0.99282, 0.99285, 0.99255, 0.99278, 0.99263, 0.99219, 0.99197, 0.94380],
                       [0.99379, 0.99341, 0.99359, 0.99325, 0.99469, 0.99383, 0.99336,
                        0.99395, 0.99372, 0.99197, 0.99307, 0.99326, 0.99380, 0.99340,
                        0.99379, 0.99331, 0.99384, 0.99374, 0.99252, 0.99308, 0.99275,
                        0.99288, 0.99382, 0.99320, 0.99254, 0.99343, 0.99339, 0.99236, 0.94405],
                       [0.99376, 0.99369, 0.99349, 0.99408, 0.99488, 0.99403, 0.99286,
                        0.99389, 0.99328, 0.99258, 0.99358, 0.99243, 0.99321, 0.99419,
                        0.99312, 0.99249, 0.99358, 0.99251, 0.99277, 0.99405, 0.99300,
                        0.99278, 0.99338, 0.99321, 0.99251, 0.99364, 0.99336, 0.99288, 0.94353],
                       [0.99327, 0.99333, 0.99285, 0.99350, 0.99391, 0.99330, 0.99279,
                        0.99296, 0.99241, 0.99307, 0.99324, 0.99183, 0.99293, 0.99301,
                        0.99246, 0.99189, 0.99260, 0.99154, 0.99262, 0.99384, 0.99315,
                        0.99261, 0.99205, 0.99243, 0.99239, 0.99305, 0.99251, 0.99268, 0.94281],
                       [0.99339, 0.99331, 0.99286, 0.99321, 0.99246, 0.99245, 0.99317,
                        0.99260, 0.99199, 0.99305, 0.99235, 0.99237, 0.99299, 0.99172,
                        0.99253, 0.99264, 0.99260, 0.99193, 0.99233, 0.99276, 0.99334,
                        0.99260, 0.99227, 0.99251, 0.99266, 0.99278, 0.99260, 0.99229, 0.94303],
                       [0.99397, 0.99336, 0.99346, 0.99384, 0.99241, 0.99172, 0.99373,
                        0.99330, 0.99206, 0.99286, 0.99227, 0.99334, 0.99353, 0.99254,
                        0.99316, 0.99331, 0.99303, 0.99290, 0.99265, 0.99262, 0.99399,
                        0.99284, 0.99346, 0.99303, 0.99316, 0.99275, 0.99315, 0.99262, 0.94393],
                       [0.99322, 0.99269, 0.99269, 0.99355, 0.99260, 0.99147, 0.99304,
                        0.99270, 0.99185, 0.99223, 0.99282, 0.99349, 0.99293, 0.99295,
                        0.99254, 0.99239, 0.99224, 0.99257, 0.99245, 0.99269, 0.99330,
                        0.99220, 0.99319, 0.99256, 0.99203, 0.99204, 0.99224, 0.99235, 0.94331],
                       [0.99233, 0.99283, 0.99172, 0.99245, 0.99278, 0.99135, 0.99192,
                        0.99166, 0.99184, 0.99160, 0.99320, 0.99323, 0.99149, 0.99205,
                        0.99165, 0.99164, 0.99229, 0.99188, 0.99182, 0.99195, 0.99227,
                        0.99128, 0.99248, 0.99133, 0.99083, 0.99143, 0.99141, 0.99160, 0.94299],
                       [0.99236, 0.99372, 0.99213, 0.99202, 0.99335, 0.99212, 0.99256,
                        0.99211, 0.99304, 0.99221, 0.99349, 0.99283, 0.99185, 0.99197,
                        0.99254, 0.99305, 0.99327, 0.99244, 0.99184, 0.99180, 0.99220,
                        0.99165, 0.99267, 0.99121, 0.99109, 0.99195, 0.99193, 0.99170, 0.94375],
                       [0.99225, 0.99385, 0.99267, 0.99243, 0.99276, 0.99385, 0.99322,
                        0.99203, 0.99374, 0.99276, 0.99303, 0.99211, 0.99296, 0.99275,
                        0.99335, 0.99420, 0.99286, 0.99316, 0.99230, 0.99236, 0.99245,
                        0.99229, 0.99303, 0.99249, 0.99228, 0.99330, 0.99277, 0.99244, 0.94368],
                       [0.99234, 0.99265, 0.99270, 0.99261, 0.99199, 0.99397, 0.99274,
                        0.99142, 0.99253, 0.99246, 0.99214, 0.99189, 0.99219, 0.99265,
                        0.99252, 0.99303, 0.99214, 0.99249, 0.99255, 0.99205, 0.99207,
                        0.99234, 0.99256, 0.99267, 0.99298, 0.99337, 0.99275, 0.99272, 0.94353],
                       [0.99226, 0.99107, 0.99155, 0.99172, 0.99178, 0.99190, 0.99211,
                        0.99187, 0.99127, 0.99173, 0.99150, 0.99160, 0.99092, 0.99174,
                        0.99077, 0.99112, 0.99158, 0.99164, 0.99178, 0.99124, 0.99109,
                        0.99195, 0.99176, 0.99134, 0.99209, 0.99206, 0.99205, 0.99228, 0.94308],
                       [0.99197, 0.99084, 0.99054, 0.99094, 0.99169, 0.99054, 0.99172,
                        0.99268, 0.99087, 0.99094, 0.99129, 0.99097, 0.99088, 0.99102,
                        0.99021, 0.99048, 0.99114, 0.99086, 0.99082, 0.99109, 0.99051,
                        0.99097, 0.99126, 0.99047, 0.99073, 0.99110, 0.99162, 0.99172, 0.94170],
                       [0.99215, 0.99164, 0.99167, 0.99137, 0.99152, 0.99125, 0.99147,
                        0.99269, 0.99120, 0.99081, 0.99105, 0.99148, 0.99108, 0.99142,
                        0.99159, 0.99091, 0.99125, 0.99102, 0.99064, 0.99108, 0.99105,
                        0.99080, 0.99088, 0.99101, 0.99093, 0.99103, 0.99174, 0.99158, 0.94150],
                       [0.99163, 0.99138, 0.99194, 0.99189, 0.99107, 0.99229, 0.99143,
                        0.99175, 0.99198, 0.99134, 0.99103, 0.99291, 0.99083, 0.99174,
                        0.99165, 0.99077, 0.99160, 0.99140, 0.99040, 0.99103, 0.99143,
                        0.99097, 0.99060, 0.99155, 0.99195, 0.99098, 0.99135, 0.99126, 0.94210],
                       [0.99079, 0.99101, 0.99135, 0.99177, 0.99096, 0.99208, 0.99180,
                        0.99093, 0.99219, 0.99137, 0.99188, 0.99279, 0.99087, 0.99137,
                        0.99028, 0.98989, 0.99153, 0.99098, 0.99065, 0.99155, 0.99125,
                        0.99018, 0.99107, 0.99108, 0.99171, 0.99092, 0.99089, 0.99032, 0.94139],
                       [0.99088, 0.99140, 0.99161, 0.99118, 0.99132, 0.99093, 0.99182,
                        0.98996, 0.99172, 0.99044, 0.99175, 0.99117, 0.99082, 0.99035,
                        0.99103, 0.98965, 0.99042, 0.99039, 0.99116, 0.99118, 0.99095,
                        0.98948, 0.99118, 0.99055, 0.99119, 0.99081, 0.99066, 0.98956, 0.94093],
                       [0.99110, 0.99119, 0.99167, 0.99112, 0.99093, 0.99015, 0.99113,
                        0.98899, 0.99113, 0.98995, 0.99004, 0.99027, 0.99097, 0.98970,
                        0.99203, 0.99014, 0.98932, 0.99033, 0.99061, 0.98977, 0.99086,
                        0.98934, 0.99059, 0.99042, 0.99078, 0.99010, 0.98967, 0.98945, 0.94056],
                       [0.99053, 0.99075, 0.99096, 0.99065, 0.98992, 0.98967, 0.99057,
                        0.98878, 0.99077, 0.99002, 0.98916, 0.98986, 0.99084, 0.98977,
                        0.99071, 0.98995, 0.98947, 0.99020, 0.98902, 0.98922, 0.99023,
                        0.98946, 0.98996, 0.98949, 0.98965, 0.98893, 0.98896, 0.98939, 0.93942],
                       [0.98984, 0.99053, 0.99075, 0.99008, 0.98982, 0.98990, 0.99092,
                        0.98932, 0.99053, 0.99034, 0.99030, 0.99008, 0.99044, 0.98977,
                        0.98972, 0.98968, 0.98967, 0.98973, 0.98818, 0.98925, 0.98921,
                        0.98974, 0.98985, 0.98908, 0.98886, 0.98900, 0.98934, 0.98987, 0.93932],
                       [0.98949, 0.98986, 0.99027, 0.98947, 0.98986, 0.99030, 0.99036,
                        0.98981, 0.99011, 0.99003, 0.99078, 0.98985, 0.98972, 0.98916,
                        0.98939, 0.98887, 0.98851, 0.98929, 0.98775, 0.98898, 0.98859,
                        0.98868, 0.98965, 0.98915, 0.98878, 0.98888, 0.98928, 0.98980, 0.93963],
                       [0.99024, 0.98944, 0.98946, 0.98903, 0.98969, 0.98964, 0.98953,
                        0.98990, 0.98941, 0.98882, 0.98993, 0.98842, 0.98874, 0.98863,
                        0.98858, 0.98748, 0.98717, 0.98857, 0.98755, 0.98787, 0.98842,
                        0.98735, 0.98890, 0.98837, 0.98843, 0.98729, 0.98814, 0.98894, 0.93919],
                       [0.99019, 0.98889, 0.98880, 0.98937, 0.98955, 0.98908, 0.98927,
                        0.98909, 0.98830, 0.98812, 0.98898, 0.98857, 0.98809, 0.98801,
                        0.98797, 0.98662, 0.98599, 0.98722, 0.98753, 0.98652, 0.98751,
                        0.98700, 0.98807, 0.98746, 0.98699, 0.98630, 0.98664, 0.98807, 0.93899],
                       [0.98928, 0.98823, 0.98824, 0.98935, 0.98876, 0.98885, 0.98861,
                        0.98843, 0.98776, 0.98793, 0.98830, 0.98912, 0.98765, 0.98708,
                        0.98726, 0.98717, 0.98560, 0.98555, 0.98724, 0.98634, 0.98686,
                        0.98661, 0.98694, 0.98680, 0.98602, 0.98667, 0.98609, 0.98708, 0.93804],
                       [0.98795, 0.98778, 0.98759, 0.98792, 0.98692, 0.98751, 0.98731,
                        0.98798, 0.98755, 0.98732, 0.98756, 0.98753, 0.98688, 0.98659,
                        0.98573, 0.98716, 0.98528, 0.98452, 0.98598, 0.98629, 0.98591,
                        0.98561, 0.98520, 0.98543, 0.98572, 0.98596, 0.98527, 0.98530, 0.93607],
                       [0.98655, 0.98721, 0.98717, 0.98611, 0.98601, 0.98586, 0.98706,
                        0.98729, 0.98749, 0.98683, 0.98720, 0.98604, 0.98609, 0.98616,
                        0.98485, 0.98605, 0.98411, 0.98474, 0.98444, 0.98487, 0.98480,
                        0.98492, 0.98454, 0.98403, 0.98499, 0.98465, 0.98417, 0.98387, 0.93519],
                       [0.98621, 0.98680, 0.98699, 0.98553, 0.98623, 0.98624, 0.98718,
                        0.98655, 0.98712, 0.98655, 0.98712, 0.98537, 0.98508, 0.98513,
                        0.98516, 0.98454, 0.98327, 0.98418, 0.98336, 0.98325, 0.98451,
                        0.98442, 0.98436, 0.98345, 0.98400, 0.98359, 0.98297, 0.98320, 0.93494],
                       [0.98604, 0.98708, 0.98690, 0.98593, 0.98601, 0.98723, 0.98620,
                        0.98625, 0.98662, 0.98542, 0.98679, 0.98434, 0.98406, 0.98435,
                        0.98529, 0.98330, 0.98299, 0.98255, 0.98263, 0.98275, 0.98375,
                        0.98422, 0.98361, 0.98334, 0.98303, 0.98252, 0.98196, 0.98243, 0.93478],
                       [0.98550, 0.98632, 0.98627, 0.98500, 0.98516, 0.98590, 0.98461,
                        0.98552, 0.98537, 0.98412, 0.98508, 0.98357, 0.98371, 0.98332,
                        0.98367, 0.98205, 0.98134, 0.98139, 0.98172, 0.98219, 0.98213,
                        0.98316, 0.98234, 0.98229, 0.98169, 0.98117, 0.98148, 0.98112, 0.93329],
                       [0.98434, 0.98357, 0.98396, 0.98338, 0.98375, 0.98338, 0.98310,
                        0.98313, 0.98322, 0.98332, 0.98273, 0.98245, 0.98316, 0.98187,
                        0.98035, 0.98002, 0.97855, 0.97985, 0.97989, 0.97989, 0.98030,
                        0.97965, 0.98053, 0.97979, 0.98019, 0.97855, 0.98017, 0.97958, 0.93028],
                       [0.98240, 0.98134, 0.98100, 0.98177, 0.98147, 0.98121, 0.98169,
                        0.98008, 0.98094, 0.98154, 0.98091, 0.98017, 0.98097, 0.97907,
                        0.97744, 0.97713, 0.97649, 0.97747, 0.97666, 0.97685, 0.97804,
                        0.97593, 0.97793, 0.97752, 0.97742, 0.97612, 0.97710, 0.97746, 0.92761],
                       [0.98082, 0.98039, 0.98016, 0.98036, 0.97990, 0.98017, 0.98035,
                        0.97850, 0.97940, 0.97936, 0.97995, 0.97889, 0.97813, 0.97618,
                        0.97636, 0.97508, 0.97478, 0.97571, 0.97433, 0.97549, 0.97594,
                        0.97483, 0.97545, 0.97593, 0.97477, 0.97520, 0.97357, 0.97428, 0.92577],
                       [0.97946, 0.97959, 0.97987, 0.97910, 0.97923, 0.98003, 0.97921,
                        0.97846, 0.97862, 0.97811, 0.97843, 0.97781, 0.97578, 0.97445,
                        0.97502, 0.97355, 0.97284, 0.97402, 0.97371, 0.97437, 0.97416,
                        0.97463, 0.97419, 0.97433, 0.97351, 0.97358, 0.97161, 0.97131, 0.92484],
                       [0.97804, 0.97754, 0.97750, 0.97668, 0.97704, 0.97757, 0.97746,
                        0.97750, 0.97712, 0.97668, 0.97529, 0.97483, 0.97357, 0.97258,
                        0.97152, 0.97100, 0.96988, 0.97094, 0.97142, 0.97070, 0.97127,
                        0.97185, 0.97175, 0.97128, 0.97070, 0.97016, 0.97000, 0.96860, 0.92230],
                       [0.97577, 0.97461, 0.97449, 0.97397, 0.97452, 0.97358, 0.97468,
                        0.97508, 0.97463, 0.97413, 0.97230, 0.97198, 0.97089, 0.96968,
                        0.96811, 0.96783, 0.96648, 0.96729, 0.96727, 0.96621, 0.96814,
                        0.96767, 0.96798, 0.96755, 0.96656, 0.96656, 0.96669, 0.96502, 0.91708],
                       [0.97250, 0.97142, 0.97176, 0.97076, 0.97140, 0.97020, 0.97088,
                        0.97135, 0.97167, 0.97122, 0.96994, 0.96941, 0.96730, 0.96595,
                        0.96466, 0.96380, 0.96298, 0.96277, 0.96289, 0.96299, 0.96502,
                        0.96393, 0.96372, 0.96413, 0.96305, 0.96257, 0.96204, 0.96143, 0.91225],
                       [0.96913, 0.96768, 0.96833, 0.96696, 0.96706, 0.96704, 0.96658,
                        0.96709, 0.96794, 0.96789, 0.96650, 0.96536, 0.96281, 0.96151,
                        0.95970, 0.95808, 0.95866, 0.95738, 0.95809, 0.95927, 0.95933,
                        0.95992, 0.95936, 0.95973, 0.95892, 0.95757, 0.95732, 0.95720, 0.90827],
                       [0.96528, 0.96482, 0.96493, 0.96386, 0.96357, 0.96328, 0.96373,
                        0.96376, 0.96373, 0.96347, 0.96163, 0.96049, 0.95844, 0.95635,
                        0.95504, 0.95272, 0.95327, 0.95205, 0.95273, 0.95397, 0.95341,
                        0.95520, 0.95518, 0.95452, 0.95397, 0.95233, 0.95229, 0.95138, 0.90358],
                       [0.96157, 0.96198, 0.96181, 0.96008, 0.96069, 0.95948, 0.96062,
                        0.96037, 0.96003, 0.95919, 0.95703, 0.95616, 0.95474, 0.95155,
                        0.95039, 0.94883, 0.94759, 0.94721, 0.94793, 0.94879, 0.94905,
                        0.94991, 0.95042, 0.94945, 0.94888, 0.94769, 0.94726, 0.94559, 0.89843],
                       [0.95721, 0.95629, 0.95686, 0.95490, 0.95542, 0.95491, 0.95478,
                        0.95485, 0.95496, 0.95451, 0.95191, 0.95036, 0.94853, 0.94523,
                        0.94400, 0.94320, 0.94125, 0.94089, 0.94141, 0.94257, 0.94287,
                        0.94305, 0.94329, 0.94306, 0.94201, 0.94130, 0.94030, 0.93949, 0.89194],
                       [0.95156, 0.94985, 0.95032, 0.94924, 0.94870, 0.94857, 0.94877,
                        0.94886, 0.94856, 0.94849, 0.94620, 0.94386, 0.94059, 0.93809,
                        0.93725, 0.93493, 0.93365, 0.93324, 0.93314, 0.93487, 0.93522,
                        0.93609, 0.93621, 0.93467, 0.93411, 0.93386, 0.93228, 0.93173, 0.88527],
                       [0.94543, 0.94465, 0.94426, 0.94338, 0.94255, 0.94173, 0.94287,
                        0.94266, 0.94241, 0.94135, 0.94021, 0.93771, 0.93305, 0.93146,
                        0.92931, 0.92629, 0.92527, 0.92559, 0.92600, 0.92642, 0.92743,
                        0.92930, 0.92888, 0.92643, 0.92576, 0.92619, 0.92428, 0.92343, 0.87834],
                       [0.94018, 0.93891, 0.93805, 0.93749, 0.93684, 0.93568, 0.93685,
                        0.93563, 0.93604, 0.93453, 0.93362, 0.93052, 0.92647, 0.92464,
                        0.92019, 0.91829, 0.91719, 0.91737, 0.91912, 0.91833, 0.91950,
                        0.92187, 0.92006, 0.91935, 0.91771, 0.91738, 0.91611, 0.91544, 0.87066],
                       [0.93293, 0.93050, 0.92907, 0.92919, 0.92871, 0.92742, 0.92849,
                        0.92686, 0.92728, 0.92670, 0.92530, 0.92098, 0.91834, 0.91450,
                        0.91030, 0.90803, 0.90774, 0.90753, 0.90811, 0.90865, 0.90992,
                        0.91177, 0.90962, 0.91001, 0.90811, 0.90614, 0.90575, 0.90527, 0.86080],
                       [0.92239, 0.92046, 0.91928, 0.91894, 0.91734, 0.91694, 0.91783,
                        0.91755, 0.91757, 0.91661, 0.91452, 0.91076, 0.90702, 0.90187,
                        0.89897, 0.89569, 0.89604, 0.89536, 0.89555, 0.89679, 0.89831,
                        0.89911, 0.89827, 0.89840, 0.89627, 0.89421, 0.89313, 0.89303, 0.84947],
                       [0.91137, 0.91028, 0.90974, 0.90774, 0.90661, 0.90712, 0.90698,
                        0.90865, 0.90731, 0.90563, 0.90223, 0.89992, 0.89489, 0.88971,
                        0.88628, 0.88351, 0.88242, 0.88170, 0.88351, 0.88425, 0.88581,
                        0.88670, 0.88654, 0.88607, 0.88358, 0.88207, 0.88033, 0.88011, 0.83733],
                       [0.90083, 0.90018, 0.89962, 0.89612, 0.89706, 0.89706, 0.89666,
                        0.89753, 0.89613, 0.89499, 0.89054, 0.88819, 0.88274, 0.87711,
                        0.87343, 0.87089, 0.86785, 0.86776, 0.87041, 0.87188, 0.87302,
                        0.87481, 0.87407, 0.87305, 0.87030, 0.86893, 0.86750, 0.86630, 0.82452],
                       [0.88876, 0.88800, 0.88688, 0.88333, 0.88430, 0.88352, 0.88471,
                        0.88301, 0.88302, 0.88206, 0.87866, 0.87458, 0.86828, 0.86221,
                        0.85891, 0.85545, 0.85226, 0.85244, 0.85534, 0.85688, 0.85809,
                        0.85985, 0.85959, 0.85814, 0.85525, 0.85450, 0.85270, 0.85005, 0.80960],
                       [0.87516, 0.87392, 0.87185, 0.86952, 0.86899, 0.86785, 0.86949,
                        0.86776, 0.86870, 0.86642, 0.86424, 0.85899, 0.85233, 0.84642,
                        0.84159, 0.83756, 0.83552, 0.83525, 0.83785, 0.83912, 0.84077,
                        0.84266, 0.84334, 0.84131, 0.83812, 0.83844, 0.83540, 0.83349, 0.79279],
                       [0.86063, 0.85912, 0.85651, 0.85520, 0.85358, 0.85290, 0.85291,
                        0.85251, 0.85351, 0.85050, 0.84812, 0.84258, 0.83649, 0.82976,
                        0.82264, 0.81911, 0.81746, 0.81697, 0.81895, 0.82114, 0.82304,
                        0.82597, 0.82556, 0.82338, 0.82033, 0.82009, 0.81726, 0.81649, 0.77620],
                       [0.84362, 0.84189, 0.83917, 0.83788, 0.83670, 0.83643, 0.83610,
                        0.83587, 0.83597, 0.83363, 0.83007, 0.82394, 0.81804, 0.80995,
                        0.80297, 0.79871, 0.79701, 0.79685, 0.79856, 0.80169, 0.80409,
                        0.80677, 0.80547, 0.80297, 0.80072, 0.79893, 0.79759, 0.79601, 0.75724],
                       [0.82429, 0.82231, 0.81983, 0.81767, 0.81683, 0.81683, 0.81705,
                        0.81724, 0.81637, 0.81399, 0.80940, 0.80394, 0.79611, 0.78712,
                        0.78130, 0.77553, 0.77421, 0.77404, 0.77616, 0.77977, 0.78301,
                        0.78413, 0.78375, 0.78139, 0.77907, 0.77678, 0.77491, 0.77327, 0.73554],
                       [0.80423, 0.80301, 0.80003, 0.79762, 0.79583, 0.79637, 0.79575,
                        0.79719, 0.79606, 0.79297, 0.78831, 0.78339, 0.77307, 0.76368,
                        0.75756, 0.75165, 0.75025, 0.75030, 0.75253, 0.75635, 0.76053,
                        0.76126, 0.76142, 0.75998, 0.75648, 0.75404, 0.75127, 0.75057, 0.71371],
                       [0.78237, 0.78217, 0.77821, 0.77601, 0.77347, 0.77437, 0.77347,
                        0.77455, 0.77372, 0.77058, 0.76632, 0.75952, 0.74896, 0.73971,
                        0.73171, 0.72695, 0.72462, 0.72499, 0.72633, 0.73059, 0.73524,
                        0.73689, 0.73709, 0.73577, 0.73182, 0.72868, 0.72635, 0.72592, 0.69007],
                       [0.75831, 0.75721, 0.75355, 0.75064, 0.74845, 0.74909, 0.75001,
                        0.74848, 0.74848, 0.74522, 0.74151, 0.73197, 0.72341, 0.71294,
                        0.70327, 0.69942, 0.69642, 0.69717, 0.69821, 0.70319, 0.70760,
                        0.70987, 0.71014, 0.70813, 0.70513, 0.70073, 0.69914, 0.69801, 0.66427],
                       [0.73233, 0.72999, 0.72733, 0.72351, 0.72212, 0.72179, 0.72371,
                        0.72153, 0.72146, 0.71825, 0.71430, 0.70359, 0.69569, 0.68436,
                        0.67442, 0.66949, 0.66619, 0.66796, 0.67007, 0.67495, 0.67913,
                        0.68199, 0.68197, 0.67899, 0.67635, 0.67257, 0.67077, 0.66897, 0.63752],
                       [0.70494, 0.70215, 0.69951, 0.69598, 0.69454, 0.69367, 0.69446,
                        0.69453, 0.69346, 0.69062, 0.68529, 0.67545, 0.66534, 0.65409,
                        0.64492, 0.63788, 0.63472, 0.63694, 0.64013, 0.64523, 0.64921,
                        0.65223, 0.65214, 0.64907, 0.64640, 0.64371, 0.64110, 0.63885, 0.60906],
                       [0.67616, 0.67357, 0.66909, 0.66595, 0.66435, 0.66337, 0.66350,
                        0.66465, 0.66373, 0.66082, 0.65453, 0.64549, 0.63316, 0.62125,
                        0.61286, 0.60497, 0.60180, 0.60388, 0.60745, 0.61317, 0.61752,
                        0.61979, 0.62013, 0.61816, 0.61500, 0.61209, 0.60903, 0.60681, 0.57875],
                       [0.64537, 0.64320, 0.63680, 0.63382, 0.63251, 0.63141, 0.63190,
                        0.63248, 0.63183, 0.62921, 0.62235, 0.61346, 0.60036, 0.58811,
                        0.57902, 0.57187, 0.56877, 0.57054, 0.57423, 0.57954, 0.58485,
                        0.58743, 0.58770, 0.58650, 0.58263, 0.57865, 0.57566, 0.57416, 0.54802],
                       [0.61272, 0.61076, 0.60401, 0.60158, 0.60011, 0.59913, 0.59981,
                        0.59962, 0.59856, 0.59580, 0.58976, 0.58028, 0.56694, 0.55554,
                        0.54488, 0.53857, 0.53583, 0.53692, 0.54055, 0.54584, 0.55151,
                        0.55541, 0.55534, 0.55328, 0.54931, 0.54501, 0.54294, 0.54170, 0.51643],
                       [0.57833, 0.57651, 0.57124, 0.56777, 0.56574, 0.56533, 0.56583,
                        0.56606, 0.56483, 0.56086, 0.55623, 0.54599, 0.53240, 0.52067,
                        0.50984, 0.50389, 0.50110, 0.50230, 0.50554, 0.51118, 0.51731,
                        0.52154, 0.52197, 0.51864, 0.51460, 0.51092, 0.50934, 0.50838, 0.48354],
                       [0.54438, 0.54184, 0.53785, 0.53315, 0.53096, 0.53062, 0.53107,
                        0.53218, 0.53087, 0.52740, 0.52187, 0.51175, 0.49836, 0.48531,
                        0.47477, 0.46876, 0.46584, 0.46772, 0.47108, 0.47686, 0.48312,
                        0.48691, 0.48758, 0.48464, 0.48004, 0.47710, 0.47526, 0.47450, 0.45104],
                       [0.51023, 0.50774, 0.50293, 0.49855, 0.49589, 0.49606, 0.49655,
                        0.49722, 0.49636, 0.49385, 0.48672, 0.47680, 0.46401, 0.45049,
                        0.44061, 0.43411, 0.43071, 0.43258, 0.43712, 0.44320, 0.44900,
                        0.45211, 0.45349, 0.45075, 0.44611, 0.44360, 0.44105, 0.44015, 0.41890],
                       [0.47519, 0.47381, 0.46733, 0.46310, 0.46059, 0.46148, 0.46192,
                        0.46171, 0.46109, 0.45816, 0.45163, 0.44140, 0.42836, 0.41581,
                        0.40597, 0.40010, 0.39642, 0.39762, 0.40346, 0.40864, 0.41474,
                        0.41807, 0.41945, 0.41633, 0.41276, 0.40923, 0.40675, 0.40601, 0.38694],
                       [0.43988, 0.43810, 0.43202, 0.42693, 0.42614, 0.42675, 0.42672,
                        0.42633, 0.42612, 0.42294, 0.41716, 0.40671, 0.39348, 0.38186,
                        0.37169, 0.36622, 0.36328, 0.36444, 0.37019, 0.37456, 0.38081,
                        0.38519, 0.38534, 0.38281, 0.37936, 0.37505, 0.37359, 0.37249, 0.35564],
                       [0.40482, 0.40184, 0.39689, 0.39162, 0.39147, 0.39192, 0.39089,
                        0.39162, 0.39153, 0.38872, 0.38247, 0.37247, 0.36016, 0.34818,
                        0.33883, 0.33265, 0.33085, 0.33295, 0.33715, 0.34258, 0.34778,
                        0.35227, 0.35258, 0.35047, 0.34674, 0.34291, 0.34180, 0.34039, 0.32510],
                       [0.37049, 0.36793, 0.36342, 0.35807, 0.35703, 0.35753, 0.35683,
                        0.35847, 0.35797, 0.35509, 0.34845, 0.33979, 0.32810, 0.31575,
                        0.30762, 0.30116, 0.30017, 0.30265, 0.30576, 0.31181, 0.31688,
                        0.32029, 0.32156, 0.31950, 0.31616, 0.31266, 0.31137, 0.30996, 0.29540],
                       [0.33779, 0.33642, 0.33196, 0.32709, 0.32466, 0.32461, 0.32571,
                        0.32691, 0.32633, 0.32317, 0.31711, 0.30877, 0.29716, 0.28605,
                        0.27862, 0.27295, 0.27168, 0.27359, 0.27680, 0.28215, 0.28802,
                        0.29102, 0.29157, 0.28966, 0.28720, 0.28370, 0.28218, 0.28097, 0.26712],
                       [0.30676, 0.30567, 0.30117, 0.29734, 0.29448, 0.29399, 0.29546,
                        0.29597, 0.29549, 0.29250, 0.28777, 0.27899, 0.26809, 0.25862,
                        0.25092, 0.24588, 0.24449, 0.24656, 0.24938, 0.25465, 0.26003,
                        0.26356, 0.26312, 0.26099, 0.25965, 0.25652, 0.25425, 0.25376, 0.24102],
                       [0.27793, 0.27565, 0.27149, 0.26730, 0.26643, 0.26582, 0.26609,
                        0.26641, 0.26618, 0.26361, 0.26007, 0.25116, 0.24163, 0.23309,
                        0.22533, 0.22054, 0.21866, 0.22149, 0.22394, 0.22936, 0.23363,
                        0.23685, 0.23676, 0.23484, 0.23325, 0.23064, 0.22896, 0.22864, 0.21738],
                       [0.25086, 0.24763, 0.24375, 0.23953, 0.23979, 0.23950, 0.23942,
                        0.24043, 0.23944, 0.23780, 0.23402, 0.22590, 0.21719, 0.20883,
                        0.20231, 0.19767, 0.19538, 0.19807, 0.20104, 0.20556, 0.20983,
                        0.21249, 0.21288, 0.21140, 0.20873, 0.20671, 0.20627, 0.20513, 0.19515],
                       [0.22482, 0.22245, 0.21866, 0.21526, 0.21449, 0.21482, 0.21525,
                        0.21683, 0.21481, 0.21421, 0.20949, 0.20305, 0.19452, 0.18658,
                        0.18100, 0.17634, 0.17556, 0.17744, 0.18024, 0.18385, 0.18868,
                        0.19103, 0.19132, 0.18955, 0.18756, 0.18562, 0.18489, 0.18335, 0.17433],
                       [0.20131, 0.19999, 0.19592, 0.19353, 0.19178, 0.19275, 0.19248,
                        0.19381, 0.19281, 0.19215, 0.18712, 0.18182, 0.17378, 0.16701,
                        0.16157, 0.15734, 0.15813, 0.15858, 0.16134, 0.16432, 0.16895,
                        0.17156, 0.17175, 0.16949, 0.16865, 0.16632, 0.16544, 0.16403, 0.15653],
                       [0.18039, 0.17898, 0.17590, 0.17326, 0.17207, 0.17238, 0.17199,
                        0.17276, 0.17254, 0.17179, 0.16756, 0.16236, 0.15582, 0.14969,
                        0.14427, 0.14142, 0.14096, 0.14094, 0.14462, 0.14705, 0.15123,
                        0.15386, 0.15388, 0.15237, 0.15102, 0.14865, 0.14827, 0.14687, 0.14046],
                       [0.16197, 0.15949, 0.15853, 0.15459, 0.15432, 0.15404, 0.15462,
                        0.15435, 0.15435, 0.15371, 0.14997, 0.14490, 0.13994, 0.13417,
                        0.12851, 0.12779, 0.12541, 0.12631, 0.12966, 0.13217, 0.13561,
                        0.13788, 0.13788, 0.13714, 0.13525, 0.13322, 0.13225, 0.13208, 0.12549],
                       [0.14517, 0.14303, 0.14191, 0.13860, 0.13743, 0.13783, 0.13858,
                        0.13786, 0.13833, 0.13775, 0.13362, 0.12934, 0.12483, 0.11963,
                        0.11474, 0.11443, 0.11247, 0.11371, 0.11527, 0.11868, 0.12036,
                        0.12303, 0.12386, 0.12212, 0.12134, 0.11947, 0.11750, 0.11893, 0.11269],
                       [0.12944, 0.12865, 0.12614, 0.12385, 0.12300, 0.12345, 0.12301,
                        0.12373, 0.12419, 0.12289, 0.11973, 0.11589, 0.11176, 0.10690,
                        0.10334, 0.10193, 0.10102, 0.10197, 0.10270, 0.10577, 0.10692,
                        0.11000, 0.11076, 0.10890, 0.10872, 0.10734, 0.10551, 0.10670, 0.10095],
                       [0.11533, 0.11562, 0.11206, 0.11024, 0.11115, 0.11113, 0.10938,
                        0.11135, 0.11108, 0.10997, 0.10810, 0.10388, 0.10061, 0.09603,
                        0.09384, 0.09105, 0.09105, 0.09127, 0.09281, 0.09430, 0.09652,
                        0.09908, 0.09837, 0.09775, 0.09696, 0.09677, 0.09552, 0.09512, 0.08967],
                       [0.10313, 0.10403, 0.10044, 0.09857, 0.10021, 0.09918, 0.09822,
                        0.09942, 0.09917, 0.09949, 0.09718, 0.09252, 0.09054, 0.08649,
                        0.08490, 0.08177, 0.08183, 0.08146, 0.08333, 0.08447, 0.08740,
                        0.08824, 0.08755, 0.08788, 0.08639, 0.08726, 0.08594, 0.08467, 0.08013],
                       [0.09356, 0.09373, 0.09121, 0.08831, 0.08965, 0.08861, 0.08884,
                        0.08863, 0.08896, 0.08989, 0.08678, 0.08286, 0.08130, 0.07786,
                        0.07556, 0.07357, 0.07352, 0.07342, 0.07364, 0.07591, 0.07860,
                        0.07909, 0.07913, 0.07978, 0.07818, 0.07835, 0.07780, 0.07567, 0.07226],
                       [0.08445, 0.08365, 0.08220, 0.07924, 0.07901, 0.07993, 0.08007,
                        0.07942, 0.08006, 0.07971, 0.07719, 0.07516, 0.07247, 0.06968,
                        0.06687, 0.06656, 0.06617, 0.06617, 0.06559, 0.06948, 0.07064,
                        0.07185, 0.07198, 0.07127, 0.07131, 0.06987, 0.06960, 0.06831, 0.06498],
                       [0.07510, 0.07376, 0.07299, 0.07213, 0.07000, 0.07159, 0.07155,
                        0.07219, 0.07194, 0.07104, 0.07001, 0.06790, 0.06474, 0.06268,
                        0.06051, 0.05978, 0.05929, 0.05965, 0.05963, 0.06315, 0.06327,
                        0.06430, 0.06464, 0.06297, 0.06450, 0.06197, 0.06115, 0.06203, 0.05833],
                       [0.06729, 0.06650, 0.06466, 0.06550, 0.06394, 0.06506, 0.06442,
                        0.06607, 0.06381, 0.06389, 0.06412, 0.06107, 0.05870, 0.05619,
                        0.05505, 0.05377, 0.05207, 0.05479, 0.05526, 0.05590, 0.05593,
                        0.05744, 0.05746, 0.05684, 0.05696, 0.05561, 0.05459, 0.05639, 0.05251],
                       [0.06020, 0.06052, 0.05787, 0.05781, 0.05922, 0.05902, 0.05823,
                        0.05865, 0.05693, 0.05683, 0.05702, 0.05424, 0.05350, 0.04984,
                        0.04886, 0.04930, 0.04632, 0.04958, 0.05042, 0.04953, 0.04986,
                        0.05247, 0.05079, 0.05181, 0.04974, 0.05049, 0.04949, 0.05035, 0.04692],
                       [0.05366, 0.05372, 0.05288, 0.05140, 0.05334, 0.05262, 0.05219,
                        0.05079, 0.05235, 0.05113, 0.04980, 0.04801, 0.04829, 0.04535,
                        0.04306, 0.04398, 0.04264, 0.04387, 0.04493, 0.04470, 0.04488,
                        0.04740, 0.04593, 0.04666, 0.04537, 0.04551, 0.04468, 0.04421, 0.04215],
                       [0.04903, 0.04726, 0.04766, 0.04709, 0.04750, 0.04693, 0.04686,
                        0.04515, 0.04831, 0.04635, 0.04407, 0.04387, 0.04371, 0.04137,
                        0.03903, 0.03861, 0.03907, 0.03880, 0.03958, 0.04152, 0.04014,
                        0.04169, 0.04159, 0.04164, 0.04185, 0.04093, 0.04107, 0.03985, 0.03858],
                       [0.04392, 0.04231, 0.04228, 0.04237, 0.04252, 0.04066, 0.04155,
                        0.04146, 0.04310, 0.04188, 0.04027, 0.03969, 0.03879, 0.03616,
                        0.03545, 0.03505, 0.03437, 0.03482, 0.03471, 0.03747, 0.03561,
                        0.03708, 0.03717, 0.03688, 0.03724, 0.03687, 0.03741, 0.03658, 0.03468],
                       [0.03828, 0.03925, 0.03812, 0.03775, 0.03872, 0.03533, 0.03712,
                        0.03733, 0.03789, 0.03823, 0.03665, 0.03602, 0.03372, 0.03192,
                        0.03211, 0.03217, 0.02994, 0.03149, 0.03085, 0.03222, 0.03263,
                        0.03409, 0.03414, 0.03328, 0.03332, 0.03260, 0.03319, 0.03290, 0.03063],
                       [0.03432, 0.03635, 0.03463, 0.03419, 0.03520, 0.03201, 0.03450,
                        0.03347, 0.03426, 0.03383, 0.03251, 0.03225, 0.02968, 0.02907,
                        0.02911, 0.02874, 0.02715, 0.02836, 0.02799, 0.02838, 0.02980,
                        0.03086, 0.03088, 0.03024, 0.02913, 0.02904, 0.02949, 0.02982, 0.02639],
                       [0.03140, 0.03175, 0.03117, 0.03097, 0.03093, 0.02985, 0.03104,
                        0.02983, 0.03067, 0.02975, 0.02942, 0.02822, 0.02680, 0.02597,
                        0.02651, 0.02530, 0.02522, 0.02507, 0.02581, 0.02620, 0.02666,
                        0.02674, 0.02729, 0.02701, 0.02545, 0.02541, 0.02625, 0.02659, 0.02382],
                       [0.02941, 0.02780, 0.02833, 0.02790, 0.02635, 0.02697, 0.02666,
                        0.02630, 0.02779, 0.02631, 0.02708, 0.02452, 0.02482, 0.02356,
                        0.02367, 0.02220, 0.02227, 0.02219, 0.02383, 0.02386, 0.02365,
                        0.02350, 0.02464, 0.02425, 0.02304, 0.02287, 0.02426, 0.02341, 0.02296],
                       [0.02648, 0.02474, 0.02563, 0.02470, 0.02262, 0.02409, 0.02341,
                        0.02340, 0.02539, 0.02391, 0.02396, 0.02230, 0.02305, 0.02154,
                        0.02062, 0.01966, 0.01940, 0.02049, 0.02123, 0.02127, 0.02152,
                        0.02185, 0.02283, 0.02173, 0.02093, 0.02172, 0.02232, 0.02106, 0.02115],
                       [0.02277, 0.02198, 0.02208, 0.02144, 0.02150, 0.02181, 0.02140,
                        0.02131, 0.02254, 0.02274, 0.02086, 0.02071, 0.02107, 0.01941,
                        0.01789, 0.01758, 0.01723, 0.01778, 0.01814, 0.01839, 0.02017,
                        0.02001, 0.02084, 0.01939, 0.01953, 0.02042, 0.01938, 0.01882, 0.01783],
                       [0.01995, 0.02058, 0.01952, 0.01962, 0.02114, 0.01975, 0.01969,
                        0.01985, 0.02005, 0.02049, 0.01844, 0.01912, 0.01854, 0.01661,
                        0.01603, 0.01594, 0.01591, 0.01624, 0.01559, 0.01597, 0.01836,
                        0.01762, 0.01753, 0.01863, 0.01768, 0.01820, 0.01684, 0.01724, 0.01544],
                       [0.01734, 0.01889, 0.01718, 0.01844, 0.01882, 0.01849, 0.01777,
                        0.01774, 0.01785, 0.01882, 0.01644, 0.01712, 0.01589, 0.01424,
                        0.01439, 0.01491, 0.01433, 0.01537, 0.01413, 0.01476, 0.01442,
                        0.01594, 0.01443, 0.01626, 0.01535, 0.01489, 0.01509, 0.01608, 0.01447],
                       [0.01600, 0.01691, 0.01558, 0.01740, 0.01585, 0.01644, 0.01619,
                        0.01614, 0.01569, 0.01678, 0.01529, 0.01489, 0.01417, 0.01347,
                        0.01274, 0.01375, 0.01218, 0.01384, 0.01348, 0.01366, 0.01141,
                        0.01491, 0.01349, 0.01320, 0.01380, 0.01238, 0.01434, 0.01474, 0.01357],
                       [0.01541, 0.01483, 0.01420, 0.01578, 0.01402, 0.01428, 0.01493,
                        0.01399, 0.01414, 0.01371, 0.01376, 0.01296, 0.01282, 0.01237,
                        0.01177, 0.01184, 0.01059, 0.01222, 0.01199, 0.01176, 0.01163,
                        0.01293, 0.01302, 0.01182, 0.01255, 0.01163, 0.01308, 0.01307, 0.01206],
                       [0.01416, 0.01276, 0.01336, 0.01336, 0.01353, 0.01363, 0.01393,
                        0.01215, 0.01333, 0.01203, 0.01220, 0.01138, 0.01148, 0.01005,
                        0.01135, 0.00987, 0.00970, 0.01145, 0.00989, 0.01011, 0.01161,
                        0.01118, 0.01204, 0.01116, 0.01104, 0.01175, 0.01154, 0.01136, 0.01043],
                       [0.01232, 0.01183, 0.01217, 0.01129, 0.01310, 0.01244, 0.01309,
                        0.01190, 0.01295, 0.01152, 0.01114, 0.01141, 0.01052, 0.00904,
                        0.01105, 0.00884, 0.00913, 0.01031, 0.00880, 0.00991, 0.01035,
                        0.01052, 0.01050, 0.01002, 0.01052, 0.01052, 0.00933, 0.01060, 0.00926],
                       [0.01093, 0.01091, 0.01000, 0.01036, 0.01121, 0.01120, 0.01173,
                        0.01077, 0.01173, 0.01050, 0.00972, 0.01103, 0.00942, 0.00922,
                        0.00975, 0.00829, 0.00852, 0.00857, 0.00851, 0.00965, 0.00902,
                        0.00954, 0.00903, 0.00872, 0.00967, 0.00768, 0.00775, 0.00948, 0.00835],
                       [0.00951, 0.00965, 0.00941, 0.01029, 0.00960, 0.00966, 0.00918,
                        0.00927, 0.00950, 0.00992, 0.00920, 0.00915, 0.00803, 0.00809,
                        0.00815, 0.00785, 0.00819, 0.00730, 0.00747, 0.00798, 0.00787,
                        0.00900, 0.00857, 0.00779, 0.00817, 0.00620, 0.00795, 0.00801, 0.00749],
                       [0.00764, 0.00853, 0.00850, 0.00931, 0.00911, 0.00787, 0.00748,
                        0.00905, 0.00733, 0.00963, 0.00828, 0.00748, 0.00665, 0.00609,
                        0.00656, 0.00660, 0.00709, 0.00630, 0.00623, 0.00663, 0.00741,
                        0.00831, 0.00829, 0.00706, 0.00707, 0.00625, 0.00782, 0.00674, 0.00680],
                       [0.00740, 0.00800, 0.00726, 0.00800, 0.00845, 0.00747, 0.00761,
                        0.00897, 0.00658, 0.00820, 0.00703, 0.00755, 0.00635, 0.00583,
                        0.00597, 0.00626, 0.00612, 0.00558, 0.00577, 0.00638, 0.00729,
                        0.00761, 0.00712, 0.00681, 0.00601, 0.00659, 0.00768, 0.00627, 0.00632],
                       [0.00748, 0.00766, 0.00648, 0.00722, 0.00698, 0.00717, 0.00686,
                        0.00742, 0.00644, 0.00662, 0.00640, 0.00703, 0.00623, 0.00546,
                        0.00540, 0.00626, 0.00559, 0.00518, 0.00547, 0.00511, 0.00598,
                        0.00692, 0.00617, 0.00659, 0.00462, 0.00637, 0.00654, 0.00586, 0.00486],
                       [0.00721, 0.00686, 0.00603, 0.00670, 0.00577, 0.00693, 0.00616,
                        0.00643, 0.00665, 0.00660, 0.00606, 0.00530, 0.00539, 0.00545,
                        0.00488, 0.00572, 0.00572, 0.00567, 0.00518, 0.00469, 0.00527,
                        0.00547, 0.00559, 0.00703, 0.00440, 0.00595, 0.00560, 0.00542, 0.00334],
                       [0.00656, 0.00527, 0.00590, 0.00575, 0.00527, 0.00598, 0.00646,
                        0.00645, 0.00671, 0.00623, 0.00537, 0.00399, 0.00513, 0.00556,
                        0.00510, 0.00526, 0.00576, 0.00588, 0.00496, 0.00533, 0.00584,
                        0.00397, 0.00486, 0.00620, 0.00498, 0.00526, 0.00484, 0.00471, 0.00421],
                       [0.00591, 0.00421, 0.00589, 0.00544, 0.00543, 0.00439, 0.00612,
                        0.00596, 0.00620, 0.00551, 0.00449, 0.00474, 0.00550, 0.00546,
                        0.00502, 0.00398, 0.00491, 0.00455, 0.00528, 0.00563, 0.00635,
                        0.00393, 0.00351, 0.00424, 0.00511, 0.00446, 0.00388, 0.00463, 0.00525],
                       [0.00527, 0.00412, 0.00489, 0.00499, 0.00547, 0.00405, 0.00458,
                        0.00462, 0.00532, 0.00573, 0.00401, 0.00556, 0.00523, 0.00472,
                        0.00439, 0.00288, 0.00382, 0.00376, 0.00487, 0.00510, 0.00550,
                        0.00377, 0.00271, 0.00312, 0.00473, 0.00451, 0.00433, 0.00484, 0.00411],
                       [0.00497, 0.00486, 0.00369, 0.00395, 0.00511, 0.00439, 0.00406,
                        0.00413, 0.00440, 0.00538, 0.00392, 0.00533, 0.00362, 0.00398,
                        0.00376, 0.00323, 0.00294, 0.00424, 0.00398, 0.00411, 0.00393,
                        0.00318, 0.00320, 0.00334, 0.00400, 0.00438, 0.00522, 0.00427, 0.00331],
                       [0.00527, 0.00457, 0.00341, 0.00328, 0.00419, 0.00408, 0.00417,
                        0.00516, 0.00367, 0.00395, 0.00344, 0.00415, 0.00301, 0.00350,
                        0.00318, 0.00496, 0.00318, 0.00422, 0.00334, 0.00359, 0.00299,
                        0.00358, 0.00360, 0.00407, 0.00346, 0.00390, 0.00423, 0.00386, 0.00385],
                       [0.00515, 0.00341, 0.00392, 0.00361, 0.00292, 0.00359, 0.00405,
                        0.00508, 0.00301, 0.00327, 0.00274, 0.00296, 0.00370, 0.00349,
                        0.00222, 0.00526, 0.00355, 0.00301, 0.00288, 0.00309, 0.00246,
                        0.00335, 0.00366, 0.00322, 0.00363, 0.00291, 0.00299, 0.00343, 0.00417],
                       [0.00402, 0.00376, 0.00386, 0.00381, 0.00286, 0.00366, 0.00411,
                        0.00360, 0.00361, 0.00390, 0.00315, 0.00304, 0.00389, 0.00425,
                        0.00227, 0.00376, 0.00353, 0.00205, 0.00285, 0.00304, 0.00254,
                        0.00311, 0.00425, 0.00311, 0.00327, 0.00342, 0.00379, 0.00350, 0.00389],
                       [0.00285, 0.00420, 0.00324, 0.00348, 0.00373, 0.00327, 0.00324,
                        0.00247, 0.00429, 0.00382, 0.00323, 0.00309, 0.00267, 0.00465,
                        0.00305, 0.00266, 0.00298, 0.00227, 0.00317, 0.00277, 0.00248,
                        0.00315, 0.00336, 0.00300, 0.00317, 0.00386, 0.00428, 0.00403, 0.00275],
                       [0.00295, 0.00389, 0.00334, 0.00384, 0.00383, 0.00293, 0.00234,
                        0.00320, 0.00348, 0.00370, 0.00282, 0.00330, 0.00239, 0.00381,
                        0.00278, 0.00244, 0.00203, 0.00289, 0.00338, 0.00260, 0.00268,
                        0.00274, 0.00194, 0.00312, 0.00347, 0.00324, 0.00309, 0.00403, 0.00251],
                       [0.00281, 0.00386, 0.00388, 0.00417, 0.00317, 0.00353, 0.00234,
                        0.00382, 0.00225, 0.00356, 0.00325, 0.00241, 0.00267, 0.00245,
                        0.00229, 0.00218, 0.00128, 0.00282, 0.00265, 0.00292, 0.00269,
                        0.00212, 0.00208, 0.00309, 0.00330, 0.00251, 0.00188, 0.00330, 0.00237],
                       [0.00252, 0.00350, 0.00347, 0.00416, 0.00303, 0.00402, 0.00273,
                        0.00323, 0.00234, 0.00334, 0.00326, 0.00238, 0.00294, 0.00227,
                        0.00227, 0.00257, 0.00244, 0.00192, 0.00199, 0.00268, 0.00205,
                        0.00234, 0.00283, 0.00267, 0.00263, 0.00223, 0.00180, 0.00254, 0.00230],
                       [0.00255, 0.00231, 0.00277, 0.00329, 0.00278, 0.00327, 0.00261,
                        0.00235, 0.00276, 0.00242, 0.00186, 0.00330, 0.00243, 0.00274,
                        0.00230, 0.00275, 0.00303, 0.00189, 0.00248, 0.00233, 0.00191,
                        0.00165, 0.00275, 0.00211, 0.00171, 0.00216, 0.00217, 0.00207, 0.00205],
                       [0.00214, 0.00147, 0.00230, 0.00243, 0.00186, 0.00190, 0.00161,
                        0.00241, 0.00248, 0.00199, 0.00154, 0.00345, 0.00240, 0.00265,
                        0.00206, 0.00180, 0.00211, 0.00215, 0.00283, 0.00210, 0.00220,
                        0.00189, 0.00228, 0.00203, 0.00131, 0.00224, 0.00258, 0.00184, 0.00135],
                       [0.00141, 0.00223, 0.00181, 0.00213, 0.00188, 0.00212, 0.00209,
                        0.00249, 0.00236, 0.00233, 0.00167, 0.00233, 0.00225, 0.00223,
                        0.00218, 0.00188, 0.00153, 0.00203, 0.00272, 0.00273, 0.00248,
                        0.00205, 0.00229, 0.00236, 0.00198, 0.00280, 0.00256, 0.00226, 0.00157],
                       [0.00114, 0.00320, 0.00140, 0.00202, 0.00163, 0.00297, 0.00257,
                        0.00256, 0.00184, 0.00249, 0.00115, 0.00110, 0.00207, 0.00191,
                        0.00165, 0.00186, 0.00184, 0.00165, 0.00216, 0.00286, 0.00201,
                        0.00143, 0.00206, 0.00205, 0.00222, 0.00259, 0.00206, 0.00245, 0.00201],
                       [0.00239, 0.00273, 0.00175, 0.00260, 0.00127, 0.00251, 0.00174,
                        0.00197, 0.00260, 0.00251, 0.00253, 0.00145, 0.00262, 0.00152,
                        0.00108, 0.00234, 0.00220, 0.00163, 0.00205, 0.00196, 0.00135,
                        0.00154, 0.00190, 0.00195, 0.00250, 0.00189, 0.00205, 0.00196, 0.00225],
                       [0.00238, 0.00169, 0.00261, 0.00268, 0.00166, 0.00159, 0.00169,
                        0.00157, 0.00281, 0.00192, 0.00285, 0.00187, 0.00199, 0.00165,
                        0.00109, 0.00185, 0.00178, 0.00218, 0.00235, 0.00177, 0.00252,
                        0.00176, 0.00202, 0.00210, 0.00186, 0.00143, 0.00147, 0.00154, 0.00203],
                       [0.00169, 0.00157, 0.00244, 0.00253, 0.00288, 0.00257, 0.00171,
                        0.00192, 0.00237, 0.00125, 0.00221, 0.00148, 0.00138, 0.00149,
                        0.00110, 0.00107, 0.00190, 0.00175, 0.00165, 0.00148, 0.00246,
                        0.00225, 0.00222, 0.00157, 0.00159, 0.00250, 0.00166, 0.00116, 0.00274],
                       [0.00139, 0.00172, 0.00134, 0.00218, 0.00288, 0.00279, 0.00181,
                        0.00193, 0.00157, 0.00081, 0.00151, 0.00151, 0.00134, 0.00247,
                        0.00143, 0.00149, 0.00238, 0.00174, 0.00157, 0.00090, 0.00206,
                        0.00244, 0.00198, 0.00133, 0.00187, 0.00305, 0.00126, 0.00119, 0.00238],
                       ])),
    y=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                            100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                            180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                            260.0, 270.0, 280.0]),
           lam=np.array([900.06, 900.51, 900.96, 901.41, 901.86, 902.31, 902.76, 903.21,
                         903.66, 904.11, 904.56, 905.01, 905.46, 905.91, 906.36, 906.81,
                         907.26, 907.71, 908.16, 908.61, 909.06, 909.52, 909.97, 910.42,
                         910.87, 911.32, 911.77, 912.22, 912.67, 913.12, 913.57, 914.02,
                         914.47, 914.92, 915.37, 915.82, 916.27, 916.72, 917.17, 917.62,
                         918.07, 918.53, 918.98, 919.43, 919.88, 920.33, 920.78, 921.23,
                         921.68, 922.13, 922.58, 923.03, 923.48, 923.94, 924.39, 924.84,
                         925.29, 925.74, 926.19, 926.64, 927.09, 927.54, 927.99, 928.45,
                         928.90, 929.35, 929.80, 930.25, 930.70, 931.15, 931.60, 932.06,
                         932.51, 932.96, 933.41, 933.86, 934.31, 934.76, 935.22, 935.67,
                         936.12, 936.57, 937.02, 937.47, 937.92, 938.38, 938.83, 939.28,
                         939.73, 940.18, 940.63, 941.09, 941.54, 941.99, 942.44, 942.89,
                         943.34, 943.80, 944.25, 944.70, 945.15, 945.60, 946.06, 946.51,
                         946.96, 947.41, 947.86, 948.31, 948.77, 949.22, 949.67, 950.12,
                         950.58, 951.03, 951.48, 951.93, 952.38, 952.84, 953.29, 953.74,
                         954.19, 954.64, 955.10, 955.55, 956.00, 956.45, 956.91, 957.36,
                         957.81, 958.26, 958.72, 959.17, 959.62, 960.07, 960.52, 960.98,
                         961.43, 961.88, 962.33, 962.79, 963.24, 963.69, 964.15, 964.60,
                         965.05, 965.50, 965.96, 966.41, 966.86, 967.31, 967.77, 968.22,
                         968.67, 969.12, 969.58, 970.03, 970.48, 970.94, 971.39, 971.84,
                         972.29, 972.75, 973.20, 973.65, 974.11, 974.56, 975.01, 975.47,
                         975.92, 976.37, 976.82, 977.28, 977.73, 978.18, 978.64, 979.09,
                         979.54, 980.00, 980.45, 980.90, 981.36, 981.81, 982.26, 982.71,
                         983.17, 983.62, 984.07, 984.53, 984.98, 985.43, 985.89, 986.34,
                         986.79, 987.25, 987.70, 988.15, 988.61, 989.06, 989.52, 989.97,
                         990.42, 990.88, 991.33, 991.78, 992.24, 992.69, 993.14, 993.60,
                         994.05, 994.50, 994.96, 995.41, 995.86, 996.32, 996.77, 997.23,
                         997.68, 998.13, 998.59, 999.04, 999.49, 999.95, 1000.40,
                         1000.86, 1001.31, 1001.76, 1002.22, 1002.67, 1003.13, 1003.58,
                         1004.03, 1004.49, 1004.94, 1005.39, 1005.85, 1006.30, 1006.76,
                         1007.21, 1007.66, 1008.12, 1008.57, 1009.03, 1009.48, 1009.93,
                         1010.39, 1010.84, 1011.30, 1011.75, 1012.20, 1012.66, 1013.11,
                         1013.57, 1014.02, 1014.48, 1014.93, 1015.38, 1015.84, 1016.29,
                         1016.75, 1017.20, 1017.65, 1018.11, 1018.56, 1019.02, 1019.47,
                         1019.93, 1020.38, 1020.83, 1021.29, 1021.74, 1022.20, 1022.65,
                         1023.11, 1023.56, 1024.02, 1024.47, 1024.92, 1025.38, 1025.83,
                         1026.29, 1026.74, 1027.20, 1027.65, 1028.11, 1028.56, 1029.01,
                         1029.47, 1029.92, 1030.38, 1030.83, 1031.29, 1031.74, 1032.20,
                         1032.65, 1033.11, 1033.56, 1034.01, 1034.47, 1034.92, 1035.38,
                         1035.83, 1036.29, 1036.74, 1037.20, 1037.65, 1038.11, 1038.56,
                         1039.02, 1039.47, 1039.93, 1040.38, 1040.84, 1041.29, 1041.74,
                         1042.20, 1042.65, 1043.11, 1043.56, 1044.02, 1044.47, 1044.93,
                         1045.38, 1045.84, 1046.29, 1046.75, 1047.20, 1047.66, 1048.11,
                         1048.57, 1049.02, 1049.48, 1049.93, 1050.39, 1050.84, 1051.30,
                         1051.75, 1052.21, 1052.66, 1053.12, 1053.57, 1054.03, 1054.48,
                         1054.94, 1055.39, 1055.85, 1056.30, 1056.76, 1057.21, 1057.67,
                         1058.12, 1058.58, 1059.03, 1059.49, 1059.94, 1060.40, 1060.85,
                         1061.31, 1061.76, 1062.22, 1062.67, 1063.13, 1063.58, 1064.04,
                         1064.49, 1064.95, 1065.40, 1065.86, 1066.31, 1066.77, 1067.23,
                         1067.68, 1068.14, 1068.59, 1069.05, 1069.50, 1069.96, 1070.41,
                         1070.87, 1071.32, 1071.78, 1072.23, 1072.69, 1073.14, 1073.60,
                         1074.05, 1074.51, 1074.96, 1075.42, 1075.88, 1076.33, 1076.79,
                         1077.24, 1077.70, 1078.15, 1078.61]),
           T=np.array([[0.00165, 0.00205, 0.00213, 0.00172, 0.00145, 0.00135, 0.00192,
                        0.00188, 0.00177, 0.00179, 0.00137, 0.00174, 0.00170, 0.00162,
                        0.00178, 0.00199, 0.00240, 0.00167, 0.00186, 0.00146, 0.00162,
                        0.00151, 0.00176, 0.00183, 0.00231, 0.00179, 0.00196, 0.00243, 0.00302],
                       [0.00159, 0.00212, 0.00230, 0.00188, 0.00162, 0.00157, 0.00183,
                        0.00194, 0.00196, 0.00188, 0.00146, 0.00174, 0.00170, 0.00174,
                        0.00176, 0.00181, 0.00232, 0.00182, 0.00169, 0.00149, 0.00189,
                        0.00139, 0.00155, 0.00173, 0.00221, 0.00190, 0.00202, 0.00245, 0.00316],
                       [0.00172, 0.00214, 0.00231, 0.00202, 0.00186, 0.00187, 0.00188,
                        0.00189, 0.00213, 0.00181, 0.00151, 0.00170, 0.00164, 0.00191,
                        0.00184, 0.00153, 0.00215, 0.00191, 0.00147, 0.00154, 0.00203,
                        0.00144, 0.00151, 0.00152, 0.00206, 0.00213, 0.00230, 0.00237, 0.00322],
                       [0.00194, 0.00212, 0.00227, 0.00209, 0.00200, 0.00204, 0.00200,
                        0.00184, 0.00216, 0.00160, 0.00148, 0.00178, 0.00163, 0.00204,
                        0.00185, 0.00139, 0.00201, 0.00201, 0.00139, 0.00173, 0.00202,
                        0.00172, 0.00171, 0.00149, 0.00195, 0.00238, 0.00262, 0.00240, 0.00326],
                       [0.00221, 0.00215, 0.00232, 0.00208, 0.00196, 0.00206, 0.00222,
                        0.00180, 0.00215, 0.00149, 0.00151, 0.00194, 0.00183, 0.00219,
                        0.00177, 0.00150, 0.00204, 0.00200, 0.00152, 0.00194, 0.00205,
                        0.00209, 0.00201, 0.00172, 0.00193, 0.00249, 0.00262, 0.00263, 0.00337],
                       [0.00247, 0.00228, 0.00242, 0.00202, 0.00183, 0.00203, 0.00244,
                        0.00177, 0.00225, 0.00170, 0.00168, 0.00205, 0.00203, 0.00226,
                        0.00175, 0.00166, 0.00213, 0.00189, 0.00180, 0.00199, 0.00215,
                        0.00232, 0.00225, 0.00202, 0.00197, 0.00242, 0.00234, 0.00289, 0.00363],
                       [0.00262, 0.00242, 0.00248, 0.00208, 0.00176, 0.00208, 0.00247,
                        0.00192, 0.00236, 0.00200, 0.00183, 0.00203, 0.00201, 0.00217,
                        0.00195, 0.00173, 0.00219, 0.00188, 0.00214, 0.00203, 0.00217,
                        0.00236, 0.00247, 0.00222, 0.00203, 0.00230, 0.00224, 0.00307, 0.00388],
                       [0.00262, 0.00245, 0.00253, 0.00228, 0.00179, 0.00219, 0.00238,
                        0.00216, 0.00230, 0.00221, 0.00186, 0.00195, 0.00190, 0.00200,
                        0.00216, 0.00187, 0.00220, 0.00197, 0.00238, 0.00219, 0.00213,
                        0.00230, 0.00254, 0.00223, 0.00217, 0.00235, 0.00250, 0.00313, 0.00396],
                       [0.00252, 0.00244, 0.00258, 0.00246, 0.00199, 0.00225, 0.00242,
                        0.00229, 0.00217, 0.00224, 0.00190, 0.00205, 0.00194, 0.00194,
                        0.00217, 0.00220, 0.00219, 0.00202, 0.00242, 0.00242, 0.00218,
                        0.00226, 0.00241, 0.00220, 0.00240, 0.00266, 0.00298, 0.00311, 0.00397],
                       [0.00229, 0.00258, 0.00259, 0.00254, 0.00234, 0.00220, 0.00258,
                        0.00238, 0.00217, 0.00214, 0.00202, 0.00231, 0.00222, 0.00207,
                        0.00213, 0.00250, 0.00227, 0.00201, 0.00239, 0.00253, 0.00228,
                        0.00244, 0.00224, 0.00233, 0.00254, 0.00295, 0.00339, 0.00315, 0.00409],
                       [0.00207, 0.00281, 0.00264, 0.00260, 0.00276, 0.00222, 0.00269,
                        0.00263, 0.00236, 0.00221, 0.00218, 0.00243, 0.00251, 0.00233,
                        0.00224, 0.00262, 0.00241, 0.00215, 0.00252, 0.00251, 0.00237,
                        0.00272, 0.00224, 0.00256, 0.00258, 0.00295, 0.00360, 0.00339, 0.00433],
                       [0.00216, 0.00285, 0.00276, 0.00272, 0.00314, 0.00250, 0.00270,
                        0.00303, 0.00254, 0.00254, 0.00229, 0.00231, 0.00253, 0.00252,
                        0.00234, 0.00264, 0.00243, 0.00245, 0.00278, 0.00262, 0.00248,
                        0.00284, 0.00250, 0.00266, 0.00268, 0.00282, 0.00366, 0.00379, 0.00461],
                       [0.00248, 0.00268, 0.00288, 0.00285, 0.00331, 0.00296, 0.00273,
                        0.00332, 0.00259, 0.00283, 0.00233, 0.00217, 0.00249, 0.00264,
                        0.00246, 0.00265, 0.00240, 0.00275, 0.00294, 0.00292, 0.00270,
                        0.00277, 0.00278, 0.00271, 0.00293, 0.00288, 0.00362, 0.00417, 0.00489],
                       [0.00271, 0.00262, 0.00292, 0.00292, 0.00323, 0.00323, 0.00290,
                        0.00333, 0.00265, 0.00295, 0.00234, 0.00213, 0.00264, 0.00274,
                        0.00272, 0.00268, 0.00253, 0.00286, 0.00294, 0.00312, 0.00300,
                        0.00275, 0.00286, 0.00284, 0.00317, 0.00318, 0.00351, 0.00436, 0.00520],
                       [0.00285, 0.00275, 0.00303, 0.00291, 0.00308, 0.00319, 0.00313,
                        0.00315, 0.00283, 0.00301, 0.00232, 0.00222, 0.00281, 0.00276,
                        0.00293, 0.00281, 0.00272, 0.00284, 0.00298, 0.00321, 0.00320,
                        0.00297, 0.00291, 0.00300, 0.00327, 0.00350, 0.00349, 0.00442, 0.00558],
                       [0.00315, 0.00291, 0.00326, 0.00291, 0.00308, 0.00306, 0.00324,
                        0.00301, 0.00298, 0.00311, 0.00231, 0.00250, 0.00283, 0.00264,
                        0.00295, 0.00300, 0.00290, 0.00286, 0.00316, 0.00326, 0.00323,
                        0.00324, 0.00308, 0.00310, 0.00331, 0.00373, 0.00367, 0.00463, 0.00597],
                       [0.00349, 0.00303, 0.00334, 0.00314, 0.00320, 0.00305, 0.00314,
                        0.00300, 0.00306, 0.00327, 0.00235, 0.00291, 0.00284, 0.00251,
                        0.00298, 0.00306, 0.00306, 0.00300, 0.00347, 0.00320, 0.00322,
                        0.00335, 0.00330, 0.00318, 0.00341, 0.00394, 0.00397, 0.00499, 0.00639],
                       [0.00358, 0.00313, 0.00327, 0.00347, 0.00328, 0.00319, 0.00304,
                        0.00298, 0.00315, 0.00337, 0.00251, 0.00317, 0.00297, 0.00260,
                        0.00311, 0.00296, 0.00324, 0.00314, 0.00374, 0.00310, 0.00336,
                        0.00342, 0.00349, 0.00334, 0.00354, 0.00420, 0.00432, 0.00525, 0.00692],
                       [0.00345, 0.00327, 0.00338, 0.00359, 0.00323, 0.00348, 0.00298,
                        0.00297, 0.00316, 0.00334, 0.00267, 0.00313, 0.00316, 0.00283,
                        0.00315, 0.00288, 0.00334, 0.00322, 0.00369, 0.00312, 0.00353,
                        0.00353, 0.00356, 0.00361, 0.00364, 0.00442, 0.00470, 0.00531, 0.00744],
                       [0.00337, 0.00336, 0.00370, 0.00352, 0.00320, 0.00375, 0.00295,
                        0.00309, 0.00304, 0.00326, 0.00286, 0.00302, 0.00329, 0.00291,
                        0.00307, 0.00297, 0.00337, 0.00335, 0.00342, 0.00323, 0.00362,
                        0.00366, 0.00357, 0.00391, 0.00386, 0.00454, 0.00504, 0.00540, 0.00784],
                       [0.00352, 0.00342, 0.00391, 0.00343, 0.00327, 0.00383, 0.00305,
                        0.00334, 0.00303, 0.00317, 0.00316, 0.00304, 0.00318, 0.00287,
                        0.00307, 0.00329, 0.00349, 0.00362, 0.00327, 0.00339, 0.00364,
                        0.00379, 0.00362, 0.00417, 0.00429, 0.00460, 0.00519, 0.00568, 0.00813],
                       [0.00375, 0.00354, 0.00397, 0.00354, 0.00339, 0.00382, 0.00327,
                        0.00355, 0.00326, 0.00315, 0.00347, 0.00316, 0.00302, 0.00291,
                        0.00324, 0.00366, 0.00374, 0.00393, 0.00340, 0.00370, 0.00384,
                        0.00399, 0.00380, 0.00440, 0.00477, 0.00467, 0.00526, 0.00611, 0.00847],
                       [0.00389, 0.00384, 0.00394, 0.00389, 0.00353, 0.00391, 0.00349,
                        0.00360, 0.00350, 0.00345, 0.00365, 0.00330, 0.00322, 0.00314,
                        0.00342, 0.00382, 0.00395, 0.00415, 0.00376, 0.00410, 0.00429,
                        0.00422, 0.00414, 0.00468, 0.00500, 0.00479, 0.00542, 0.00653, 0.00905],
                       [0.00392, 0.00422, 0.00393, 0.00434, 0.00377, 0.00400, 0.00370,
                        0.00355, 0.00353, 0.00401, 0.00373, 0.00353, 0.00364, 0.00357,
                        0.00349, 0.00383, 0.00396, 0.00427, 0.00420, 0.00442, 0.00473,
                        0.00441, 0.00459, 0.00502, 0.00492, 0.00499, 0.00559, 0.00694, 0.00996],
                       [0.00392, 0.00447, 0.00406, 0.00474, 0.00407, 0.00406, 0.00390,
                        0.00360, 0.00353, 0.00440, 0.00385, 0.00387, 0.00391, 0.00399,
                        0.00357, 0.00392, 0.00396, 0.00434, 0.00452, 0.00466, 0.00505,
                        0.00463, 0.00490, 0.00526, 0.00500, 0.00524, 0.00570, 0.00750, 0.01107],
                       [0.00406, 0.00460, 0.00439, 0.00497, 0.00430, 0.00429, 0.00402,
                        0.00384, 0.00363, 0.00449, 0.00402, 0.00416, 0.00401, 0.00428,
                        0.00380, 0.00415, 0.00415, 0.00446, 0.00459, 0.00488, 0.00514,
                        0.00494, 0.00495, 0.00525, 0.00545, 0.00552, 0.00595, 0.00815, 0.01232],
                       [0.00429, 0.00471, 0.00481, 0.00511, 0.00450, 0.00469, 0.00411,
                        0.00419, 0.00379, 0.00453, 0.00416, 0.00428, 0.00414, 0.00444,
                        0.00410, 0.00454, 0.00439, 0.00453, 0.00459, 0.00506, 0.00500,
                        0.00524, 0.00492, 0.00521, 0.00591, 0.00597, 0.00652, 0.00876, 0.01359],
                       [0.00450, 0.00484, 0.00521, 0.00527, 0.00473, 0.00505, 0.00425,
                        0.00453, 0.00397, 0.00471, 0.00431, 0.00435, 0.00435, 0.00453,
                        0.00432, 0.00494, 0.00452, 0.00452, 0.00481, 0.00517, 0.00498,
                        0.00556, 0.00505, 0.00549, 0.00614, 0.00662, 0.00727, 0.00926, 0.01474],
                       [0.00466, 0.00509, 0.00551, 0.00542, 0.00497, 0.00527, 0.00446,
                        0.00479, 0.00426, 0.00495, 0.00459, 0.00442, 0.00456, 0.00462,
                        0.00447, 0.00517, 0.00460, 0.00456, 0.00517, 0.00529, 0.00531,
                        0.00584, 0.00531, 0.00594, 0.00626, 0.00727, 0.00798, 0.00969, 0.01592],
                       [0.00479, 0.00555, 0.00567, 0.00564, 0.00526, 0.00539, 0.00477,
                        0.00497, 0.00467, 0.00519, 0.00491, 0.00453, 0.00474, 0.00479,
                        0.00468, 0.00524, 0.00473, 0.00471, 0.00539, 0.00547, 0.00574,
                        0.00600, 0.00566, 0.00622, 0.00650, 0.00767, 0.00854, 0.01017, 0.01750],
                       [0.00514, 0.00610, 0.00585, 0.00593, 0.00566, 0.00555, 0.00516,
                        0.00516, 0.00515, 0.00530, 0.00511, 0.00472, 0.00497, 0.00503,
                        0.00495, 0.00538, 0.00488, 0.00503, 0.00550, 0.00566, 0.00603,
                        0.00619, 0.00621, 0.00645, 0.00687, 0.00790, 0.00893, 0.01084, 0.01962],
                       [0.00571, 0.00655, 0.00622, 0.00625, 0.00618, 0.00592, 0.00563,
                        0.00548, 0.00553, 0.00534, 0.00524, 0.00502, 0.00524, 0.00535,
                        0.00524, 0.00561, 0.00508, 0.00541, 0.00566, 0.00590, 0.00624,
                        0.00658, 0.00687, 0.00682, 0.00732, 0.00822, 0.00937, 0.01178, 0.02209],
                       [0.00618, 0.00694, 0.00676, 0.00669, 0.00665, 0.00644, 0.00608,
                        0.00598, 0.00578, 0.00549, 0.00545, 0.00545, 0.00538, 0.00564,
                        0.00559, 0.00576, 0.00539, 0.00569, 0.00594, 0.00627, 0.00647,
                        0.00713, 0.00734, 0.00726, 0.00789, 0.00876, 0.01004, 0.01291, 0.02482],
                       [0.00670, 0.00747, 0.00747, 0.00725, 0.00700, 0.00702, 0.00647,
                        0.00646, 0.00606, 0.00582, 0.00573, 0.00598, 0.00535, 0.00576,
                        0.00608, 0.00593, 0.00588, 0.00589, 0.00627, 0.00684, 0.00673,
                        0.00766, 0.00755, 0.00768, 0.00849, 0.00946, 0.01095, 0.01426, 0.02775],
                       [0.00766, 0.00822, 0.00825, 0.00796, 0.00739, 0.00749, 0.00695,
                        0.00685, 0.00645, 0.00621, 0.00603, 0.00645, 0.00529, 0.00590,
                        0.00657, 0.00634, 0.00648, 0.00609, 0.00660, 0.00754, 0.00707,
                        0.00816, 0.00777, 0.00804, 0.00906, 0.01032, 0.01208, 0.01582, 0.03087],
                       [0.00888, 0.00909, 0.00902, 0.00881, 0.00805, 0.00788, 0.00773,
                        0.00732, 0.00687, 0.00671, 0.00649, 0.00681, 0.00551, 0.00636,
                        0.00691, 0.00695, 0.00707, 0.00640, 0.00707, 0.00820, 0.00761,
                        0.00866, 0.00828, 0.00846, 0.00974, 0.01129, 0.01343, 0.01753, 0.03430],
                       [0.00985, 0.00991, 0.00987, 0.00971, 0.00908, 0.00858, 0.00867,
                        0.00800, 0.00731, 0.00732, 0.00712, 0.00717, 0.00622, 0.00707,
                        0.00709, 0.00750, 0.00769, 0.00695, 0.00774, 0.00876, 0.00839,
                        0.00914, 0.00895, 0.00915, 0.01065, 0.01224, 0.01477, 0.01937, 0.03807],
                       [0.01067, 0.01070, 0.01084, 0.01073, 0.01041, 0.00977, 0.00957,
                        0.00894, 0.00787, 0.00798, 0.00773, 0.00768, 0.00725, 0.00769,
                        0.00739, 0.00798, 0.00822, 0.00781, 0.00854, 0.00935, 0.00927,
                        0.00962, 0.00963, 0.01007, 0.01159, 0.01323, 0.01595, 0.02155, 0.04233],
                       [0.01166, 0.01170, 0.01195, 0.01204, 0.01175, 0.01104, 0.01034,
                        0.01002, 0.00869, 0.00861, 0.00826, 0.00834, 0.00830, 0.00811,
                        0.00799, 0.00855, 0.00861, 0.00880, 0.00938, 0.00997, 0.01005,
                        0.01024, 0.01055, 0.01107, 0.01243, 0.01431, 0.01723, 0.02425, 0.04727],
                       [0.01292, 0.01308, 0.01318, 0.01358, 0.01292, 0.01219, 0.01118,
                        0.01103, 0.00980, 0.00932, 0.00890, 0.00908, 0.00924, 0.00870,
                        0.00880, 0.00937, 0.00924, 0.00972, 0.01011, 0.01069, 0.01077,
                        0.01113, 0.01170, 0.01219, 0.01345, 0.01565, 0.01887, 0.02735, 0.05301],
                       [0.01442, 0.01471, 0.01462, 0.01515, 0.01413, 0.01343, 0.01230,
                        0.01203, 0.01096, 0.01032, 0.00974, 0.00995, 0.01002, 0.00965,
                        0.00973, 0.01042, 0.01019, 0.01052, 0.01088, 0.01155, 0.01173,
                        0.01226, 0.01286, 0.01357, 0.01482, 0.01752, 0.02103, 0.03064, 0.05954],
                       [0.01627, 0.01653, 0.01645, 0.01674, 0.01574, 0.01502, 0.01383,
                        0.01326, 0.01198, 0.01171, 0.01080, 0.01109, 0.01079, 0.01085,
                        0.01076, 0.01144, 0.01124, 0.01145, 0.01190, 0.01251, 0.01309,
                        0.01354, 0.01406, 0.01516, 0.01639, 0.01980, 0.02373, 0.03435, 0.06678],
                       [0.01852, 0.01866, 0.01862, 0.01860, 0.01782, 0.01698, 0.01581,
                        0.01470, 0.01317, 0.01329, 0.01204, 0.01232, 0.01169, 0.01201,
                        0.01184, 0.01231, 0.01221, 0.01275, 0.01316, 0.01361, 0.01450,
                        0.01495, 0.01555, 0.01695, 0.01817, 0.02210, 0.02693, 0.03885, 0.07474],
                       [0.02113, 0.02122, 0.02106, 0.02089, 0.02023, 0.01931, 0.01792,
                        0.01639, 0.01488, 0.01488, 0.01358, 0.01342, 0.01280, 0.01315,
                        0.01312, 0.01333, 0.01336, 0.01440, 0.01454, 0.01520, 0.01589,
                        0.01659, 0.01734, 0.01898, 0.02028, 0.02444, 0.03066, 0.04424, 0.08349],
                       [0.02401, 0.02420, 0.02382, 0.02359, 0.02289, 0.02189, 0.02006,
                        0.01856, 0.01703, 0.01644, 0.01533, 0.01449, 0.01430, 0.01445,
                        0.01462, 0.01476, 0.01501, 0.01613, 0.01608, 0.01723, 0.01750,
                        0.01847, 0.01930, 0.02115, 0.02272, 0.02727, 0.03473, 0.05040, 0.09294],
                       [0.02727, 0.02755, 0.02700, 0.02674, 0.02583, 0.02472, 0.02263,
                        0.02129, 0.01941, 0.01801, 0.01721, 0.01585, 0.01621, 0.01601,
                        0.01629, 0.01662, 0.01706, 0.01793, 0.01799, 0.01932, 0.01949,
                        0.02056, 0.02153, 0.02353, 0.02555, 0.03075, 0.03912, 0.05726, 0.10317],
                       [0.03096, 0.03119, 0.03070, 0.03028, 0.02927, 0.02802, 0.02580,
                        0.02436, 0.02201, 0.01990, 0.01932, 0.01784, 0.01836, 0.01797,
                        0.01824, 0.01875, 0.01923, 0.02003, 0.02034, 0.02141, 0.02193,
                        0.02301, 0.02425, 0.02633, 0.02896, 0.03468, 0.04429, 0.06476, 0.11441],
                       [0.03505, 0.03502, 0.03494, 0.03424, 0.03329, 0.03193, 0.02937,
                        0.02755, 0.02495, 0.02258, 0.02172, 0.02040, 0.02062, 0.02041,
                        0.02062, 0.02113, 0.02164, 0.02249, 0.02314, 0.02394, 0.02481,
                        0.02593, 0.02757, 0.02957, 0.03299, 0.03910, 0.05047, 0.07308, 0.12688],
                       [0.03961, 0.03924, 0.03959, 0.03892, 0.03770, 0.03641, 0.03329,
                        0.03089, 0.02828, 0.02597, 0.02453, 0.02323, 0.02310, 0.02315,
                        0.02350, 0.02387, 0.02463, 0.02531, 0.02635, 0.02715, 0.02810,
                        0.02928, 0.03131, 0.03323, 0.03748, 0.04433, 0.05751, 0.08257, 0.14076],
                       [0.04462, 0.04413, 0.04463, 0.04440, 0.04250, 0.04129, 0.03775,
                        0.03456, 0.03196, 0.02964, 0.02781, 0.02635, 0.02605, 0.02615,
                        0.02677, 0.02707, 0.02811, 0.02861, 0.02986, 0.03083, 0.03185,
                        0.03308, 0.03545, 0.03749, 0.04249, 0.05045, 0.06541, 0.09334, 0.15605],
                       [0.05023, 0.04985, 0.05029, 0.05029, 0.04798, 0.04646, 0.04282,
                        0.03894, 0.03612, 0.03358, 0.03155, 0.02990, 0.02970, 0.02972,
                        0.03018, 0.03072, 0.03185, 0.03249, 0.03373, 0.03491, 0.03621,
                        0.03751, 0.04016, 0.04261, 0.04826, 0.05737, 0.07430, 0.10533, 0.17262],
                       [0.05661, 0.05642, 0.05676, 0.05638, 0.05430, 0.05212, 0.04842,
                        0.04418, 0.04093, 0.03800, 0.03572, 0.03378, 0.03395, 0.03384,
                        0.03390, 0.03481, 0.03582, 0.03691, 0.03812, 0.03963, 0.04117,
                        0.04266, 0.04549, 0.04871, 0.05485, 0.06515, 0.08410, 0.11843, 0.19011],
                       [0.06368, 0.06369, 0.06404, 0.06293, 0.06128, 0.05843, 0.05454,
                        0.05008, 0.04629, 0.04290, 0.04042, 0.03812, 0.03853, 0.03827,
                        0.03834, 0.03959, 0.04033, 0.04187, 0.04317, 0.04495, 0.04670,
                        0.04860, 0.05156, 0.05555, 0.06233, 0.07400, 0.09474, 0.13242, 0.20827],
                       [0.07134, 0.07144, 0.07199, 0.07036, 0.06879, 0.06533, 0.06118,
                        0.05644, 0.05202, 0.04830, 0.04564, 0.04328, 0.04342, 0.04304,
                        0.04354, 0.04517, 0.04580, 0.04750, 0.04900, 0.05086, 0.05286,
                        0.05525, 0.05841, 0.06311, 0.07079, 0.08391, 0.10645, 0.14736, 0.22745],
                       [0.07960, 0.07956, 0.08042, 0.07868, 0.07683, 0.07282, 0.06843,
                        0.06318, 0.05831, 0.05426, 0.05136, 0.04931, 0.04877, 0.04838,
                        0.04941, 0.05136, 0.05229, 0.05399, 0.05564, 0.05764, 0.05982,
                        0.06262, 0.06614, 0.07145, 0.08023, 0.09483, 0.11946, 0.16360, 0.24796],
                       [0.08850, 0.08829, 0.08941, 0.08772, 0.08551, 0.08108, 0.07643,
                        0.07055, 0.06554, 0.06082, 0.05776, 0.05604, 0.05490, 0.05458,
                        0.05595, 0.05798, 0.05952, 0.06132, 0.06307, 0.06540, 0.06771,
                        0.07085, 0.07493, 0.08071, 0.09065, 0.10680, 0.13370, 0.18134, 0.26968],
                       [0.09817, 0.09794, 0.09915, 0.09750, 0.09505, 0.09023, 0.08511,
                        0.07873, 0.07370, 0.06811, 0.06493, 0.06322, 0.06200, 0.06162,
                        0.06308, 0.06506, 0.06718, 0.06939, 0.07128, 0.07405, 0.07641,
                        0.07991, 0.08473, 0.09110, 0.10199, 0.11989, 0.14916, 0.20051, 0.29241],
                       [0.10877, 0.10878, 0.10975, 0.10823, 0.10565, 0.10034, 0.09462,
                        0.08793, 0.08254, 0.07638, 0.07280, 0.07074, 0.06981, 0.06930,
                        0.07083, 0.07285, 0.07535, 0.07819, 0.08035, 0.08357, 0.08608,
                        0.09013, 0.09547, 0.10279, 0.11456, 0.13434, 0.16600, 0.22101, 0.31602],
                       [0.12032, 0.12068, 0.12120, 0.11984, 0.11718, 0.11138, 0.10527,
                        0.09830, 0.09196, 0.08566, 0.08136, 0.07892, 0.07800, 0.07778,
                        0.07949, 0.08160, 0.08436, 0.08782, 0.09040, 0.09404, 0.09704,
                        0.10187, 0.10727, 0.11564, 0.12871, 0.15028, 0.18429, 0.24290, 0.34045],
                       [0.13274, 0.13313, 0.13360, 0.13229, 0.12932, 0.12318, 0.11690,
                        0.10963, 0.10205, 0.09578, 0.09077, 0.08808, 0.08672, 0.08712,
                        0.08908, 0.09133, 0.09456, 0.09840, 0.10153, 0.10564, 0.10925,
                        0.11487, 0.12031, 0.12949, 0.14414, 0.16743, 0.20409, 0.26607, 0.36556],
                       [0.14595, 0.14594, 0.14673, 0.14557, 0.14193, 0.13559, 0.12901,
                        0.12149, 0.11282, 0.10642, 0.10098, 0.09808, 0.09644, 0.09714,
                        0.09946, 0.10202, 0.10580, 0.10997, 0.11369, 0.11813, 0.12239,
                        0.12837, 0.13449, 0.14421, 0.16026, 0.18538, 0.22520, 0.29001, 0.39068],
                       [0.15995, 0.15959, 0.16051, 0.15969, 0.15531, 0.14889, 0.14159,
                        0.13378, 0.12435, 0.11757, 0.11197, 0.10892, 0.10733, 0.10812,
                        0.11064, 0.11367, 0.11776, 0.12246, 0.12673, 0.13117, 0.13626,
                        0.14235, 0.14969, 0.16000, 0.17714, 0.20410, 0.24722, 0.31419, 0.41540],
                       [0.17487, 0.17461, 0.17522, 0.17459, 0.16988, 0.16319, 0.15503,
                        0.14678, 0.13690, 0.12958, 0.12396, 0.12076, 0.11924, 0.12036,
                        0.12285, 0.12630, 0.13046, 0.13585, 0.14059, 0.14508, 0.15103,
                        0.15741, 0.16591, 0.17718, 0.19538, 0.22407, 0.26998, 0.33866, 0.44021],
                       [0.19083, 0.19103, 0.19113, 0.19034, 0.18560, 0.17825, 0.16955,
                        0.16058, 0.15062, 0.14262, 0.13699, 0.13354, 0.13206, 0.13358,
                        0.13631, 0.13997, 0.14434, 0.15027, 0.15539, 0.16052, 0.16698,
                        0.17411, 0.18319, 0.19578, 0.21533, 0.24568, 0.29355, 0.36384, 0.46564],
                       [0.20783, 0.20844, 0.20821, 0.20718, 0.20214, 0.19418, 0.18497,
                        0.17506, 0.16532, 0.15658, 0.15081, 0.14704, 0.14571, 0.14744,
                        0.15073, 0.15446, 0.15949, 0.16554, 0.17112, 0.17736, 0.18433,
                        0.19236, 0.20161, 0.21555, 0.23662, 0.26842, 0.31782, 0.38985, 0.49147],
                       [0.22589, 0.22658, 0.22627, 0.22512, 0.21962, 0.21124, 0.20115,
                        0.19059, 0.18085, 0.17139, 0.16523, 0.16120, 0.16022, 0.16194,
                        0.16574, 0.16961, 0.17552, 0.18162, 0.18784, 0.19505, 0.20288,
                        0.21159, 0.22125, 0.23623, 0.25869, 0.29182, 0.34255, 0.41652, 0.51700],
                       [0.24508, 0.24564, 0.24545, 0.24390, 0.23844, 0.22940, 0.21843,
                        0.20764, 0.19715, 0.18721, 0.18043, 0.17620, 0.17563, 0.17729,
                        0.18146, 0.18551, 0.19219, 0.19888, 0.20569, 0.21348, 0.22224,
                        0.23145, 0.24183, 0.25770, 0.28124, 0.31613, 0.36786, 0.44346, 0.54154],
                       [0.26522, 0.26577, 0.26567, 0.26354, 0.25854, 0.24873, 0.23720,
                        0.22597, 0.21424, 0.20409, 0.19654, 0.19236, 0.19178, 0.19368,
                        0.19821, 0.20252, 0.20971, 0.21744, 0.22475, 0.23277, 0.24228,
                        0.25203, 0.26313, 0.27991, 0.30423, 0.34128, 0.39379, 0.47009, 0.56492],
                       [0.28619, 0.28685, 0.28682, 0.28450, 0.27959, 0.26914, 0.25723,
                        0.24512, 0.23235, 0.22188, 0.21359, 0.20967, 0.20857, 0.21110,
                        0.21598, 0.22073, 0.22824, 0.23695, 0.24499, 0.25290, 0.26323,
                        0.27349, 0.28552, 0.30295, 0.32802, 0.36650, 0.42011, 0.49636, 0.58781],
                       [0.30820, 0.30886, 0.30918, 0.30704, 0.30143, 0.29041, 0.27819,
                        0.26493, 0.25190, 0.24042, 0.23177, 0.22781, 0.22628, 0.22933,
                        0.23452, 0.23993, 0.24777, 0.25703, 0.26618, 0.27404, 0.28513,
                        0.29580, 0.30907, 0.32688, 0.35274, 0.39154, 0.44664, 0.52246, 0.61080],
                       [0.33149, 0.33203, 0.33280, 0.33088, 0.32411, 0.31270, 0.30009,
                        0.28556, 0.27280, 0.25971, 0.25126, 0.24667, 0.24526, 0.24821,
                        0.25365, 0.25995, 0.26827, 0.27767, 0.28778, 0.29617, 0.30762,
                        0.31879, 0.33322, 0.35137, 0.37808, 0.41691, 0.47325, 0.54840, 0.63373],
                       [0.35602, 0.35650, 0.35752, 0.35583, 0.34786, 0.33618, 0.32287,
                        0.30737, 0.29436, 0.27994, 0.27165, 0.26640, 0.26547, 0.26791,
                        0.27364, 0.28062, 0.28951, 0.29923, 0.30956, 0.31893, 0.33029,
                        0.34229, 0.35757, 0.37593, 0.40360, 0.44274, 0.49942, 0.57391, 0.65606],
                       [0.38192, 0.38212, 0.38358, 0.38180, 0.37292, 0.36079, 0.34636,
                        0.33073, 0.31623, 0.30136, 0.29258, 0.28726, 0.28652, 0.28873,
                        0.29492, 0.30196, 0.31129, 0.32185, 0.33177, 0.34212, 0.35323,
                        0.36616, 0.38213, 0.40077, 0.42910, 0.46874, 0.52495, 0.59874, 0.67773],
                       [0.40929, 0.40895, 0.41125, 0.40884, 0.39968, 0.38671, 0.37101,
                        0.35545, 0.33894, 0.32410, 0.31439, 0.30929, 0.30826, 0.31092,
                        0.31743, 0.32429, 0.33391, 0.34538, 0.35497, 0.36593, 0.37703,
                        0.39053, 0.40705, 0.42640, 0.45474, 0.49469, 0.55022, 0.62311, 0.69909],
                       [0.43781, 0.43721, 0.44021, 0.43722, 0.42829, 0.41417, 0.39750,
                        0.38106, 0.36324, 0.34821, 0.33756, 0.33202, 0.33073, 0.33427,
                        0.34064, 0.34781, 0.35761, 0.36947, 0.37929, 0.39044, 0.40175,
                        0.41551, 0.43225, 0.45240, 0.48057, 0.52035, 0.57549, 0.64708, 0.72008],
                       [0.46721, 0.46686, 0.47007, 0.46704, 0.45826, 0.44301, 0.42562,
                        0.40767, 0.38931, 0.37358, 0.36209, 0.35540, 0.35424, 0.35843,
                        0.36452, 0.37239, 0.38217, 0.39413, 0.40444, 0.41574, 0.42703,
                        0.44109, 0.45758, 0.47825, 0.50681, 0.54569, 0.60079, 0.67092, 0.74033],
                       [0.49779, 0.49796, 0.50103, 0.49799, 0.48898, 0.47320, 0.45484,
                        0.43589, 0.41688, 0.39985, 0.38768, 0.38012, 0.37921, 0.38345,
                        0.38943, 0.39792, 0.40754, 0.41954, 0.43042, 0.44181, 0.45307,
                        0.46716, 0.48337, 0.50424, 0.53332, 0.57144, 0.62629, 0.69513, 0.75992],
                       [0.52960, 0.53041, 0.53328, 0.52990, 0.52049, 0.50461, 0.48542,
                        0.46574, 0.44554, 0.42702, 0.41417, 0.40655, 0.40574, 0.40950,
                        0.41545, 0.42416, 0.43386, 0.44565, 0.45713, 0.46853, 0.48027,
                        0.49359, 0.50990, 0.53064, 0.55927, 0.59792, 0.65195, 0.71936, 0.77897],
                       [0.56226, 0.56360, 0.56644, 0.56283, 0.55327, 0.53699, 0.51767,
                        0.49654, 0.47511, 0.45553, 0.44185, 0.43440, 0.43337, 0.43652,
                        0.44261, 0.45092, 0.46117, 0.47253, 0.48423, 0.49587, 0.50842,
                        0.52052, 0.53692, 0.55724, 0.58471, 0.62448, 0.67723, 0.74294, 0.79733],
                       [0.59572, 0.59706, 0.60001, 0.59671, 0.58719, 0.57020, 0.55083,
                        0.52787, 0.50560, 0.48558, 0.47112, 0.46329, 0.46174, 0.46450,
                        0.47083, 0.47855, 0.48933, 0.50031, 0.51168, 0.52375, 0.53660,
                        0.54791, 0.56413, 0.58380, 0.61065, 0.65066, 0.70175, 0.76565, 0.81491],
                       [0.62981, 0.63086, 0.63382, 0.63123, 0.62151, 0.60393, 0.58377,
                        0.55991, 0.53715, 0.51703, 0.50190, 0.49314, 0.49109, 0.49359,
                        0.49973, 0.50730, 0.51807, 0.52884, 0.53996, 0.55193, 0.56422,
                        0.57554, 0.59177, 0.61045, 0.63754, 0.67654, 0.72567, 0.78757, 0.83164],
                       [0.66393, 0.66489, 0.66778, 0.66577, 0.65552, 0.63785, 0.61655,
                        0.59265, 0.56960, 0.54922, 0.53356, 0.52402, 0.52166, 0.52370,
                        0.52922, 0.53705, 0.54741, 0.55768, 0.56920, 0.58038, 0.59160,
                        0.60338, 0.61943, 0.63747, 0.66496, 0.70184, 0.74906, 0.80862, 0.84708],
                       [0.69772, 0.69877, 0.70187, 0.69981, 0.68906, 0.67195, 0.64988,
                        0.62619, 0.60303, 0.58187, 0.56557, 0.55571, 0.55337, 0.55435,
                        0.55957, 0.56754, 0.57763, 0.58690, 0.59889, 0.60919, 0.61933,
                        0.63145, 0.64665, 0.66506, 0.69210, 0.72641, 0.77222, 0.82834, 0.86098],
                       [0.73118, 0.73225, 0.73568, 0.73324, 0.72225, 0.70633, 0.68417,
                        0.66055, 0.63767, 0.61505, 0.59856, 0.58794, 0.58573, 0.58561,
                        0.59063, 0.59865, 0.60836, 0.61685, 0.62831, 0.63843, 0.64790,
                        0.65974, 0.67354, 0.69280, 0.71789, 0.75053, 0.79515, 0.84659, 0.87359],
                       [0.76372, 0.76523, 0.76824, 0.76600, 0.75506, 0.74036, 0.71891,
                        0.69506, 0.67252, 0.64851, 0.63272, 0.62044, 0.61792, 0.61772,
                        0.62204, 0.63025, 0.63896, 0.64746, 0.65729, 0.66795, 0.67717,
                        0.68794, 0.70051, 0.71960, 0.74207, 0.77404, 0.81689, 0.86356, 0.88476],
                       [0.79471, 0.79734, 0.79913, 0.79747, 0.78703, 0.77327, 0.75269,
                        0.72897, 0.70609, 0.68166, 0.66649, 0.65303, 0.64977, 0.65010,
                        0.65399, 0.66202, 0.66937, 0.67830, 0.68651, 0.69720, 0.70614,
                        0.71561, 0.72798, 0.74510, 0.76567, 0.79671, 0.83673, 0.87930, 0.89414],
                       [0.82404, 0.82718, 0.82826, 0.82656, 0.81709, 0.80411, 0.78424,
                        0.76141, 0.73785, 0.71406, 0.69858, 0.68561, 0.68153, 0.68212,
                        0.68635, 0.69328, 0.69931, 0.70861, 0.71598, 0.72554, 0.73406,
                        0.74229, 0.75494, 0.76976, 0.78912, 0.81840, 0.85497, 0.89417, 0.90208],
                       [0.85105, 0.85334, 0.85491, 0.85265, 0.84457, 0.83206, 0.81318,
                        0.79149, 0.76820, 0.74553, 0.72946, 0.71784, 0.71272, 0.71351,
                        0.71790, 0.72331, 0.72865, 0.73754, 0.74483, 0.75280, 0.76083,
                        0.76796, 0.78015, 0.79349, 0.81169, 0.83870, 0.87196, 0.90800, 0.90906],
                       [0.87521, 0.87650, 0.87861, 0.87615, 0.86961, 0.85700, 0.83971,
                        0.81941, 0.79750, 0.77625, 0.75973, 0.74924, 0.74326, 0.74416,
                        0.74775, 0.75221, 0.75803, 0.76532, 0.77232, 0.77931, 0.78631,
                        0.79290, 0.80364, 0.81579, 0.83307, 0.85710, 0.88746, 0.91966, 0.91533],
                       [0.89707, 0.89786, 0.89977, 0.89815, 0.89262, 0.87969, 0.86415,
                        0.84582, 0.82567, 0.80602, 0.78924, 0.77971, 0.77343, 0.77391,
                        0.77621, 0.78060, 0.78699, 0.79263, 0.79812, 0.80562, 0.81046,
                        0.81721, 0.82588, 0.83686, 0.85365, 0.87379, 0.90162, 0.92915, 0.92106],
                       [0.91654, 0.91678, 0.91850, 0.91849, 0.91312, 0.90035, 0.88662,
                        0.87034, 0.85222, 0.83373, 0.81777, 0.80855, 0.80239, 0.80230,
                        0.80363, 0.80843, 0.81398, 0.81872, 0.82263, 0.83112, 0.83351,
                        0.84027, 0.84707, 0.85700, 0.87318, 0.88936, 0.91435, 0.93750, 0.92616],
                       [0.93297, 0.93223, 0.93451, 0.93573, 0.93031, 0.91840, 0.90675,
                        0.89220, 0.87640, 0.85876, 0.84459, 0.83480, 0.82900, 0.82893,
                        0.82979, 0.83477, 0.83883, 0.84225, 0.84638, 0.85406, 0.85539,
                        0.86100, 0.86728, 0.87577, 0.89039, 0.90404, 0.92506, 0.94495, 0.93022],
                       [0.94608, 0.94457, 0.94777, 0.94875, 0.94396, 0.93382, 0.92383,
                        0.91112, 0.89772, 0.88169, 0.86885, 0.85856, 0.85324, 0.85334,
                        0.85420, 0.85857, 0.86196, 0.86320, 0.86859, 0.87346, 0.87520,
                        0.87921, 0.88582, 0.89262, 0.90460, 0.91732, 0.93421, 0.95113, 0.93254],
                       [0.95639, 0.95495, 0.95844, 0.95799, 0.95410, 0.94699, 0.93776,
                        0.92727, 0.91572, 0.90240, 0.89008, 0.88017, 0.87533, 0.87490,
                        0.87598, 0.87918, 0.88233, 0.88246, 0.88788, 0.89013, 0.89241,
                        0.89544, 0.90177, 0.90731, 0.91656, 0.92861, 0.94243, 0.95585, 0.93355],
                       [0.96465, 0.96387, 0.96616, 0.96476, 0.96145, 0.95784, 0.94924,
                        0.94048, 0.93034, 0.91959, 0.90831, 0.89931, 0.89494, 0.89390,
                        0.89459, 0.89685, 0.89937, 0.90003, 0.90369, 0.90531, 0.90723,
                        0.91020, 0.91478, 0.91950, 0.92688, 0.93763, 0.94905, 0.95907, 0.93423],
                       [0.97085, 0.97073, 0.97085, 0.96997, 0.96725, 0.96571, 0.95869,
                        0.95043, 0.94206, 0.93296, 0.92394, 0.91568, 0.91203, 0.91095,
                        0.91045, 0.91226, 0.91398, 0.91506, 0.91659, 0.91884, 0.92020,
                        0.92328, 0.92533, 0.92920, 0.93537, 0.94466, 0.95357, 0.96140, 0.93497],
                       [0.97490, 0.97547, 0.97384, 0.97396, 0.97199, 0.97073, 0.96636,
                        0.95818, 0.95207, 0.94386, 0.93742, 0.92953, 0.92707, 0.92590,
                        0.92478, 0.92576, 0.92726, 0.92802, 0.92807, 0.93038, 0.93182,
                        0.93391, 0.93486, 0.93786, 0.94225, 0.95041, 0.95712, 0.96390, 0.93621],
                       [0.97688, 0.97832, 0.97649, 0.97692, 0.97520, 0.97414, 0.97210,
                        0.96506, 0.96065, 0.95318, 0.94841, 0.94136, 0.93960, 0.93842,
                        0.93767, 0.93736, 0.93898, 0.93958, 0.93913, 0.94040, 0.94162,
                        0.94203, 0.94385, 0.94644, 0.94841, 0.95507, 0.96076, 0.96687, 0.93762],
                       [0.97768, 0.97943, 0.97900, 0.97926, 0.97702, 0.97666, 0.97569,
                        0.97106, 0.96731, 0.96097, 0.95714, 0.95124, 0.94956, 0.94858,
                        0.94857, 0.94717, 0.94819, 0.94929, 0.94910, 0.94876, 0.94938,
                        0.94904, 0.95143, 0.95402, 0.95450, 0.95873, 0.96396, 0.96954, 0.93814],
                       [0.97851, 0.97951, 0.98054, 0.98081, 0.97814, 0.97788, 0.97715,
                        0.97563, 0.97176, 0.96690, 0.96434, 0.95865, 0.95752, 0.95613,
                        0.95707, 0.95505, 0.95500, 0.95671, 0.95696, 0.95481, 0.95559,
                        0.95553, 0.95715, 0.95905, 0.95998, 0.96154, 0.96631, 0.97094, 0.93757],
                       [0.97905, 0.97914, 0.98031, 0.98096, 0.97843, 0.97779, 0.97706,
                        0.97806, 0.97386, 0.97107, 0.96956, 0.96385, 0.96348, 0.96162,
                        0.96227, 0.96047, 0.96015, 0.96177, 0.96267, 0.95890, 0.96048,
                        0.96002, 0.96107, 0.96139, 0.96378, 0.96391, 0.96817, 0.97073, 0.93631],
                       [0.97844, 0.97798, 0.97901, 0.97974, 0.97764, 0.97720, 0.97651,
                        0.97776, 0.97469, 0.97346, 0.97220, 0.96770, 0.96707, 0.96594,
                        0.96433, 0.96348, 0.96398, 0.96471, 0.96645, 0.96178, 0.96371,
                        0.96237, 0.96308, 0.96228, 0.96570, 0.96580, 0.96899, 0.96945, 0.93510],
                       [0.97709, 0.97629, 0.97791, 0.97832, 0.97680, 0.97690, 0.97643,
                        0.97613, 0.97547, 0.97460, 0.97296, 0.97061, 0.96907, 0.96908,
                        0.96578, 0.96531, 0.96681, 0.96658, 0.96810, 0.96406, 0.96572,
                        0.96430, 0.96413, 0.96328, 0.96645, 0.96686, 0.96871, 0.96849, 0.93493],
                       [0.97547, 0.97490, 0.97695, 0.97696, 0.97643, 0.97662, 0.97656,
                        0.97512, 0.97549, 0.97479, 0.97321, 0.97269, 0.97037, 0.97090,
                        0.96839, 0.96668, 0.96872, 0.96775, 0.96826, 0.96578, 0.96691,
                        0.96607, 0.96527, 0.96485, 0.96656, 0.96728, 0.96810, 0.96820, 0.93532],
                       [0.97401, 0.97439, 0.97576, 0.97542, 0.97597, 0.97603, 0.97626,
                        0.97518, 0.97457, 0.97427, 0.97362, 0.97434, 0.97177, 0.97212,
                        0.97112, 0.96777, 0.96972, 0.96812, 0.96850, 0.96712, 0.96753,
                        0.96720, 0.96640, 0.96655, 0.96674, 0.96791, 0.96775, 0.96840, 0.93528],
                       [0.97346, 0.97416, 0.97469, 0.97427, 0.97514, 0.97516, 0.97551,
                        0.97561, 0.97411, 0.97368, 0.97405, 0.97557, 0.97320, 0.97314,
                        0.97245, 0.96916, 0.97013, 0.96850, 0.96948, 0.96841, 0.96823,
                        0.96784, 0.96685, 0.96740, 0.96720, 0.96845, 0.96767, 0.96876, 0.93463],
                       [0.97386, 0.97383, 0.97422, 0.97413, 0.97416, 0.97439, 0.97482,
                        0.97589, 0.97433, 0.97333, 0.97467, 0.97592, 0.97373, 0.97366,
                        0.97211, 0.97141, 0.97033, 0.96920, 0.97086, 0.96942, 0.96936,
                        0.96784, 0.96712, 0.96747, 0.96701, 0.96843, 0.96745, 0.96875, 0.93412],
                       [0.97454, 0.97404, 0.97434, 0.97464, 0.97341, 0.97426, 0.97459,
                        0.97626, 0.97466, 0.97318, 0.97601, 0.97575, 0.97390, 0.97391,
                        0.97152, 0.97374, 0.97110, 0.96994, 0.97183, 0.96985, 0.97045,
                        0.96775, 0.96814, 0.96765, 0.96639, 0.96840, 0.96691, 0.96858, 0.93413],
                       [0.97504, 0.97455, 0.97440, 0.97471, 0.97338, 0.97431, 0.97469,
                        0.97638, 0.97507, 0.97339, 0.97723, 0.97549, 0.97460, 0.97411,
                        0.97197, 0.97465, 0.97255, 0.97024, 0.97221, 0.96992, 0.97088,
                        0.96853, 0.96929, 0.96823, 0.96676, 0.96866, 0.96654, 0.96850, 0.93441],
                       [0.97568, 0.97477, 0.97409, 0.97454, 0.97432, 0.97396, 0.97498,
                        0.97557, 0.97568, 0.97406, 0.97708, 0.97519, 0.97531, 0.97426,
                        0.97335, 0.97425, 0.97385, 0.97052, 0.97278, 0.97033, 0.97096,
                        0.96991, 0.96989, 0.96911, 0.96850, 0.96905, 0.96702, 0.96833, 0.93500],
                       [0.97632, 0.97519, 0.97371, 0.97490, 0.97530, 0.97362, 0.97544,
                        0.97438, 0.97618, 0.97460, 0.97585, 0.97487, 0.97530, 0.97459,
                        0.97431, 0.97392, 0.97444, 0.97164, 0.97353, 0.97113, 0.97120,
                        0.97104, 0.97042, 0.96993, 0.97014, 0.96959, 0.96832, 0.96795, 0.93563],
                       [0.97609, 0.97567, 0.97347, 0.97536, 0.97552, 0.97335, 0.97582,
                        0.97394, 0.97582, 0.97474, 0.97498, 0.97473, 0.97480, 0.97507,
                        0.97414, 0.97404, 0.97422, 0.97323, 0.97373, 0.97215, 0.97164,
                        0.97164, 0.97130, 0.96999, 0.97045, 0.97005, 0.96969, 0.96787, 0.93541],
                       [0.97484, 0.97484, 0.97333, 0.97487, 0.97515, 0.97291, 0.97568,
                        0.97414, 0.97468, 0.97515, 0.97510, 0.97505, 0.97482, 0.97553,
                        0.97414, 0.97410, 0.97357, 0.97428, 0.97339, 0.97325, 0.97219,
                        0.97198, 0.97213, 0.96962, 0.97018, 0.97001, 0.97070, 0.96811, 0.93440],
                       [0.97310, 0.97234, 0.97266, 0.97327, 0.97406, 0.97184, 0.97481,
                        0.97432, 0.97344, 0.97562, 0.97520, 0.97531, 0.97494, 0.97568,
                        0.97484, 0.97373, 0.97312, 0.97417, 0.97297, 0.97366, 0.97222,
                        0.97208, 0.97221, 0.96920, 0.97024, 0.96966, 0.97110, 0.96841, 0.93330],
                       [0.97152, 0.96980, 0.97148, 0.97146, 0.97175, 0.97027, 0.97339,
                        0.97397, 0.97232, 0.97533, 0.97419, 0.97496, 0.97412, 0.97485,
                        0.97512, 0.97280, 0.97267, 0.97309, 0.97252, 0.97310, 0.97152,
                        0.97160, 0.97123, 0.96889, 0.97035, 0.96945, 0.97064, 0.96857, 0.93291],
                       [0.97006, 0.96848, 0.97037, 0.97002, 0.96877, 0.96909, 0.97198,
                        0.97288, 0.97148, 0.97410, 0.97220, 0.97407, 0.97276, 0.97307,
                        0.97406, 0.97159, 0.97205, 0.97184, 0.97206, 0.97213, 0.97069,
                        0.97105, 0.96968, 0.96934, 0.96961, 0.96944, 0.96951, 0.96809, 0.93331],
                       [0.96833, 0.96796, 0.96913, 0.96866, 0.96651, 0.96841, 0.97060,
                        0.97154, 0.97108, 0.97208, 0.97047, 0.97277, 0.97175, 0.97161,
                        0.97216, 0.97079, 0.97190, 0.97111, 0.97151, 0.97124, 0.97024,
                        0.97089, 0.96890, 0.97048, 0.96863, 0.96953, 0.96806, 0.96731, 0.93356],
                       [0.96664, 0.96758, 0.96748, 0.96735, 0.96603, 0.96746, 0.96902,
                        0.97051, 0.97075, 0.96988, 0.97001, 0.97141, 0.97154, 0.97122,
                        0.97074, 0.97061, 0.97244, 0.97090, 0.97099, 0.97100, 0.97072,
                        0.97090, 0.96967, 0.97128, 0.96859, 0.96985, 0.96704, 0.96690, 0.93378],
                       [0.96525, 0.96709, 0.96602, 0.96644, 0.96669, 0.96628, 0.96765,
                        0.96949, 0.97023, 0.96851, 0.97085, 0.97056, 0.97180, 0.97161,
                        0.97034, 0.97096, 0.97270, 0.97062, 0.97073, 0.97131, 0.97213,
                        0.97064, 0.97107, 0.97114, 0.96919, 0.97043, 0.96738, 0.96701, 0.93462],
                       [0.96371, 0.96581, 0.96502, 0.96560, 0.96621, 0.96517, 0.96643,
                        0.96770, 0.96908, 0.96760, 0.97129, 0.97000, 0.97117, 0.97140,
                        0.97002, 0.97142, 0.97153, 0.96971, 0.97000, 0.97112, 0.97257,
                        0.96965, 0.97148, 0.97042, 0.96953, 0.97036, 0.96851, 0.96731, 0.93517],
                       [0.96234, 0.96363, 0.96401, 0.96448, 0.96377, 0.96383, 0.96515,
                        0.96574, 0.96730, 0.96657, 0.97004, 0.96925, 0.96928, 0.96990,
                        0.96903, 0.97137, 0.96948, 0.96885, 0.96883, 0.97033, 0.97118,
                        0.96892, 0.97089, 0.96989, 0.96986, 0.96965, 0.96925, 0.96764, 0.93431],
                       [0.96177, 0.96164, 0.96272, 0.96322, 0.96123, 0.96275, 0.96409,
                        0.96471, 0.96580, 0.96559, 0.96827, 0.96829, 0.96756, 0.96817,
                        0.96805, 0.97067, 0.96806, 0.96865, 0.96817, 0.96958, 0.96948,
                        0.96940, 0.97031, 0.96984, 0.97062, 0.96938, 0.96953, 0.96800, 0.93289],
                       [0.96126, 0.96036, 0.96096, 0.96183, 0.95993, 0.96223, 0.96302,
                        0.96401, 0.96482, 0.96450, 0.96703, 0.96727, 0.96685, 0.96706,
                        0.96739, 0.96924, 0.96750, 0.96830, 0.96797, 0.96906, 0.96831,
                        0.97010, 0.96978, 0.96993, 0.97094, 0.96962, 0.96919, 0.96793, 0.93264],
                       [0.95984, 0.95916, 0.95899, 0.96032, 0.95922, 0.96138, 0.96115,
                        0.96246, 0.96323, 0.96274, 0.96560, 0.96620, 0.96635, 0.96617,
                        0.96620, 0.96694, 0.96666, 0.96690, 0.96738, 0.96818, 0.96729,
                        0.96972, 0.96902, 0.96948, 0.96984, 0.96936, 0.96793, 0.96686, 0.93331],
                       [0.95800, 0.95791, 0.95762, 0.95892, 0.95835, 0.95966, 0.95881,
                        0.96027, 0.96106, 0.96078, 0.96347, 0.96494, 0.96515, 0.96509,
                        0.96445, 0.96421, 0.96509, 0.96504, 0.96589, 0.96667, 0.96639,
                        0.96837, 0.96817, 0.96845, 0.96800, 0.96843, 0.96657, 0.96541, 0.93337],
                       [0.95675, 0.95681, 0.95735, 0.95782, 0.95748, 0.95776, 0.95702,
                        0.95837, 0.95969, 0.95966, 0.96117, 0.96340, 0.96371, 0.96369,
                        0.96302, 0.96189, 0.96364, 0.96378, 0.96397, 0.96518, 0.96572,
                        0.96679, 0.96694, 0.96737, 0.96665, 0.96752, 0.96608, 0.96480, 0.93249],
                       [0.95614, 0.95562, 0.95731, 0.95689, 0.95662, 0.95627, 0.95572,
                        0.95690, 0.95908, 0.95893, 0.95910, 0.96167, 0.96246, 0.96158,
                        0.96187, 0.96032, 0.96229, 0.96293, 0.96250, 0.96380, 0.96464,
                        0.96521, 0.96506, 0.96603, 0.96578, 0.96668, 0.96563, 0.96488, 0.93141],
                       [0.95594, 0.95467, 0.95674, 0.95589, 0.95570, 0.95525, 0.95464,
                        0.95593, 0.95835, 0.95799, 0.95760, 0.95998, 0.96101, 0.95911,
                        0.96063, 0.95945, 0.96037, 0.96169, 0.96153, 0.96252, 0.96313,
                        0.96370, 0.96351, 0.96434, 0.96473, 0.96565, 0.96477, 0.96451, 0.93031],
                       [0.95625, 0.95460, 0.95589, 0.95500, 0.95531, 0.95476, 0.95395,
                        0.95565, 0.95786, 0.95693, 0.95690, 0.95830, 0.95948, 0.95751,
                        0.95946, 0.95904, 0.95864, 0.96002, 0.96042, 0.96181, 0.96207,
                        0.96233, 0.96302, 0.96310, 0.96374, 0.96432, 0.96406, 0.96370, 0.92908],
                       [0.95647, 0.95517, 0.95526, 0.95486, 0.95566, 0.95463, 0.95379,
                        0.95565, 0.95770, 0.95586, 0.95621, 0.95673, 0.95815, 0.95729,
                        0.95873, 0.95858, 0.95797, 0.95883, 0.95901, 0.96131, 0.96137,
                        0.96103, 0.96255, 0.96250, 0.96305, 0.96260, 0.96313, 0.96293, 0.92820],
                       [0.95627, 0.95600, 0.95527, 0.95571, 0.95607, 0.95499, 0.95457,
                        0.95582, 0.95720, 0.95511, 0.95519, 0.95567, 0.95702, 0.95750,
                        0.95846, 0.95819, 0.95770, 0.95847, 0.95798, 0.96018, 0.96029,
                        0.95974, 0.96153, 0.96215, 0.96243, 0.96127, 0.96181, 0.96236, 0.92777],
                       [0.95597, 0.95655, 0.95584, 0.95654, 0.95615, 0.95548, 0.95592,
                        0.95600, 0.95617, 0.95495, 0.95414, 0.95515, 0.95603, 0.95703,
                        0.95811, 0.95797, 0.95707, 0.95817, 0.95748, 0.95865, 0.95871,
                        0.95847, 0.96038, 0.96160, 0.96171, 0.96079, 0.96076, 0.96144, 0.92760],
                       [0.95594, 0.95661, 0.95645, 0.95683, 0.95627, 0.95570, 0.95689,
                        0.95613, 0.95532, 0.95541, 0.95344, 0.95532, 0.95542, 0.95648,
                        0.95736, 0.95759, 0.95645, 0.95742, 0.95735, 0.95777, 0.95765,
                        0.95787, 0.95952, 0.96100, 0.96116, 0.96072, 0.96022, 0.96023, 0.92794],
                       [0.95642, 0.95652, 0.95681, 0.95694, 0.95656, 0.95586, 0.95688,
                        0.95617, 0.95506, 0.95601, 0.95351, 0.95572, 0.95545, 0.95645,
                        0.95611, 0.95668, 0.95620, 0.95660, 0.95710, 0.95755, 0.95755,
                        0.95790, 0.95889, 0.96042, 0.96054, 0.96088, 0.95956, 0.95952, 0.92819],
                       [0.95725, 0.95645, 0.95672, 0.95706, 0.95700, 0.95601, 0.95614,
                        0.95606, 0.95526, 0.95615, 0.95420, 0.95556, 0.95588, 0.95590,
                        0.95461, 0.95506, 0.95585, 0.95615, 0.95617, 0.95688, 0.95752,
                        0.95748, 0.95803, 0.95935, 0.95928, 0.96075, 0.95847, 0.95915, 0.92770],
                       [0.95805, 0.95644, 0.95628, 0.95733, 0.95737, 0.95631, 0.95562,
                        0.95614, 0.95572, 0.95576, 0.95487, 0.95493, 0.95606, 0.95437,
                        0.95378, 0.95367, 0.95539, 0.95605, 0.95504, 0.95538, 0.95686,
                        0.95633, 0.95712, 0.95805, 0.95760, 0.95942, 0.95771, 0.95844, 0.92705],
                       [0.95855, 0.95712, 0.95641, 0.95810, 0.95794, 0.95726, 0.95628,
                        0.95695, 0.95648, 0.95561, 0.95574, 0.95492, 0.95607, 0.95393,
                        0.95456, 0.95404, 0.95558, 0.95655, 0.95494, 0.95446, 0.95615,
                        0.95545, 0.95682, 0.95746, 0.95666, 0.95752, 0.95794, 0.95775, 0.92719],
                       [0.95898, 0.95863, 0.95806, 0.95927, 0.95942, 0.95889, 0.95798,
                        0.95815, 0.95752, 0.95653, 0.95688, 0.95573, 0.95616, 0.95558,
                        0.95663, 0.95598, 0.95624, 0.95761, 0.95628, 0.95499, 0.95603,
                        0.95552, 0.95728, 0.95731, 0.95690, 0.95637, 0.95894, 0.95753, 0.92779],
                       [0.96013, 0.96035, 0.96076, 0.96068, 0.96168, 0.96063, 0.95971,
                        0.95907, 0.95889, 0.95813, 0.95756, 0.95675, 0.95692, 0.95749,
                        0.95847, 0.95811, 0.95678, 0.95853, 0.95801, 0.95639, 0.95640,
                        0.95670, 0.95821, 0.95721, 0.95778, 0.95609, 0.96006, 0.95782, 0.92799],
                       [0.96177, 0.96175, 0.96290, 0.96204, 0.96342, 0.96193, 0.96075,
                        0.95963, 0.96021, 0.95931, 0.95779, 0.95782, 0.95825, 0.95836,
                        0.95902, 0.95933, 0.95697, 0.95871, 0.95889, 0.95780, 0.95666,
                        0.95842, 0.95885, 0.95719, 0.95855, 0.95651, 0.96021, 0.95843, 0.92764],
                       [0.96304, 0.96273, 0.96363, 0.96300, 0.96378, 0.96279, 0.96116,
                        0.96030, 0.96087, 0.95986, 0.95811, 0.95911, 0.95918, 0.95884,
                        0.95879, 0.95944, 0.95701, 0.95836, 0.95846, 0.95877, 0.95660,
                        0.95930, 0.95843, 0.95704, 0.95882, 0.95757, 0.95900, 0.95895, 0.92726],
                       [0.96401, 0.96366, 0.96355, 0.96386, 0.96364, 0.96343, 0.96177,
                        0.96134, 0.96145, 0.96042, 0.95911, 0.96052, 0.95973, 0.95971,
                        0.95893, 0.95922, 0.95730, 0.95823, 0.95766, 0.95937, 0.95698,
                        0.95910, 0.95779, 0.95705, 0.95877, 0.95869, 0.95798, 0.95927, 0.92734],
                       [0.96512, 0.96496, 0.96388, 0.96518, 0.96416, 0.96415, 0.96319,
                        0.96252, 0.96282, 0.96179, 0.96110, 0.96177, 0.96106, 0.96118,
                        0.95983, 0.95975, 0.95831, 0.95891, 0.95834, 0.96024, 0.95832,
                        0.95907, 0.95815, 0.95789, 0.95913, 0.95944, 0.95863, 0.95981, 0.92795],
                       [0.96632, 0.96620, 0.96507, 0.96643, 0.96516, 0.96517, 0.96484,
                        0.96358, 0.96427, 0.96367, 0.96319, 0.96253, 0.96309, 0.96271,
                        0.96096, 0.96078, 0.95970, 0.96023, 0.96067, 0.96119, 0.95988,
                        0.95970, 0.95923, 0.95935, 0.95987, 0.95962, 0.96010, 0.96075, 0.92861],
                       [0.96702, 0.96691, 0.96651, 0.96698, 0.96616, 0.96645, 0.96576,
                        0.96487, 0.96501, 0.96509, 0.96424, 0.96314, 0.96467, 0.96405,
                        0.96179, 0.96172, 0.96114, 0.96146, 0.96277, 0.96131, 0.96112,
                        0.96071, 0.96031, 0.96100, 0.96064, 0.95974, 0.96116, 0.96198, 0.92951],
                       [0.96680, 0.96714, 0.96713, 0.96713, 0.96673, 0.96739, 0.96617,
                        0.96617, 0.96509, 0.96563, 0.96432, 0.96405, 0.96487, 0.96524,
                        0.96224, 0.96219, 0.96284, 0.96206, 0.96331, 0.96080, 0.96187,
                        0.96176, 0.96110, 0.96233, 0.96132, 0.96044, 0.96171, 0.96308, 0.93079],
                       [0.96614, 0.96716, 0.96690, 0.96719, 0.96672, 0.96750, 0.96665,
                        0.96640, 0.96500, 0.96554, 0.96419, 0.96503, 0.96413, 0.96545,
                        0.96258, 0.96225, 0.96436, 0.96215, 0.96298, 0.96075, 0.96212,
                        0.96247, 0.96195, 0.96303, 0.96168, 0.96118, 0.96205, 0.96362, 0.93177],
                       [0.96607, 0.96729, 0.96698, 0.96728, 0.96659, 0.96720, 0.96742,
                        0.96585, 0.96541, 0.96594, 0.96457, 0.96578, 0.96393, 0.96473,
                        0.96297, 0.96287, 0.96498, 0.96253, 0.96302, 0.96154, 0.96252,
                        0.96271, 0.96308, 0.96351, 0.96182, 0.96170, 0.96237, 0.96373, 0.93203],
                       [0.96650, 0.96776, 0.96766, 0.96757, 0.96684, 0.96699, 0.96825,
                        0.96587, 0.96627, 0.96691, 0.96565, 0.96635, 0.96457, 0.96425,
                        0.96343, 0.96417, 0.96468, 0.96355, 0.96372, 0.96255, 0.96353,
                        0.96258, 0.96426, 0.96405, 0.96240, 0.96241, 0.96268, 0.96378, 0.93221],
                       [0.96651, 0.96796, 0.96815, 0.96777, 0.96726, 0.96668, 0.96826,
                        0.96666, 0.96656, 0.96726, 0.96637, 0.96675, 0.96508, 0.96416,
                        0.96388, 0.96502, 0.96409, 0.96446, 0.96415, 0.96295, 0.96436,
                        0.96253, 0.96460, 0.96433, 0.96346, 0.96322, 0.96323, 0.96385, 0.93258],
                       [0.96613, 0.96710, 0.96817, 0.96758, 0.96733, 0.96613, 0.96739,
                        0.96724, 0.96607, 0.96665, 0.96604, 0.96711, 0.96539, 0.96431,
                        0.96434, 0.96505, 0.96411, 0.96466, 0.96407, 0.96266, 0.96413,
                        0.96311, 0.96387, 0.96445, 0.96414, 0.96387, 0.96408, 0.96411, 0.93296],
                       [0.96585, 0.96570, 0.96784, 0.96718, 0.96671, 0.96568, 0.96640,
                        0.96706, 0.96565, 0.96588, 0.96533, 0.96706, 0.96583, 0.96493,
                        0.96484, 0.96492, 0.96450, 0.96444, 0.96431, 0.96248, 0.96325,
                        0.96389, 0.96307, 0.96452, 0.96426, 0.96401, 0.96466, 0.96464, 0.93346],
                       [0.96589, 0.96525, 0.96738, 0.96708, 0.96610, 0.96564, 0.96584,
                        0.96617, 0.96586, 0.96558, 0.96516, 0.96670, 0.96612, 0.96601,
                        0.96553, 0.96497, 0.96443, 0.96463, 0.96508, 0.96317, 0.96306,
                        0.96444, 0.96304, 0.96433, 0.96458, 0.96357, 0.96505, 0.96527, 0.93412],
                       [0.96575, 0.96555, 0.96696, 0.96726, 0.96603, 0.96564, 0.96577,
                        0.96513, 0.96615, 0.96555, 0.96539, 0.96618, 0.96578, 0.96658,
                        0.96596, 0.96484, 0.96414, 0.96518, 0.96548, 0.96417, 0.96368,
                        0.96465, 0.96332, 0.96409, 0.96541, 0.96289, 0.96526, 0.96577, 0.93421],
                       [0.96508, 0.96543, 0.96593, 0.96685, 0.96589, 0.96504, 0.96570,
                        0.96471, 0.96583, 0.96552, 0.96535, 0.96547, 0.96504, 0.96575,
                        0.96529, 0.96415, 0.96429, 0.96536, 0.96469, 0.96431, 0.96399,
                        0.96394, 0.96320, 0.96412, 0.96587, 0.96259, 0.96473, 0.96620, 0.93350],
                       [0.96439, 0.96494, 0.96475, 0.96591, 0.96534, 0.96427, 0.96565,
                        0.96489, 0.96519, 0.96559, 0.96512, 0.96500, 0.96462, 0.96408,
                        0.96401, 0.96326, 0.96472, 0.96512, 0.96315, 0.96378, 0.96368,
                        0.96302, 0.96301, 0.96440, 0.96540, 0.96323, 0.96398, 0.96681, 0.93276],
                       [0.96433, 0.96494, 0.96457, 0.96538, 0.96503, 0.96416, 0.96611,
                        0.96540, 0.96497, 0.96580, 0.96535, 0.96515, 0.96510, 0.96308,
                        0.96375, 0.96330, 0.96521, 0.96495, 0.96218, 0.96376, 0.96323,
                        0.96337, 0.96372, 0.96481, 0.96462, 0.96451, 0.96397, 0.96720, 0.93240],
                       [0.96519, 0.96574, 0.96545, 0.96562, 0.96551, 0.96497, 0.96713,
                        0.96647, 0.96555, 0.96627, 0.96607, 0.96596, 0.96647, 0.96399,
                        0.96529, 0.96488, 0.96593, 0.96496, 0.96302, 0.96462, 0.96364,
                        0.96483, 0.96538, 0.96539, 0.96464, 0.96563, 0.96504, 0.96691, 0.93241],
                       [0.96613, 0.96628, 0.96633, 0.96630, 0.96614, 0.96604, 0.96755,
                        0.96747, 0.96638, 0.96691, 0.96650, 0.96675, 0.96765, 0.96594,
                        0.96735, 0.96664, 0.96629, 0.96488, 0.96481, 0.96522, 0.96468,
                        0.96582, 0.96662, 0.96582, 0.96547, 0.96588, 0.96633, 0.96605, 0.93245],
                       [0.96605, 0.96596, 0.96619, 0.96675, 0.96591, 0.96665, 0.96667,
                        0.96729, 0.96691, 0.96716, 0.96633, 0.96697, 0.96721, 0.96713,
                        0.96800, 0.96692, 0.96590, 0.96482, 0.96535, 0.96489, 0.96508,
                        0.96548, 0.96647, 0.96589, 0.96607, 0.96535, 0.96682, 0.96509, 0.93217],
                       [0.96492, 0.96554, 0.96509, 0.96653, 0.96497, 0.96670, 0.96548,
                        0.96585, 0.96701, 0.96651, 0.96578, 0.96657, 0.96569, 0.96710,
                        0.96707, 0.96592, 0.96535, 0.96495, 0.96459, 0.96409, 0.96456,
                        0.96446, 0.96559, 0.96583, 0.96581, 0.96476, 0.96643, 0.96446, 0.93146],
                       [0.96367, 0.96505, 0.96396, 0.96566, 0.96395, 0.96599, 0.96488,
                        0.96382, 0.96665, 0.96509, 0.96503, 0.96544, 0.96476, 0.96612,
                        0.96551, 0.96499, 0.96490, 0.96523, 0.96376, 0.96342, 0.96372,
                        0.96353, 0.96478, 0.96537, 0.96492, 0.96433, 0.96535, 0.96415, 0.93047],
                       [0.96321, 0.96410, 0.96353, 0.96459, 0.96333, 0.96465, 0.96458,
                        0.96258, 0.96606, 0.96374, 0.96455, 0.96421, 0.96451, 0.96462,
                        0.96409, 0.96491, 0.96452, 0.96543, 0.96328, 0.96307, 0.96311,
                        0.96269, 0.96415, 0.96408, 0.96402, 0.96392, 0.96414, 0.96417, 0.92963],
                       [0.96358, 0.96325, 0.96370, 0.96404, 0.96364, 0.96360, 0.96463,
                        0.96320, 0.96552, 0.96355, 0.96492, 0.96421, 0.96455, 0.96370,
                        0.96347, 0.96531, 0.96460, 0.96515, 0.96353, 0.96327, 0.96332,
                        0.96215, 0.96396, 0.96268, 0.96381, 0.96332, 0.96341, 0.96463, 0.92948],
                       [0.96404, 0.96304, 0.96382, 0.96431, 0.96453, 0.96374, 0.96553,
                        0.96475, 0.96513, 0.96452, 0.96565, 0.96562, 0.96483, 0.96366,
                        0.96367, 0.96555, 0.96489, 0.96448, 0.96458, 0.96395, 0.96426,
                        0.96246, 0.96412, 0.96264, 0.96434, 0.96245, 0.96312, 0.96476, 0.92975],
                       [0.96432, 0.96324, 0.96359, 0.96495, 0.96496, 0.96463, 0.96669,
                        0.96538, 0.96495, 0.96580, 0.96579, 0.96704, 0.96504, 0.96406,
                        0.96426, 0.96539, 0.96477, 0.96374, 0.96556, 0.96445, 0.96508,
                        0.96338, 0.96407, 0.96380, 0.96470, 0.96187, 0.96288, 0.96374, 0.92989],
                       [0.96406, 0.96347, 0.96330, 0.96528, 0.96460, 0.96455, 0.96688,
                        0.96454, 0.96460, 0.96618, 0.96509, 0.96715, 0.96494, 0.96458,
                        0.96486, 0.96501, 0.96406, 0.96283, 0.96543, 0.96418, 0.96517,
                        0.96394, 0.96342, 0.96462, 0.96407, 0.96194, 0.96239, 0.96213, 0.92953],
                       [0.96304, 0.96357, 0.96340, 0.96483, 0.96370, 0.96321, 0.96586,
                        0.96320, 0.96378, 0.96543, 0.96382, 0.96619, 0.96491, 0.96501,
                        0.96539, 0.96490, 0.96321, 0.96216, 0.96448, 0.96372, 0.96477,
                        0.96369, 0.96277, 0.96443, 0.96271, 0.96221, 0.96166, 0.96124, 0.92851],
                       [0.96199, 0.96386, 0.96402, 0.96385, 0.96314, 0.96237, 0.96446,
                        0.96267, 0.96339, 0.96474, 0.96244, 0.96554, 0.96538, 0.96547,
                        0.96584, 0.96538, 0.96318, 0.96284, 0.96395, 0.96391, 0.96440,
                        0.96336, 0.96278, 0.96393, 0.96194, 0.96230, 0.96134, 0.96140, 0.92755],
                       [0.96137, 0.96444, 0.96500, 0.96313, 0.96352, 0.96293, 0.96334,
                        0.96299, 0.96384, 0.96451, 0.96179, 0.96548, 0.96599, 0.96587,
                        0.96588, 0.96606, 0.96385, 0.96438, 0.96405, 0.96441, 0.96431,
                        0.96362, 0.96292, 0.96386, 0.96224, 0.96230, 0.96196, 0.96181, 0.92743],
                       [0.96159, 0.96505, 0.96582, 0.96326, 0.96455, 0.96408, 0.96308,
                        0.96363, 0.96434, 0.96452, 0.96232, 0.96552, 0.96646, 0.96633,
                        0.96542, 0.96626, 0.96467, 0.96521, 0.96433, 0.96466, 0.96478,
                        0.96441, 0.96303, 0.96392, 0.96295, 0.96270, 0.96334, 0.96208, 0.92783],
                       [0.96263, 0.96535, 0.96559, 0.96385, 0.96513, 0.96474, 0.96343,
                        0.96441, 0.96423, 0.96489, 0.96345, 0.96554, 0.96685, 0.96678,
                        0.96506, 0.96587, 0.96549, 0.96517, 0.96459, 0.96493, 0.96543,
                        0.96517, 0.96387, 0.96363, 0.96330, 0.96348, 0.96431, 0.96209, 0.92799],
                       [0.96355, 0.96517, 0.96417, 0.96408, 0.96448, 0.96443, 0.96359,
                        0.96519, 0.96388, 0.96549, 0.96458, 0.96586, 0.96686, 0.96660,
                        0.96540, 0.96546, 0.96602, 0.96526, 0.96489, 0.96540, 0.96570,
                        0.96563, 0.96557, 0.96321, 0.96323, 0.96418, 0.96362, 0.96189, 0.92768],
                       [0.96400, 0.96455, 0.96263, 0.96378, 0.96319, 0.96392, 0.96349,
                        0.96563, 0.96376, 0.96568, 0.96572, 0.96644, 0.96612, 0.96599,
                        0.96609, 0.96554, 0.96629, 0.96574, 0.96520, 0.96580, 0.96564,
                        0.96581, 0.96676, 0.96318, 0.96321, 0.96469, 0.96202, 0.96182, 0.92763],
                       [0.96390, 0.96373, 0.96204, 0.96306, 0.96218, 0.96369, 0.96328,
                        0.96554, 0.96394, 0.96514, 0.96651, 0.96670, 0.96514, 0.96564,
                        0.96610, 0.96587, 0.96612, 0.96607, 0.96538, 0.96586, 0.96552,
                        0.96583, 0.96657, 0.96355, 0.96327, 0.96511, 0.96104, 0.96172, 0.92832],
                       [0.96318, 0.96282, 0.96233, 0.96220, 0.96152, 0.96304, 0.96303,
                        0.96484, 0.96417, 0.96442, 0.96625, 0.96611, 0.96473, 0.96552,
                        0.96541, 0.96576, 0.96502, 0.96587, 0.96548, 0.96567, 0.96538,
                        0.96586, 0.96581, 0.96395, 0.96307, 0.96503, 0.96082, 0.96112, 0.92912],
                       [0.96245, 0.96221, 0.96284, 0.96197, 0.96134, 0.96211, 0.96290,
                        0.96393, 0.96425, 0.96419, 0.96571, 0.96531, 0.96520, 0.96564,
                        0.96507, 0.96523, 0.96400, 0.96535, 0.96577, 0.96556, 0.96519,
                        0.96606, 0.96521, 0.96416, 0.96300, 0.96446, 0.96127, 0.96050, 0.92942],
                       [0.96202, 0.96214, 0.96303, 0.96219, 0.96172, 0.96177, 0.96286,
                        0.96335, 0.96377, 0.96443, 0.96568, 0.96477, 0.96585, 0.96575,
                        0.96524, 0.96470, 0.96414, 0.96503, 0.96594, 0.96551, 0.96498,
                        0.96622, 0.96464, 0.96437, 0.96364, 0.96397, 0.96234, 0.96084, 0.92935],
                       [0.96155, 0.96168, 0.96267, 0.96190, 0.96206, 0.96176, 0.96260,
                        0.96293, 0.96249, 0.96424, 0.96520, 0.96415, 0.96563, 0.96494,
                        0.96522, 0.96445, 0.96467, 0.96470, 0.96570, 0.96499, 0.96483,
                        0.96561, 0.96381, 0.96465, 0.96451, 0.96375, 0.96335, 0.96202, 0.92923],
                       [0.96067, 0.96034, 0.96172, 0.96110, 0.96173, 0.96140, 0.96175,
                        0.96207, 0.96112, 0.96330, 0.96357, 0.96302, 0.96442, 0.96303,
                        0.96462, 0.96416, 0.96424, 0.96404, 0.96533, 0.96417, 0.96473,
                        0.96399, 0.96278, 0.96449, 0.96464, 0.96330, 0.96342, 0.96295, 0.92902],
                       [0.95925, 0.95873, 0.96047, 0.96032, 0.96072, 0.96079, 0.96072,
                        0.96082, 0.96061, 0.96213, 0.96162, 0.96170, 0.96287, 0.96106,
                        0.96368, 0.96354, 0.96322, 0.96347, 0.96468, 0.96354, 0.96440,
                        0.96232, 0.96182, 0.96376, 0.96388, 0.96246, 0.96253, 0.96272, 0.92861],
                       [0.95803, 0.95748, 0.95933, 0.95976, 0.95943, 0.96009, 0.96010,
                        0.95987, 0.96080, 0.96156, 0.96057, 0.96100, 0.96168, 0.96012,
                        0.96240, 0.96293, 0.96241, 0.96313, 0.96336, 0.96303, 0.96369,
                        0.96142, 0.96121, 0.96302, 0.96287, 0.96169, 0.96131, 0.96173, 0.92829],
                       [0.95757, 0.95691, 0.95834, 0.95940, 0.95834, 0.95894, 0.95967,
                        0.95946, 0.96084, 0.96182, 0.96044, 0.96088, 0.96126, 0.96012,
                        0.96121, 0.96237, 0.96166, 0.96252, 0.96148, 0.96231, 0.96274,
                        0.96115, 0.96110, 0.96248, 0.96217, 0.96130, 0.96033, 0.96099, 0.92832],
                       [0.95758, 0.95719, 0.95785, 0.95910, 0.95762, 0.95769, 0.95910,
                        0.95931, 0.96033, 0.96188, 0.96034, 0.96074, 0.96148, 0.96041,
                        0.96071, 0.96143, 0.96095, 0.96131, 0.95983, 0.96135, 0.96176,
                        0.96133, 0.96134, 0.96195, 0.96181, 0.96100, 0.95996, 0.96077, 0.92856],
                       [0.95782, 0.95817, 0.95812, 0.95908, 0.95740, 0.95758, 0.95842,
                        0.95931, 0.95959, 0.96138, 0.95996, 0.96064, 0.96194, 0.96057,
                        0.96065, 0.96044, 0.96038, 0.96001, 0.95932, 0.96057, 0.96053,
                        0.96191, 0.96171, 0.96144, 0.96144, 0.96041, 0.96047, 0.96073, 0.92897],
                       [0.95805, 0.95916, 0.95877, 0.95919, 0.95752, 0.95807, 0.95771,
                        0.95912, 0.95868, 0.96057, 0.95949, 0.96042, 0.96163, 0.96033,
                        0.96026, 0.95978, 0.95956, 0.95908, 0.95953, 0.95992, 0.95908,
                        0.96192, 0.96158, 0.96076, 0.96058, 0.95983, 0.96093, 0.96061, 0.92911],
                       [0.95792, 0.95930, 0.95896, 0.95880, 0.95754, 0.95763, 0.95672,
                        0.95835, 0.95779, 0.95949, 0.95894, 0.95953, 0.95987, 0.95952,
                        0.95868, 0.95902, 0.95797, 0.95810, 0.95931, 0.95871, 0.95794,
                        0.96044, 0.96053, 0.95974, 0.95918, 0.95950, 0.96058, 0.96025, 0.92869],
                       [0.95755, 0.95845, 0.95814, 0.95815, 0.95738, 0.95723, 0.95558,
                        0.95754, 0.95771, 0.95849, 0.95828, 0.95824, 0.95763, 0.95818,
                        0.95630, 0.95831, 0.95633, 0.95684, 0.95861, 0.95725, 0.95743,
                        0.95853, 0.95901, 0.95901, 0.95826, 0.95907, 0.96019, 0.95980, 0.92824],
                       [0.95738, 0.95763, 0.95682, 0.95754, 0.95783, 0.95808, 0.95535,
                        0.95708, 0.95853, 0.95777, 0.95780, 0.95736, 0.95599, 0.95701,
                        0.95493, 0.95821, 0.95562, 0.95625, 0.95814, 0.95670, 0.95723,
                        0.95804, 0.95791, 0.95903, 0.95842, 0.95849, 0.96024, 0.95961, 0.92827],
                       [0.95740, 0.95761, 0.95635, 0.95703, 0.95911, 0.95912, 0.95644,
                        0.95669, 0.95912, 0.95768, 0.95755, 0.95736, 0.95545, 0.95677,
                        0.95561, 0.95848, 0.95561, 0.95688, 0.95840, 0.95718, 0.95716,
                        0.95868, 0.95781, 0.95930, 0.95904, 0.95838, 0.96000, 0.95994, 0.92873],
                       [0.95740, 0.95847, 0.95725, 0.95721, 0.96019, 0.95928, 0.95794,
                        0.95692, 0.95894, 0.95855, 0.95759, 0.95787, 0.95595, 0.95732,
                        0.95764, 0.95857, 0.95618, 0.95772, 0.95899, 0.95760, 0.95744,
                        0.95863, 0.95841, 0.95917, 0.95938, 0.95892, 0.95914, 0.96065, 0.92940],
                       [0.95770, 0.95994, 0.95898, 0.95840, 0.96035, 0.95903, 0.95912,
                        0.95817, 0.95877, 0.95955, 0.95787, 0.95825, 0.95707, 0.95806,
                        0.95979, 0.95835, 0.95731, 0.95757, 0.95905, 0.95751, 0.95775,
                        0.95758, 0.95879, 0.95859, 0.95926, 0.95957, 0.95873, 0.96158, 0.93022],
                       [0.95853, 0.96103, 0.96091, 0.95997, 0.96021, 0.95915, 0.96003,
                        0.95932, 0.95926, 0.95979, 0.95831, 0.95854, 0.95832, 0.95890,
                        0.96078, 0.95813, 0.95830, 0.95719, 0.95853, 0.95769, 0.95776,
                        0.95688, 0.95876, 0.95825, 0.95873, 0.96035, 0.95973, 0.96259, 0.93104],
                       [0.95971, 0.96122, 0.96231, 0.96127, 0.96048, 0.95979, 0.96062,
                        0.95947, 0.96020, 0.95932, 0.95851, 0.95879, 0.95883, 0.95959,
                        0.95986, 0.95789, 0.95832, 0.95758, 0.95777, 0.95824, 0.95768,
                        0.95720, 0.95846, 0.95862, 0.95810, 0.96100, 0.96114, 0.96308, 0.93165],
                       [0.96122, 0.96107, 0.96294, 0.96197, 0.96080, 0.96056, 0.96046,
                        0.95933, 0.96073, 0.95864, 0.95834, 0.95911, 0.95823, 0.95951,
                        0.95783, 0.95770, 0.95770, 0.95820, 0.95719, 0.95826, 0.95770,
                        0.95790, 0.95774, 0.95927, 0.95798, 0.96090, 0.96151, 0.96274, 0.93192],
                       [0.96249, 0.96061, 0.96276, 0.96193, 0.96048, 0.96105, 0.95940,
                        0.95996, 0.95996, 0.95816, 0.95795, 0.95946, 0.95736, 0.95859,
                        0.95630, 0.95772, 0.95707, 0.95831, 0.95682, 0.95743, 0.95763,
                        0.95840, 0.95675, 0.95942, 0.95835, 0.96020, 0.96093, 0.96205, 0.93176],
                       [0.96274, 0.95998, 0.96203, 0.96177, 0.96016, 0.96147, 0.95835,
                        0.96083, 0.95859, 0.95829, 0.95774, 0.95948, 0.95713, 0.95761,
                        0.95630, 0.95798, 0.95675, 0.95780, 0.95670, 0.95665, 0.95747,
                        0.95881, 0.95598, 0.95886, 0.95857, 0.95925, 0.96031, 0.96169, 0.93149],
                       [0.96252, 0.96045, 0.96157, 0.96229, 0.96102, 0.96237, 0.95864,
                        0.96109, 0.95826, 0.95930, 0.95826, 0.95961, 0.95759, 0.95755,
                        0.95756, 0.95839, 0.95703, 0.95699, 0.95728, 0.95707, 0.95786,
                        0.95928, 0.95616, 0.95827, 0.95856, 0.95878, 0.96034, 0.96237, 0.93180],
                       [0.96255, 0.96215, 0.96198, 0.96290, 0.96273, 0.96349, 0.96050,
                        0.96151, 0.95931, 0.96112, 0.95939, 0.96048, 0.95845, 0.95837,
                        0.95920, 0.95912, 0.95800, 0.95660, 0.95842, 0.95867, 0.95939,
                        0.95956, 0.95787, 0.95818, 0.95861, 0.95926, 0.96116, 0.96363, 0.93240],
                       [0.96333, 0.96370, 0.96303, 0.96329, 0.96433, 0.96440, 0.96287,
                        0.96274, 0.96077, 0.96299, 0.96084, 0.96167, 0.95951, 0.95968,
                        0.96074, 0.96027, 0.95946, 0.95762, 0.95955, 0.96044, 0.96131,
                        0.95981, 0.96029, 0.95861, 0.95926, 0.96019, 0.96210, 0.96443, 0.93255],
                       [0.96491, 0.96453, 0.96430, 0.96395, 0.96559, 0.96510, 0.96462,
                        0.96430, 0.96187, 0.96410, 0.96233, 0.96253, 0.96085, 0.96119,
                        0.96205, 0.96116, 0.96079, 0.95985, 0.96010, 0.96116, 0.96218,
                        0.96031, 0.96202, 0.95950, 0.96041, 0.96135, 0.96274, 0.96481, 0.93241],
                       [0.96621, 0.96513, 0.96545, 0.96463, 0.96632, 0.96534, 0.96488,
                        0.96535, 0.96293, 0.96419, 0.96318, 0.96300, 0.96199, 0.96230,
                        0.96285, 0.96129, 0.96148, 0.96184, 0.96013, 0.96074, 0.96162,
                        0.96071, 0.96251, 0.96078, 0.96133, 0.96238, 0.96310, 0.96522, 0.93236],
                       [0.96664, 0.96590, 0.96596, 0.96521, 0.96681, 0.96517, 0.96413,
                        0.96595, 0.96459, 0.96400, 0.96337, 0.96361, 0.96235, 0.96297,
                        0.96301, 0.96115, 0.96192, 0.96283, 0.96042, 0.96058, 0.96121,
                        0.96118, 0.96266, 0.96216, 0.96187, 0.96308, 0.96341, 0.96556, 0.93263],
                       [0.96637, 0.96656, 0.96612, 0.96575, 0.96751, 0.96523, 0.96390,
                        0.96640, 0.96612, 0.96408, 0.96385, 0.96468, 0.96223, 0.96363,
                        0.96303, 0.96138, 0.96262, 0.96308, 0.96141, 0.96152, 0.96205,
                        0.96210, 0.96315, 0.96327, 0.96261, 0.96357, 0.96396, 0.96529, 0.93305],
                       [0.96602, 0.96686, 0.96662, 0.96616, 0.96814, 0.96622, 0.96521,
                        0.96685, 0.96674, 0.96442, 0.96534, 0.96602, 0.96289, 0.96451,
                        0.96358, 0.96249, 0.96357, 0.96365, 0.96277, 0.96275, 0.96355,
                        0.96311, 0.96358, 0.96379, 0.96376, 0.96406, 0.96484, 0.96497, 0.93361],
                       [0.96605, 0.96695, 0.96715, 0.96686, 0.96802, 0.96755, 0.96700,
                        0.96718, 0.96680, 0.96493, 0.96694, 0.96697, 0.96445, 0.96556,
                        0.96473, 0.96439, 0.96427, 0.96499, 0.96405, 0.96365, 0.96472,
                        0.96380, 0.96373, 0.96383, 0.96489, 0.96488, 0.96544, 0.96535, 0.93444],
                       [0.96652, 0.96741, 0.96743, 0.96828, 0.96753, 0.96818, 0.96817,
                        0.96742, 0.96726, 0.96576, 0.96821, 0.96711, 0.96594, 0.96667,
                        0.96625, 0.96637, 0.96469, 0.96630, 0.96512, 0.96499, 0.96528,
                        0.96473, 0.96415, 0.96417, 0.96597, 0.96607, 0.96592, 0.96627, 0.93526],
                       [0.96718, 0.96801, 0.96797, 0.96978, 0.96771, 0.96805, 0.96891,
                        0.96747, 0.96840, 0.96693, 0.96905, 0.96707, 0.96709, 0.96758,
                        0.96767, 0.96796, 0.96531, 0.96736, 0.96612, 0.96656, 0.96551,
                        0.96601, 0.96530, 0.96523, 0.96685, 0.96708, 0.96690, 0.96735, 0.93577],
                       [0.96816, 0.96817, 0.96873, 0.97040, 0.96829, 0.96794, 0.96955,
                        0.96706, 0.96950, 0.96810, 0.96907, 0.96783, 0.96841, 0.96785,
                        0.96834, 0.96877, 0.96647, 0.96805, 0.96696, 0.96727, 0.96552,
                        0.96688, 0.96666, 0.96633, 0.96725, 0.96760, 0.96792, 0.96809, 0.93570],
                       [0.96908, 0.96801, 0.96886, 0.96960, 0.96832, 0.96818, 0.97000,
                        0.96652, 0.96979, 0.96865, 0.96853, 0.96877, 0.96948, 0.96766,
                        0.96821, 0.96889, 0.96781, 0.96785, 0.96751, 0.96705, 0.96538,
                        0.96693, 0.96746, 0.96647, 0.96725, 0.96780, 0.96791, 0.96808, 0.93488],
                       [0.96895, 0.96781, 0.96816, 0.96788, 0.96775, 0.96841, 0.96988,
                        0.96658, 0.96910, 0.96823, 0.96806, 0.96871, 0.96935, 0.96754,
                        0.96790, 0.96881, 0.96826, 0.96734, 0.96767, 0.96657, 0.96541,
                        0.96642, 0.96770, 0.96568, 0.96702, 0.96763, 0.96702, 0.96755, 0.93375],
                       [0.96809, 0.96762, 0.96717, 0.96643, 0.96735, 0.96843, 0.96893,
                        0.96724, 0.96793, 0.96744, 0.96802, 0.96828, 0.96874, 0.96775,
                        0.96778, 0.96871, 0.96766, 0.96763, 0.96754, 0.96617, 0.96598,
                        0.96601, 0.96766, 0.96531, 0.96670, 0.96739, 0.96648, 0.96717, 0.93297],
                       [0.96729, 0.96757, 0.96650, 0.96583, 0.96743, 0.96837, 0.96746,
                        0.96759, 0.96729, 0.96679, 0.96822, 0.96815, 0.96883, 0.96808,
                        0.96776, 0.96859, 0.96701, 0.96848, 0.96738, 0.96602, 0.96695,
                        0.96614, 0.96745, 0.96615, 0.96648, 0.96764, 0.96664, 0.96717, 0.93268],
                       [0.96659, 0.96777, 0.96639, 0.96617, 0.96750, 0.96800, 0.96623,
                        0.96734, 0.96700, 0.96640, 0.96850, 0.96806, 0.96930, 0.96822,
                        0.96791, 0.96806, 0.96671, 0.96904, 0.96745, 0.96611, 0.96791,
                        0.96668, 0.96721, 0.96740, 0.96670, 0.96798, 0.96709, 0.96742, 0.93265],
                       [0.96585, 0.96748, 0.96671, 0.96680, 0.96711, 0.96736, 0.96581,
                        0.96724, 0.96636, 0.96653, 0.96889, 0.96794, 0.96939, 0.96818,
                        0.96827, 0.96695, 0.96651, 0.96911, 0.96762, 0.96636, 0.96869,
                        0.96717, 0.96695, 0.96810, 0.96755, 0.96772, 0.96787, 0.96743, 0.93273],
                       [0.96560, 0.96659, 0.96706, 0.96694, 0.96663, 0.96678, 0.96654,
                        0.96750, 0.96603, 0.96722, 0.96902, 0.96804, 0.96945, 0.96848,
                        0.96862, 0.96652, 0.96667, 0.96897, 0.96768, 0.96722, 0.96898,
                        0.96766, 0.96688, 0.96842, 0.96909, 0.96751, 0.96896, 0.96731, 0.93295],
                       [0.96605, 0.96567, 0.96696, 0.96641, 0.96663, 0.96636, 0.96768,
                        0.96775, 0.96651, 0.96794, 0.96868, 0.96846, 0.96960, 0.96928,
                        0.96874, 0.96769, 0.96769, 0.96873, 0.96778, 0.96857, 0.96870,
                        0.96846, 0.96739, 0.96896, 0.97018, 0.96849, 0.96977, 0.96762, 0.93324],
                       [0.96614, 0.96479, 0.96613, 0.96560, 0.96655, 0.96587, 0.96781,
                        0.96750, 0.96701, 0.96798, 0.96819, 0.96843, 0.96925, 0.96958,
                        0.96847, 0.96938, 0.96911, 0.96823, 0.96813, 0.96909, 0.96834,
                        0.96904, 0.96798, 0.96945, 0.96997, 0.96995, 0.96953, 0.96813, 0.93337],
                       [0.96537, 0.96404, 0.96487, 0.96489, 0.96563, 0.96552, 0.96672,
                        0.96644, 0.96680, 0.96747, 0.96775, 0.96766, 0.96861, 0.96862,
                        0.96793, 0.97008, 0.96992, 0.96766, 0.96848, 0.96857, 0.96819,
                        0.96905, 0.96806, 0.96945, 0.96891, 0.97045, 0.96857, 0.96824, 0.93358],
                       [0.96420, 0.96352, 0.96374, 0.96436, 0.96410, 0.96537, 0.96545,
                        0.96529, 0.96562, 0.96679, 0.96739, 0.96678, 0.96788, 0.96705,
                        0.96771, 0.96949, 0.96937, 0.96720, 0.96837, 0.96781, 0.96787,
                        0.96853, 0.96805, 0.96899, 0.96745, 0.96963, 0.96761, 0.96768, 0.93372],
                       [0.96290, 0.96260, 0.96239, 0.96356, 0.96249, 0.96457, 0.96433,
                        0.96472, 0.96401, 0.96568, 0.96671, 0.96591, 0.96638, 0.96542,
                        0.96746, 0.96778, 0.96739, 0.96630, 0.96721, 0.96697, 0.96711,
                        0.96747, 0.96819, 0.96805, 0.96613, 0.96806, 0.96638, 0.96662, 0.93321],
                       [0.96192, 0.96126, 0.96091, 0.96241, 0.96180, 0.96307, 0.96319,
                        0.96431, 0.96314, 0.96453, 0.96551, 0.96499, 0.96457, 0.96440,
                        0.96680, 0.96608, 0.96536, 0.96554, 0.96561, 0.96635, 0.96632,
                        0.96693, 0.96785, 0.96683, 0.96593, 0.96678, 0.96534, 0.96588, 0.93250],
                       [0.96177, 0.96047, 0.95994, 0.96152, 0.96227, 0.96190, 0.96244,
                        0.96344, 0.96331, 0.96429, 0.96427, 0.96437, 0.96372, 0.96405,
                        0.96616, 0.96560, 0.96457, 0.96588, 0.96458, 0.96618, 0.96604,
                        0.96762, 0.96704, 0.96595, 0.96614, 0.96640, 0.96558, 0.96594, 0.93227],
                       [0.96189, 0.96069, 0.95961, 0.96117, 0.96278, 0.96139, 0.96206,
                        0.96242, 0.96324, 0.96446, 0.96327, 0.96423, 0.96384, 0.96403,
                        0.96580, 0.96582, 0.96469, 0.96682, 0.96397, 0.96595, 0.96614,
                        0.96833, 0.96636, 0.96572, 0.96585, 0.96663, 0.96663, 0.96641, 0.93228],
                       [0.96119, 0.96073, 0.95921, 0.96075, 0.96196, 0.96080, 0.96098,
                        0.96145, 0.96158, 0.96346, 0.96206, 0.96378, 0.96374, 0.96379,
                        0.96523, 0.96535, 0.96422, 0.96658, 0.96310, 0.96472, 0.96543,
                        0.96743, 0.96561, 0.96531, 0.96515, 0.96635, 0.96652, 0.96611, 0.93175],
                       [0.95969, 0.95921, 0.95855, 0.95971, 0.95993, 0.95985, 0.95965,
                        0.96025, 0.95932, 0.96141, 0.96096, 0.96254, 0.96304, 0.96324,
                        0.96393, 0.96421, 0.96307, 0.96466, 0.96211, 0.96263, 0.96371,
                        0.96498, 0.96449, 0.96420, 0.96428, 0.96515, 0.96498, 0.96489, 0.93080],
                       [0.95823, 0.95672, 0.95833, 0.95821, 0.95818, 0.95894, 0.95883,
                        0.95913, 0.95831, 0.95967, 0.96067, 0.96131, 0.96234, 0.96270,
                        0.96211, 0.96293, 0.96223, 0.96232, 0.96176, 0.96091, 0.96240,
                        0.96238, 0.96333, 0.96305, 0.96338, 0.96410, 0.96378, 0.96383, 0.92986],
                       [0.95741, 0.95556, 0.95859, 0.95717, 0.95783, 0.95829, 0.95829,
                        0.95899, 0.95899, 0.95917, 0.96096, 0.96093, 0.96202, 0.96239,
                        0.96106, 0.96203, 0.96195, 0.96077, 0.96229, 0.96038, 0.96226,
                        0.96116, 0.96279, 0.96259, 0.96329, 0.96413, 0.96389, 0.96357, 0.92919],
                       [0.95698, 0.95651, 0.95867, 0.95737, 0.95841, 0.95789, 0.95811,
                        0.95935, 0.96034, 0.95951, 0.96088, 0.96096, 0.96157, 0.96221,
                        0.96138, 0.96142, 0.96144, 0.96039, 0.96286, 0.96039, 0.96227,
                        0.96115, 0.96272, 0.96257, 0.96389, 0.96424, 0.96398, 0.96343, 0.92874],
                       [0.95655, 0.95802, 0.95845, 0.95871, 0.95891, 0.95778, 0.95779,
                        0.95917, 0.96091, 0.95921, 0.95980, 0.96099, 0.96058, 0.96186,
                        0.96189, 0.96021, 0.96034, 0.96075, 0.96231, 0.95985, 0.96161,
                        0.96113, 0.96226, 0.96253, 0.96361, 0.96304, 0.96343, 0.96271, 0.92853],
                       [0.95626, 0.95806, 0.95791, 0.95983, 0.95860, 0.95762, 0.95658,
                        0.95843, 0.95980, 0.95777, 0.95784, 0.96054, 0.95951, 0.96057,
                        0.96099, 0.95802, 0.95920, 0.96059, 0.96029, 0.95857, 0.96030,
                        0.96030, 0.96108, 0.96214, 0.96194, 0.96103, 0.96276, 0.96150, 0.92818],
                       [0.95651, 0.95661, 0.95704, 0.95965, 0.95752, 0.95707, 0.95547,
                        0.95773, 0.95775, 0.95602, 0.95631, 0.95948, 0.95896, 0.95876,
                        0.95869, 0.95597, 0.95863, 0.95971, 0.95797, 0.95725, 0.95911,
                        0.95879, 0.96010, 0.96131, 0.96015, 0.95975, 0.96226, 0.96039, 0.92737],
                       [0.95725, 0.95528, 0.95625, 0.95833, 0.95646, 0.95653, 0.95532,
                        0.95710, 0.95620, 0.95489, 0.95623, 0.95814, 0.95885, 0.95786,
                        0.95686, 0.95516, 0.95844, 0.95913, 0.95672, 0.95653, 0.95845,
                        0.95756, 0.96002, 0.96014, 0.95895, 0.95963, 0.96158, 0.95983, 0.92668],
                       [0.95788, 0.95489, 0.95591, 0.95677, 0.95621, 0.95632, 0.95555,
                        0.95624, 0.95568, 0.95484, 0.95679, 0.95682, 0.95829, 0.95788,
                        0.95652, 0.95532, 0.95802, 0.95867, 0.95673, 0.95645, 0.95791,
                        0.95695, 0.96023, 0.95895, 0.95833, 0.95963, 0.96054, 0.95993, 0.92673],
                       [0.95811, 0.95561, 0.95641, 0.95641, 0.95695, 0.95643, 0.95591,
                        0.95579, 0.95575, 0.95598, 0.95725, 0.95593, 0.95727, 0.95813,
                        0.95695, 0.95606, 0.95776, 0.95811, 0.95752, 0.95703, 0.95737,
                        0.95696, 0.96033, 0.95856, 0.95865, 0.95922, 0.95986, 0.96058, 0.92727],
                       [0.95797, 0.95676, 0.95737, 0.95746, 0.95773, 0.95678, 0.95624,
                        0.95626, 0.95599, 0.95723, 0.95740, 0.95564, 0.95653, 0.95827,
                        0.95727, 0.95723, 0.95771, 0.95765, 0.95832, 0.95746, 0.95663,
                        0.95735, 0.96048, 0.95896, 0.95982, 0.95858, 0.95982, 0.96121, 0.92753],
                       [0.95788, 0.95783, 0.95805, 0.95859, 0.95758, 0.95746, 0.95648,
                        0.95703, 0.95645, 0.95732, 0.95706, 0.95621, 0.95681, 0.95832,
                        0.95724, 0.95847, 0.95727, 0.95718, 0.95846, 0.95714, 0.95608,
                        0.95769, 0.96047, 0.95941, 0.96044, 0.95790, 0.95991, 0.96148, 0.92759],
                       [0.95821, 0.95902, 0.95848, 0.95924, 0.95706, 0.95846, 0.95691,
                        0.95761, 0.95728, 0.95653, 0.95712, 0.95751, 0.95806, 0.95843,
                        0.95743, 0.95892, 0.95676, 0.95706, 0.95819, 0.95651, 0.95661,
                        0.95769, 0.96020, 0.95940, 0.96002, 0.95721, 0.95987, 0.96159, 0.92795],
                       [0.95893, 0.96020, 0.95909, 0.96013, 0.95783, 0.95948, 0.95775,
                        0.95819, 0.95872, 0.95644, 0.95840, 0.95862, 0.95941, 0.95858,
                        0.95808, 0.95840, 0.95705, 0.95755, 0.95874, 0.95644, 0.95777,
                        0.95751, 0.96006, 0.95940, 0.96007, 0.95687, 0.96012, 0.96164, 0.92844],
                       [0.95944, 0.96066, 0.96001, 0.96109, 0.95987, 0.95991, 0.95904,
                        0.95899, 0.96025, 0.95770, 0.95967, 0.95893, 0.95993, 0.95852,
                        0.95834, 0.95800, 0.95813, 0.95834, 0.95965, 0.95704, 0.95806,
                        0.95730, 0.96015, 0.95980, 0.96069, 0.95701, 0.96066, 0.96124, 0.92865],
                       [0.95934, 0.96026, 0.96111, 0.96157, 0.96154, 0.95980, 0.96017,
                        0.96005, 0.96091, 0.95930, 0.95955, 0.95891, 0.95940, 0.95805,
                        0.95780, 0.95853, 0.95921, 0.95907, 0.95931, 0.95780, 0.95709,
                        0.95716, 0.96007, 0.95987, 0.96044, 0.95741, 0.96103, 0.96071, 0.92864],
                       [0.95916, 0.96019, 0.96232, 0.96173, 0.96242, 0.95998, 0.96047,
                        0.96133, 0.96072, 0.96019, 0.95885, 0.95920, 0.95862, 0.95778,
                        0.95714, 0.95934, 0.95973, 0.95954, 0.95795, 0.95841, 0.95605,
                        0.95734, 0.95939, 0.95916, 0.95968, 0.95806, 0.96078, 0.96068, 0.92897],
                       [0.95964, 0.96115, 0.96366, 0.96204, 0.96311, 0.96119, 0.96014,
                        0.96218, 0.96059, 0.96068, 0.95936, 0.95990, 0.95864, 0.95851,
                        0.95716, 0.95951, 0.95981, 0.95948, 0.95714, 0.95882, 0.95635,
                        0.95785, 0.95835, 0.95832, 0.95960, 0.95892, 0.96036, 0.96123, 0.92978],
                       [0.96057, 0.96196, 0.96474, 0.96264, 0.96362, 0.96262, 0.95981,
                        0.96205, 0.96089, 0.96126, 0.96088, 0.96041, 0.95948, 0.95957,
                        0.95785, 0.95897, 0.95974, 0.95882, 0.95762, 0.95880, 0.95778,
                        0.95873, 0.95751, 0.95796, 0.95963, 0.95956, 0.96066, 0.96208, 0.93045],
                       [0.96164, 0.96216, 0.96467, 0.96294, 0.96394, 0.96299, 0.96001,
                        0.96144, 0.96093, 0.96131, 0.96180, 0.96013, 0.96015, 0.95994,
                        0.95864, 0.95862, 0.95949, 0.95812, 0.95836, 0.95853, 0.95917,
                        0.95977, 0.95726, 0.95805, 0.95909, 0.95986, 0.96132, 0.96251, 0.93046],
                       [0.96306, 0.96306, 0.96390, 0.96299, 0.96449, 0.96255, 0.96086,
                        0.96158, 0.96052, 0.96060, 0.96162, 0.95984, 0.96069, 0.96026,
                        0.95942, 0.95931, 0.95904, 0.95823, 0.95850, 0.95858, 0.96035,
                        0.96048, 0.95814, 0.95844, 0.95878, 0.95990, 0.96188, 0.96217, 0.93042],
                       [0.96458, 0.96460, 0.96424, 0.96369, 0.96527, 0.96263, 0.96231,
                        0.96290, 0.96062, 0.96045, 0.96138, 0.96061, 0.96174, 0.96127,
                        0.96071, 0.96079, 0.95918, 0.95947, 0.95862, 0.95942, 0.96151,
                        0.96079, 0.95953, 0.95927, 0.95934, 0.96036, 0.96239, 0.96189, 0.93104],
                       [0.96524, 0.96525, 0.96510, 0.96498, 0.96527, 0.96374, 0.96386,
                        0.96419, 0.96168, 0.96120, 0.96149, 0.96163, 0.96290, 0.96232,
                        0.96209, 0.96159, 0.95986, 0.96070, 0.95909, 0.96083, 0.96209,
                        0.96053, 0.95993, 0.95979, 0.95982, 0.96125, 0.96281, 0.96202, 0.93135],
                       [0.96464, 0.96476, 0.96479, 0.96605, 0.96447, 0.96474, 0.96468,
                        0.96452, 0.96300, 0.96208, 0.96161, 0.96202, 0.96328, 0.96279,
                        0.96253, 0.96134, 0.96091, 0.96061, 0.96008, 0.96193, 0.96166,
                        0.95975, 0.95971, 0.95969, 0.95975, 0.96171, 0.96313, 0.96227, 0.93085],
                       [0.96360, 0.96430, 0.96404, 0.96658, 0.96423, 0.96498, 0.96440,
                        0.96394, 0.96385, 0.96258, 0.96240, 0.96242, 0.96261, 0.96327,
                        0.96224, 0.96131, 0.96245, 0.96011, 0.96160, 0.96206, 0.96092,
                        0.95948, 0.96039, 0.96009, 0.95990, 0.96171, 0.96352, 0.96236, 0.93078],
                       [0.96330, 0.96495, 0.96429, 0.96687, 0.96488, 0.96485, 0.96384,
                        0.96328, 0.96436, 0.96296, 0.96419, 0.96288, 0.96212, 0.96434,
                        0.96236, 0.96203, 0.96409, 0.96101, 0.96294, 0.96173, 0.96099,
                        0.96041, 0.96252, 0.96123, 0.96062, 0.96204, 0.96374, 0.96279, 0.93131],
                       [0.96435, 0.96667, 0.96547, 0.96758, 0.96566, 0.96488, 0.96419,
                        0.96381, 0.96526, 0.96422, 0.96642, 0.96379, 0.96326, 0.96570,
                        0.96374, 0.96346, 0.96516, 0.96282, 0.96380, 0.96236, 0.96211,
                        0.96250, 0.96495, 0.96235, 0.96188, 0.96307, 0.96412, 0.96448, 0.93195],
                       [0.96515, 0.96800, 0.96603, 0.96848, 0.96578, 0.96541, 0.96513,
                        0.96502, 0.96641, 0.96628, 0.96750, 0.96515, 0.96469, 0.96638,
                        0.96529, 0.96497, 0.96518, 0.96384, 0.96387, 0.96364, 0.96333,
                        0.96480, 0.96540, 0.96305, 0.96325, 0.96383, 0.96456, 0.96647, 0.93254],
                       [0.96489, 0.96783, 0.96569, 0.96862, 0.96543, 0.96643, 0.96614,
                        0.96606, 0.96712, 0.96782, 0.96706, 0.96589, 0.96483, 0.96633,
                        0.96589, 0.96609, 0.96473, 0.96421, 0.96319, 0.96448, 0.96426,
                        0.96626, 0.96401, 0.96334, 0.96441, 0.96418, 0.96454, 0.96752, 0.93280],
                       [0.96496, 0.96682, 0.96593, 0.96784, 0.96559, 0.96762, 0.96736,
                        0.96728, 0.96723, 0.96799, 0.96657, 0.96546, 0.96472, 0.96647,
                        0.96611, 0.96688, 0.96523, 0.96481, 0.96324, 0.96501, 0.96543,
                        0.96681, 0.96339, 0.96325, 0.96492, 0.96508, 0.96460, 0.96817, 0.93278],
                       [0.96628, 0.96614, 0.96709, 0.96700, 0.96641, 0.96812, 0.96804,
                        0.96839, 0.96715, 0.96740, 0.96686, 0.96507, 0.96542, 0.96714,
                        0.96641, 0.96747, 0.96697, 0.96590, 0.96492, 0.96595, 0.96658,
                        0.96697, 0.96470, 0.96334, 0.96477, 0.96607, 0.96554, 0.96876, 0.93324],
                       [0.96743, 0.96548, 0.96795, 0.96614, 0.96690, 0.96735, 0.96703,
                        0.96830, 0.96690, 0.96666, 0.96733, 0.96537, 0.96602, 0.96772,
                        0.96642, 0.96746, 0.96832, 0.96690, 0.96695, 0.96673, 0.96686,
                        0.96664, 0.96638, 0.96379, 0.96428, 0.96630, 0.96645, 0.96831, 0.93407],
                       [0.96694, 0.96446, 0.96776, 0.96506, 0.96649, 0.96645, 0.96527,
                        0.96682, 0.96675, 0.96608, 0.96710, 0.96574, 0.96592, 0.96762,
                        0.96616, 0.96622, 0.96791, 0.96702, 0.96777, 0.96651, 0.96633,
                        0.96571, 0.96678, 0.96397, 0.96380, 0.96606, 0.96644, 0.96684, 0.93411],
                       [0.96549, 0.96435, 0.96697, 0.96490, 0.96581, 0.96660, 0.96479,
                        0.96524, 0.96707, 0.96589, 0.96625, 0.96598, 0.96615, 0.96726,
                        0.96639, 0.96501, 0.96699, 0.96636, 0.96776, 0.96570, 0.96619,
                        0.96521, 0.96596, 0.96460, 0.96422, 0.96581, 0.96635, 0.96618, 0.93337],
                       [0.96484, 0.96580, 0.96656, 0.96631, 0.96589, 0.96736, 0.96550,
                        0.96538, 0.96746, 0.96611, 0.96547, 0.96662, 0.96731, 0.96772,
                        0.96707, 0.96580, 0.96774, 0.96575, 0.96795, 0.96585, 0.96736,
                        0.96569, 0.96518, 0.96654, 0.96611, 0.96591, 0.96732, 0.96695, 0.93350],
                       [0.96467, 0.96709, 0.96661, 0.96774, 0.96636, 0.96713, 0.96592,
                        0.96704, 0.96707, 0.96641, 0.96510, 0.96761, 0.96776, 0.96865,
                        0.96750, 0.96767, 0.96932, 0.96545, 0.96807, 0.96728, 0.96879,
                        0.96625, 0.96487, 0.96829, 0.96757, 0.96625, 0.96850, 0.96735, 0.93425],
                       [0.96372, 0.96670, 0.96679, 0.96761, 0.96607, 0.96557, 0.96567,
                        0.96819, 0.96568, 0.96659, 0.96489, 0.96793, 0.96658, 0.96840,
                        0.96722, 0.96826, 0.96939, 0.96510, 0.96733, 0.96806, 0.96872,
                        0.96627, 0.96482, 0.96820, 0.96725, 0.96659, 0.96842, 0.96685, 0.93408],
                       [0.96251, 0.96516, 0.96679, 0.96649, 0.96496, 0.96391, 0.96523,
                        0.96770, 0.96443, 0.96697, 0.96453, 0.96742, 0.96536, 0.96651,
                        0.96664, 0.96725, 0.96765, 0.96494, 0.96603, 0.96740, 0.96753,
                        0.96620, 0.96509, 0.96688, 0.96639, 0.96684, 0.96733, 0.96670, 0.93321],
                       [0.96217, 0.96399, 0.96615, 0.96591, 0.96422, 0.96300, 0.96494,
                        0.96644, 0.96432, 0.96724, 0.96442, 0.96736, 0.96588, 0.96454,
                        0.96636, 0.96619, 0.96593, 0.96542, 0.96532, 0.96660, 0.96656,
                        0.96634, 0.96624, 0.96566, 0.96593, 0.96672, 0.96656, 0.96663, 0.93288],
                       [0.96325, 0.96410, 0.96518, 0.96606, 0.96385, 0.96290, 0.96511,
                        0.96582, 0.96546, 0.96713, 0.96485, 0.96809, 0.96769, 0.96425,
                        0.96669, 0.96613, 0.96541, 0.96620, 0.96600, 0.96666, 0.96648,
                        0.96650, 0.96801, 0.96549, 0.96598, 0.96654, 0.96698, 0.96602, 0.93328],
                       [0.96497, 0.96523, 0.96469, 0.96600, 0.96300, 0.96333, 0.96573,
                        0.96638, 0.96749, 0.96675, 0.96598, 0.96852, 0.96876, 0.96526,
                        0.96738, 0.96656, 0.96561, 0.96634, 0.96734, 0.96750, 0.96746,
                        0.96653, 0.96888, 0.96648, 0.96636, 0.96725, 0.96869, 0.96605, 0.93425],
                       [0.96564, 0.96590, 0.96444, 0.96516, 0.96208, 0.96346, 0.96603,
                        0.96707, 0.96869, 0.96574, 0.96715, 0.96809, 0.96788, 0.96617,
                        0.96754, 0.96645, 0.96585, 0.96581, 0.96769, 0.96804, 0.96842,
                        0.96623, 0.96775, 0.96753, 0.96668, 0.96852, 0.97028, 0.96678, 0.93514],
                       [0.96512, 0.96509, 0.96398, 0.96388, 0.96185, 0.96292, 0.96489,
                        0.96670, 0.96801, 0.96429, 0.96695, 0.96705, 0.96577, 0.96610,
                        0.96660, 0.96566, 0.96566, 0.96569, 0.96697, 0.96713, 0.96799,
                        0.96543, 0.96566, 0.96746, 0.96678, 0.96919, 0.96989, 0.96723, 0.93498],
                       [0.96415, 0.96348, 0.96339, 0.96317, 0.96253, 0.96244, 0.96337,
                        0.96503, 0.96640, 0.96350, 0.96516, 0.96588, 0.96391, 0.96537,
                        0.96489, 0.96493, 0.96500, 0.96588, 0.96607, 0.96530, 0.96661,
                        0.96426, 0.96443, 0.96656, 0.96640, 0.96874, 0.96773, 0.96712, 0.93400],
                       [0.96343, 0.96262, 0.96284, 0.96325, 0.96380, 0.96290, 0.96321,
                        0.96323, 0.96511, 0.96392, 0.96377, 0.96516, 0.96325, 0.96508,
                        0.96369, 0.96488, 0.96434, 0.96545, 0.96598, 0.96456, 0.96578,
                        0.96359, 0.96494, 0.96582, 0.96584, 0.96778, 0.96581, 0.96668, 0.93350],
                       [0.96308, 0.96213, 0.96236, 0.96323, 0.96445, 0.96402, 0.96384,
                        0.96272, 0.96421, 0.96498, 0.96364, 0.96500, 0.96343, 0.96555,
                        0.96376, 0.96501, 0.96404, 0.96438, 0.96676, 0.96486, 0.96593,
                        0.96379, 0.96643, 0.96544, 0.96535, 0.96710, 0.96508, 0.96602, 0.93366],
                       [0.96264, 0.96096, 0.96247, 0.96253, 0.96390, 0.96503, 0.96369,
                        0.96350, 0.96370, 0.96574, 0.96366, 0.96468, 0.96355, 0.96621,
                        0.96455, 0.96497, 0.96434, 0.96334, 0.96763, 0.96531, 0.96667,
                        0.96453, 0.96730, 0.96533, 0.96459, 0.96639, 0.96519, 0.96573, 0.93363],
                       [0.96210, 0.95972, 0.96282, 0.96138, 0.96313, 0.96500, 0.96251,
                        0.96440, 0.96345, 0.96517, 0.96327, 0.96376, 0.96326, 0.96616,
                        0.96501, 0.96506, 0.96525, 0.96240, 0.96757, 0.96551, 0.96709,
                        0.96520, 0.96615, 0.96490, 0.96341, 0.96502, 0.96535, 0.96564, 0.93310],
                       [0.96185, 0.95920, 0.96270, 0.96079, 0.96296, 0.96347, 0.96152,
                        0.96457, 0.96317, 0.96333, 0.96281, 0.96301, 0.96284, 0.96520,
                        0.96461, 0.96520, 0.96615, 0.96170, 0.96646, 0.96535, 0.96625,
                        0.96515, 0.96347, 0.96396, 0.96266, 0.96343, 0.96477, 0.96463, 0.93305],
                       [0.96201, 0.95944, 0.96252, 0.96148, 0.96279, 0.96176, 0.96152,
                        0.96408, 0.96287, 0.96213, 0.96257, 0.96329, 0.96290, 0.96394,
                        0.96378, 0.96510, 0.96610, 0.96160, 0.96571, 0.96486, 0.96480,
                        0.96459, 0.96192, 0.96347, 0.96269, 0.96302, 0.96383, 0.96352, 0.93392],
                       [0.96218, 0.95997, 0.96235, 0.96234, 0.96183, 0.96060, 0.96159,
                        0.96254, 0.96234, 0.96228, 0.96223, 0.96360, 0.96304, 0.96227,
                        0.96291, 0.96466, 0.96479, 0.96124, 0.96560, 0.96377, 0.96330,
                        0.96399, 0.96252, 0.96337, 0.96303, 0.96359, 0.96296, 0.96353, 0.93389],
                       [0.96190, 0.96041, 0.96173, 0.96228, 0.96099, 0.95979, 0.96116,
                        0.96016, 0.96187, 0.96221, 0.96119, 0.96259, 0.96262, 0.96051,
                        0.96238, 0.96384, 0.96272, 0.96034, 0.96485, 0.96195, 0.96138,
                        0.96284, 0.96366, 0.96300, 0.96324, 0.96384, 0.96202, 0.96399, 0.93209],
                       [0.96101, 0.96067, 0.96101, 0.96184, 0.96092, 0.95979, 0.96114,
                        0.95873, 0.96187, 0.96159, 0.96041, 0.96124, 0.96238, 0.96043,
                        0.96262, 0.96338, 0.96188, 0.96060, 0.96359, 0.96056, 0.96023,
                        0.96144, 0.96451, 0.96303, 0.96390, 0.96331, 0.96169, 0.96384, 0.93101],
                       [0.96029, 0.96068, 0.96048, 0.96155, 0.96108, 0.96082, 0.96174,
                        0.95913, 0.96235, 0.96111, 0.96107, 0.96108, 0.96248, 0.96264,
                        0.96296, 0.96410, 0.96301, 0.96208, 0.96322, 0.96089, 0.96092,
                        0.96125, 0.96501, 0.96381, 0.96542, 0.96252, 0.96287, 0.96330, 0.93185],
                       [0.96006, 0.96026, 0.95993, 0.96121, 0.96111, 0.96165, 0.96197,
                        0.96098, 0.96252, 0.96043, 0.96289, 0.96176, 0.96211, 0.96488,
                        0.96215, 0.96510, 0.96399, 0.96266, 0.96320, 0.96188, 0.96177,
                        0.96167, 0.96418, 0.96464, 0.96648, 0.96219, 0.96467, 0.96269, 0.93298],
                       [0.96004, 0.95982, 0.95962, 0.96052, 0.96127, 0.96140, 0.96146,
                        0.96309, 0.96194, 0.95947, 0.96456, 0.96237, 0.96163, 0.96546,
                        0.96107, 0.96489, 0.96323, 0.96231, 0.96300, 0.96202, 0.96190,
                        0.96157, 0.96198, 0.96510, 0.96649, 0.96290, 0.96567, 0.96235, 0.93337],
                       [0.96034, 0.95981, 0.95970, 0.95943, 0.96136, 0.96141, 0.96089,
                        0.96393, 0.96125, 0.95964, 0.96476, 0.96234, 0.96199, 0.96463,
                        0.96116, 0.96375, 0.96152, 0.96215, 0.96307, 0.96174, 0.96271,
                        0.96177, 0.95996, 0.96516, 0.96605, 0.96455, 0.96597, 0.96289, 0.93279],
                       [0.96073, 0.96008, 0.95978, 0.95839, 0.96109, 0.96243, 0.96098,
                        0.96340, 0.96150, 0.96182, 0.96359, 0.96179, 0.96278, 0.96294,
                        0.96177, 0.96273, 0.96024, 0.96240, 0.96314, 0.96168, 0.96400,
                        0.96293, 0.95918, 0.96461, 0.96557, 0.96584, 0.96580, 0.96352, 0.93177],
                       [0.96018, 0.96014, 0.95997, 0.95785, 0.96084, 0.96213, 0.96099,
                        0.96195, 0.96241, 0.96362, 0.96195, 0.96119, 0.96241, 0.96107,
                        0.96142, 0.96180, 0.95944, 0.96188, 0.96270, 0.96138, 0.96333,
                        0.96365, 0.95910, 0.96344, 0.96437, 0.96505, 0.96445, 0.96279, 0.93067],
                       [0.95900, 0.96007, 0.96107, 0.95878, 0.96066, 0.96008, 0.96021,
                        0.96023, 0.96273, 0.96310, 0.96054, 0.96134, 0.96092, 0.96028,
                        0.96071, 0.96137, 0.95928, 0.96079, 0.96216, 0.96134, 0.96150,
                        0.96349, 0.95984, 0.96300, 0.96278, 0.96279, 0.96294, 0.96183, 0.92991],
                       [0.95834, 0.95952, 0.96230, 0.96042, 0.95995, 0.95811, 0.95881,
                        0.95926, 0.96171, 0.96141, 0.95914, 0.96202, 0.96011, 0.96119,
                        0.96049, 0.96130, 0.96002, 0.96044, 0.96167, 0.96194, 0.96113,
                        0.96303, 0.96117, 0.96374, 0.96185, 0.96128, 0.96233, 0.96228, 0.93028],
                       [0.95816, 0.95849, 0.96228, 0.96116, 0.95955, 0.95748, 0.95781,
                        0.95935, 0.96044, 0.96048, 0.95786, 0.96244, 0.96089, 0.96270,
                        0.96026, 0.96072, 0.96147, 0.96112, 0.96121, 0.96274, 0.96254,
                        0.96270, 0.96170, 0.96419, 0.96209, 0.96179, 0.96211, 0.96322, 0.93186],
                       [0.95779, 0.95786, 0.96130, 0.96051, 0.95994, 0.95796, 0.95778,
                        0.95969, 0.95974, 0.96046, 0.95732, 0.96204, 0.96152, 0.96290,
                        0.95996, 0.95973, 0.96259, 0.96165, 0.96068, 0.96244, 0.96421,
                        0.96216, 0.96108, 0.96312, 0.96277, 0.96267, 0.96158, 0.96308, 0.93298],
                       [0.95835, 0.95828, 0.96134, 0.95925, 0.96056, 0.95888, 0.95814,
                        0.95992, 0.95895, 0.96083, 0.95816, 0.96139, 0.96063, 0.96116,
                        0.96054, 0.95944, 0.96223, 0.96148, 0.96064, 0.96084, 0.96445,
                        0.96119, 0.96040, 0.96188, 0.96286, 0.96241, 0.96162, 0.96214, 0.93289],
                       [0.96073, 0.95991, 0.96249, 0.95880, 0.96141, 0.96039, 0.95955,
                        0.96065, 0.95828, 0.96147, 0.96022, 0.96116, 0.96014, 0.95898,
                        0.96230, 0.96046, 0.96076, 0.96147, 0.96158, 0.95980, 0.96308,
                        0.96044, 0.96039, 0.96235, 0.96275, 0.96199, 0.96290, 0.96215, 0.93311],
                       [0.96266, 0.96210, 0.96315, 0.95970, 0.96213, 0.96230, 0.96244,
                        0.96133, 0.95893, 0.96239, 0.96249, 0.96074, 0.96134, 0.95844,
                        0.96385, 0.96221, 0.95964, 0.96176, 0.96303, 0.96030, 0.96152,
                        0.96049, 0.96094, 0.96348, 0.96249, 0.96191, 0.96376, 0.96351, 0.93430],
                       [0.96190, 0.96357, 0.96243, 0.96084, 0.96172, 0.96354, 0.96447,
                        0.96079, 0.96065, 0.96291, 0.96370, 0.95960, 0.96240, 0.95970,
                        0.96386, 0.96323, 0.95925, 0.96174, 0.96373, 0.96100, 0.96080,
                        0.96104, 0.96150, 0.96330, 0.96144, 0.96214, 0.96326, 0.96498, 0.93517],
                       [0.95984, 0.96397, 0.96063, 0.96104, 0.96050, 0.96309, 0.96405,
                        0.95938, 0.96148, 0.96246, 0.96280, 0.95862, 0.96196, 0.96125,
                        0.96272, 0.96216, 0.95926, 0.96090, 0.96274, 0.96121, 0.96053,
                        0.96146, 0.96191, 0.96167, 0.96007, 0.96283, 0.96253, 0.96589, 0.93401],
                       [0.95886, 0.96353, 0.95914, 0.96050, 0.95956, 0.96125, 0.96308,
                        0.95836, 0.96108, 0.96153, 0.96008, 0.95867, 0.96133, 0.96202,
                        0.96191, 0.95995, 0.95958, 0.95996, 0.96081, 0.96165, 0.96024,
                        0.96112, 0.96236, 0.96019, 0.95912, 0.96358, 0.96192, 0.96623, 0.93087],
                       [0.95894, 0.96180, 0.95891, 0.95994, 0.95913, 0.95930, 0.96280,
                        0.95831, 0.96108, 0.96105, 0.95788, 0.95956, 0.96189, 0.96232,
                        0.96153, 0.95867, 0.96012, 0.96009, 0.95956, 0.96197, 0.96021,
                        0.96041, 0.96272, 0.96014, 0.95906, 0.96396, 0.96114, 0.96591, 0.92819],
                       [0.95884, 0.95910, 0.95913, 0.95937, 0.95879, 0.95838, 0.96177,
                        0.95870, 0.96182, 0.96094, 0.95794, 0.96021, 0.96298, 0.96231,
                        0.96054, 0.95860, 0.96014, 0.96114, 0.95916, 0.96131, 0.96013,
                        0.95988, 0.96136, 0.96017, 0.96031, 0.96354, 0.96090, 0.96463, 0.92785],
                       [0.95898, 0.95722, 0.95913, 0.95920, 0.95867, 0.95868, 0.95974,
                        0.95939, 0.96277, 0.96122, 0.95946, 0.96040, 0.96328, 0.96221,
                        0.95930, 0.95938, 0.95962, 0.96202, 0.95927, 0.96041, 0.96012,
                        0.96015, 0.95876, 0.95941, 0.96235, 0.96274, 0.96186, 0.96355, 0.92934],
                       [0.96038, 0.95775, 0.95935, 0.96036, 0.95968, 0.96033, 0.95912,
                        0.96071, 0.96364, 0.96208, 0.96107, 0.96103, 0.96281, 0.96249,
                        0.95960, 0.96063, 0.95946, 0.96244, 0.96023, 0.96100, 0.96033,
                        0.96205, 0.95800, 0.95950, 0.96429, 0.96311, 0.96386, 0.96413, 0.93115],
                       [0.96192, 0.96021, 0.95944, 0.96253, 0.96186, 0.96266, 0.96077,
                        0.96196, 0.96368, 0.96294, 0.96266, 0.96268, 0.96222, 0.96298,
                        0.96165, 0.96171, 0.95981, 0.96276, 0.96125, 0.96274, 0.96007,
                        0.96477, 0.96014, 0.96140, 0.96588, 0.96423, 0.96547, 0.96526, 0.93182],
                       [0.96203, 0.96268, 0.95885, 0.96369, 0.96368, 0.96339, 0.96236,
                        0.96208, 0.96270, 0.96290, 0.96342, 0.96366, 0.96183, 0.96296,
                        0.96293, 0.96161, 0.96002, 0.96302, 0.96093, 0.96336, 0.95897,
                        0.96531, 0.96281, 0.96348, 0.96649, 0.96396, 0.96535, 0.96529, 0.93133],
                       [0.96114, 0.96396, 0.95873, 0.96325, 0.96390, 0.96197, 0.96265,
                        0.96193, 0.96209, 0.96234, 0.96275, 0.96290, 0.96160, 0.96225,
                        0.96262, 0.96053, 0.96011, 0.96334, 0.95970, 0.96166, 0.95860,
                        0.96350, 0.96395, 0.96444, 0.96631, 0.96242, 0.96458, 0.96431, 0.93118],
                       [0.96077, 0.96387, 0.96043, 0.96314, 0.96310, 0.96069, 0.96253,
                        0.96213, 0.96244, 0.96213, 0.96223, 0.96224, 0.96178, 0.96185,
                        0.96227, 0.96006, 0.96091, 0.96315, 0.95913, 0.95898, 0.96003,
                        0.96262, 0.96390, 0.96467, 0.96587, 0.96201, 0.96491, 0.96351, 0.93242],
                       [0.96138, 0.96315, 0.96326, 0.96365, 0.96287, 0.96132, 0.96260,
                        0.96236, 0.96261, 0.96241, 0.96257, 0.96269, 0.96284, 0.96201,
                        0.96289, 0.96082, 0.96212, 0.96218, 0.96022, 0.95784, 0.96159,
                        0.96410, 0.96428, 0.96468, 0.96561, 0.96364, 0.96554, 0.96374, 0.93457],
                       [0.96203, 0.96236, 0.96568, 0.96341, 0.96303, 0.96245, 0.96277,
                        0.96265, 0.96227, 0.96260, 0.96328, 0.96315, 0.96414, 0.96181,
                        0.96361, 0.96227, 0.96270, 0.96139, 0.96249, 0.95942, 0.96219,
                        0.96591, 0.96492, 0.96438, 0.96595, 0.96571, 0.96419, 0.96499, 0.93644],
                       [0.96198, 0.96162, 0.96664, 0.96242, 0.96248, 0.96269, 0.96303,
                        0.96240, 0.96220, 0.96244, 0.96353, 0.96324, 0.96463, 0.96130,
                        0.96278, 0.96328, 0.96193, 0.96080, 0.96491, 0.96211, 0.96237,
                        0.96585, 0.96431, 0.96348, 0.96609, 0.96639, 0.96171, 0.96647, 0.93698],
                       [0.96149, 0.96068, 0.96531, 0.96134, 0.96110, 0.96233, 0.96243,
                        0.96124, 0.96288, 0.96200, 0.96213, 0.96287, 0.96341, 0.96095,
                        0.96097, 0.96336, 0.95982, 0.96027, 0.96591, 0.96308, 0.96264,
                        0.96455, 0.96323, 0.96234, 0.96491, 0.96543, 0.96124, 0.96719, 0.93584],
                       [0.96145, 0.95936, 0.96237, 0.96078, 0.96012, 0.96162, 0.96089,
                        0.96026, 0.96297, 0.96138, 0.95950, 0.96154, 0.96110, 0.96063,
                        0.96056, 0.96304, 0.95821, 0.96051, 0.96396, 0.96197, 0.96305,
                        0.96376, 0.96349, 0.96147, 0.96358, 0.96388, 0.96300, 0.96647, 0.93418],
                       [0.96104, 0.95769, 0.95952, 0.96085, 0.95978, 0.96002, 0.95941,
                        0.95963, 0.96123, 0.96074, 0.95803, 0.95978, 0.95965, 0.96012,
                        0.96118, 0.96186, 0.95860, 0.96138, 0.95929, 0.95993, 0.96215,
                        0.96326, 0.96444, 0.96045, 0.96307, 0.96263, 0.96445, 0.96526, 0.93259],
                       [0.95955, 0.95652, 0.95774, 0.96166, 0.95913, 0.95798, 0.95905,
                        0.95904, 0.95913, 0.96035, 0.95886, 0.95903, 0.95934, 0.95968,
                        0.96120, 0.96006, 0.96035, 0.96174, 0.95542, 0.95786, 0.95986,
                        0.96223, 0.96442, 0.95987, 0.96286, 0.96218, 0.96463, 0.96458, 0.93082],
                       [0.95801, 0.95690, 0.95661, 0.96250, 0.95818, 0.95690, 0.95954,
                        0.95873, 0.95831, 0.96006, 0.95975, 0.95885, 0.95899, 0.95995,
                        0.96085, 0.95894, 0.96150, 0.96073, 0.95515, 0.95669, 0.95836,
                        0.96085, 0.96322, 0.96029, 0.96278, 0.96204, 0.96439, 0.96384, 0.92973],
                       [0.95764, 0.95925, 0.95644, 0.96214, 0.95832, 0.95772, 0.96061,
                        0.95950, 0.95825, 0.96054, 0.95940, 0.95913, 0.95870, 0.96111,
                        0.96140, 0.95962, 0.96108, 0.95895, 0.95787, 0.95686, 0.95911,
                        0.96089, 0.96180, 0.96069, 0.96280, 0.96185, 0.96416, 0.96330, 0.93131],
                       [0.95869, 0.96188, 0.95827, 0.96081, 0.95937, 0.95949, 0.96178,
                        0.96102, 0.95813, 0.96194, 0.95815, 0.95964, 0.95872, 0.96152,
                        0.96179, 0.96111, 0.95970, 0.95826, 0.96082, 0.95800, 0.96105,
                        0.96228, 0.96067, 0.96037, 0.96250, 0.96186, 0.96369, 0.96370, 0.93435],
                       [0.96054, 0.96284, 0.96063, 0.95969, 0.95983, 0.96024, 0.96171,
                        0.96162, 0.95820, 0.96263, 0.95678, 0.95970, 0.95913, 0.96062,
                        0.96087, 0.96150, 0.95923, 0.95948, 0.96180, 0.95918, 0.96274,
                        0.96261, 0.96040, 0.96124, 0.96187, 0.96195, 0.96352, 0.96458, 0.93592],
                       [0.96134, 0.96190, 0.96056, 0.95884, 0.95928, 0.95911, 0.95969,
                        0.95944, 0.95818, 0.96086, 0.95573, 0.95896, 0.95882, 0.95928,
                        0.95995, 0.95959, 0.95971, 0.96075, 0.96072, 0.95897, 0.96307,
                        0.96047, 0.96050, 0.96375, 0.96129, 0.96148, 0.96295, 0.96471, 0.93494],
                       [0.96091, 0.96022, 0.95881, 0.95792, 0.95882, 0.95739, 0.95744,
                        0.95614, 0.95780, 0.95778, 0.95558, 0.95831, 0.95742, 0.95858,
                        0.96021, 0.95722, 0.96029, 0.95989, 0.95909, 0.95731, 0.96216,
                        0.95827, 0.95987, 0.96554, 0.96159, 0.96049, 0.96241, 0.96376, 0.93257],
                       [0.96039, 0.95918, 0.95835, 0.95727, 0.95909, 0.95717, 0.95724,
                        0.95538, 0.95801, 0.95593, 0.95714, 0.95850, 0.95705, 0.95930,
                        0.96111, 0.95694, 0.96070, 0.95803, 0.95804, 0.95545, 0.96126,
                        0.95842, 0.95899, 0.96526, 0.96292, 0.96015, 0.96384, 0.96329, 0.93107],
                       [0.95925, 0.95805, 0.95938, 0.95687, 0.95887, 0.95770, 0.95838,
                        0.95660, 0.95931, 0.95539, 0.95927, 0.95912, 0.95874, 0.95932,
                        0.96160, 0.95805, 0.96047, 0.95676, 0.95732, 0.95464, 0.96049,
                        0.95917, 0.95912, 0.96341, 0.96357, 0.96103, 0.96599, 0.96351, 0.93098],
                       [0.95714, 0.95629, 0.95953, 0.95656, 0.95711, 0.95690, 0.95847,
                        0.95766, 0.96021, 0.95479, 0.95943, 0.95902, 0.96037, 0.95714,
                        0.96079, 0.95855, 0.95956, 0.95545, 0.95689, 0.95478, 0.95865,
                        0.95847, 0.95980, 0.96118, 0.96307, 0.96216, 0.96589, 0.96286, 0.93111],
                       [0.95581, 0.95520, 0.95780, 0.95560, 0.95535, 0.95542, 0.95716,
                        0.95824, 0.95996, 0.95483, 0.95766, 0.95793, 0.96066, 0.95491,
                        0.95919, 0.95775, 0.95904, 0.95485, 0.95700, 0.95499, 0.95647,
                        0.95713, 0.95942, 0.96040, 0.96309, 0.96311, 0.96357, 0.96147, 0.93077],
                       [0.95554, 0.95449, 0.95539, 0.95348, 0.95477, 0.95475, 0.95540,
                        0.95750, 0.95955, 0.95630, 0.95635, 0.95708, 0.96022, 0.95455,
                        0.95791, 0.95675, 0.95861, 0.95614, 0.95700, 0.95569, 0.95617,
                        0.95669, 0.95773, 0.96117, 0.96329, 0.96354, 0.96105, 0.96050, 0.92970],
                       [0.95529, 0.95410, 0.95329, 0.95176, 0.95509, 0.95463, 0.95402,
                        0.95630, 0.96003, 0.95841, 0.95595, 0.95694, 0.95929, 0.95657,
                        0.95732, 0.95586, 0.95714, 0.95854, 0.95669, 0.95779, 0.95781,
                        0.95750, 0.95613, 0.96192, 0.96157, 0.96272, 0.96016, 0.95963, 0.92827],
                       [0.95488, 0.95471, 0.95199, 0.95169, 0.95625, 0.95449, 0.95411,
                        0.95652, 0.96076, 0.95994, 0.95581, 0.95710, 0.95826, 0.95926,
                        0.95781, 0.95493, 0.95550, 0.96086, 0.95689, 0.96039, 0.95888,
                        0.95940, 0.95622, 0.96155, 0.95928, 0.96107, 0.96076, 0.95856, 0.92727],
                       [0.95461, 0.95519, 0.95225, 0.95180, 0.95702, 0.95446, 0.95468,
                        0.95667, 0.96029, 0.96008, 0.95661, 0.95736, 0.95812, 0.95967,
                        0.95862, 0.95448, 0.95527, 0.96127, 0.95731, 0.96130, 0.95770,
                        0.96114, 0.95791, 0.96031, 0.95873, 0.95981, 0.96089, 0.95869, 0.92682],
                       [0.95446, 0.95482, 0.95350, 0.95154, 0.95598, 0.95444, 0.95446,
                        0.95561, 0.95859, 0.95895, 0.95767, 0.95783, 0.95833, 0.95813,
                        0.95861, 0.95478, 0.95556, 0.95905, 0.95751, 0.96048, 0.95525,
                        0.96105, 0.95929, 0.95971, 0.95971, 0.95908, 0.95982, 0.96103, 0.92673],
                       [0.95413, 0.95399, 0.95377, 0.95149, 0.95392, 0.95401, 0.95421,
                        0.95444, 0.95669, 0.95782, 0.95665, 0.95837, 0.95816, 0.95723,
                        0.95761, 0.95525, 0.95564, 0.95632, 0.95812, 0.95884, 0.95342,
                        0.95876, 0.95941, 0.95944, 0.96073, 0.95846, 0.95827, 0.96296, 0.92702],
                       [0.95399, 0.95400, 0.95321, 0.95211, 0.95251, 0.95406, 0.95490,
                        0.95383, 0.95529, 0.95742, 0.95478, 0.95861, 0.95821, 0.95754,
                        0.95622, 0.95638, 0.95661, 0.95498, 0.95878, 0.95737, 0.95345,
                        0.95670, 0.95856, 0.95792, 0.96037, 0.95826, 0.95777, 0.96214, 0.92750],
                       [0.95317, 0.95466, 0.95317, 0.95349, 0.95201, 0.95457, 0.95622,
                        0.95371, 0.95381, 0.95647, 0.95481, 0.95780, 0.95765, 0.95737,
                        0.95464, 0.95733, 0.95764, 0.95413, 0.95788, 0.95641, 0.95415,
                        0.95705, 0.95699, 0.95437, 0.95828, 0.95743, 0.95808, 0.95967, 0.92715],
                       [0.95102, 0.95423, 0.95369, 0.95448, 0.95199, 0.95428, 0.95765,
                        0.95377, 0.95275, 0.95487, 0.95625, 0.95613, 0.95596, 0.95592,
                        0.95318, 0.95659, 0.95750, 0.95321, 0.95597, 0.95582, 0.95407,
                        0.95922, 0.95557, 0.95144, 0.95628, 0.95564, 0.95860, 0.95763, 0.92625],
                       [0.94928, 0.95233, 0.95399, 0.95359, 0.95175, 0.95292, 0.95746,
                        0.95403, 0.95377, 0.95349, 0.95591, 0.95407, 0.95434, 0.95410,
                        0.95279, 0.95538, 0.95577, 0.95328, 0.95447, 0.95548, 0.95397,
                        0.96087, 0.95490, 0.95169, 0.95535, 0.95492, 0.95990, 0.95636, 0.92660],
                       [0.94920, 0.95099, 0.95409, 0.95186, 0.95131, 0.95229, 0.95501,
                        0.95381, 0.95616, 0.95272, 0.95428, 0.95238, 0.95307, 0.95352,
                        0.95403, 0.95553, 0.95355, 0.95478, 0.95459, 0.95535, 0.95486,
                        0.96074, 0.95452, 0.95386, 0.95499, 0.95648, 0.96150, 0.95532, 0.92766],
                       [0.94920, 0.95039, 0.95280, 0.95019, 0.95016, 0.95280, 0.95191,
                        0.95134, 0.95638, 0.95263, 0.95396, 0.95165, 0.95146, 0.95382,
                        0.95419, 0.95519, 0.95266, 0.95589, 0.95610, 0.95441, 0.95543,
                        0.95839, 0.95340, 0.95559, 0.95437, 0.95762, 0.96029, 0.95395, 0.92700],
                       [0.94850, 0.94885, 0.94991, 0.94866, 0.94797, 0.95236, 0.94899,
                        0.94716, 0.95334, 0.95157, 0.95384, 0.95137, 0.95049, 0.95279,
                        0.95122, 0.95189, 0.95302, 0.95464, 0.95680, 0.95193, 0.95344,
                        0.95423, 0.95165, 0.95609, 0.95302, 0.95636, 0.95538, 0.95261, 0.92424],
                       [0.94801, 0.94750, 0.94862, 0.94800, 0.94617, 0.95040, 0.94656,
                        0.94439, 0.94973, 0.94792, 0.95202, 0.95088, 0.95117, 0.94986,
                        0.94725, 0.94721, 0.95314, 0.95182, 0.95612, 0.94956, 0.95005,
                        0.95109, 0.95069, 0.95574, 0.95133, 0.95437, 0.95129, 0.95243, 0.92106],
                       [0.94820, 0.94759, 0.95076, 0.94899, 0.94539, 0.94854, 0.94576,
                        0.94546, 0.94814, 0.94481, 0.95016, 0.95109, 0.95238, 0.94826,
                        0.94651, 0.94537, 0.95246, 0.94926, 0.95554, 0.95002, 0.94870,
                        0.95128, 0.95188, 0.95547, 0.95054, 0.95404, 0.95128, 0.95357, 0.91942],
                       [0.94780, 0.94754, 0.95304, 0.95015, 0.94491, 0.94806, 0.94672,
                        0.94807, 0.94853, 0.94570, 0.95036, 0.95179, 0.95186, 0.94852,
                        0.94992, 0.94700, 0.95207, 0.94795, 0.95504, 0.95177, 0.94991,
                        0.95264, 0.95423, 0.95507, 0.95102, 0.95507, 0.95321, 0.95475, 0.91961],
                       [0.94627, 0.94596, 0.95240, 0.94900, 0.94453, 0.94743, 0.94671,
                        0.94782, 0.94858, 0.94805, 0.95021, 0.94986, 0.94898, 0.94758,
                        0.95283, 0.94843, 0.95214, 0.94725, 0.95261, 0.95167, 0.95031,
                        0.95199, 0.95447, 0.95279, 0.95153, 0.95558, 0.95337, 0.95488, 0.91961],
                       [0.94349, 0.94387, 0.94951, 0.94567, 0.94388, 0.94565, 0.94352,
                        0.94577, 0.94753, 0.94864, 0.94710, 0.94545, 0.94564, 0.94523,
                        0.95152, 0.94754, 0.95164, 0.94588, 0.94719, 0.95097, 0.94866,
                        0.95036, 0.95125, 0.94936, 0.95105, 0.95595, 0.95065, 0.95377, 0.91848],
                       [0.94084, 0.94313, 0.94563, 0.94229, 0.94333, 0.94422, 0.94008,
                        0.94517, 0.94655, 0.94893, 0.94393, 0.94241, 0.94404, 0.94447,
                        0.94842, 0.94630, 0.95006, 0.94446, 0.94218, 0.95147, 0.94749,
                        0.94988, 0.94738, 0.94793, 0.95064, 0.95693, 0.94714, 0.95205, 0.91774],
                       [0.94014, 0.94292, 0.94162, 0.94083, 0.94328, 0.94313, 0.93986,
                        0.94508, 0.94619, 0.94897, 0.94321, 0.94167, 0.94354, 0.94576,
                        0.94632, 0.94603, 0.94767, 0.94507, 0.94136, 0.95142, 0.94835,
                        0.94965, 0.94507, 0.94714, 0.95075, 0.95631, 0.94524, 0.95072, 0.91825],
                       [0.94067, 0.94261, 0.93931, 0.94128, 0.94263, 0.94194, 0.94215,
                        0.94386, 0.94560, 0.94634, 0.94342, 0.94223, 0.94293, 0.94752,
                        0.94543, 0.94496, 0.94477, 0.94782, 0.94337, 0.94921, 0.94930,
                        0.94842, 0.94454, 0.94487, 0.94974, 0.95278, 0.94396, 0.95002, 0.91912],
                       [0.94064, 0.94259, 0.93936, 0.94140, 0.94113, 0.94103, 0.94337,
                        0.94293, 0.94394, 0.94243, 0.94319, 0.94334, 0.94234, 0.94772,
                        0.94453, 0.94165, 0.94202, 0.94914, 0.94397, 0.94477, 0.94843,
                        0.94682, 0.94570, 0.94370, 0.94725, 0.94854, 0.94233, 0.94950, 0.91865],
                       [0.93968, 0.94272, 0.94072, 0.94061, 0.93996, 0.94075, 0.94205,
                        0.94269, 0.94170, 0.94063, 0.94327, 0.94399, 0.94255, 0.94534,
                        0.94381, 0.93907, 0.93975, 0.94639, 0.94321, 0.94069, 0.94638,
                        0.94625, 0.94775, 0.94490, 0.94535, 0.94579, 0.94195, 0.94856, 0.91681],
                       [0.93736, 0.94162, 0.94104, 0.93974, 0.93909, 0.94043, 0.93886,
                        0.94095, 0.93958, 0.94139, 0.94252, 0.94314, 0.94304, 0.94153,
                        0.94397, 0.93923, 0.93718, 0.94158, 0.94276, 0.93919, 0.94384,
                        0.94597, 0.94893, 0.94570, 0.94353, 0.94464, 0.94304, 0.94677, 0.91434],
                       [0.93440, 0.93816, 0.93858, 0.93788, 0.93770, 0.93932, 0.93520,
                        0.93742, 0.93744, 0.94264, 0.93981, 0.94152, 0.94160, 0.93858,
                        0.94350, 0.94059, 0.93412, 0.93845, 0.94201, 0.93905, 0.94131,
                        0.94478, 0.94725, 0.94521, 0.94133, 0.94434, 0.94370, 0.94468, 0.91044],
                       [0.93195, 0.93363, 0.93408, 0.93406, 0.93502, 0.93629, 0.93200,
                        0.93379, 0.93487, 0.94229, 0.93599, 0.93946, 0.93718, 0.93753,
                        0.93990, 0.94001, 0.93139, 0.93685, 0.93949, 0.93812, 0.93873,
                        0.94254, 0.94242, 0.94435, 0.94056, 0.94384, 0.94294, 0.94331, 0.90547],
                       [0.93026, 0.93067, 0.93053, 0.92983, 0.93145, 0.93223, 0.93038,
                        0.93160, 0.93129, 0.94018, 0.93387, 0.93630, 0.93280, 0.93664,
                        0.93340, 0.93706, 0.93039, 0.93430, 0.93545, 0.93555, 0.93505,
                        0.93979, 0.93794, 0.94251, 0.94067, 0.94220, 0.94246, 0.94237, 0.90214],
                       [0.92895, 0.92992, 0.92969, 0.92910, 0.92894, 0.92936, 0.93100,
                        0.93165, 0.92760, 0.93733, 0.93469, 0.93293, 0.93137, 0.93471,
                        0.92751, 0.93447, 0.93094, 0.93066, 0.93144, 0.93265, 0.93105,
                        0.93748, 0.93567, 0.93930, 0.93985, 0.93948, 0.94354, 0.94066, 0.90172],
                       [0.92700, 0.93049, 0.92970, 0.93090, 0.92846, 0.92737, 0.93151,
                        0.93219, 0.92600, 0.93447, 0.93544, 0.92988, 0.93094, 0.93205,
                        0.92530, 0.93377, 0.93072, 0.92766, 0.92800, 0.93079, 0.92879,
                        0.93511, 0.93424, 0.93651, 0.93807, 0.93669, 0.94367, 0.93804, 0.90168],
                       [0.92416, 0.93060, 0.92849, 0.93025, 0.92867, 0.92536, 0.92817,
                        0.93034, 0.92711, 0.93137, 0.93319, 0.92742, 0.92951, 0.92886,
                        0.92569, 0.93334, 0.92829, 0.92580, 0.92505, 0.92892, 0.92827,
                        0.93175, 0.93295, 0.93478, 0.93690, 0.93400, 0.94082, 0.93499, 0.89959],
                       [0.92122, 0.92764, 0.92621, 0.92675, 0.92650, 0.92361, 0.92139,
                        0.92579, 0.92782, 0.92835, 0.92910, 0.92637, 0.92834, 0.92511,
                        0.92616, 0.93092, 0.92434, 0.92417, 0.92316, 0.92613, 0.92757,
                        0.92791, 0.93190, 0.93292, 0.93702, 0.93104, 0.93645, 0.93181, 0.89600],
                       [0.91851, 0.92150, 0.92338, 0.92302, 0.92101, 0.92244, 0.91558,
                        0.92100, 0.92496, 0.92588, 0.92470, 0.92544, 0.92690, 0.92006,
                        0.92512, 0.92601, 0.92002, 0.92092, 0.92198, 0.92234, 0.92556,
                        0.92433, 0.93009, 0.93036, 0.93745, 0.92860, 0.93260, 0.92903, 0.89311],
                       [0.91501, 0.91556, 0.91880, 0.91955, 0.91460, 0.92044, 0.91315,
                        0.91706, 0.92014, 0.92293, 0.91946, 0.92316, 0.92202, 0.91411,
                        0.92105, 0.92003, 0.91569, 0.91559, 0.91977, 0.91771, 0.92207,
                        0.92041, 0.92596, 0.92704, 0.93504, 0.92674, 0.93001, 0.92669, 0.89028],
                       [0.91034, 0.91225, 0.91323, 0.91513, 0.90974, 0.91651, 0.91141,
                        0.91390, 0.91648, 0.91856, 0.91531, 0.92030, 0.91515, 0.90997,
                        0.91509, 0.91490, 0.91136, 0.91061, 0.91645, 0.91328, 0.91774,
                        0.91746, 0.92028, 0.92240, 0.92829, 0.92470, 0.92804, 0.92359, 0.88557],
                       [0.90461, 0.90959, 0.90923, 0.90884, 0.90563, 0.91182, 0.90625,
                        0.91149, 0.91298, 0.91281, 0.91331, 0.91623, 0.91115, 0.90803,
                        0.90937, 0.90974, 0.90775, 0.90790, 0.91222, 0.90995, 0.91382,
                        0.91662, 0.91583, 0.91627, 0.92043, 0.92215, 0.92474, 0.91949, 0.87967],
                       [0.89853, 0.90483, 0.90588, 0.90026, 0.90032, 0.90647, 0.89831,
                        0.90796, 0.90744, 0.90603, 0.91087, 0.90906, 0.90986, 0.90490,
                        0.90302, 0.90270, 0.90315, 0.90545, 0.90605, 0.90690, 0.90870,
                        0.91473, 0.91191, 0.90992, 0.91426, 0.91787, 0.92029, 0.91458, 0.87460],
                       [0.89449, 0.89810, 0.90112, 0.89196, 0.89418, 0.89912, 0.89249,
                        0.90275, 0.90170, 0.90023, 0.90708, 0.90056, 0.90701, 0.90015,
                        0.89539, 0.89581, 0.89602, 0.90148, 0.89891, 0.90250, 0.90069,
                        0.90937, 0.90654, 0.90555, 0.90962, 0.91252, 0.91653, 0.90850, 0.87054],
                       [0.89171, 0.89015, 0.89407, 0.88628, 0.88774, 0.88851, 0.88814,
                        0.89684, 0.89622, 0.89554, 0.90138, 0.89416, 0.90064, 0.89545,
                        0.88792, 0.89032, 0.88806, 0.89571, 0.89273, 0.89581, 0.89212,
                        0.90119, 0.90057, 0.90195, 0.90533, 0.90756, 0.91198, 0.90266, 0.86604],
                       [0.88876, 0.88254, 0.88524, 0.88251, 0.88074, 0.87711, 0.88142,
                        0.89055, 0.89004, 0.88974, 0.89391, 0.89051, 0.89220, 0.89000,
                        0.88154, 0.88513, 0.88149, 0.88776, 0.88681, 0.88801, 0.88529,
                        0.89171, 0.89512, 0.89737, 0.89965, 0.90305, 0.90418, 0.89834, 0.86087],
                       [0.88544, 0.87772, 0.87515, 0.87878, 0.87356, 0.86889, 0.87411,
                        0.88416, 0.88304, 0.88308, 0.88583, 0.88691, 0.88266, 0.88300,
                        0.87574, 0.87883, 0.87634, 0.87936, 0.87904, 0.88044, 0.87992,
                        0.88314, 0.88898, 0.89273, 0.89354, 0.89778, 0.89530, 0.89470, 0.85406],
                       [0.88106, 0.87586, 0.86664, 0.87508, 0.86907, 0.86627, 0.87060,
                        0.87927, 0.87647, 0.87683, 0.87947, 0.88310, 0.87474, 0.87663,
                        0.87261, 0.87215, 0.87201, 0.87415, 0.87144, 0.87489, 0.87640,
                        0.87891, 0.88304, 0.88891, 0.88978, 0.89261, 0.89021, 0.89239, 0.84692],
                       [0.87524, 0.87319, 0.86256, 0.87059, 0.86666, 0.86713, 0.86988,
                        0.87451, 0.87131, 0.86973, 0.87379, 0.87948, 0.86952, 0.87185,
                        0.87107, 0.86755, 0.86802, 0.87052, 0.86588, 0.87109, 0.87409,
                        0.87764, 0.87847, 0.88511, 0.88889, 0.88826, 0.88814, 0.88972, 0.84097],
                       [0.86767, 0.86729, 0.85994, 0.86415, 0.86190, 0.86589, 0.86675,
                        0.86667, 0.86748, 0.86252, 0.86604, 0.87514, 0.86443, 0.86729,
                        0.86737, 0.86442, 0.86246, 0.86410, 0.86035, 0.86647, 0.86973,
                        0.87414, 0.87422, 0.88003, 0.88796, 0.88309, 0.88457, 0.88367, 0.83440],
                       [0.85803, 0.85760, 0.85470, 0.85481, 0.85239, 0.86020, 0.85791,
                        0.85578, 0.86226, 0.85671, 0.85710, 0.86840, 0.85751, 0.86204,
                        0.86059, 0.85994, 0.85432, 0.85515, 0.85310, 0.85948, 0.86096,
                        0.86647, 0.86856, 0.87251, 0.88232, 0.87666, 0.87754, 0.87452, 0.82621],
                       [0.84676, 0.84588, 0.84608, 0.84283, 0.84042, 0.85037, 0.84429,
                        0.84405, 0.85262, 0.85136, 0.84950, 0.85873, 0.85055, 0.85552,
                        0.85168, 0.85231, 0.84457, 0.84539, 0.84459, 0.85071, 0.85091,
                        0.85627, 0.86119, 0.86326, 0.87124, 0.87007, 0.86942, 0.86479, 0.81702],
                       [0.83383, 0.83517, 0.83586, 0.83114, 0.82891, 0.83626, 0.82996,
                        0.83248, 0.83952, 0.84475, 0.84289, 0.84733, 0.84398, 0.84578,
                        0.84133, 0.84068, 0.83326, 0.83365, 0.83654, 0.83956, 0.84259,
                        0.84555, 0.85189, 0.85351, 0.85923, 0.86302, 0.86263, 0.85517, 0.80700],
                       [0.82098, 0.82545, 0.82492, 0.82085, 0.81880, 0.82004, 0.81832,
                        0.82157, 0.82579, 0.83632, 0.83549, 0.83625, 0.83530, 0.83210,
                        0.83008, 0.82628, 0.82159, 0.82159, 0.82918, 0.82599, 0.83315,
                        0.83523, 0.83972, 0.84464, 0.84849, 0.85358, 0.85632, 0.84532, 0.79693],
                       [0.80931, 0.81392, 0.81246, 0.80920, 0.80891, 0.80463, 0.80830,
                        0.81110, 0.81274, 0.82558, 0.82581, 0.82569, 0.82307, 0.81600,
                        0.81854, 0.81209, 0.81118, 0.81180, 0.81982, 0.81289, 0.82079,
                        0.82483, 0.82690, 0.83555, 0.83889, 0.84136, 0.84725, 0.83581, 0.78645],
                       [0.79832, 0.79968, 0.79947, 0.79464, 0.79910, 0.79222, 0.79755,
                        0.80101, 0.80066, 0.81218, 0.81402, 0.81381, 0.80887, 0.80136,
                        0.80700, 0.80079, 0.80166, 0.80128, 0.80658, 0.80317, 0.80809,
                        0.81502, 0.81690, 0.82558, 0.83080, 0.82988, 0.83550, 0.82745, 0.77508],
                       [0.78826, 0.78645, 0.78703, 0.77856, 0.78978, 0.78288, 0.78745,
                        0.79183, 0.79082, 0.79835, 0.80341, 0.80090, 0.79699, 0.79126,
                        0.79554, 0.79295, 0.79204, 0.78828, 0.79154, 0.79504, 0.79673,
                        0.80578, 0.80935, 0.81636, 0.82343, 0.82219, 0.82553, 0.81921, 0.76454],
                       [0.77720, 0.77541, 0.77397, 0.76465, 0.77705, 0.77296, 0.77802,
                        0.78244, 0.78360, 0.78626, 0.79531, 0.78866, 0.78804, 0.78286,
                        0.78396, 0.78522, 0.78133, 0.77540, 0.77628, 0.78479, 0.78593,
                        0.79584, 0.80180, 0.80756, 0.81535, 0.81548, 0.81724, 0.80910, 0.75544],
                       [0.76380, 0.76384, 0.75952, 0.75403, 0.75866, 0.76078, 0.76703,
                        0.77087, 0.77664, 0.77485, 0.78493, 0.77718, 0.77817, 0.77174,
                        0.77210, 0.77258, 0.76943, 0.76328, 0.75970, 0.77171, 0.77455,
                        0.78369, 0.79267, 0.79751, 0.80630, 0.80522, 0.80615, 0.79877, 0.74576],
                       [0.75020, 0.74901, 0.74398, 0.74251, 0.73898, 0.74723, 0.75355,
                        0.75629, 0.76479, 0.76091, 0.76832, 0.76533, 0.76563, 0.75691,
                        0.75913, 0.75433, 0.75655, 0.75015, 0.74272, 0.75608, 0.76137,
                        0.76889, 0.78130, 0.78628, 0.79615, 0.79110, 0.79159, 0.78954, 0.73325],
                       [0.73753, 0.73131, 0.72745, 0.72705, 0.72319, 0.73291, 0.73778,
                        0.73993, 0.74670, 0.74355, 0.74878, 0.75156, 0.75161, 0.74135,
                        0.74494, 0.73604, 0.74064, 0.73484, 0.72857, 0.73763, 0.74607,
                        0.75372, 0.76763, 0.77502, 0.78355, 0.77715, 0.77747, 0.77817, 0.71831],
                       [0.72314, 0.71337, 0.71085, 0.70866, 0.71008, 0.71674, 0.72052,
                        0.72261, 0.72730, 0.72439, 0.73092, 0.73554, 0.73696, 0.72741,
                        0.73004, 0.72116, 0.72227, 0.71859, 0.71807, 0.71900, 0.72968,
                        0.73981, 0.75214, 0.76354, 0.76960, 0.76564, 0.76567, 0.76142, 0.70340],
                       [0.70519, 0.69757, 0.69693, 0.69060, 0.69627, 0.69899, 0.70413,
                        0.70621, 0.71061, 0.70705, 0.71489, 0.71890, 0.72100, 0.71373,
                        0.71318, 0.70722, 0.70513, 0.70460, 0.70771, 0.70371, 0.71437,
                        0.72676, 0.73618, 0.75024, 0.75534, 0.75424, 0.75550, 0.74274, 0.68917],
                       [0.68525, 0.68282, 0.68355, 0.67508, 0.68074, 0.68028, 0.68805,
                        0.69070, 0.69572, 0.69237, 0.70038, 0.70270, 0.70372, 0.69695,
                        0.69443, 0.69162, 0.69031, 0.69255, 0.69293, 0.69043, 0.70029,
                        0.71321, 0.71952, 0.73418, 0.73891, 0.74060, 0.74398, 0.72709, 0.67351],
                       [0.66554, 0.66612, 0.66593, 0.66061, 0.66417, 0.66095, 0.67025,
                        0.67293, 0.68056, 0.67749, 0.68637, 0.68654, 0.68709, 0.67775,
                        0.67647, 0.67576, 0.67550, 0.67786, 0.67265, 0.67490, 0.68651,
                        0.69857, 0.70005, 0.71560, 0.72121, 0.72486, 0.72889, 0.71300, 0.65427],
                       [0.64731, 0.64747, 0.64510, 0.64438, 0.64697, 0.64296, 0.64985,
                        0.65286, 0.66423, 0.66143, 0.67035, 0.66926, 0.67130, 0.65953,
                        0.65890, 0.65991, 0.65800, 0.65798, 0.65132, 0.65690, 0.67194,
                        0.68177, 0.68027, 0.69632, 0.70565, 0.70696, 0.71111, 0.69832, 0.63388],
                       [0.63090, 0.62953, 0.62523, 0.62662, 0.62879, 0.62666, 0.62965,
                        0.63450, 0.64651, 0.64507, 0.65233, 0.65086, 0.65439, 0.64274,
                        0.64161, 0.64262, 0.63836, 0.63531, 0.63333, 0.63954, 0.65496,
                        0.66423, 0.66539, 0.67911, 0.69186, 0.68893, 0.69231, 0.68304, 0.61771],
                       [0.61486, 0.61194, 0.60715, 0.60744, 0.60968, 0.61036, 0.61227,
                        0.61873, 0.62679, 0.62668, 0.63487, 0.63290, 0.63506, 0.62526,
                        0.62536, 0.62214, 0.61833, 0.61370, 0.61622, 0.62279, 0.63450,
                        0.64588, 0.65179, 0.66317, 0.67672, 0.67337, 0.67486, 0.66569, 0.60441],
                       [0.59832, 0.59279, 0.58929, 0.58582, 0.59093, 0.59306, 0.59506,
                        0.60208, 0.60550, 0.60559, 0.61821, 0.61675, 0.61365, 0.60716,
                        0.60724, 0.60049, 0.59923, 0.59535, 0.59620, 0.60336, 0.61222,
                        0.62467, 0.63325, 0.64686, 0.65988, 0.65913, 0.65902, 0.64683, 0.58952],
                       [0.58134, 0.57485, 0.57282, 0.56574, 0.57356, 0.57544, 0.57611,
                        0.58493, 0.58608, 0.58638, 0.60251, 0.60186, 0.59328, 0.59021,
                        0.58719, 0.58439, 0.58223, 0.58061, 0.57681, 0.58188, 0.59174,
                        0.60306, 0.61359, 0.62996, 0.64437, 0.64548, 0.64319, 0.63029, 0.57240],
                       [0.56327, 0.56028, 0.55744, 0.54992, 0.55567, 0.55765, 0.55754,
                        0.56961, 0.56856, 0.57219, 0.58624, 0.58510, 0.57586, 0.57433,
                        0.56889, 0.57204, 0.56574, 0.56716, 0.56227, 0.56252, 0.57316,
                        0.58388, 0.59697, 0.61129, 0.63021, 0.63096, 0.62690, 0.61588, 0.55340],
                       [0.54478, 0.54489, 0.54036, 0.53373, 0.53498, 0.53848, 0.54037,
                        0.55389, 0.54867, 0.55889, 0.56672, 0.56441, 0.55973, 0.55728,
                        0.55340, 0.55454, 0.54659, 0.55169, 0.55110, 0.54621, 0.55443,
                        0.56658, 0.58080, 0.59156, 0.61324, 0.61271, 0.60945, 0.60032, 0.53521],
                       [0.52692, 0.52513, 0.52108, 0.51494, 0.51315, 0.51811, 0.52252,
                        0.53670, 0.52696, 0.54111, 0.54447, 0.54242, 0.54334, 0.53692,
                        0.53751, 0.53289, 0.52609, 0.53262, 0.53784, 0.52975, 0.53605,
                        0.55043, 0.56258, 0.57255, 0.59284, 0.59129, 0.59091, 0.58149, 0.52039],
                       [0.50895, 0.50483, 0.50076, 0.49541, 0.49274, 0.49767, 0.50365,
                        0.51744, 0.50668, 0.51966, 0.52223, 0.52285, 0.52548, 0.51389,
                        0.51788, 0.51339, 0.50732, 0.51203, 0.51865, 0.51082, 0.51869,
                        0.53558, 0.54338, 0.55382, 0.57216, 0.57051, 0.57237, 0.55943, 0.50472],
                       [0.49117, 0.48739, 0.48078, 0.47783, 0.47528, 0.47871, 0.48519,
                        0.49682, 0.48944, 0.50014, 0.50279, 0.50654, 0.50559, 0.49387,
                        0.49835, 0.49722, 0.49163, 0.49143, 0.49688, 0.49182, 0.50275,
                        0.52003, 0.52603, 0.53591, 0.55268, 0.55350, 0.55570, 0.53870, 0.48632],
                       [0.47370, 0.47034, 0.46376, 0.46310, 0.46134, 0.46229, 0.46857,
                        0.47618, 0.47416, 0.48384, 0.48683, 0.48978, 0.48664, 0.47998,
                        0.48328, 0.48123, 0.47845, 0.47024, 0.47645, 0.47556, 0.48747,
                        0.50082, 0.51126, 0.51906, 0.53272, 0.53881, 0.54055, 0.52171, 0.46849],
                       [0.45552, 0.45217, 0.44953, 0.44836, 0.44790, 0.44792, 0.45397,
                        0.45481, 0.45836, 0.46848, 0.47248, 0.47094, 0.47069, 0.46940,
                        0.47076, 0.46290, 0.46405, 0.45147, 0.45757, 0.46079, 0.47069,
                        0.47951, 0.49661, 0.50149, 0.51188, 0.52302, 0.52513, 0.50624, 0.45268],
                       [0.43805, 0.43324, 0.43437, 0.43032, 0.43114, 0.43305, 0.43749,
                        0.43442, 0.44184, 0.45166, 0.45784, 0.45283, 0.45476, 0.45681,
                        0.45544, 0.44315, 0.44582, 0.43801, 0.43926, 0.44456, 0.45293,
                        0.46049, 0.47853, 0.48273, 0.49275, 0.50502, 0.50797, 0.49029, 0.43634],
                       [0.42294, 0.41500, 0.41665, 0.41081, 0.41209, 0.41690, 0.41792,
                        0.41941, 0.42702, 0.43281, 0.44230, 0.43545, 0.43661, 0.44090,
                        0.43719, 0.42467, 0.42640, 0.42669, 0.42267, 0.42639, 0.43641,
                        0.44499, 0.45884, 0.46552, 0.47771, 0.48575, 0.48960, 0.47476, 0.41914],
                       [0.40872, 0.39948, 0.39983, 0.39605, 0.39312, 0.40123, 0.39890,
                        0.40939, 0.41399, 0.41388, 0.42708, 0.41755, 0.41923, 0.42498,
                        0.41929, 0.40929, 0.40965, 0.41410, 0.40954, 0.41017, 0.42060,
                        0.43023, 0.44200, 0.45112, 0.46457, 0.46627, 0.47142, 0.45949, 0.40302],
                       [0.39331, 0.38724, 0.38776, 0.38838, 0.37745, 0.38749, 0.38336,
                        0.40112, 0.40234, 0.39830, 0.41408, 0.40235, 0.40721, 0.41134,
                        0.40439, 0.39671, 0.39686, 0.40237, 0.39873, 0.39868, 0.40591,
                        0.41493, 0.42957, 0.43740, 0.45189, 0.44926, 0.45421, 0.44567, 0.38972],
                       [0.37631, 0.37637, 0.37739, 0.38129, 0.36631, 0.37350, 0.37018,
                        0.39189, 0.39223, 0.38629, 0.40261, 0.39274, 0.39858, 0.39693,
                        0.39208, 0.38500, 0.38707, 0.39288, 0.38593, 0.38855, 0.39265,
                        0.39984, 0.41823, 0.42373, 0.44013, 0.43593, 0.43870, 0.43270, 0.37756],
                       [0.35609, 0.36107, 0.36080, 0.36418, 0.35285, 0.35231, 0.35351,
                        0.37479, 0.37784, 0.37165, 0.38652, 0.38178, 0.38550, 0.37584,
                        0.37590, 0.36790, 0.37400, 0.37843, 0.36726, 0.37258, 0.37530,
                        0.38001, 0.40132, 0.40761, 0.42509, 0.41882, 0.42101, 0.41392, 0.36034],
                       ])),
    N387=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                               100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                               180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                               260.0, 270.0]),
              lam=np.array([380.15, 380.55, 380.96, 381.36, 381.77, 382.17, 382.58,
                            382.98, 383.38, 383.79, 384.19, 384.60, 385.00, 385.41,
                            385.81, 386.22, 386.62, 387.03, 387.43, 387.84, 388.24,
                            388.65, 389.05, 389.46, 389.86, 390.27, 390.68, 391.08,
                            391.49, 391.89, 392.30, 392.70, 393.11, 393.51, 393.92,
                            394.33, 394.73]),
              T=np.array([[0.00954, 0.01177, 0.02095, 0.02880, 0.02507, 0.02293, 0.02928,
                           0.02823, 0.02473, 0.01495, 0.02058, 0.01104, 0.01110, 0.01038,
                           0.01502, 0.00844, 0.00999, 0.00883, 0.01441, 0.01294, 0.01192,
                           0.01300, 0.01655, 0.01481, 0.01838, 0.01290, 0.01324, 0.01464],
                          [0.01004, 0.02120, 0.01675, 0.02667, 0.02660, 0.01929, 0.02015,
                           0.02102, 0.01872, 0.01431, 0.01986, 0.01859, 0.01716, 0.01008,
                           0.01887, 0.01113, 0.00993, 0.01726, 0.02239, 0.00993, 0.00778,
                           0.00880, 0.01699, 0.01296, 0.01607, 0.01178, 0.00798, 0.01240],
                          [0.00947, 0.02323, 0.02844, 0.02946, 0.02700, 0.01797, 0.01627,
                           0.01700, 0.01931, 0.01774, 0.01515, 0.02123, 0.01643, 0.01475,
                           0.01367, 0.01034, 0.00791, 0.01246, 0.02031, 0.00922, 0.01595,
                           0.00779, 0.01789, 0.01603, 0.01372, 0.01224, 0.00984, 0.01255],
                          [0.00638, 0.01875, 0.02752, 0.02516, 0.02531, 0.02532, 0.01595,
                           0.01685, 0.02353, 0.01979, 0.01844, 0.01401, 0.01845, 0.01051,
                           0.01273, 0.01156, 0.01321, 0.00929, 0.01087, 0.01034, 0.01215,
                           0.00569, 0.01441, 0.01331, 0.01151, 0.01034, 0.00792, 0.01409],
                          [0.03162, 0.04135, 0.03509, 0.05226, 0.03677, 0.03786, 0.03008,
                           0.01767, 0.01675, 0.02265, 0.01782, 0.01057, 0.01735, 0.00968,
                           0.01084, 0.00953, 0.00847, 0.01289, 0.00952, 0.01507, 0.00981,
                           0.01249, 0.01556, 0.01363, 0.01549, 0.00825, 0.01136, 0.01173],
                          [0.09415, 0.11651, 0.09402, 0.12402, 0.10154, 0.08525, 0.05154,
                           0.02418, 0.01830, 0.01834, 0.02506, 0.02370, 0.02276, 0.02810,
                           0.01777, 0.01906, 0.01977, 0.01827, 0.02103, 0.03929, 0.04018,
                           0.05089, 0.06225, 0.05485, 0.05549, 0.03431, 0.02730, 0.01126],
                          [0.20015, 0.23921, 0.21104, 0.24390, 0.22605, 0.18526, 0.10975,
                           0.06612, 0.05938, 0.06948, 0.07850, 0.08171, 0.07575, 0.07503,
                           0.05951, 0.05751, 0.05919, 0.06656, 0.08526, 0.10090, 0.11349,
                           0.12940, 0.15134, 0.13825, 0.12891, 0.09822, 0.06778, 0.03747],
                          [0.34849, 0.38635, 0.36787, 0.39442, 0.39480, 0.33051, 0.21568,
                           0.16333, 0.14965, 0.17071, 0.18484, 0.18689, 0.17429, 0.15900,
                           0.14342, 0.14365, 0.14715, 0.16807, 0.19301, 0.21004, 0.23570,
                           0.25351, 0.27861, 0.26834, 0.24298, 0.19731, 0.14563, 0.10353],
                          [0.51995, 0.53324, 0.53642, 0.55238, 0.57059, 0.49826, 0.35913,
                           0.29447, 0.28375, 0.30607, 0.32856, 0.32609, 0.31311, 0.29289,
                           0.27438, 0.28062, 0.28259, 0.30979, 0.33603, 0.35846, 0.39478,
                           0.41162, 0.42815, 0.42805, 0.38742, 0.33169, 0.26256, 0.19847],
                          [0.67217, 0.65996, 0.68272, 0.68790, 0.71221, 0.65249, 0.51932,
                           0.44093, 0.44049, 0.46476, 0.49072, 0.48439, 0.47297, 0.45691,
                           0.43576, 0.44285, 0.44503, 0.46898, 0.49561, 0.52173, 0.55727,
                           0.56910, 0.58085, 0.58546, 0.54067, 0.48377, 0.40399, 0.31270],
                          [0.77157, 0.75966, 0.78460, 0.78707, 0.80392, 0.76576, 0.66729,
                           0.59256, 0.59716, 0.62821, 0.64693, 0.64135, 0.62851, 0.61798,
                           0.60114, 0.60646, 0.60366, 0.62188, 0.64753, 0.66928, 0.69209,
                           0.70044, 0.70500, 0.71332, 0.67866, 0.62852, 0.54691, 0.44631],
                          [0.81726, 0.82471, 0.83859, 0.84071, 0.84626, 0.82636, 0.77108,
                           0.72586, 0.72716, 0.75503, 0.76366, 0.76628, 0.74607, 0.74546,
                           0.73365, 0.73362, 0.73195, 0.74135, 0.76085, 0.77468, 0.77843,
                           0.78463, 0.78885, 0.79059, 0.77480, 0.73553, 0.66842, 0.57700],
                          [0.83737, 0.85501, 0.86113, 0.85654, 0.85203, 0.84755, 0.82499,
                           0.81284, 0.80880, 0.82050, 0.82712, 0.83541, 0.81029, 0.82047,
                           0.81137, 0.80392, 0.80643, 0.81061, 0.82087, 0.82307, 0.81652,
                           0.82283, 0.82477, 0.82166, 0.81710, 0.79353, 0.75484, 0.68081],
                          [0.85148, 0.86212, 0.86795, 0.85514, 0.84636, 0.85338, 0.84398,
                           0.84873, 0.84147, 0.84036, 0.84401, 0.85476, 0.83672, 0.84154,
                           0.83771, 0.82371, 0.83080, 0.83281, 0.83484, 0.82857, 0.82504,
                           0.82522, 0.82640, 0.82402, 0.81960, 0.81349, 0.80018, 0.74489],
                          [0.86389, 0.86247, 0.87054, 0.85506, 0.85028, 0.85644, 0.85169,
                           0.85863, 0.85084, 0.84813, 0.84416, 0.85149, 0.84479, 0.83732,
                           0.83866, 0.82448, 0.82718, 0.83018, 0.82764, 0.82227, 0.82659,
                           0.82088, 0.81677, 0.82103, 0.81000, 0.81663, 0.81301, 0.78237],
                          [0.87093, 0.86558, 0.87310, 0.86067, 0.86151, 0.85965, 0.85795,
                           0.85868, 0.85529, 0.85490, 0.84735, 0.84455, 0.84636, 0.83495,
                           0.83401, 0.82664, 0.81941, 0.82708, 0.82455, 0.82608, 0.82921,
                           0.82274, 0.81433, 0.82133, 0.80558, 0.81753, 0.81376, 0.80540],
                          [0.86572, 0.86654, 0.86750, 0.86096, 0.86605, 0.85652, 0.85771,
                           0.85440, 0.85554, 0.85244, 0.85257, 0.84171, 0.84498, 0.83842,
                           0.83108, 0.83133, 0.82125, 0.82960, 0.82974, 0.83019, 0.82872,
                           0.82198, 0.81810, 0.81523, 0.80475, 0.81376, 0.81054, 0.81169],
                          [0.84852, 0.85170, 0.85095, 0.84922, 0.85732, 0.84812, 0.85603,
                           0.85278, 0.85383, 0.84886, 0.85807, 0.84690, 0.84330, 0.84314,
                           0.83523, 0.84089, 0.82980, 0.83641, 0.83557, 0.83032, 0.82614,
                           0.81811, 0.81359, 0.80204, 0.80011, 0.80382, 0.79890, 0.80258],
                          [0.81771, 0.81315, 0.82215, 0.81617, 0.82947, 0.82923, 0.84601,
                           0.85304, 0.85142, 0.84957, 0.85493, 0.85206, 0.84339, 0.84461,
                           0.84013, 0.84498, 0.83949, 0.83662, 0.83046, 0.82335, 0.81227,
                           0.79980, 0.79013, 0.77387, 0.77626, 0.77678, 0.77668, 0.77555],
                          [0.76355, 0.74074, 0.76801, 0.75126, 0.76931, 0.78403, 0.81752,
                           0.84115, 0.84252, 0.84374, 0.83574, 0.83662, 0.82851, 0.83219,
                           0.82937, 0.83355, 0.82751, 0.81489, 0.80175, 0.79155, 0.77108,
                           0.75180, 0.73211, 0.71813, 0.72004, 0.72826, 0.73811, 0.73125],
                          [0.66817, 0.62747, 0.66921, 0.64426, 0.65887, 0.69251, 0.75163,
                           0.79358, 0.80287, 0.80059, 0.77957, 0.77905, 0.77509, 0.77893,
                           0.77904, 0.78106, 0.77185, 0.75440, 0.73263, 0.71205, 0.68418,
                           0.65565, 0.63222, 0.62152, 0.62412, 0.64556, 0.66870, 0.66165],
                          [0.52846, 0.48704, 0.52843, 0.50336, 0.50300, 0.55486, 0.64495,
                           0.70494, 0.71745, 0.70337, 0.67606, 0.67545, 0.67218, 0.67441,
                           0.68059, 0.67692, 0.66896, 0.64675, 0.61918, 0.58656, 0.55413,
                           0.51963, 0.49787, 0.48801, 0.49799, 0.52668, 0.56306, 0.56396],
                          [0.36467, 0.33878, 0.36913, 0.34806, 0.32638, 0.39175, 0.50737,
                           0.58227, 0.59062, 0.56384, 0.53538, 0.53118, 0.52840, 0.53332,
                           0.54309, 0.53648, 0.52734, 0.50241, 0.47281, 0.43402, 0.40024,
                           0.37043, 0.34442, 0.33782, 0.35343, 0.38431, 0.43267, 0.44917],
                          [0.20953, 0.20301, 0.21489, 0.20313, 0.16797, 0.23255, 0.35505,
                           0.43626, 0.43559, 0.40229, 0.37308, 0.36589, 0.36619, 0.37494,
                           0.38423, 0.37952, 0.36852, 0.34458, 0.31587, 0.27971, 0.24873,
                           0.22609, 0.20057, 0.19714, 0.21449, 0.24314, 0.29407, 0.32695],
                          [0.09322, 0.09841, 0.09543, 0.09216, 0.06034, 0.10645, 0.21173,
                           0.28519, 0.27861, 0.24324, 0.21904, 0.21080, 0.21243, 0.22431,
                           0.23337, 0.23158, 0.22015, 0.20016, 0.17771, 0.14808, 0.12585,
                           0.11247, 0.09251, 0.09285, 0.10518, 0.12877, 0.16878, 0.21269],
                          [0.02823, 0.03500, 0.02813, 0.02723, 0.01238, 0.03051, 0.09934,
                           0.15095, 0.14644, 0.11453, 0.09907, 0.09406, 0.09456, 0.10491,
                           0.11471, 0.11457, 0.10570, 0.09146, 0.07734, 0.05774, 0.04737,
                           0.04002, 0.03275, 0.03338, 0.03833, 0.05261, 0.07776, 0.11932],
                          [0.00504, 0.00852, 0.00803, 0.00862, 0.01169, 0.00784, 0.03137,
                           0.05793, 0.05742, 0.03659, 0.02779, 0.02657, 0.02653, 0.03341,
                           0.04066, 0.04339, 0.03460, 0.02679, 0.02118, 0.01329, 0.01159,
                           0.00805, 0.00789, 0.00837, 0.00991, 0.01364, 0.02810, 0.05281],
                          [0.00586, 0.00354, 0.00792, 0.00733, 0.01208, 0.00936, 0.00893,
                           0.01202, 0.01304, 0.00777, 0.00587, 0.00506, 0.00471, 0.00570,
                           0.00609, 0.01143, 0.00842, 0.00186, 0.00241, 0.00481, 0.00542,
                           0.00438, 0.00386, 0.00303, 0.00495, 0.00290, 0.00790, 0.01471],
                          [0.00413, 0.00536, 0.00684, 0.00865, 0.01085, 0.00898, 0.00907,
                           0.00894, 0.00845, 0.00661, 0.00683, 0.00677, 0.00433, 0.00541,
                           0.00587, 0.00393, 0.00587, 0.00597, 0.00372, 0.00280, 0.00382,
                           0.00442, 0.00201, 0.00439, 0.00469, 0.00207, 0.00593, 0.00384],
                          [0.00389, 0.00762, 0.00569, 0.00928, 0.00780, 0.00772, 0.00776,
                           0.00700, 0.00756, 0.00660, 0.00447, 0.00575, 0.00424, 0.00408,
                           0.00430, 0.00432, 0.00555, 0.00641, 0.00382, 0.00521, 0.00354,
                           0.00386, 0.00328, 0.00365, 0.00206, 0.00301, 0.00715, 0.00408],
                          [0.00417, 0.00842, 0.00854, 0.00811, 0.00578, 0.00717, 0.00659,
                           0.00760, 0.00431, 0.00678, 0.00523, 0.00423, 0.00544, 0.00443,
                           0.00426, 0.00380, 0.00444, 0.00567, 0.00270, 0.00519, 0.00222,
                           0.00302, 0.00384, 0.00531, 0.00218, 0.00483, 0.00624, 0.00331],
                          [0.00417, 0.00743, 0.00898, 0.00867, 0.00650, 0.00644, 0.00802,
                           0.00675, 0.00320, 0.00695, 0.00495, 0.00393, 0.00528, 0.00326,
                           0.00402, 0.00304, 0.00455, 0.00525, 0.00397, 0.00295, 0.00512,
                           0.00270, 0.00323, 0.00450, 0.00326, 0.00509, 0.00375, 0.00477],
                          [0.00339, 0.00459, 0.00914, 0.00930, 0.00779, 0.00671, 0.00768,
                           0.00681, 0.00539, 0.00772, 0.00363, 0.00516, 0.00546, 0.00196,
                           0.00458, 0.00303, 0.00464, 0.00444, 0.00417, 0.00366, 0.00507,
                           0.00313, 0.00450, 0.00494, 0.00218, 0.00387, 0.00314, 0.00509],
                          [0.00438, 0.00492, 0.00671, 0.00675, 0.00705, 0.00800, 0.00924,
                           0.00603, 0.00690, 0.00857, 0.00354, 0.00627, 0.00453, 0.00230,
                           0.00418, 0.00268, 0.00399, 0.00182, 0.00311, 0.00418, 0.00347,
                           0.00285, 0.00585, 0.00491, 0.00298, 0.00263, 0.00311, 0.00463],
                          [0.00275, 0.00755, 0.00525, 0.00580, 0.00766, 0.00748, 0.00652,
                           0.00543, 0.00677, 0.00714, 0.00540, 0.00370, 0.00490, 0.00390,
                           0.00504, 0.00478, 0.00407, 0.00287, 0.00355, 0.00398, 0.00377,
                           0.00267, 0.00481, 0.00293, 0.00370, 0.00353, 0.00305, 0.00352],
                          [0.00241, 0.00606, 0.00654, 0.00768, 0.00767, 0.00804, 0.00668,
                           0.00480, 0.00634, 0.00506, 0.00631, 0.00303, 0.00426, 0.00437,
                           0.00540, 0.00672, 0.00383, 0.00145, 0.00403, 0.00188, 0.00327,
                           0.00276, 0.00365, 0.00344, 0.00290, 0.00436, 0.00386, 0.00372],
                          [0.00241, 0.00367, 0.00766, 0.00857, 0.00812, 0.00771, 0.00717,
                           0.00586, 0.00630, 0.00351, 0.00571, 0.00391, 0.00341, 0.00445,
                           0.00465, 0.00529, 0.00401, 0.00370, 0.00522, 0.00351, 0.00215,
                           0.00188, 0.00218, 0.00356, 0.00296, 0.00244, 0.00326, 0.00223],
                          ])),
    N816=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                               100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                               180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                               260.0, 270.0]),
              lam=np.array([805.22, 805.66, 806.10, 806.55, 806.99, 807.44, 807.88,
                            808.33, 808.77, 809.22, 809.66, 810.11, 810.55, 810.99,
                            811.44, 811.88, 812.33, 812.77, 813.22, 813.66, 814.11,
                            814.55, 815.00, 815.44, 815.89, 816.33, 816.78, 817.22,
                            817.67, 818.11, 818.56, 819.00, 819.45, 819.90, 820.34,
                            820.79, 821.23, 821.68, 822.12, 822.57, 823.01, 823.46,
                            823.90, 824.35, 824.79, 825.24, 825.69, 826.13, 826.58,
                            827.02, 827.47, 827.91, 828.36, 828.81, 829.25, 829.70]),
              T=np.array([[0.00785, 0.00802, 0.00776, 0.00792, 0.00776, 0.00740, 0.00761,
                           0.00709, 0.00703, 0.00692, 0.00651, 0.00648, 0.00602, 0.00604,
                           0.00580, 0.00576, 0.00546, 0.00553, 0.00544, 0.00548, 0.00577,
                           0.00560, 0.00579, 0.00604, 0.00671, 0.00718, 0.00847, 0.01655],
                          [0.00999, 0.00990, 0.00982, 0.00969, 0.00961, 0.00904, 0.00931,
                           0.00861, 0.00860, 0.00817, 0.00787, 0.00765, 0.00705, 0.00684,
                           0.00715, 0.00671, 0.00658, 0.00667, 0.00623, 0.00652, 0.00649,
                           0.00649, 0.00667, 0.00719, 0.00791, 0.00872, 0.01044, 0.02135],
                          [0.01271, 0.01255, 0.01263, 0.01219, 0.01222, 0.01164, 0.01140,
                           0.01093, 0.01073, 0.00990, 0.00970, 0.00930, 0.00871, 0.00821,
                           0.00859, 0.00802, 0.00789, 0.00794, 0.00746, 0.00760, 0.00767,
                           0.00767, 0.00802, 0.00852, 0.00957, 0.01085, 0.01328, 0.02754],
                          [0.01679, 0.01657, 0.01649, 0.01589, 0.01604, 0.01554, 0.01480,
                           0.01425, 0.01346, 0.01286, 0.01227, 0.01171, 0.01101, 0.01045,
                           0.01031, 0.00981, 0.00938, 0.00950, 0.00918, 0.00906, 0.00930,
                           0.00937, 0.00987, 0.01059, 0.01197, 0.01399, 0.01739, 0.03577],
                          [0.02305, 0.02280, 0.02252, 0.02180, 0.02161, 0.02099, 0.01984,
                           0.01892, 0.01778, 0.01701, 0.01590, 0.01517, 0.01430, 0.01371,
                           0.01296, 0.01233, 0.01175, 0.01183, 0.01157, 0.01133, 0.01136,
                           0.01196, 0.01253, 0.01379, 0.01547, 0.01841, 0.02356, 0.04711],
                          [0.03246, 0.03226, 0.03200, 0.03107, 0.03015, 0.02905, 0.02754,
                           0.02605, 0.02479, 0.02299, 0.02127, 0.02039, 0.01905, 0.01825,
                           0.01709, 0.01604, 0.01561, 0.01513, 0.01491, 0.01478, 0.01477,
                           0.01557, 0.01643, 0.01818, 0.02056, 0.02468, 0.03284, 0.06250],
                          [0.04659, 0.04651, 0.04613, 0.04498, 0.04339, 0.04153, 0.03951,
                           0.03708, 0.03503, 0.03220, 0.02982, 0.02827, 0.02626, 0.02486,
                           0.02325, 0.02162, 0.02111, 0.01996, 0.01975, 0.01971, 0.01999,
                           0.02068, 0.02213, 0.02441, 0.02799, 0.03420, 0.04618, 0.08323],
                          [0.06771, 0.06777, 0.06695, 0.06537, 0.06330, 0.06031, 0.05735,
                           0.05380, 0.05024, 0.04641, 0.04320, 0.04015, 0.03726, 0.03477,
                           0.03256, 0.03016, 0.02902, 0.02763, 0.02716, 0.02691, 0.02750,
                           0.02836, 0.03046, 0.03390, 0.03910, 0.04844, 0.06507, 0.11054],
                          [0.09809, 0.09785, 0.09653, 0.09405, 0.09149, 0.08734, 0.08284,
                           0.07808, 0.07294, 0.06776, 0.06290, 0.05805, 0.05376, 0.04981,
                           0.04654, 0.04327, 0.04100, 0.03939, 0.03847, 0.03791, 0.03851,
                           0.03996, 0.04297, 0.04801, 0.05583, 0.06897, 0.09104, 0.14475],
                          [0.13788, 0.13726, 0.13546, 0.13228, 0.12888, 0.12370, 0.11761,
                           0.11124, 0.10445, 0.09746, 0.09055, 0.08391, 0.07790, 0.07200,
                           0.06727, 0.06273, 0.05903, 0.05655, 0.05517, 0.05448, 0.05501,
                           0.05719, 0.06166, 0.06865, 0.07974, 0.09730, 0.12561, 0.18602],
                          [0.18582, 0.18558, 0.18300, 0.17976, 0.17515, 0.16890, 0.16171,
                           0.15345, 0.14472, 0.13609, 0.12705, 0.11850, 0.11087, 0.10272,
                           0.09602, 0.09008, 0.08501, 0.08108, 0.07911, 0.07824, 0.07881,
                           0.08168, 0.08799, 0.09725, 0.11145, 0.13399, 0.16864, 0.23464],
                          [0.24140, 0.24112, 0.23802, 0.23462, 0.22921, 0.22191, 0.21390,
                           0.20395, 0.19365, 0.18340, 0.17258, 0.16210, 0.15235, 0.14249,
                           0.13369, 0.12622, 0.11979, 0.11461, 0.11178, 0.11033, 0.11123,
                           0.11496, 0.12263, 0.13446, 0.15187, 0.17893, 0.21888, 0.28997],
                          [0.30350, 0.30248, 0.29984, 0.29571, 0.29005, 0.28193, 0.27279,
                           0.26180, 0.25047, 0.23841, 0.22625, 0.21420, 0.20205, 0.19110,
                           0.18056, 0.17133, 0.16331, 0.15714, 0.15354, 0.15127, 0.15271,
                           0.15740, 0.16608, 0.18039, 0.20128, 0.23195, 0.27608, 0.35130],
                          [0.37109, 0.36987, 0.36804, 0.36278, 0.35668, 0.34798, 0.33779,
                           0.32620, 0.31361, 0.30015, 0.28654, 0.27318, 0.25971, 0.24763,
                           0.23551, 0.22442, 0.21503, 0.20800, 0.20361, 0.20111, 0.20270,
                           0.20811, 0.21801, 0.23425, 0.25821, 0.29173, 0.33986, 0.41845],
                          [0.44391, 0.44299, 0.44085, 0.43527, 0.42817, 0.41913, 0.40818,
                           0.39592, 0.38175, 0.36749, 0.35250, 0.33782, 0.32344, 0.31014,
                           0.29664, 0.28400, 0.27366, 0.26598, 0.26062, 0.25836, 0.25995,
                           0.26573, 0.27692, 0.29436, 0.32080, 0.35691, 0.40883, 0.49040],
                          [0.52105, 0.52004, 0.51704, 0.51185, 0.50412, 0.49469, 0.48287,
                           0.47007, 0.45465, 0.43954, 0.42358, 0.40748, 0.39180, 0.37721,
                           0.36272, 0.34928, 0.33827, 0.32972, 0.32355, 0.32129, 0.32287,
                           0.32888, 0.34128, 0.36000, 0.38858, 0.42714, 0.48199, 0.56538],
                          [0.60051, 0.59923, 0.59619, 0.59079, 0.58359, 0.57401, 0.56136,
                           0.54814, 0.53207, 0.51614, 0.49930, 0.48160, 0.46510, 0.44932,
                           0.43414, 0.41989, 0.40799, 0.39823, 0.39180, 0.38947, 0.39050,
                           0.39736, 0.41036, 0.43099, 0.46138, 0.50221, 0.55854, 0.64111],
                          [0.67983, 0.67872, 0.67575, 0.67019, 0.66383, 0.65429, 0.64266,
                           0.62862, 0.61277, 0.59640, 0.57877, 0.56025, 0.54333, 0.52675,
                           0.51075, 0.49544, 0.48221, 0.47193, 0.46521, 0.46251, 0.46346,
                           0.47111, 0.48443, 0.50654, 0.53810, 0.58082, 0.63655, 0.71408],
                          [0.75334, 0.75271, 0.74969, 0.74518, 0.73906, 0.73020, 0.72086,
                           0.70728, 0.69203, 0.67631, 0.65893, 0.64085, 0.62399, 0.60681,
                           0.59023, 0.57412, 0.56036, 0.55039, 0.54282, 0.53949, 0.54129,
                           0.54862, 0.56280, 0.58481, 0.61667, 0.65925, 0.71171, 0.77880],
                          [0.81369, 0.81309, 0.81071, 0.80772, 0.80284, 0.79600, 0.78794,
                           0.77755, 0.76353, 0.75006, 0.73441, 0.71806, 0.70219, 0.68576,
                           0.66989, 0.65321, 0.63998, 0.63022, 0.62226, 0.61896, 0.62094,
                           0.62807, 0.64254, 0.66339, 0.69393, 0.73310, 0.77889, 0.83137],
                          [0.85671, 0.85649, 0.85479, 0.85291, 0.85091, 0.84665, 0.83979,
                           0.83297, 0.82218, 0.81203, 0.79983, 0.78615, 0.77228, 0.75911,
                           0.74474, 0.72910, 0.71720, 0.70737, 0.70034, 0.69709, 0.69879,
                           0.70618, 0.71905, 0.73801, 0.76514, 0.79778, 0.83371, 0.87029],
                          [0.88326, 0.88326, 0.88225, 0.88151, 0.88170, 0.87986, 0.87561,
                           0.87089, 0.86469, 0.85805, 0.84994, 0.83968, 0.82909, 0.81997,
                           0.80825, 0.79586, 0.78616, 0.77715, 0.77186, 0.76863, 0.76987,
                           0.77678, 0.78710, 0.80273, 0.82428, 0.84869, 0.87351, 0.89527],
                          [0.89676, 0.89639, 0.89648, 0.89685, 0.89753, 0.89774, 0.89618,
                           0.89344, 0.89105, 0.88724, 0.88233, 0.87619, 0.86990, 0.86394,
                           0.85607, 0.84780, 0.84062, 0.83421, 0.83049, 0.82797, 0.82859,
                           0.83383, 0.84169, 0.85276, 0.86821, 0.88391, 0.89882, 0.90860],
                          [0.90163, 0.90138, 0.90214, 0.90326, 0.90433, 0.90533, 0.90521,
                           0.90477, 0.90436, 0.90261, 0.89997, 0.89757, 0.89493, 0.89197,
                           0.88784, 0.88311, 0.87815, 0.87513, 0.87236, 0.87086, 0.87129,
                           0.87504, 0.88013, 0.88727, 0.89718, 0.90532, 0.91248, 0.91463],
                          [0.90283, 0.90285, 0.90373, 0.90530, 0.90698, 0.90797, 0.90845,
                           0.90954, 0.90962, 0.90985, 0.90919, 0.90827, 0.90786, 0.90738,
                           0.90688, 0.90437, 0.90099, 0.90060, 0.89905, 0.89852, 0.89863,
                           0.90199, 0.90435, 0.90862, 0.91422, 0.91721, 0.91905, 0.91734],
                          [0.90277, 0.90239, 0.90342, 0.90535, 0.90739, 0.90821, 0.90975,
                           0.91111, 0.91092, 0.91291, 0.91333, 0.91285, 0.91376, 0.91457,
                           0.91647, 0.91513, 0.91336, 0.91440, 0.91451, 0.91435, 0.91430,
                           0.91709, 0.91823, 0.92028, 0.92282, 0.92311, 0.92194, 0.91781],
                          [0.90193, 0.90141, 0.90221, 0.90423, 0.90647, 0.90768, 0.90983,
                           0.91085, 0.91101, 0.91315, 0.91384, 0.91434, 0.91574, 0.91762,
                           0.91965, 0.91923, 0.91941, 0.92097, 0.92219, 0.92187, 0.92217,
                           0.92365, 0.92458, 0.92574, 0.92616, 0.92511, 0.92279, 0.91585],
                          [0.90042, 0.90002, 0.90044, 0.90243, 0.90451, 0.90682, 0.90843,
                           0.90965, 0.91029, 0.91220, 0.91301, 0.91443, 0.91541, 0.91866,
                           0.92009, 0.92045, 0.92190, 0.92349, 0.92535, 0.92489, 0.92529,
                           0.92614, 0.92636, 0.92739, 0.92691, 0.92485, 0.92222, 0.91176],
                          [0.89701, 0.89697, 0.89764, 0.89965, 0.90180, 0.90451, 0.90629,
                           0.90833, 0.90871, 0.91117, 0.91278, 0.91375, 0.91521, 0.91885,
                           0.92045, 0.92100, 0.92270, 0.92440, 0.92638, 0.92620, 0.92648,
                           0.92764, 0.92720, 0.92733, 0.92693, 0.92442, 0.92074, 0.90687],
                          [0.89019, 0.89022, 0.89163, 0.89340, 0.89666, 0.89900, 0.90219,
                           0.90437, 0.90600, 0.90901, 0.91160, 0.91234, 0.91471, 0.91795,
                           0.92032, 0.92112, 0.92221, 0.92448, 0.92564, 0.92666, 0.92655,
                           0.92792, 0.92743, 0.92706, 0.92606, 0.92336, 0.91850, 0.89961],
                          [0.87885, 0.87850, 0.88007, 0.88197, 0.88645, 0.88869, 0.89323,
                           0.89578, 0.90010, 0.90364, 0.90700, 0.90896, 0.91166, 0.91528,
                           0.91850, 0.91982, 0.92060, 0.92306, 0.92421, 0.92532, 0.92566,
                           0.92650, 0.92648, 0.92588, 0.92393, 0.92031, 0.91408, 0.88750],
                          [0.86082, 0.86065, 0.86175, 0.86471, 0.86961, 0.87320, 0.87826,
                           0.88248, 0.88835, 0.89316, 0.89765, 0.90164, 0.90514, 0.91021,
                           0.91396, 0.91625, 0.91820, 0.92058, 0.92276, 0.92315, 0.92439,
                           0.92467, 0.92418, 0.92268, 0.92065, 0.91525, 0.90573, 0.87014],
                          [0.83361, 0.83416, 0.83525, 0.83959, 0.84477, 0.85047, 0.85603,
                           0.86196, 0.86867, 0.87569, 0.88164, 0.88773, 0.89326, 0.89984,
                           0.90494, 0.90882, 0.91209, 0.91530, 0.91795, 0.91913, 0.91994,
                           0.92094, 0.91880, 0.91652, 0.91305, 0.90536, 0.89098, 0.84660],
                          [0.79845, 0.79921, 0.80125, 0.80613, 0.81192, 0.81908, 0.82604,
                           0.83336, 0.84101, 0.85086, 0.85885, 0.86645, 0.87455, 0.88275,
                           0.89058, 0.89612, 0.90038, 0.90495, 0.90805, 0.91058, 0.91092,
                           0.91240, 0.90898, 0.90554, 0.89902, 0.88803, 0.86865, 0.81643],
                          [0.75635, 0.75694, 0.75965, 0.76451, 0.77136, 0.77934, 0.78794,
                           0.79670, 0.80605, 0.81759, 0.82812, 0.83731, 0.84748, 0.85789,
                           0.86808, 0.87581, 0.88145, 0.88737, 0.89223, 0.89481, 0.89565,
                           0.89644, 0.89244, 0.88691, 0.87719, 0.86218, 0.83775, 0.77901],
                          [0.70737, 0.70798, 0.71086, 0.71594, 0.72359, 0.73243, 0.74239,
                           0.75258, 0.76436, 0.77602, 0.78895, 0.80024, 0.81212, 0.82447,
                           0.83593, 0.84633, 0.85434, 0.86140, 0.86818, 0.87084, 0.87169,
                           0.87180, 0.86763, 0.85970, 0.84720, 0.82847, 0.79902, 0.73482],
                          [0.65217, 0.65278, 0.65601, 0.66151, 0.66939, 0.67939, 0.69036,
                           0.70207, 0.71541, 0.72811, 0.74202, 0.75555, 0.76928, 0.78362,
                           0.79660, 0.80839, 0.81859, 0.82720, 0.83435, 0.83837, 0.83910,
                           0.83874, 0.83416, 0.82426, 0.80946, 0.78760, 0.75399, 0.68461],
                          [0.59015, 0.59109, 0.59465, 0.60111, 0.60973, 0.62013, 0.63191,
                           0.64524, 0.65970, 0.67476, 0.68954, 0.70449, 0.72020, 0.73601,
                           0.75114, 0.76295, 0.77499, 0.78568, 0.79314, 0.79797, 0.79917,
                           0.79855, 0.79278, 0.78163, 0.76481, 0.74032, 0.70318, 0.62845],
                          [0.52050, 0.52185, 0.52548, 0.53315, 0.54293, 0.55351, 0.56654,
                           0.58153, 0.59717, 0.61442, 0.63140, 0.64748, 0.66474, 0.68163,
                           0.69866, 0.71157, 0.72545, 0.73703, 0.74610, 0.75085, 0.75276,
                           0.75201, 0.74469, 0.73240, 0.71383, 0.68731, 0.64582, 0.56539],
                          [0.44334, 0.44487, 0.44861, 0.45673, 0.46686, 0.47869, 0.49366,
                           0.50962, 0.52702, 0.54580, 0.56500, 0.58290, 0.60185, 0.62081,
                           0.63919, 0.65495, 0.66980, 0.68186, 0.69189, 0.69738, 0.69999,
                           0.69850, 0.69015, 0.67663, 0.65655, 0.62725, 0.57994, 0.49396],
                          [0.36131, 0.36282, 0.36667, 0.37445, 0.38480, 0.39767, 0.41370,
                           0.43019, 0.44937, 0.46937, 0.49014, 0.51061, 0.53134, 0.55276,
                           0.57282, 0.59067, 0.60659, 0.62058, 0.63063, 0.63746, 0.64024,
                           0.63822, 0.62927, 0.61445, 0.59226, 0.55902, 0.50485, 0.41437],
                          [0.28002, 0.28128, 0.28479, 0.29191, 0.30216, 0.31477, 0.32987,
                           0.34691, 0.36602, 0.38708, 0.40877, 0.43112, 0.45323, 0.47633,
                           0.49836, 0.51755, 0.53511, 0.55097, 0.56219, 0.57003, 0.57267,
                           0.57083, 0.56136, 0.54420, 0.51946, 0.48194, 0.42186, 0.33076],
                          [0.20598, 0.20663, 0.20979, 0.21602, 0.22498, 0.23610, 0.24912,
                           0.26511, 0.28265, 0.30311, 0.32458, 0.34666, 0.36952, 0.39283,
                           0.41583, 0.43719, 0.45570, 0.47224, 0.48535, 0.49368, 0.49658,
                           0.49475, 0.48455, 0.46528, 0.43811, 0.39708, 0.33527, 0.24996],
                          [0.14487, 0.14511, 0.14772, 0.15282, 0.15961, 0.16872, 0.17925,
                           0.19236, 0.20733, 0.22525, 0.24396, 0.26389, 0.28557, 0.30756,
                           0.33014, 0.35218, 0.37119, 0.38777, 0.40152, 0.41029, 0.41326,
                           0.41120, 0.40014, 0.38080, 0.35244, 0.31035, 0.25250, 0.17930],
                          [0.09884, 0.09933, 0.10116, 0.10476, 0.10963, 0.11626, 0.12410,
                           0.13402, 0.14562, 0.15955, 0.17421, 0.19098, 0.20896, 0.22825,
                           0.24862, 0.26821, 0.28651, 0.30312, 0.31567, 0.32437, 0.32738,
                           0.32478, 0.31382, 0.29585, 0.26851, 0.22973, 0.18083, 0.12386],
                          [0.06674, 0.06752, 0.06883, 0.07088, 0.07421, 0.07861, 0.08404,
                           0.09095, 0.09966, 0.10890, 0.12028, 0.13305, 0.14642, 0.16159,
                           0.17795, 0.19358, 0.20906, 0.22438, 0.23506, 0.24243, 0.24558,
                           0.24262, 0.23304, 0.21742, 0.19345, 0.16212, 0.12449, 0.08447],
                          [0.04595, 0.04641, 0.04710, 0.04838, 0.05045, 0.05352, 0.05716,
                           0.06171, 0.06790, 0.07369, 0.08206, 0.09069, 0.10023, 0.11088,
                           0.12258, 0.13432, 0.14603, 0.15778, 0.16671, 0.17220, 0.17463,
                           0.17222, 0.16479, 0.15238, 0.13374, 0.11073, 0.08432, 0.05788],
                          [0.03267, 0.03256, 0.03304, 0.03386, 0.03530, 0.03746, 0.03979,
                           0.04284, 0.04644, 0.05078, 0.05592, 0.06152, 0.06818, 0.07506,
                           0.08299, 0.09131, 0.09967, 0.10728, 0.11392, 0.11816, 0.11944,
                           0.11802, 0.11285, 0.10383, 0.09070, 0.07482, 0.05746, 0.03987],
                          [0.02385, 0.02342, 0.02387, 0.02449, 0.02576, 0.02703, 0.02849,
                           0.03047, 0.03236, 0.03567, 0.03863, 0.04251, 0.04674, 0.05109,
                           0.05637, 0.06199, 0.06769, 0.07259, 0.07685, 0.08027, 0.08091,
                           0.08026, 0.07651, 0.07034, 0.06176, 0.05133, 0.04008, 0.02832],
                          [0.01784, 0.01734, 0.01761, 0.01836, 0.01917, 0.01991, 0.02106,
                           0.02215, 0.02349, 0.02552, 0.02761, 0.03021, 0.03263, 0.03571,
                           0.03910, 0.04279, 0.04631, 0.04995, 0.05265, 0.05498, 0.05567,
                           0.05496, 0.05230, 0.04820, 0.04282, 0.03617, 0.02861, 0.02115],
                          [0.01350, 0.01344, 0.01361, 0.01421, 0.01438, 0.01516, 0.01588,
                           0.01662, 0.01792, 0.01895, 0.02055, 0.02196, 0.02359, 0.02601,
                           0.02803, 0.03038, 0.03294, 0.03501, 0.03694, 0.03826, 0.03913,
                           0.03810, 0.03672, 0.03392, 0.03035, 0.02610, 0.02098, 0.01622],
                          [0.01034, 0.01085, 0.01089, 0.01107, 0.01108, 0.01192, 0.01231,
                           0.01279, 0.01387, 0.01469, 0.01578, 0.01642, 0.01782, 0.01964,
                           0.02073, 0.02225, 0.02436, 0.02510, 0.02652, 0.02731, 0.02806,
                           0.02748, 0.02675, 0.02477, 0.02233, 0.01943, 0.01605, 0.01255],
                          [0.00827, 0.00883, 0.00878, 0.00851, 0.00886, 0.00944, 0.00983,
                           0.00995, 0.01068, 0.01170, 0.01237, 0.01263, 0.01386, 0.01494,
                           0.01569, 0.01680, 0.01806, 0.01873, 0.01955, 0.02018, 0.02059,
                           0.02055, 0.02011, 0.01855, 0.01706, 0.01484, 0.01276, 0.00999],
                          [0.00690, 0.00720, 0.00720, 0.00675, 0.00736, 0.00759, 0.00795,
                           0.00813, 0.00840, 0.00926, 0.00960, 0.00981, 0.01113, 0.01151,
                           0.01219, 0.01286, 0.01360, 0.01444, 0.01490, 0.01556, 0.01560,
                           0.01565, 0.01547, 0.01414, 0.01325, 0.01166, 0.01029, 0.00812],
                          [0.00559, 0.00598, 0.00600, 0.00564, 0.00609, 0.00621, 0.00656,
                           0.00685, 0.00684, 0.00718, 0.00748, 0.00787, 0.00902, 0.00909,
                           0.00982, 0.00999, 0.01079, 0.01142, 0.01176, 0.01232, 0.01216,
                           0.01217, 0.01206, 0.01115, 0.01042, 0.00971, 0.00821, 0.00635],
                          [0.00450, 0.00487, 0.00495, 0.00490, 0.00504, 0.00507, 0.00547,
                           0.00576, 0.00572, 0.00571, 0.00611, 0.00669, 0.00721, 0.00726,
                           0.00812, 0.00818, 0.00876, 0.00918, 0.00925, 0.00954, 0.00971,
                           0.00961, 0.00965, 0.00891, 0.00832, 0.00807, 0.00645, 0.00496],
                          ])),
    N921=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0,
                               100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0, 170.0,
                               180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0, 250.0,
                               260.0, 270.0]),
              lam=np.array([905.13, 905.58, 906.03, 906.48, 906.93, 907.38, 907.83,
                            908.28, 908.73, 909.18, 909.64, 910.09, 910.54, 910.99,
                            911.44, 911.89, 912.34, 912.79, 913.24, 913.69, 914.14,
                            914.59, 915.04, 915.49, 915.94, 916.39, 916.84, 917.29,
                            917.74, 918.19, 918.65, 919.10, 919.55, 920.00, 920.45,
                            920.90, 921.35, 921.80, 922.25, 922.70, 923.15, 923.60,
                            924.06, 924.51, 924.96, 925.41, 925.86, 926.31, 926.76,
                            927.21, 927.66, 928.11, 928.57, 929.02, 929.47, 929.92,
                            930.37, 930.82, 931.27, 931.72, 932.18, 932.63, 933.08,
                            933.53, 933.98, 934.43, 934.88]),
              T=np.array([[0.00350, 0.00321, 0.00393, 0.00355, 0.00341, 0.00344, 0.00325,
                           0.00285, 0.00311, 0.00319, 0.00349, 0.00300, 0.00306, 0.00302,
                           0.00263, 0.00220, 0.00264, 0.00272, 0.00305, 0.00250, 0.00237,
                           0.00249, 0.00286, 0.00257, 0.00265, 0.00256, 0.00310, 0.00805],
                          [0.00388, 0.00376, 0.00442, 0.00425, 0.00382, 0.00385, 0.00371,
                           0.00344, 0.00337, 0.00377, 0.00388, 0.00318, 0.00350, 0.00349,
                           0.00310, 0.00250, 0.00321, 0.00321, 0.00337, 0.00280, 0.00285,
                           0.00297, 0.00294, 0.00291, 0.00307, 0.00297, 0.00358, 0.00923],
                          [0.00445, 0.00459, 0.00484, 0.00487, 0.00444, 0.00443, 0.00436,
                           0.00439, 0.00389, 0.00450, 0.00429, 0.00372, 0.00387, 0.00400,
                           0.00360, 0.00333, 0.00392, 0.00374, 0.00352, 0.00308, 0.00330,
                           0.00352, 0.00310, 0.00336, 0.00350, 0.00336, 0.00397, 0.01069],
                          [0.00528, 0.00550, 0.00547, 0.00539, 0.00528, 0.00523, 0.00525,
                           0.00554, 0.00482, 0.00514, 0.00475, 0.00459, 0.00422, 0.00442,
                           0.00412, 0.00428, 0.00445, 0.00399, 0.00379, 0.00345, 0.00383,
                           0.00392, 0.00352, 0.00383, 0.00413, 0.00390, 0.00443, 0.01240],
                          [0.00621, 0.00641, 0.00638, 0.00610, 0.00629, 0.00616, 0.00629,
                           0.00656, 0.00589, 0.00571, 0.00530, 0.00556, 0.00482, 0.00491,
                           0.00491, 0.00506, 0.00476, 0.00421, 0.00427, 0.00410, 0.00443,
                           0.00434, 0.00425, 0.00429, 0.00496, 0.00470, 0.00514, 0.01434],
                          [0.00725, 0.00746, 0.00753, 0.00730, 0.00748, 0.00713, 0.00742,
                           0.00735, 0.00688, 0.00651, 0.00611, 0.00644, 0.00578, 0.00581,
                           0.00605, 0.00581, 0.00513, 0.00488, 0.00498, 0.00515, 0.00517,
                           0.00503, 0.00510, 0.00499, 0.00576, 0.00564, 0.00610, 0.01663],
                          [0.00881, 0.00892, 0.00890, 0.00897, 0.00909, 0.00847, 0.00867,
                           0.00822, 0.00805, 0.00776, 0.00742, 0.00744, 0.00700, 0.00697,
                           0.00743, 0.00669, 0.00590, 0.00610, 0.00604, 0.00638, 0.00624,
                           0.00600, 0.00593, 0.00606, 0.00646, 0.00662, 0.00727, 0.01966],
                          [0.01119, 0.01105, 0.01081, 0.01092, 0.01119, 0.01046, 0.01030,
                           0.00963, 0.00972, 0.00940, 0.00937, 0.00889, 0.00842, 0.00808,
                           0.00889, 0.00782, 0.00729, 0.00761, 0.00741, 0.00749, 0.00747,
                           0.00718, 0.00696, 0.00727, 0.00741, 0.00785, 0.00880, 0.02361],
                          [0.01428, 0.01401, 0.01367, 0.01348, 0.01362, 0.01318, 0.01282,
                           0.01200, 0.01213, 0.01144, 0.01174, 0.01088, 0.01019, 0.00953,
                           0.01020, 0.00941, 0.00913, 0.00924, 0.00898, 0.00860, 0.00863,
                           0.00853, 0.00842, 0.00869, 0.00892, 0.00957, 0.01090, 0.02850],
                          [0.01827, 0.01808, 0.01776, 0.01729, 0.01685, 0.01680, 0.01649,
                           0.01560, 0.01541, 0.01441, 0.01429, 0.01342, 0.01263, 0.01179,
                           0.01165, 0.01155, 0.01125, 0.01109, 0.01078, 0.01017, 0.01012,
                           0.01022, 0.01039, 0.01058, 0.01090, 0.01171, 0.01372, 0.03470],
                          [0.02413, 0.02392, 0.02363, 0.02310, 0.02210, 0.02193, 0.02148,
                           0.02060, 0.01983, 0.01889, 0.01764, 0.01678, 0.01621, 0.01506,
                           0.01425, 0.01414, 0.01389, 0.01348, 0.01308, 0.01252, 0.01261,
                           0.01254, 0.01289, 0.01300, 0.01345, 0.01437, 0.01747, 0.04288],
                          [0.03297, 0.03263, 0.03231, 0.03175, 0.03052, 0.02976, 0.02856,
                           0.02747, 0.02624, 0.02529, 0.02318, 0.02180, 0.02123, 0.01967,
                           0.01880, 0.01763, 0.01754, 0.01683, 0.01633, 0.01588, 0.01610,
                           0.01567, 0.01610, 0.01617, 0.01713, 0.01833, 0.02270, 0.05356],
                          [0.04594, 0.04550, 0.04519, 0.04448, 0.04306, 0.04158, 0.03933,
                           0.03768, 0.03592, 0.03439, 0.03197, 0.02972, 0.02829, 0.02644,
                           0.02538, 0.02312, 0.02278, 0.02166, 0.02107, 0.02068, 0.02049,
                           0.01997, 0.02051, 0.02063, 0.02248, 0.02450, 0.03024, 0.06723],
                          [0.06465, 0.06412, 0.06379, 0.06268, 0.06081, 0.05858, 0.05559,
                           0.05312, 0.05029, 0.04760, 0.04464, 0.04155, 0.03872, 0.03644,
                           0.03452, 0.03174, 0.03055, 0.02883, 0.02791, 0.02756, 0.02664,
                           0.02623, 0.02689, 0.02733, 0.03003, 0.03349, 0.04129, 0.08460],
                          [0.09049, 0.09004, 0.08937, 0.08762, 0.08506, 0.08211, 0.07864,
                           0.07506, 0.07088, 0.06661, 0.06239, 0.05834, 0.05432, 0.05092,
                           0.04764, 0.04444, 0.04210, 0.03959, 0.03796, 0.03745, 0.03601,
                           0.03558, 0.03634, 0.03748, 0.04087, 0.04623, 0.05715, 0.10665],
                          [0.12429, 0.12396, 0.12276, 0.12036, 0.11710, 0.11342, 0.10908,
                           0.10426, 0.09892, 0.09293, 0.08697, 0.08169, 0.07653, 0.07135,
                           0.06658, 0.06252, 0.05881, 0.05558, 0.05279, 0.05172, 0.05003,
                           0.04940, 0.05033, 0.05236, 0.05667, 0.06423, 0.07909, 0.13447],
                          [0.16618, 0.16554, 0.16406, 0.16108, 0.15735, 0.15271, 0.14702,
                           0.14106, 0.13470, 0.12725, 0.11957, 0.11266, 0.10606, 0.09908,
                           0.09277, 0.08733, 0.08203, 0.07810, 0.07388, 0.07172, 0.06987,
                           0.06926, 0.07028, 0.07318, 0.07900, 0.08884, 0.10806, 0.16872],
                          [0.21506, 0.21381, 0.21218, 0.20890, 0.20474, 0.19908, 0.19212,
                           0.18510, 0.17751, 0.16896, 0.15995, 0.15119, 0.14304, 0.13464,
                           0.12666, 0.11953, 0.11276, 0.10760, 0.10217, 0.09864, 0.09656,
                           0.09621, 0.09713, 0.10099, 0.10866, 0.12066, 0.14422, 0.20879],
                          [0.26882, 0.26740, 0.26551, 0.26219, 0.25741, 0.25108, 0.24350,
                           0.23545, 0.22632, 0.21681, 0.20700, 0.19653, 0.18701, 0.17740,
                           0.16760, 0.15895, 0.15092, 0.14414, 0.13795, 0.13326, 0.13081,
                           0.13045, 0.13131, 0.13608, 0.14554, 0.15968, 0.18669, 0.25350],
                          [0.32612, 0.32504, 0.32323, 0.31955, 0.31423, 0.30753, 0.29990,
                           0.29080, 0.28022, 0.26980, 0.25947, 0.24772, 0.23704, 0.22604,
                           0.21476, 0.20514, 0.19564, 0.18758, 0.18083, 0.17552, 0.17241,
                           0.17162, 0.17274, 0.17800, 0.18886, 0.20530, 0.23438, 0.30269],
                          [0.38729, 0.38642, 0.38490, 0.38043, 0.37499, 0.36800, 0.36012,
                           0.34995, 0.33840, 0.32713, 0.31636, 0.30374, 0.29183, 0.27937,
                           0.26739, 0.25709, 0.24608, 0.23712, 0.22969, 0.22414, 0.22023,
                           0.21894, 0.22057, 0.22587, 0.23745, 0.25616, 0.28646, 0.35663],
                          [0.45318, 0.45197, 0.45038, 0.44532, 0.43986, 0.43251, 0.42369,
                           0.41282, 0.40052, 0.38854, 0.37708, 0.36379, 0.35044, 0.33673,
                           0.32459, 0.31323, 0.30150, 0.29153, 0.28316, 0.27738, 0.27291,
                           0.27120, 0.27333, 0.27865, 0.29044, 0.31099, 0.34275, 0.41498],
                          [0.52406, 0.52236, 0.52023, 0.51520, 0.50941, 0.50129, 0.49137,
                           0.48014, 0.46712, 0.45449, 0.44170, 0.42763, 0.41311, 0.39844,
                           0.38565, 0.37290, 0.36123, 0.35002, 0.34082, 0.33443, 0.32965,
                           0.32760, 0.32982, 0.33558, 0.34776, 0.36952, 0.40351, 0.47737],
                          [0.59915, 0.59742, 0.59464, 0.58992, 0.58376, 0.57451, 0.56406,
                           0.55209, 0.53866, 0.52514, 0.51058, 0.49567, 0.48036, 0.46506,
                           0.45065, 0.43672, 0.42468, 0.41239, 0.40271, 0.39540, 0.39022,
                           0.38792, 0.38989, 0.39659, 0.40959, 0.43196, 0.46865, 0.54384],
                          [0.67617, 0.67485, 0.67171, 0.66706, 0.66083, 0.65087, 0.64056,
                           0.62768, 0.61442, 0.59956, 0.58355, 0.56801, 0.55205, 0.53617,
                           0.52005, 0.50533, 0.49173, 0.47886, 0.46856, 0.46048, 0.45475,
                           0.45240, 0.45401, 0.46185, 0.47567, 0.49856, 0.53735, 0.61378],
                          [0.75115, 0.75017, 0.74697, 0.74278, 0.73657, 0.72684, 0.71706,
                           0.70431, 0.69169, 0.67573, 0.65932, 0.64369, 0.62721, 0.61059,
                           0.59372, 0.57841, 0.56287, 0.54985, 0.53843, 0.52986, 0.52371,
                           0.52138, 0.52274, 0.53111, 0.54567, 0.56938, 0.60888, 0.68460],
                          [0.81880, 0.81776, 0.81477, 0.81173, 0.80583, 0.79714, 0.78827,
                           0.77709, 0.76551, 0.74999, 0.73446, 0.71981, 0.70319, 0.68633,
                           0.66974, 0.65407, 0.63767, 0.62458, 0.61226, 0.60333, 0.59687,
                           0.59443, 0.59576, 0.60376, 0.61875, 0.64302, 0.68169, 0.75191],
                          [0.87359, 0.87259, 0.87000, 0.86779, 0.86319, 0.85636, 0.84864,
                           0.84013, 0.82986, 0.81686, 0.80357, 0.79063, 0.77530, 0.75968,
                           0.74395, 0.72863, 0.71305, 0.69993, 0.68764, 0.67870, 0.67201,
                           0.66937, 0.67085, 0.67796, 0.69247, 0.71592, 0.75186, 0.81118],
                          [0.91215, 0.91156, 0.90945, 0.90745, 0.90474, 0.90061, 0.89431,
                           0.88866, 0.88018, 0.87111, 0.86104, 0.84985, 0.83799, 0.82491,
                           0.81108, 0.79722, 0.78375, 0.77116, 0.75990, 0.75158, 0.74497,
                           0.74190, 0.74360, 0.74956, 0.76260, 0.78305, 0.81400, 0.85877],
                          [0.93505, 0.93476, 0.93348, 0.93176, 0.93053, 0.92889, 0.92440,
                           0.92097, 0.91487, 0.90996, 0.90286, 0.89410, 0.88653, 0.87661,
                           0.86618, 0.85481, 0.84424, 0.83316, 0.82394, 0.81659, 0.81056,
                           0.80706, 0.80857, 0.81317, 0.82405, 0.83962, 0.86356, 0.89268],
                          [0.94627, 0.94590, 0.94586, 0.94465, 0.94424, 0.94381, 0.94111,
                           0.93926, 0.93575, 0.93388, 0.92880, 0.92339, 0.91886, 0.91234,
                           0.90611, 0.89783, 0.89043, 0.88177, 0.87510, 0.86898, 0.86381,
                           0.86077, 0.86128, 0.86442, 0.87262, 0.88263, 0.89863, 0.91403],
                          [0.95046, 0.95024, 0.95080, 0.95011, 0.95005, 0.94980, 0.94838,
                           0.94756, 0.94649, 0.94569, 0.94220, 0.93997, 0.93711, 0.93327,
                           0.93046, 0.92529, 0.92090, 0.91505, 0.91049, 0.90621, 0.90192,
                           0.90004, 0.89959, 0.90110, 0.90631, 0.91173, 0.92046, 0.92634],
                          [0.95130, 0.95195, 0.95202, 0.95145, 0.95161, 0.95130, 0.95079,
                           0.95023, 0.95077, 0.94971, 0.94795, 0.94770, 0.94620, 0.94379,
                           0.94252, 0.93973, 0.93784, 0.93461, 0.93126, 0.92923, 0.92589,
                           0.92453, 0.92414, 0.92413, 0.92648, 0.92942, 0.93279, 0.93330],
                          [0.95136, 0.95250, 0.95214, 0.95119, 0.95187, 0.95128, 0.95157,
                           0.95109, 0.95179, 0.95032, 0.95017, 0.95053, 0.95011, 0.94863,
                           0.94760, 0.94606, 0.94573, 0.94435, 0.94180, 0.94120, 0.93907,
                           0.93747, 0.93760, 0.93691, 0.93727, 0.93931, 0.94003, 0.93728],
                          [0.95215, 0.95251, 0.95227, 0.95132, 0.95263, 0.95162, 0.95225,
                           0.95233, 0.95236, 0.95093, 0.95164, 0.95191, 0.95168, 0.95107,
                           0.95000, 0.94900, 0.94900, 0.94846, 0.94711, 0.94664, 0.94544,
                           0.94414, 0.94425, 0.94382, 0.94340, 0.94489, 0.94539, 0.94013],
                          [0.95328, 0.95261, 0.95254, 0.95271, 0.95397, 0.95302, 0.95321,
                           0.95377, 0.95352, 0.95240, 0.95330, 0.95352, 0.95278, 0.95260,
                           0.95200, 0.95129, 0.95085, 0.95048, 0.95058, 0.94964, 0.94864,
                           0.94829, 0.94803, 0.94813, 0.94776, 0.94863, 0.94959, 0.94244],
                          [0.95407, 0.95326, 0.95334, 0.95486, 0.95522, 0.95496, 0.95458,
                           0.95481, 0.95528, 0.95437, 0.95510, 0.95532, 0.95459, 0.95440,
                           0.95471, 0.95422, 0.95349, 0.95320, 0.95390, 0.95283, 0.95176,
                           0.95193, 0.95155, 0.95188, 0.95163, 0.95221, 0.95298, 0.94403],
                          [0.95383, 0.95361, 0.95367, 0.95531, 0.95495, 0.95534, 0.95525,
                           0.95500, 0.95633, 0.95598, 0.95628, 0.95644, 0.95679, 0.95641,
                           0.95737, 0.95714, 0.95681, 0.95654, 0.95661, 0.95675, 0.95558,
                           0.95550, 0.95519, 0.95550, 0.95478, 0.95574, 0.95603, 0.94432],
                          [0.95163, 0.95205, 0.95187, 0.95221, 0.95225, 0.95277, 0.95362,
                           0.95355, 0.95517, 0.95593, 0.95600, 0.95632, 0.95788, 0.95736,
                           0.95848, 0.95877, 0.95918, 0.95879, 0.95819, 0.95978, 0.95885,
                           0.95820, 0.95805, 0.95821, 0.95682, 0.95833, 0.95832, 0.94244],
                          [0.94628, 0.94699, 0.94683, 0.94606, 0.94706, 0.94743, 0.94914,
                           0.94987, 0.95125, 0.95313, 0.95375, 0.95470, 0.95656, 0.95630,
                           0.95751, 0.95863, 0.95954, 0.95917, 0.95888, 0.96036, 0.96025,
                           0.95921, 0.95937, 0.95935, 0.95796, 0.95928, 0.95864, 0.93756],
                          [0.93745, 0.93781, 0.93798, 0.93767, 0.93933, 0.93987, 0.94190,
                           0.94370, 0.94498, 0.94759, 0.94944, 0.95134, 0.95261, 0.95342,
                           0.95504, 0.95701, 0.95798, 0.95796, 0.95872, 0.95920, 0.95977,
                           0.95872, 0.95914, 0.95923, 0.95814, 0.95840, 0.95644, 0.93015],
                          [0.92439, 0.92419, 0.92476, 0.92551, 0.92756, 0.92891, 0.93106,
                           0.93370, 0.93547, 0.93885, 0.94191, 0.94492, 0.94599, 0.94813,
                           0.95061, 0.95301, 0.95416, 0.95474, 0.95652, 0.95672, 0.95762,
                           0.95661, 0.95722, 0.95733, 0.95616, 0.95501, 0.95167, 0.92051],
                          [0.90546, 0.90528, 0.90631, 0.90773, 0.90985, 0.91245, 0.91496,
                           0.91836, 0.92104, 0.92553, 0.92953, 0.93359, 0.93615, 0.93915,
                           0.94259, 0.94508, 0.94751, 0.94878, 0.95116, 0.95185, 0.95294,
                           0.95222, 0.95265, 0.95242, 0.95095, 0.94863, 0.94372, 0.90759],
                          [0.88000, 0.88010, 0.88175, 0.88371, 0.88546, 0.88955, 0.89267,
                           0.89671, 0.90099, 0.90654, 0.91157, 0.91661, 0.92159, 0.92535,
                           0.92956, 0.93273, 0.93690, 0.93920, 0.94205, 0.94318, 0.94442,
                           0.94472, 0.94433, 0.94396, 0.94229, 0.93888, 0.93143, 0.89022],
                          [0.84849, 0.84857, 0.85068, 0.85341, 0.85516, 0.86030, 0.86414,
                           0.86863, 0.87523, 0.88165, 0.88778, 0.89431, 0.90086, 0.90609,
                           0.91116, 0.91608, 0.92142, 0.92497, 0.92865, 0.93005, 0.93158,
                           0.93317, 0.93211, 0.93183, 0.92998, 0.92503, 0.91415, 0.86806],
                          [0.81134, 0.81130, 0.81337, 0.81686, 0.81973, 0.82510, 0.82946,
                           0.83498, 0.84336, 0.85083, 0.85820, 0.86656, 0.87385, 0.88113,
                           0.88762, 0.89431, 0.90060, 0.90543, 0.91008, 0.91219, 0.91429,
                           0.91664, 0.91604, 0.91547, 0.91299, 0.90630, 0.89162, 0.84123],
                          [0.76859, 0.76863, 0.77055, 0.77430, 0.77897, 0.78433, 0.78908,
                           0.79617, 0.80518, 0.81401, 0.82296, 0.83278, 0.84107, 0.84999,
                           0.85839, 0.86613, 0.87379, 0.88018, 0.88541, 0.88905, 0.89199,
                           0.89448, 0.89516, 0.89407, 0.89022, 0.88184, 0.86380, 0.80951],
                          [0.72032, 0.72090, 0.72301, 0.72678, 0.73272, 0.73812, 0.74364,
                           0.75207, 0.76144, 0.77178, 0.78223, 0.79327, 0.80273, 0.81280,
                           0.82280, 0.83162, 0.84088, 0.84888, 0.85478, 0.86019, 0.86403,
                           0.86671, 0.86832, 0.86694, 0.86155, 0.85157, 0.83105, 0.77267],
                          [0.66705, 0.66824, 0.67069, 0.67483, 0.68139, 0.68673, 0.69308,
                           0.70295, 0.71303, 0.72486, 0.73632, 0.74869, 0.75928, 0.77055,
                           0.78169, 0.79202, 0.80245, 0.81187, 0.81884, 0.82569, 0.83031,
                           0.83363, 0.83538, 0.83388, 0.82762, 0.81605, 0.79336, 0.73090],
                          [0.60904, 0.61037, 0.61303, 0.61777, 0.62517, 0.63042, 0.63736,
                           0.64859, 0.65977, 0.67286, 0.68544, 0.69878, 0.71097, 0.72352,
                           0.73585, 0.74784, 0.75882, 0.76980, 0.77776, 0.78548, 0.79107,
                           0.79530, 0.79686, 0.79537, 0.78850, 0.77531, 0.75006, 0.68425],
                          [0.54602, 0.54736, 0.55006, 0.55543, 0.56347, 0.56914, 0.57704,
                           0.58862, 0.60123, 0.61533, 0.62946, 0.64335, 0.65728, 0.67137,
                           0.68494, 0.69836, 0.71022, 0.72265, 0.73163, 0.73971, 0.74637,
                           0.75152, 0.75314, 0.75147, 0.74384, 0.72899, 0.70096, 0.63246],
                          [0.47832, 0.47965, 0.48261, 0.48843, 0.49617, 0.50313, 0.51252,
                           0.52396, 0.53787, 0.55269, 0.56824, 0.58311, 0.59851, 0.61413,
                           0.62899, 0.64337, 0.65692, 0.67049, 0.68064, 0.68917, 0.69642,
                           0.70244, 0.70412, 0.70203, 0.69410, 0.67739, 0.64700, 0.57585],
                          [0.40737, 0.40841, 0.41196, 0.41773, 0.42472, 0.43340, 0.44374,
                           0.45570, 0.47031, 0.48561, 0.50210, 0.51852, 0.53547, 0.55180,
                           0.56817, 0.58368, 0.59871, 0.61322, 0.62453, 0.63399, 0.64161,
                           0.64822, 0.64970, 0.64733, 0.63942, 0.62102, 0.58885, 0.51528],
                          [0.33587, 0.33674, 0.34050, 0.34586, 0.35236, 0.36222, 0.37229,
                           0.38500, 0.39979, 0.41561, 0.43272, 0.45022, 0.46837, 0.48487,
                           0.50278, 0.51984, 0.53564, 0.55083, 0.56357, 0.57405, 0.58251,
                           0.58931, 0.59071, 0.58813, 0.57980, 0.56050, 0.52668, 0.45160],
                          [0.26782, 0.26856, 0.27168, 0.27690, 0.28313, 0.29271, 0.30200,
                           0.31470, 0.32917, 0.34505, 0.36236, 0.37991, 0.39801, 0.41516,
                           0.43379, 0.45215, 0.46861, 0.48423, 0.49863, 0.50990, 0.51951,
                           0.52627, 0.52804, 0.52499, 0.51581, 0.49608, 0.46102, 0.38647],
                          [0.20718, 0.20742, 0.20967, 0.21480, 0.22076, 0.22864, 0.23732,
                           0.24908, 0.26239, 0.27713, 0.29379, 0.31057, 0.32747, 0.34528,
                           0.36347, 0.38228, 0.39937, 0.41505, 0.43078, 0.44269, 0.45297,
                           0.45959, 0.46206, 0.45878, 0.44857, 0.42865, 0.39356, 0.32265],
                          [0.15622, 0.15619, 0.15799, 0.16230, 0.16778, 0.17360, 0.18154,
                           0.19182, 0.20310, 0.21578, 0.23061, 0.24572, 0.26107, 0.27838,
                           0.29524, 0.31348, 0.33043, 0.34599, 0.36181, 0.37396, 0.38408,
                           0.39068, 0.39378, 0.39100, 0.37995, 0.36069, 0.32708, 0.26293],
                          [0.11582, 0.11614, 0.11760, 0.12041, 0.12501, 0.12955, 0.13612,
                           0.14463, 0.15356, 0.16401, 0.17606, 0.18866, 0.20222, 0.21777,
                           0.23278, 0.24934, 0.26504, 0.28009, 0.29476, 0.30644, 0.31594,
                           0.32269, 0.32587, 0.32394, 0.31319, 0.29536, 0.26461, 0.20912],
                          [0.08557, 0.08631, 0.08720, 0.08884, 0.09207, 0.09618, 0.10086,
                           0.10742, 0.11452, 0.12257, 0.13167, 0.14153, 0.15305, 0.16589,
                           0.17893, 0.19295, 0.20638, 0.22007, 0.23303, 0.24363, 0.25246,
                           0.25905, 0.26176, 0.26057, 0.25158, 0.23533, 0.20874, 0.16241],
                          [0.06387, 0.06460, 0.06503, 0.06616, 0.06817, 0.07173, 0.07470,
                           0.07937, 0.08528, 0.09092, 0.09765, 0.10500, 0.11453, 0.12410,
                           0.13522, 0.14631, 0.15697, 0.16843, 0.17935, 0.18862, 0.19676,
                           0.20249, 0.20465, 0.20400, 0.19711, 0.18281, 0.16135, 0.12402],
                          [0.04848, 0.04907, 0.04940, 0.05010, 0.05166, 0.05411, 0.05599,
                           0.05924, 0.06388, 0.06788, 0.07282, 0.07820, 0.08582, 0.09251,
                           0.10142, 0.10970, 0.11781, 0.12657, 0.13544, 0.14322, 0.15044,
                           0.15476, 0.15670, 0.15632, 0.15086, 0.13947, 0.12309, 0.09434],
                          [0.03761, 0.03794, 0.03840, 0.03874, 0.04025, 0.04154, 0.04289,
                           0.04526, 0.04848, 0.05136, 0.05506, 0.05916, 0.06465, 0.06976,
                           0.07595, 0.08195, 0.08827, 0.09438, 0.10157, 0.10790, 0.11372,
                           0.11668, 0.11849, 0.11811, 0.11377, 0.10588, 0.09347, 0.07229],
                          [0.02994, 0.02975, 0.03040, 0.03058, 0.03198, 0.03259, 0.03379,
                           0.03548, 0.03770, 0.03948, 0.04237, 0.04570, 0.04916, 0.05348,
                           0.05731, 0.06167, 0.06672, 0.07085, 0.07653, 0.08160, 0.08568,
                           0.08802, 0.08942, 0.08912, 0.08585, 0.08092, 0.07135, 0.05592],
                          [0.02405, 0.02367, 0.02447, 0.02451, 0.02556, 0.02627, 0.02735,
                           0.02840, 0.03014, 0.03130, 0.03328, 0.03604, 0.03830, 0.04150,
                           0.04428, 0.04740, 0.05112, 0.05430, 0.05844, 0.06229, 0.06487,
                           0.06715, 0.06820, 0.06802, 0.06563, 0.06240, 0.05509, 0.04350],
                          [0.01953, 0.01933, 0.02014, 0.02023, 0.02069, 0.02183, 0.02246,
                           0.02304, 0.02468, 0.02571, 0.02683, 0.02920, 0.03075, 0.03257,
                           0.03518, 0.03736, 0.03991, 0.04283, 0.04565, 0.04808, 0.04997,
                           0.05197, 0.05300, 0.05279, 0.05126, 0.04851, 0.04335, 0.03423],
                          [0.01630, 0.01640, 0.01681, 0.01731, 0.01722, 0.01852, 0.01858,
                           0.01904, 0.02053, 0.02140, 0.02209, 0.02428, 0.02502, 0.02612,
                           0.02841, 0.03013, 0.03189, 0.03456, 0.03660, 0.03765, 0.03963,
                           0.04091, 0.04181, 0.04168, 0.04093, 0.03808, 0.03495, 0.02738],
                          [0.01398, 0.01443, 0.01399, 0.01501, 0.01475, 0.01572, 0.01574,
                           0.01615, 0.01717, 0.01773, 0.01839, 0.02035, 0.02058, 0.02182,
                           0.02337, 0.02496, 0.02607, 0.02823, 0.02982, 0.03019, 0.03242,
                           0.03299, 0.03344, 0.03346, 0.03301, 0.03051, 0.02856, 0.02244],
                          ])),
    N1010=dict(radius=np.array([0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0,
                                90.0, 100.0, 110.0, 120.0, 130.0, 140.0, 150.0, 160.0,
                                170.0, 180.0, 190.0, 200.0, 210.0, 220.0, 230.0, 240.0,
                                250.0, 260.0, 270.0]),
               lam=np.array([995.27, 995.72, 996.17, 996.63, 997.08, 997.54, 997.99,
                             998.44, 998.90, 999.35, 999.80, 1000.26, 1000.71, 1001.17,
                             1001.62, 1002.07, 1002.53, 1002.98, 1003.44, 1003.89,
                             1004.34, 1004.80, 1005.25, 1005.70, 1006.16, 1006.61,
                             1007.07, 1007.52, 1007.97, 1008.43, 1008.88, 1009.34,
                             1009.79, 1010.24, 1010.70, 1011.15, 1011.61, 1012.06,
                             1012.51, 1012.97, 1013.42, 1013.88, 1014.33, 1014.79,
                             1015.24, 1015.69, 1016.15, 1016.60, 1017.06, 1017.51,
                             1017.96, 1018.42, 1018.87, 1019.33, 1019.78]),
               T=np.array([[0.00326, 0.00352, 0.00659, 0.00477, 0.00357, 0.00482,
                            0.00332, 0.00342, 0.00411, 0.00044, 0.00337, 0.00513,
                            0.00431, 0.00428, 0.00342, 0.00350, 0.00353, 0.00386,
                            0.00263, 0.00346, 0.00393, 0.00362, 0.00361, 0.00395,
                            0.00328, 0.00303, 0.00412, 0.00412],
                           [0.00401, 0.00423, 0.00698, 0.00490, 0.00386, 0.00450,
                            0.00324, 0.00320, 0.00422, 0.00098, 0.00542, 0.00522,
                            0.00500, 0.00445, 0.00336, 0.00397, 0.00473, 0.00448,
                            0.00339, 0.00390, 0.00494, 0.00398, 0.00480, 0.00420,
                            0.00321, 0.00312, 0.00604, 0.00604],
                           [0.00515, 0.00503, 0.00632, 0.00524, 0.00325, 0.00413,
                            0.00457, 0.00321, 0.00477, 0.00213, 0.00682, 0.00511,
                            0.00635, 0.00453, 0.00417, 0.00490, 0.00540, 0.00417,
                            0.00419, 0.00432, 0.00579, 0.00489, 0.00526, 0.00481,
                            0.00379, 0.00451, 0.00837, 0.00837],
                           [0.00621, 0.00576, 0.00526, 0.00557, 0.00325, 0.00431,
                            0.00699, 0.00500, 0.00522, 0.00408, 0.00676, 0.00539,
                            0.00812, 0.00507, 0.00543, 0.00580, 0.00581, 0.00362,
                            0.00498, 0.00505, 0.00659, 0.00604, 0.00483, 0.00605,
                            0.00472, 0.00588, 0.01033, 0.01033],
                           [0.00674, 0.00680, 0.00482, 0.00566, 0.00450, 0.00513,
                            0.00875, 0.00696, 0.00507, 0.00627, 0.00622, 0.00574,
                            0.00955, 0.00590, 0.00653, 0.00639, 0.00658, 0.00398,
                            0.00588, 0.00600, 0.00710, 0.00659, 0.00443, 0.00726,
                            0.00580, 0.00714, 0.01158, 0.01158],
                           [0.00684, 0.00794, 0.00566, 0.00610, 0.00589, 0.00651,
                            0.00908, 0.00743, 0.00478, 0.00764, 0.00647, 0.00638,
                            0.01004, 0.00675, 0.00708, 0.00685, 0.00731, 0.00550,
                            0.00660, 0.00686, 0.00698, 0.00616, 0.00533, 0.00802,
                            0.00750, 0.00935, 0.01295, 0.01295],
                           [0.00756, 0.00892, 0.00723, 0.00740, 0.00724, 0.00767,
                            0.00929, 0.00787, 0.00517, 0.00788, 0.00757, 0.00774,
                            0.00964, 0.00764, 0.00767, 0.00735, 0.00756, 0.00705,
                            0.00717, 0.00760, 0.00647, 0.00555, 0.00792, 0.00909,
                            0.01019, 0.01238, 0.01604, 0.01604],
                           [0.00938, 0.01021, 0.00898, 0.00913, 0.00936, 0.00853,
                            0.01038, 0.00892, 0.00672, 0.00775, 0.00881, 0.00923,
                            0.00917, 0.00853, 0.00922, 0.00811, 0.00809, 0.00772,
                            0.00838, 0.00876, 0.00646, 0.00622, 0.01094, 0.01118,
                            0.01346, 0.01606, 0.02193, 0.02193],
                           [0.01154, 0.01235, 0.01106, 0.01067, 0.01221, 0.01030,
                            0.01186, 0.00979, 0.00877, 0.00811, 0.01015, 0.01019,
                            0.00951, 0.00953, 0.01135, 0.00978, 0.01004, 0.00819,
                            0.01061, 0.01075, 0.00826, 0.00873, 0.01302, 0.01390,
                            0.01682, 0.02174, 0.03064, 0.03064],
                           [0.01398, 0.01533, 0.01357, 0.01256, 0.01542, 0.01326,
                            0.01346, 0.01131, 0.01095, 0.00978, 0.01206, 0.01123,
                            0.01150, 0.01098, 0.01341, 0.01232, 0.01295, 0.00949,
                            0.01350, 0.01316, 0.01226, 0.01233, 0.01520, 0.01736,
                            0.02135, 0.03025, 0.04159, 0.04159],
                           [0.01798, 0.01927, 0.01660, 0.01628, 0.01938, 0.01676,
                            0.01627, 0.01472, 0.01462, 0.01341, 0.01512, 0.01402,
                            0.01567, 0.01380, 0.01600, 0.01531, 0.01563, 0.01201,
                            0.01697, 0.01569, 0.01757, 0.01678, 0.02017, 0.02281,
                            0.02847, 0.04055, 0.05517, 0.05517],
                           [0.02433, 0.02508, 0.02157, 0.02269, 0.02480, 0.02149,
                            0.02173, 0.02036, 0.02094, 0.01911, 0.02025, 0.01970,
                            0.02171, 0.01897, 0.01995, 0.01935, 0.01877, 0.01640,
                            0.02123, 0.01957, 0.02351, 0.02385, 0.02909, 0.03135,
                            0.03864, 0.05279, 0.07298, 0.07298],
                           [0.03420, 0.03437, 0.03126, 0.03215, 0.03306, 0.02953,
                            0.03095, 0.02922, 0.03017, 0.02702, 0.02803, 0.02838,
                            0.02965, 0.02677, 0.02594, 0.02577, 0.02466, 0.02373,
                            0.02736, 0.02704, 0.03106, 0.03505, 0.04062, 0.04372,
                            0.05241, 0.06910, 0.09583, 0.09583],
                           [0.04960, 0.04871, 0.04720, 0.04597, 0.04592, 0.04238,
                            0.04442, 0.04261, 0.04280, 0.03813, 0.03901, 0.04050,
                            0.04058, 0.03714, 0.03538, 0.03578, 0.03500, 0.03502,
                            0.03720, 0.03935, 0.04222, 0.04987, 0.05401, 0.06057,
                            0.07048, 0.09074, 0.12292, 0.12292],
                           [0.07059, 0.06861, 0.06842, 0.06570, 0.06457, 0.06075,
                            0.06241, 0.06105, 0.05965, 0.05430, 0.05466, 0.05682,
                            0.05565, 0.05100, 0.04993, 0.05080, 0.05040, 0.05106,
                            0.05178, 0.05655, 0.05838, 0.06777, 0.07102, 0.08181,
                            0.09329, 0.11719, 0.15336, 0.15336],
                           [0.09535, 0.09361, 0.09349, 0.09153, 0.08944, 0.08522,
                            0.08561, 0.08431, 0.08182, 0.07680, 0.07624, 0.07756,
                            0.07567, 0.07011, 0.07037, 0.07176, 0.07086, 0.07178,
                            0.07143, 0.07869, 0.07995, 0.08919, 0.09327, 0.10680,
                            0.12113, 0.14776, 0.18773, 0.18773],
                           [0.12305, 0.12367, 0.12237, 0.12206, 0.11973, 0.11568,
                            0.11388, 0.11182, 0.10961, 0.10524, 0.10334, 0.10313,
                            0.10083, 0.09535, 0.09638, 0.09791, 0.09638, 0.09667,
                            0.09629, 0.10562, 0.10689, 0.11449, 0.12050, 0.13545,
                            0.15395, 0.18270, 0.22746, 0.22746],
                           [0.15466, 0.15896, 0.15587, 0.15611, 0.15395, 0.15069,
                            0.14628, 0.14362, 0.14164, 0.13842, 0.13515, 0.13385,
                            0.13063, 0.12664, 0.12720, 0.12801, 0.12684, 0.12613,
                            0.12615, 0.13655, 0.13856, 0.14446, 0.15287, 0.16881,
                            0.19151, 0.22315, 0.27249, 0.27249],
                           [0.19139, 0.19783, 0.19430, 0.19315, 0.19187, 0.18839,
                            0.18279, 0.18005, 0.17683, 0.17526, 0.17125, 0.16885,
                            0.16486, 0.16329, 0.16195, 0.16176, 0.16121, 0.16091,
                            0.16091, 0.17095, 0.17436, 0.17996, 0.19115, 0.20764,
                            0.23369, 0.26933, 0.32117, 0.32117],
                           [0.23370, 0.23827, 0.23709, 0.23264, 0.23365, 0.22830,
                            0.22362, 0.22034, 0.21598, 0.21491, 0.21092, 0.20738,
                            0.20346, 0.20331, 0.20019, 0.19928, 0.19832, 0.20031,
                            0.20083, 0.20908, 0.21415, 0.22035, 0.23437, 0.25156,
                            0.27991, 0.31974, 0.37299, 0.37299],
                           [0.28058, 0.28099, 0.28324, 0.27540, 0.27835, 0.27185,
                            0.26816, 0.26381, 0.25967, 0.25715, 0.25378, 0.24946,
                            0.24554, 0.24498, 0.24203, 0.24049, 0.23857, 0.24256,
                            0.24549, 0.25112, 0.25714, 0.26470, 0.28067, 0.29995,
                            0.32987, 0.37331, 0.42916, 0.42916],
                           [0.33051, 0.32854, 0.33210, 0.32306, 0.32545, 0.32027,
                            0.31637, 0.31123, 0.30706, 0.30257, 0.30048, 0.29519,
                            0.29091, 0.28865, 0.28740, 0.28536, 0.28338, 0.28696,
                            0.29302, 0.29680, 0.30273, 0.31334, 0.33000, 0.35244,
                            0.38398, 0.43023, 0.48946, 0.48946],
                           [0.38391, 0.38246, 0.38414, 0.37630, 0.37626, 0.37348,
                            0.36891, 0.36322, 0.35803, 0.35204, 0.35146, 0.34512,
                            0.34089, 0.33633, 0.33655, 0.33430, 0.33349, 0.33523,
                            0.34234, 0.34601, 0.35173, 0.36678, 0.38379, 0.40873,
                            0.44223, 0.49006, 0.55166, 0.55166],
                           [0.44260, 0.44206, 0.44121, 0.43542, 0.43273, 0.43123,
                            0.42640, 0.41972, 0.41402, 0.40670, 0.40696, 0.40072,
                            0.39634, 0.39041, 0.39074, 0.38818, 0.38862, 0.38927,
                            0.39526, 0.39929, 0.40594, 0.42463, 0.44267, 0.46890,
                            0.50399, 0.55157, 0.61352, 0.61352],
                           [0.50740, 0.50613, 0.50532, 0.50070, 0.49624, 0.49419,
                            0.48977, 0.48153, 0.47700, 0.46810, 0.46793, 0.46259,
                            0.45752, 0.45213, 0.45103, 0.44830, 0.44880, 0.44904,
                            0.45419, 0.45769, 0.46739, 0.48650, 0.50535, 0.53262,
                            0.56823, 0.61336, 0.67259, 0.67259],
                           [0.57748, 0.57475, 0.57634, 0.57149, 0.56662, 0.56376,
                            0.55919, 0.54964, 0.54702, 0.53704, 0.53499, 0.52974,
                            0.52467, 0.52064, 0.51751, 0.51490, 0.51417, 0.51393,
                            0.51945, 0.52216, 0.53573, 0.55235, 0.56987, 0.59797,
                            0.63276, 0.67284, 0.72483, 0.72483],
                           [0.64985, 0.64662, 0.64990, 0.64457, 0.64059, 0.63821,
                            0.63131, 0.62202, 0.62017, 0.61069, 0.60649, 0.60025,
                            0.59602, 0.59265, 0.58849, 0.58506, 0.58315, 0.58352,
                            0.58869, 0.59157, 0.60645, 0.62044, 0.63461, 0.66187,
                            0.69387, 0.72623, 0.76584, 0.76584],
                           [0.71795, 0.71504, 0.71755, 0.71301, 0.71070, 0.70890,
                            0.69957, 0.69214, 0.68919, 0.68169, 0.67710, 0.67059,
                            0.66666, 0.66264, 0.65945, 0.65365, 0.65208, 0.65444,
                            0.65678, 0.66098, 0.67367, 0.68531, 0.69657, 0.72005,
                            0.74626, 0.76928, 0.79220, 0.79220],
                           [0.77367, 0.77113, 0.77144, 0.76946, 0.76805, 0.76591,
                            0.75771, 0.75227, 0.74744, 0.74211, 0.73941, 0.73485,
                            0.73081, 0.72537, 0.72400, 0.71656, 0.71606, 0.71933,
                            0.71809, 0.72308, 0.73239, 0.74068, 0.75126, 0.76754,
                            0.78525, 0.79839, 0.80264, 0.80264],
                           [0.81174, 0.81055, 0.80833, 0.80962, 0.80777, 0.80608,
                            0.80192, 0.79727, 0.79221, 0.78773, 0.78742, 0.78605,
                            0.78296, 0.77722, 0.77586, 0.77023, 0.76928, 0.77103,
                            0.76873, 0.77219, 0.77852, 0.78293, 0.79377, 0.80087,
                            0.80928, 0.81212, 0.79932, 0.79932],
                           [0.83148, 0.83283, 0.82888, 0.83222, 0.83012, 0.83072,
                            0.82988, 0.82527, 0.82232, 0.81820, 0.81885, 0.81921,
                            0.81806, 0.81400, 0.81077, 0.80927, 0.80666, 0.80668,
                            0.80525, 0.80620, 0.80918, 0.81040, 0.81924, 0.81872,
                            0.81792, 0.81091, 0.78526, 0.78526],
                           [0.83621, 0.83917, 0.83592, 0.83941, 0.83753, 0.84075,
                            0.84129, 0.83741, 0.83719, 0.83474, 0.83525, 0.83494,
                            0.83487, 0.83378, 0.82960, 0.83068, 0.82713, 0.82775,
                            0.82635, 0.82588, 0.82450, 0.82347, 0.82748, 0.82172,
                            0.81240, 0.79679, 0.76242, 0.76242],
                           [0.83117, 0.83386, 0.83308, 0.83531, 0.83332, 0.83780,
                            0.83964, 0.83750, 0.83926, 0.83898, 0.83937, 0.83787,
                            0.83775, 0.84024, 0.83725, 0.83831, 0.83375, 0.83683,
                            0.83412, 0.83331, 0.82719, 0.82499, 0.82372, 0.81248,
                            0.79738, 0.77409, 0.73260, 0.73260],
                           [0.81906, 0.82161, 0.82170, 0.82292, 0.82074, 0.82531,
                            0.82858, 0.82914, 0.83134, 0.83253, 0.83262, 0.83169,
                            0.83195, 0.83668, 0.83555, 0.83639, 0.83030, 0.83439,
                            0.83005, 0.82942, 0.81951, 0.81639, 0.81100, 0.79379,
                            0.77610, 0.74615, 0.69724, 0.69724],
                           [0.79970, 0.80394, 0.80147, 0.80394, 0.80233, 0.80674,
                            0.80958, 0.81342, 0.81428, 0.81717, 0.81639, 0.81833,
                            0.81956, 0.82277, 0.82313, 0.82471, 0.81898, 0.82018,
                            0.81573, 0.81380, 0.80288, 0.79761, 0.78916, 0.76833,
                            0.74816, 0.71332, 0.65689, 0.65689],
                           [0.77405, 0.77968, 0.77407, 0.77885, 0.77973, 0.78320,
                            0.78464, 0.78990, 0.78960, 0.79468, 0.79311, 0.79825,
                            0.80047, 0.80028, 0.80141, 0.80362, 0.80017, 0.79743,
                            0.79480, 0.78816, 0.77897, 0.77074, 0.75972, 0.73862,
                            0.71383, 0.67514, 0.61189, 0.61189],
                           [0.74399, 0.74799, 0.74299, 0.74821, 0.75315, 0.75420,
                            0.75604, 0.76006, 0.75999, 0.76684, 0.76490, 0.77105,
                            0.77522, 0.77323, 0.77406, 0.77617, 0.77441, 0.77057,
                            0.76910, 0.75697, 0.74906, 0.73878, 0.72498, 0.70451,
                            0.67473, 0.63108, 0.56230, 0.56230],
                           [0.71002, 0.71053, 0.70975, 0.71364, 0.72132, 0.72071,
                            0.72396, 0.72674, 0.72718, 0.73465, 0.73272, 0.73791,
                            0.74497, 0.74285, 0.74258, 0.74444, 0.74289, 0.73995,
                            0.73798, 0.72299, 0.71439, 0.70313, 0.68577, 0.66396,
                            0.63081, 0.58052, 0.50734, 0.50734],
                           [0.67220, 0.67018, 0.67399, 0.67625, 0.68329, 0.68414,
                            0.68789, 0.69101, 0.69201, 0.69861, 0.69794, 0.70139,
                            0.71044, 0.70870, 0.70740, 0.70952, 0.70719, 0.70404,
                            0.70140, 0.68694, 0.67664, 0.66429, 0.64277, 0.61704,
                            0.58067, 0.52397, 0.44720, 0.44720],
                           [0.63052, 0.62857, 0.63505, 0.63606, 0.64043, 0.64471,
                            0.64823, 0.65254, 0.65423, 0.65974, 0.66155, 0.66282,
                            0.67164, 0.67104, 0.66948, 0.67199, 0.66846, 0.66391,
                            0.66014, 0.64817, 0.63579, 0.62159, 0.59638, 0.56546,
                            0.52369, 0.46233, 0.38372, 0.38372],
                           [0.58590, 0.58592, 0.59219, 0.59342, 0.59563, 0.60300,
                            0.60574, 0.61153, 0.61288, 0.61888, 0.62229, 0.62218,
                            0.62902, 0.62999, 0.62965, 0.63071, 0.62659, 0.62183,
                            0.61561, 0.60473, 0.59040, 0.57364, 0.54587, 0.51049,
                            0.46175, 0.39711, 0.31924, 0.31924],
                           [0.53897, 0.54033, 0.54436, 0.54789, 0.54843, 0.55777,
                            0.55978, 0.56705, 0.56784, 0.57441, 0.57800, 0.57830,
                            0.58316, 0.58426, 0.58678, 0.58422, 0.58024, 0.57717,
                            0.56812, 0.55538, 0.53936, 0.51890, 0.49002, 0.45217,
                            0.39746, 0.33104, 0.25618, 0.25618],
                           [0.48757, 0.48859, 0.49084, 0.49708, 0.49572, 0.50585,
                            0.50913, 0.51717, 0.51888, 0.52416, 0.52794, 0.53003,
                            0.53301, 0.53288, 0.53865, 0.53327, 0.52870, 0.52712,
                            0.51567, 0.50043, 0.48229, 0.45787, 0.42831, 0.38983,
                            0.33165, 0.26733, 0.19807, 0.19807],
                           [0.42851, 0.42870, 0.43062, 0.43824, 0.43651, 0.44588,
                            0.45254, 0.46016, 0.46379, 0.46735, 0.47159, 0.47638,
                            0.47645, 0.47673, 0.48379, 0.47839, 0.47207, 0.46947,
                            0.45673, 0.43980, 0.41969, 0.39350, 0.36211, 0.32353,
                            0.26609, 0.20887, 0.14797, 0.14797],
                           [0.36247, 0.36185, 0.36431, 0.37172, 0.37176, 0.37977,
                            0.38911, 0.39589, 0.40173, 0.40431, 0.40901, 0.41591,
                            0.41385, 0.41685, 0.42200, 0.41822, 0.41167, 0.40502,
                            0.39288, 0.37423, 0.35370, 0.32860, 0.29511, 0.25662,
                            0.20571, 0.15841, 0.10711, 0.10711],
                           [0.29370, 0.29213, 0.29493, 0.30147, 0.30305, 0.31095,
                            0.31990, 0.32704, 0.33471, 0.33664, 0.34247, 0.34837,
                            0.34774, 0.35274, 0.35511, 0.35247, 0.34882, 0.33746,
                            0.32681, 0.30701, 0.28779, 0.26520, 0.23151, 0.19549,
                            0.15489, 0.11717, 0.07579, 0.07579],
                           [0.22653, 0.22477, 0.22652, 0.23255, 0.23419, 0.24318,
                            0.24911, 0.25813, 0.26525, 0.26808, 0.27494, 0.27743,
                            0.28060, 0.28522, 0.28661, 0.28459, 0.28390, 0.27062,
                            0.26084, 0.24262, 0.22518, 0.20557, 0.17473, 0.14515,
                            0.11462, 0.08467, 0.05389, 0.05389],
                           [0.16535, 0.16526, 0.16438, 0.16975, 0.17189, 0.18039,
                            0.18344, 0.19394, 0.19726, 0.20343, 0.20989, 0.21020,
                            0.21513, 0.21898, 0.21980, 0.22002, 0.21964, 0.20770,
                            0.19858, 0.18452, 0.16870, 0.15253, 0.12729, 0.10621,
                            0.08372, 0.06085, 0.04028, 0.04028],
                           [0.11495, 0.11738, 0.11383, 0.11810, 0.12230, 0.12704,
                            0.12955, 0.13870, 0.13819, 0.14681, 0.15217, 0.15285,
                            0.15570, 0.16031, 0.15914, 0.16305, 0.16153, 0.15295,
                            0.14471, 0.13452, 0.12194, 0.10882, 0.09092, 0.07778,
                            0.06074, 0.04525, 0.03244, 0.03244],
                           [0.07853, 0.08177, 0.07700, 0.08158, 0.08651, 0.08689,
                            0.09067, 0.09596, 0.09446, 0.10165, 0.10589, 0.10750,
                            0.10837, 0.11367, 0.11098, 0.11678, 0.11398, 0.10986,
                            0.10214, 0.09454, 0.08705, 0.07602, 0.06610, 0.05867,
                            0.04492, 0.03518, 0.02729, 0.02729],
                           [0.05549, 0.05758, 0.05278, 0.05883, 0.06176, 0.06092,
                            0.06537, 0.06702, 0.06574, 0.07039, 0.07224, 0.07413,
                            0.07596, 0.07975, 0.07797, 0.08244, 0.07919, 0.07837,
                            0.07139, 0.06641, 0.06222, 0.05405, 0.05036, 0.04550,
                            0.03504, 0.02774, 0.02333, 0.02333],
                           [0.04229, 0.04312, 0.03880, 0.04467, 0.04562, 0.04606,
                            0.04944, 0.04994, 0.04842, 0.05203, 0.05043, 0.05235,
                            0.05560, 0.05604, 0.05684, 0.05841, 0.05715, 0.05616,
                            0.05140, 0.04927, 0.04472, 0.04128, 0.03951, 0.03512,
                            0.02888, 0.02211, 0.02068, 0.02068],
                           [0.03529, 0.03432, 0.03146, 0.03544, 0.03628, 0.03768,
                            0.03886, 0.04074, 0.03882, 0.04173, 0.03756, 0.03993,
                            0.04291, 0.03995, 0.04321, 0.04232, 0.04535, 0.04067,
                            0.03965, 0.03908, 0.03380, 0.03387, 0.03100, 0.02705,
                            0.02451, 0.01856, 0.01845, 0.01845],
                           [0.03120, 0.02772, 0.02727, 0.02913, 0.03058, 0.03251,
                            0.03113, 0.03479, 0.03222, 0.03483, 0.02965, 0.03314,
                            0.03477, 0.03039, 0.03487, 0.03242, 0.03914, 0.03000,
                            0.03288, 0.03233, 0.02835, 0.02818, 0.02437, 0.02182,
                            0.02123, 0.01637, 0.01495, 0.01495],
                           [0.02680, 0.02317, 0.02458, 0.02425, 0.02495, 0.02805,
                            0.02519, 0.02902, 0.02594, 0.02933, 0.02473, 0.02836,
                            0.02872, 0.02620, 0.02984, 0.02613, 0.03366, 0.02393,
                            0.02785, 0.02769, 0.02539, 0.02321, 0.01998, 0.01922,
                            0.01882, 0.01423, 0.01073, 0.01073],
                           ])))
